@@ -57,6 +57,7 @@ def get_arguments():
                         action='store_true', default=False);
     parser.add_argument('--no-docs', help='Skip documentation generation',
                         action='store_true', default=False)
+    parser.add_argument('--no-sbom', help='Skip SBOM generation', action='store_true', default=False)
     parser.add_argument('--no-build-date', help='Does not show build date in about dialog, for reproducible builds',
                         action='store_true', default=False)
     parser.add_argument('--no-dmg', help='Skip disk image creation (macOS)',
@@ -69,8 +70,11 @@ def get_arguments():
                         action='store_true', default=False)
     parser.add_argument('--with-cpack', help='Create packages with cpack',
                         action='store_true', default=False)
-    parser.add_argument('--with-sdk-tool', help='Builds a internal sdk-tool (not standalone) which is used in Qt Design Studio builds',
+    parser.add_argument('--with-sdk-tool', help='Includes the sdktool in the Qt Creator build. '
+                        'If you want a independent, standalone, static build of sdktool, use build_sdktool.py instead.',
                         action='store_true', default=False)
+    parser.add_argument('--with-extra-cmdbridge', help='Creates a separate archive with the cmdbridge, in addition to '
+                        'including it in the Qt Creator package.', action='store_true', default=False)
     parser.add_argument('--add-path', help='Prepends a CMAKE_PREFIX_PATH to the build',
                         action='append', dest='prefix_paths', default=[])
     parser.add_argument('--add-module-path', help='Prepends a CMAKE_MODULE_PATH to the build',
@@ -146,9 +150,12 @@ def common_cmake_arguments(args):
 
     return cmake_args
 
+
+def cmake_option(option):
+    return 'ON' if option else 'OFF'
+
+
 def build_qtcreator(args, paths):
-    def cmake_option(option):
-        return 'ON' if option else 'OFF'
     if args.no_qtcreator:
         return
     if not os.path.exists(paths.build):
@@ -165,13 +172,13 @@ def build_qtcreator(args, paths):
                   '-DCMAKE_PREFIX_PATH=' + ';'.join(prefix_paths),
                   '-DSHOW_BUILD_DATE=' + cmake_option(not args.no_build_date),
                   '-DWITH_DOCS=' + cmake_option(not args.no_docs),
+                  '-DQT_GENERATE_SBOM=' + cmake_option(not args.no_sbom),
                   '-DBUILD_QBS=' + cmake_option(build_qbs),
                   '-DBUILD_DEVELOPER_DOCS=' + cmake_option(not args.no_docs),
+                  '-DBUILD_LIBRARY_SDKTOOLLIB=' + cmake_option(args.with_sdk_tool),
                   '-DBUILD_EXECUTABLE_SDKTOOL=' + cmake_option(args.with_sdk_tool),
                   '-DQTC_FORCE_XCB=ON',
-                  '-DQTC_USE_SYSTEM_ZLIB=OFF',
-                  '-DQTC_USE_SYSTEM_BZIP2=OFF',
-                  '-DQTC_USE_SYSTEM_LZMA=OFF',
+                  '-DQTC_USE_SYSTEM_LIBARCHIVE=OFF',
                   '-DWITH_TESTS=' + cmake_option(args.with_tests)]
     cmake_args += common_cmake_arguments(args)
 
@@ -229,8 +236,11 @@ def build_wininterrupt(args, paths):
     if not os.path.exists(paths.wininterrupt_build):
         os.makedirs(paths.wininterrupt_build)
     prefix_paths = [common.to_posix_path(os.path.abspath(fp)) for fp in args.prefix_paths]
+    # Needed for Qt SBOM API
+    prefix_paths += [paths.qt]
     cmake_args = ['-DCMAKE_PREFIX_PATH=' + ';'.join(prefix_paths),
-                  '-DCMAKE_INSTALL_PREFIX=' + common.to_posix_path(paths.wininterrupt_install)]
+                  '-DCMAKE_INSTALL_PREFIX=' + common.to_posix_path(paths.wininterrupt_install),
+                  '-DQT_GENERATE_SBOM=' + cmake_option(not args.no_sbom)]
     cmake_args += common_cmake_arguments(args)
     common.check_print_call(['cmake'] + cmake_args + [os.path.join(paths.src, 'src', 'tools', 'wininterrupt')],
                             paths.wininterrupt_build)
@@ -245,11 +255,14 @@ def build_qtcreatorcdbext(args, paths):
     if not os.path.exists(paths.qtcreatorcdbext_build):
         os.makedirs(paths.qtcreatorcdbext_build)
     prefix_paths = [os.path.abspath(fp) for fp in args.prefix_paths]
+    # Needed for Qt SBOM API
+    prefix_paths += [paths.qt]
     if paths.llvm:
         prefix_paths += [paths.llvm]
     prefix_paths = [common.to_posix_path(fp) for fp in prefix_paths]
     cmake_args = ['-DCMAKE_PREFIX_PATH=' + ';'.join(prefix_paths),
-                  '-DCMAKE_INSTALL_PREFIX=' + common.to_posix_path(paths.qtcreatorcdbext_install)]
+                  '-DCMAKE_INSTALL_PREFIX=' + common.to_posix_path(paths.qtcreatorcdbext_install),
+                  '-DQT_GENERATE_SBOM=' + cmake_option(not args.no_sbom)]
     cmake_args += common_cmake_arguments(args)
     common.check_print_call(['cmake'] + cmake_args + [os.path.join(paths.src, 'src', 'libs', 'qtcreatorcdbext')],
                             paths.qtcreatorcdbext_build)
@@ -291,6 +304,17 @@ def package_qtcreator(args, paths):
                                         + [os.path.join(paths.result, 'qtcreator' + args.zip_infix + '-debug.7z'),
                                            '*'],
                                         paths.debug_install)
+            if args.with_extra_cmdbridge:
+                if common.is_linux_platform():
+                    cmdbridge_dir = os.path.join(paths.install, 'libexec', 'qtcreator')
+                elif common.is_windows_platform():
+                    cmdbridge_dir = os.path.join(paths.install, 'bin')
+                else:
+                    cmdbridge_dir = os.path.join(paths.install, 'Qt Creator.app', 'Contents', 'Resources', 'libexec')
+                common.check_print_call(zip
+                                        + [os.path.join(paths.result, 'cmdbridge' + args.zip_infix + '.7z'),
+                                           'cmdbridge-*'],
+                                        cmdbridge_dir)
         if common.is_windows_platform():
             common.check_print_call(zip
                                     + [os.path.join(paths.result, 'wininterrupt' + args.zip_infix + '.7z'),
