@@ -25,7 +25,7 @@
 
 #include "cppassert.h"
 
-#include <utils/executeondestruction.h>
+#include <QScopeGuard>
 
 #include <cctype>
 
@@ -217,14 +217,17 @@ void Lexer::scan_helper(Token *tok)
         tok->f.kind = s._tokenKind;
         const bool found = _expectedRawStringSuffix.isEmpty()
                 ? scanUntilRawStringLiteralEndSimple() : scanUntilRawStringLiteralEndPrecise();
-        if (found)
+        if (found) {
+            scanOptionalUserDefinedLiteral(tok);
             _state = 0;
+        }
         return;
     } else { // non-raw strings
         tok->f.joined = true;
         tok->f.kind = s._tokenKind;
         _state = 0;
         scanUntilQuote(tok, '"');
+        scanOptionalUserDefinedLiteral(tok);
         return;
     }
 
@@ -612,7 +615,12 @@ void Lexer::scan_helper(Token *tok)
                 tok->f.kind = T_LESS_LESS;
         } else if (_yychar == '=') {
             yyinp();
-            tok->f.kind = T_LESS_EQUAL;
+            if (_languageFeatures.cxx20Enabled && _yychar == '>') {
+                yyinp();
+                tok->f.kind = T_LESS_EQUAL_GREATER;
+            } else {
+                tok->f.kind = T_LESS_EQUAL;
+            }
         } else if (_yychar == ':') {
             if (*(_currentChar+1) != ':' || *(_currentChar+2) == ':' || *(_currentChar+2) == '>') {
                 yyinp();
@@ -748,9 +756,9 @@ void Lexer::scanStringLiteral(Token *tok, unsigned char hint)
 
 void Lexer::scanRawStringLiteral(Token *tok, unsigned char hint)
 {
-    Utils::ExecuteOnDestruction suffixCleaner;
-    if (!control())
-        suffixCleaner.reset([this] { _expectedRawStringSuffix.clear(); });
+    QScopeGuard cleanup([this] { _expectedRawStringSuffix.clear(); });
+    if (control())
+        cleanup.dismiss();
 
     const char *yytext = _currentChar;
 
@@ -819,25 +827,27 @@ void Lexer::scanRawStringLiteral(Token *tok, unsigned char hint)
         tok->f.kind = T_RAW_STRING_LITERAL;
 
     if (!control() && !closed) {
-        suffixCleaner.reset([]{});
+        cleanup.dismiss();
         s._tokenKind = tok->f.kind;
         _expectedRawStringSuffix.prepend(')');
         _expectedRawStringSuffix.append('"');
     }
+    if (closed)
+        scanOptionalUserDefinedLiteral(tok);
 }
 
 bool Lexer::scanUntilRawStringLiteralEndPrecise()
 {
-    int matchLen = 0;
+    QByteArray slidingWindow;
+    slidingWindow.reserve(_expectedRawStringSuffix.size());
     while (_yychar) {
-        if (_yychar == _expectedRawStringSuffix.at(matchLen)) {
-            if (++matchLen == _expectedRawStringSuffix.length()) {
-                _expectedRawStringSuffix.clear();
-                yyinp();
-                return true;
-            }
-        } else {
-            matchLen = 0;
+        slidingWindow.append(_yychar);
+        if (slidingWindow.size() > _expectedRawStringSuffix.size())
+            slidingWindow.remove(0, 1);
+        if (slidingWindow == _expectedRawStringSuffix) {
+            _expectedRawStringSuffix.clear();
+            yyinp();
+            return true;
         }
         yyinp();
     }
