@@ -19,7 +19,6 @@
 // THE SOFTWARE.
 
 #include "Scope.h"
-#include "Symbols.h"
 #include "Names.h"
 #include "Literals.h"
 #include "Templates.h"
@@ -40,7 +39,7 @@ public:
 
 public:
     /// Constructs an empty Scope.
-    SymbolTable(Scope *owner = 0);
+    SymbolTable(Scope *owner = nullptr);
 
     /// Destroy this scope.
     ~SymbolTable();
@@ -55,22 +54,23 @@ public:
     void enterSymbol(Symbol *symbol);
 
     /// Returns true if this Scope is empty; otherwise returns false.
-    bool isEmpty() const;
+    bool isEmpty() const { return _symbolCount == -1; }
 
     /// Returns the number of symbols is in the scope.
-    unsigned symbolCount() const;
+    int symbolCount() const { return _symbolCount + 1; }
 
     /// Returns the Symbol at the given position.
-    Symbol *symbolAt(unsigned index) const;
+    Symbol *symbolAt(int index) const;
 
     /// Returns the first Symbol in the scope.
-    iterator firstSymbol() const;
+    iterator firstSymbol() const { return _symbols; }
 
     /// Returns the last Symbol in the scope.
-    iterator lastSymbol() const;
+    iterator lastSymbol() const { return _symbols + _symbolCount + 1; }
 
     Symbol *lookat(const Identifier *id) const;
     Symbol *lookat(OperatorNameId::Kind operatorId) const;
+    Symbol *lookat(const ConversionNameId *convId) const;
 
 private:
     /// Returns the hash value for the given Symbol.
@@ -92,8 +92,8 @@ private:
 
 SymbolTable::SymbolTable(Scope *owner)
     : _owner(owner),
-      _symbols(0),
-      _hash(0),
+      _symbols(nullptr),
+      _hash(nullptr),
       _allocatedSymbols(0),
       _symbolCount(-1),
       _hashSize(0)
@@ -136,7 +136,7 @@ void SymbolTable::enterSymbol(Symbol *symbol)
 Symbol *SymbolTable::lookat(const Identifier *id) const
 {
     if (! _hash || ! id)
-        return 0;
+        return nullptr;
 
     const unsigned h = id->hashCode() % _hashSize;
     Symbol *symbol = _hash[h];
@@ -153,8 +153,8 @@ Symbol *SymbolTable::lookat(const Identifier *id) const
         } else if (const DestructorNameId *d = identity->asDestructorNameId()) {
             if (d->identifier()->match(id))
                 break;
-        } else if (identity->isQualifiedNameId()) {
-            return 0;
+        } else if (identity->asQualifiedNameId()) {
+            return nullptr;
         } else if (const SelectorNameId *selectorNameId = identity->asSelectorNameId()) {
             if (selectorNameId->identifier()->match(id))
                 break;
@@ -166,7 +166,7 @@ Symbol *SymbolTable::lookat(const Identifier *id) const
 Symbol *SymbolTable::lookat(OperatorNameId::Kind operatorId) const
 {
     if (! _hash)
-        return 0;
+        return nullptr;
 
     const unsigned h = operatorId % _hashSize;
     Symbol *symbol = _hash[h];
@@ -181,6 +181,23 @@ Symbol *SymbolTable::lookat(OperatorNameId::Kind operatorId) const
     return symbol;
 }
 
+Symbol *SymbolTable::lookat(const ConversionNameId *convId) const
+{
+    if (!_hash)
+        return nullptr;
+
+    Symbol *symbol = _hash[0]; // See Symbol::HashCode
+    for (; symbol; symbol = symbol->_next) {
+        if (const Name *identity = symbol->unqualifiedName()) {
+            if (const ConversionNameId * const id = identity->asConversionNameId()) {
+                if (id->type().match(convId->type()))
+                    break;
+            }
+        }
+    }
+    return symbol;
+}
+
 void SymbolTable::rehash()
 {
     _hashSize <<= 1;
@@ -207,35 +224,23 @@ unsigned SymbolTable::hashValue(Symbol *symbol) const
     return symbol->hashCode() % _hashSize;
 }
 
-bool SymbolTable::isEmpty() const
-{ return _symbolCount == -1; }
-
-unsigned SymbolTable::symbolCount() const
-{ return _symbolCount + 1; }
-
-Symbol *SymbolTable::symbolAt(unsigned index) const
+Symbol *SymbolTable::symbolAt(int index) const
 {
     if (! _symbols)
-        return 0;
+        return nullptr;
     return _symbols[index];
 }
 
-SymbolTable::iterator SymbolTable::firstSymbol() const
-{ return _symbols; }
-
-SymbolTable::iterator SymbolTable::lastSymbol() const
-{ return _symbols + _symbolCount + 1; }
-
-Scope::Scope(TranslationUnit *translationUnit, unsigned sourceLocation, const Name *name)
+Scope::Scope(TranslationUnit *translationUnit, int sourceLocation, const Name *name)
     : Symbol(translationUnit, sourceLocation, name),
-      _members(0),
+      _members(nullptr),
       _startOffset(0),
       _endOffset(0)
 { }
 
 Scope::Scope(Clone *clone, Subst *subst, Scope *original)
     : Symbol(clone, subst, original)
-    , _members(0)
+    , _members(nullptr)
     , _startOffset(original->_startOffset)
     , _endOffset(original->_endOffset)
 {
@@ -260,39 +265,28 @@ bool Scope::isEmpty() const
 { return _members ? _members->isEmpty() : true; }
 
 /// Returns the number of symbols is in the scope.
-unsigned Scope::memberCount() const
+int Scope::memberCount() const
 { return _members ? _members->symbolCount() : 0; }
 
 /// Returns the Symbol at the given position.
-Symbol *Scope::memberAt(unsigned index) const
-{ return _members ? _members->symbolAt(index) : 0; }
+Symbol *Scope::memberAt(int index) const
+{ return _members ? _members->symbolAt(index) : nullptr; }
 
 /// Returns the first Symbol in the scope.
 Scope::iterator Scope::memberBegin() const
-{ return _members ? _members->firstSymbol() : 0; }
+{ return _members ? _members->firstSymbol() : nullptr; }
 
 /// Returns the last Symbol in the scope.
 Scope::iterator Scope::memberEnd() const
-{ return _members ? _members->lastSymbol() : 0; }
+{ return _members ? _members->lastSymbol() : nullptr; }
 
 Symbol *Scope::find(const Identifier *id) const
-{ return _members ? _members->lookat(id) : 0; }
+{ return _members ? _members->lookat(id) : nullptr; }
 
 Symbol *Scope::find(OperatorNameId::Kind operatorId) const
-{ return _members ? _members->lookat(operatorId) : 0; }
+{ return _members ? _members->lookat(operatorId) : nullptr; }
 
-/// Set the start offset of the scope
-unsigned Scope::startOffset() const
-{ return _startOffset; }
-
-void Scope::setStartOffset(unsigned offset)
-{ _startOffset = offset; }
-
-/// Set the end offset of the scope
-unsigned Scope::endOffset() const
-{ return _endOffset; }
-
-void Scope::setEndOffset(unsigned offset)
-{ _endOffset = offset; }
+Symbol *Scope::find(const ConversionNameId *conv) const
+{ return _members ? _members->lookat(conv) : nullptr; }
 
 } // namespace CPlusPlus
