@@ -13,10 +13,9 @@
 using namespace Utils;
 using namespace CPlusPlus;
 
-FastPreprocessor::FastPreprocessor(const Snapshot &snapshot)
+FastPreprocessor::FastPreprocessor(const Snapshot &snapshot, bool expandFunctionLikeMacros)
     : _snapshot(snapshot)
-    , _preproc(this, &_env)
-    , _addIncludesToCurrentDoc(false)
+    , _expandFunctionLikeMacros(expandFunctionLikeMacros)
 { }
 
 QByteArray FastPreprocessor::run(Document::Ptr newDoc,
@@ -27,14 +26,14 @@ QByteArray FastPreprocessor::run(Document::Ptr newDoc,
     _addIncludesToCurrentDoc = _currentDoc->resolvedIncludes().isEmpty()
             && _currentDoc->unresolvedIncludes().isEmpty();
     const FilePath filePath = _currentDoc->filePath();
-    _preproc.setExpandFunctionlikeMacros(false);
     _preproc.setKeepComments(true);
+    _preproc.setExpandFunctionlikeMacros(_expandFunctionLikeMacros);
 
     if (Document::Ptr doc = _snapshot.document(filePath)) {
         _merged.insert(filePath);
 
         for (Snapshot::const_iterator i = _snapshot.begin(), ei = _snapshot.end(); i != ei; ++i) {
-            if (isInjectedFile(i.key().path()))
+            if (isInjectedFile(i.key()))
                 mergeEnvironment(i.key());
         }
 
@@ -60,7 +59,7 @@ void FastPreprocessor::sourceNeeded(int line, const FilePath &filePath, IncludeT
     if (_addIncludesToCurrentDoc) {
         // CHECKME: Is that cleanPath needed?
         const FilePath cleanPath = filePath.cleanPath();
-        _currentDoc->addIncludeFile(Document::Include(filePath.toUrlishString(), cleanPath, line, mode));
+        _currentDoc->addIncludeFile(Document::Include(filePath.path(), cleanPath, line, mode));
     }
     mergeEnvironment(filePath);
 }
@@ -110,7 +109,7 @@ void FastPreprocessor::passedMacroDefinitionCheck(int bytesOffset, int utf16char
     _currentDoc->addMacroUse(revision(_snapshot, macro),
                              bytesOffset, macro.name().size(),
                              utf16charsOffset, macro.nameToQString().size(),
-                             line, QVector<MacroArgumentReference>());
+                             line, QList<MacroArgumentReference>());
 }
 
 void FastPreprocessor::failedMacroDefinitionCheck(int bytesOffset, int utf16charsOffset,
@@ -130,12 +129,12 @@ void FastPreprocessor::notifyMacroReference(int bytesOffset, int utf16charsOffse
     _currentDoc->addMacroUse(revision(_snapshot, macro),
                              bytesOffset, macro.name().size(),
                              utf16charsOffset, macro.nameToQString().size(),
-                             line, QVector<MacroArgumentReference>());
+                             line, QList<MacroArgumentReference>());
 }
 
 void FastPreprocessor::startExpandingMacro(int bytesOffset, int utf16charsOffset,
                                            int line, const Macro &macro,
-                                           const QVector<MacroArgumentReference> &actuals)
+                                           const QList<MacroArgumentReference> &actuals)
 {
     Q_ASSERT(_currentDoc);
 
