@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 /*
   Copyright 2005 Roberto Raggi <roberto@kdevelop.org>
@@ -29,13 +29,16 @@
 #include <cplusplus/Lexer.h>
 #include <cplusplus/Token.h>
 
-#include <QVector>
+#include <utils/guard.h>
+
 #include <QBitArray>
 #include <QByteArray>
 #include <QPair>
 
 #include <functional>
 
+namespace Utils { class FilePath; }
+
 namespace CPlusPlus {
 
 class Environment;
@@ -52,11 +55,13 @@ class CPLUSPLUS_EXPORT Preprocessor
     typedef Internal::Value Value;
 
 public:
-    static QString configurationFileName();
+    static const Utils::FilePath &configurationFileName();
 
 public:
     Preprocessor(Client *client, Environment *env);
 
+    QByteArray run(const Utils::FilePath &filePath, const QByteArray &source,
+                   bool noLines = false, bool markGeneratedTokens = true);
     QByteArray run(const QString &filename, const QByteArray &source,
                    bool noLines = false, bool markGeneratedTokens = true);
 
@@ -122,7 +127,7 @@ private:
         QByteArray *m_currentExpansion;
 
         QByteArray m_expansionResult;
-        QVector<QPair<unsigned, unsigned> > m_expandedTokensInfo;
+        QList<QPair<unsigned, unsigned>> m_expandedTokensInfo;
 
         enum {
             /// State to indicate that no guard is possible anymore.
@@ -186,24 +191,25 @@ private:
     void skipPreprocesorDirective(PPToken *tk);
     bool handleIdentifier(PPToken *tk);
     bool handleFunctionLikeMacro(const Macro *macro,
-                                 QVector<PPToken> &body,
-                                 const QVector<QVector<PPToken> > &actuals,
+                                 QList<PPToken> &body,
+                                 const QList<QList<PPToken> > &actuals,
                                  unsigned lineRef);
 
     bool skipping() const
     { return m_state.m_skipping[m_state.m_ifLevel]; }
 
-    QVector<CPlusPlus::Token> tokenize(const QByteArray &text) const;
+    QList<CPlusPlus::Token> tokenize(const QByteArray &text) const;
 
     bool scanComment(PPToken *tk);
     bool consumeComments(PPToken *tk);
-    bool collectActualArguments(PPToken *tk, QVector<QVector<PPToken> > *actuals,
+    bool collectActualArguments(PPToken *tk, QList<QList<PPToken> > *actuals,
                                 const QByteArray &parentMacroName);
-    void scanActualArgument(PPToken *tk, QVector<PPToken> *tokens);
+    void scanActualArgument(PPToken *tk, QList<PPToken> *tokens);
 
     void handlePreprocessorDirective(PPToken *tk);
     void handleIncludeDirective(PPToken *tk, bool includeNext);
     void handleDefineDirective(PPToken *tk);
+    void handlePragmaDirective(PPToken *tk);
     QByteArray expand(PPToken *tk, PPToken *lastConditionToken = nullptr);
     const Internal::PPToken evalExpression(PPToken *tk, Value &result);
     void handleIfDirective(PPToken *tk);
@@ -231,12 +237,14 @@ private:
     PPToken generateConcatenated(const PPToken &leftTk, const PPToken &rightTk);
 
     void startSkippingBlocks(const PPToken &tk) const;
+    bool checkConditionalNesting() const;
 
 private:
     Client *m_client;
     Environment *m_env;
     QByteArray m_scratchBuffer;
     CancelChecker m_cancelChecker;
+    Utils::Guard m_includeDepthGuard;
 
     bool m_expandFunctionlikeMacros;
     bool m_keepComments;
