@@ -1,5 +1,5 @@
 
-#line 210 "./glsl.g"
+#line 222 "./glsl.g"
 
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
@@ -61,6 +61,7 @@ public:
         } param_declarator;
         ParameterDeclarationAST *param_declaration;
         FunctionDeclarationAST *function_declaration;
+        InterfaceBlockAST *interface_block;
     };
 
     Parser(Engine *engine, const char *source, unsigned size, int variant);
@@ -118,6 +119,21 @@ private:
         _engine->error(line, message);
     }
 
+    static bool isInterfaceBlockStorageIdentifier(int qualifier)
+    {
+        // TODO Buffer
+        qualifier = qualifier & QualifiedTypeAST::StorageMask;
+        return (qualifier == QualifiedTypeAST::In
+                || qualifier == QualifiedTypeAST::Out
+                || qualifier == QualifiedTypeAST::Uniform
+                || qualifier == QualifiedTypeAST::CentroidIn
+                || qualifier == QualifiedTypeAST::CentroidOut
+                || qualifier == QualifiedTypeAST::PatchIn
+                || qualifier == QualifiedTypeAST::PatchOut
+                || qualifier == QualifiedTypeAST::SampleIn
+                || qualifier == QualifiedTypeAST::SampleOut);
+    }
+
     template <typename T>
     T *makeAstNode()
     {
