@@ -1,5 +1,5 @@
 // Copyright (C) 2018 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "messages.h"
 
@@ -26,13 +26,19 @@ TelemetryNotification::TelemetryNotification(const JsonObject &params)
     : Notification(methodName, params)
 { }
 
-static QString messageTypeName(int messageType)
+static QString messageTypeName(ShowMessageParams::MessageType messageType)
 {
     switch (messageType) {
-    case Error: return QString("Error");
-    case Warning: return QString("Warning");
-    case Info: return QString("Info");
-    case Log: return QString("Log");
+    case ShowMessageParams::MessageType::Error:
+        return QString("Error");
+    case ShowMessageParams::MessageType::Warning:
+        return QString("Warning");
+    case ShowMessageParams::MessageType::Info:
+        return QString("Info");
+    case ShowMessageParams::MessageType::Log:
+        return QString("Log");
+    case ShowMessageParams::MessageType::Debug:
+        return QString("Debug");
     }
     return QString("");
 }
@@ -42,4 +48,22 @@ QString ShowMessageParams::toString() const
     return messageTypeName(type()) + ": " + message();
 }
 
+QtMsgType ShowMessageParams::qtMsgType() const
+{
+    switch (type()) {
+    case ShowMessageParams::MessageType::Error:
+        return QtCriticalMsg;
+    case ShowMessageParams::MessageType::Warning:
+        return QtWarningMsg;
+    case ShowMessageParams::MessageType::Info:
+        return QtInfoMsg;
+    case ShowMessageParams::MessageType::Log:
+        return QtInfoMsg;
+    case ShowMessageParams::MessageType::Debug:
+        return QtDebugMsg;
+    }
+
+    return QtCriticalMsg;
+}
+
 } // namespace LanguageServerProtocol
