@@ -23,7 +23,7 @@ bool StereotypesController::isParsable(const QString &stereotypes)
     return true;
 }
 
-QString StereotypesController::toString(const QList<QString> &stereotypes)
+QString StereotypesController::toString(const QStringList &stereotypes)
 {
     QString s;
     bool first = true;
@@ -36,9 +36,9 @@ QString StereotypesController::toString(const QList<QString> &stereotypes)
     return s;
 }
 
-QList<QString> StereotypesController::fromString(const QString &stereotypes)
+QStringList StereotypesController::fromString(const QString &stereotypes)
 {
-    QList<QString> result;
+    QStringList result;
     const QStringList list = stereotypes.split(QLatin1Char(','));
     for (const QString &part : list) {
         QString stereotype = part.trimmed();
