@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 Jochen Becher
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 Jochen Becher
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -77,13 +55,16 @@ public:
     enum class ColorType {
         EndA,
         EndB,
-        Custom
+        Custom,
+        Warning,
+        Error,
+        Soften,
     };
 
     class End {
     public:
-        QList<QString> endItems() const { return m_endItems; }
-        void setEndItems(const QList<QString> &endItems);
+        QStringList endItems() const { return m_endItems; }
+        void setEndItems(const QStringList &endItems);
         QString role() const { return m_role; }
         void setRole(const QString &role);
         QString cardinality() const { return m_cardinality; }
@@ -98,7 +79,7 @@ public:
         void setShape(const IconShape &shape);
 
     private:
-        QList<QString> m_endItems;
+        QStringList m_endItems;
         QString m_role;
         QString m_cardinality;
         bool m_navigable = false;
@@ -117,8 +98,8 @@ public:
     void setId(const QString &id);
     QString title() const { return m_title; }
     void setTitle(const QString &title);
-    QList<QString> endItems() const { return m_endItems; }
-    void setEndItems(const QList<QString> &endItems);
+    QStringList endItems() const { return m_endItems; }
+    void setEndItems(const QStringList &endItems);
     QSet<QString> stereotypes() const { return m_stereotypes; }
     void setStereotypes(const QSet<QString> &stereotypes);
     QString name() const { return m_name; }
@@ -135,12 +116,26 @@ public:
     void setColorType(ColorType colorType);
     QColor color() const { return m_color; }
     void setColor(const QColor &color);
+    bool emphasized() const { return m_emphasized; }
+    void setEmphasized(bool emphasized);
+
+    friend size_t qHash(CustomRelation::Relationship relationship) {
+        return ::qHash(static_cast<int>(relationship));
+    }
+
+    friend size_t qHash(CustomRelation::ShaftPattern pattern) {
+        return ::qHash(static_cast<int>(pattern));
+    }
+
+    friend size_t qHash(CustomRelation::Head head) {
+        return ::qHash(static_cast<int>(head));
+    }
 
 private:
     Element m_element = Element::Relation;
     QString m_id;
     QString m_title;
-    QList<QString> m_endItems;
+    QStringList m_endItems;
     QSet<QString> m_stereotypes;
     QString m_name;
     Direction m_direction = Direction::AtoB;
@@ -149,18 +144,7 @@ private:
     ShaftPattern m_shaftPattern = ShaftPattern::Solid;
     ColorType m_colorType = ColorType::EndA;
     QColor m_color;
+    bool m_emphasized = false;
 };
 
-inline auto qHash(CustomRelation::Relationship relationship) {
-    return ::qHash(static_cast<int>(relationship));
-}
-
-inline auto qHash(CustomRelation::ShaftPattern pattern) {
-    return ::qHash(static_cast<int>(pattern));
-}
-
-inline auto qHash(CustomRelation::Head head) {
-    return ::qHash(static_cast<int>(head));
-}
-
 } // namespace qmt
