@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "qmljssimplereader.h"
 
@@ -13,6 +13,7 @@
 #include "qqmljsparser_p.h"
 #endif
 
+#include "qmljstr.h"
 #include "qmljsutils.h"
 
 #include <QFile>
@@ -88,7 +89,10 @@ static Q_LOGGING_CATEGORY(simpleReaderLog, "qtc.qmljs.simpleReader", QtWarningMs
         return newNode;
     }
 
-    const SimpleReaderNode::List SimpleReaderNode::children() const { return m_children; }
+    const SimpleReaderNode::List &SimpleReaderNode::children() const
+    {
+        return m_children;
+    }
 
     void SimpleReaderNode::setProperty(const QString &name,
                                        const SourceLocation &nameLocation,
@@ -110,7 +114,7 @@ static Q_LOGGING_CATEGORY(simpleReaderLog, "qtc.qmljs.simpleReader", QtWarningMs
             file.close();
             return readFromSource(QString::fromLocal8Bit(source));
         }
-        addError(tr("Cannot find file %1.").arg(fileName));
+        addError(Tr::tr("Cannot find file %1.").arg(fileName));
         return false;
     }
 
@@ -157,14 +161,14 @@ static Q_LOGGING_CATEGORY(simpleReaderLog, "qtc.qmljs.simpleReader", QtWarningMs
     bool SimpleAbstractStreamReader::readDocument(AST::UiProgram * ast)
     {
         if (!ast) {
-            addError(tr("Could not parse document."));
+            addError(Tr::tr("Could not parse document."));
             return false;
         }
 
         AST::UiObjectDefinition *uiObjectDefinition = AST::cast<AST::UiObjectDefinition *>(
             ast->members->member);
         if (!uiObjectDefinition) {
-            addError(tr("Expected document to contain a single object definition."));
+            addError(Tr::tr("Expected document to contain a single object definition."));
             return false;
         }
         readChild(uiObjectDefinition);
@@ -237,7 +241,7 @@ static Q_LOGGING_CATEGORY(simpleReaderLog, "qtc.qmljs.simpleReader", QtWarningMs
         AST::ExpressionStatement *expStmt = AST::cast<AST::ExpressionStatement *>(
             uiScriptBinding->statement);
         if (!expStmt) {
-            addError(tr("Expected expression statement after colon."),
+            addError(Tr::tr("Expected expression statement after colon."),
                      uiScriptBinding->statement->firstSourceLocation());
             return std::make_pair(QVariant(), SourceLocation());
         }
@@ -339,7 +343,7 @@ static Q_LOGGING_CATEGORY(simpleReaderLog, "qtc.qmljs.simpleReader", QtWarningMs
 
         if (m_currentNode.toStrongRef().data()->propertyNames().contains(name)) {
             auto previousSourceLoc = m_currentNode.toStrongRef().data()->property(name).nameLocation;
-            addError(tr("Property is defined twice, previous definition at %1:%2")
+            addError(Tr::tr("Property is defined twice, previous definition at %1:%2")
                          .arg(QString::number(previousSourceLoc.startLine),
                               QString::number(previousSourceLoc.startColumn)),
                      currentSourceLocation());
