@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #ifndef _SCL_SECURE_NO_WARNINGS // silence std::string::copy
 # define _SCL_SECURE_NO_WARNINGS
@@ -36,6 +14,8 @@
 #include <codecvt>
 #include <iomanip>
 
+#include <windows.h>
+
 static const char whiteSpace[] = " \t\r\n";
 
 void trimFront(std::string &s)
@@ -152,7 +132,10 @@ std::string wStringToString(const std::wstring &w)
 
 std::wstring utf8ToUtf16(const std::string &s)
 {
-    return std::wstring_convert<std::codecvt_utf8_utf16<wchar_t>>().from_bytes(s.data());
+    const int size = MultiByteToWideChar(CP_UTF8, 0, s.data(), int(s.size()), NULL, 0);
+    std::wstring result(size, 0);
+    MultiByteToWideChar(CP_UTF8, 0, s.data(), int(s.size()), result.data(), size);
+    return result;
 }
 
 // Convert an ASCII hex digit to its value 'A'->10
