@@ -28,10 +28,12 @@ namespace Sqlite {
 
 using NanotraceHR::keyValue;
 
-BaseStatement::BaseStatement(Utils::SmallStringView sqlStatement, Database &database)
+BaseStatement::BaseStatement(Utils::SmallStringView sqlStatement,
+                             Database &database,
+                             const source_location &sourceLocation)
     : m_database(database)
 {
-    prepare(sqlStatement);
+    prepare(sqlStatement, sourceLocation);
 }
 
 class UnlockNotification
@@ -67,31 +69,31 @@ private:
     std::mutex m_mutex;
 };
 
-void BaseStatement::waitForUnlockNotify() const
+void BaseStatement::waitForUnlockNotify(const source_location &sourceLocation) const
 {
     UnlockNotification unlockNotification;
-    int resultCode = sqlite3_unlock_notify(sqliteDatabaseHandle(),
+    int resultCode = sqlite3_unlock_notify(sqliteDatabaseHandle(sourceLocation),
                                            UnlockNotification::unlockNotifyCallBack,
                                            &unlockNotification);
 
     if (resultCode == SQLITE_LOCKED)
-        throw DeadLock();
+        throw DeadLock(sourceLocation);
 
     unlockNotification.wait();
 }
 
 void BaseStatement::reset() const noexcept
 {
-    NanotraceHR::Tracer tracer{"reset"_t,
+    NanotraceHR::Tracer tracer{"reset",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle())};
 
     sqlite3_reset(m_compiledStatement.get());
 }
 
-bool BaseStatement::next() const
+bool BaseStatement::next(const source_location &sourceLocation) const
 {
-    NanotraceHR::Tracer tracer{"next"_t,
+    NanotraceHR::Tracer tracer{"next",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle())};
     int resultCode;
@@ -99,7 +101,7 @@ bool BaseStatement::next() const
     do {
         resultCode = sqlite3_step(m_compiledStatement.get());
         if (resultCode == SQLITE_LOCKED) {
-            waitForUnlockNotify();
+            waitForUnlockNotify(sourceLocation);
             sqlite3_reset(m_compiledStatement.get());
         }
 
@@ -110,34 +112,34 @@ bool BaseStatement::next() const
     else if (resultCode == SQLITE_DONE)
         return false;
 
-    Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+    Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::step() const
+void BaseStatement::step(const source_location &sourceLocation) const
 {
-    next();
+    next(sourceLocation);
 }
 
-void BaseStatement::bindNull(int index)
+void BaseStatement::bindNull(int index, const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind null"_t,
+    NanotraceHR::Tracer tracer{"bind null",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index)};
 
     int resultCode = sqlite3_bind_null(m_compiledStatement.get(), index);
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, NullValue)
+void BaseStatement::bind(int index, NullValue, const source_location &sourceLocation)
 {
-    bindNull(index);
+    bindNull(index, sourceLocation);
 }
 
-void BaseStatement::bind(int index, int value)
+void BaseStatement::bind(int index, int value, const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind int"_t,
+    NanotraceHR::Tracer tracer{"bind int",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index),
@@ -145,12 +147,12 @@ void BaseStatement::bind(int index, int value)
 
     int resultCode = sqlite3_bind_int(m_compiledStatement.get(), index, value);
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, long long value)
+void BaseStatement::bind(int index, long long value, const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind long long"_t,
+    NanotraceHR::Tracer tracer{"bind long long",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index),
@@ -158,12 +160,12 @@ void BaseStatement::bind(int index, long long value)
 
     int resultCode = sqlite3_bind_int64(m_compiledStatement.get(), index, value);
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, double value)
+void BaseStatement::bind(int index, double value, const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind double"_t,
+    NanotraceHR::Tracer tracer{"bind double",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index),
@@ -171,12 +173,12 @@ void BaseStatement::bind(int index, double value)
 
     int resultCode = sqlite3_bind_double(m_compiledStatement.get(), index, value);
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, void *pointer)
+void BaseStatement::bind(int index, void *pointer, const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind pointer"_t,
+    NanotraceHR::Tracer tracer{"bind pointer",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index),
@@ -184,12 +186,12 @@ void BaseStatement::bind(int index, void *pointer)
 
     int resultCode = sqlite3_bind_pointer(m_compiledStatement.get(), index, pointer, "carray", nullptr);
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, Utils::span<const int> values)
+void BaseStatement::bind(int index, Utils::span<const int> values, const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind int span"_t,
+    NanotraceHR::Tracer tracer{"bind int span",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index),
@@ -203,12 +205,14 @@ void BaseStatement::bind(int index, Utils::span<const int> values)
                                          CARRAY_INT32,
                                          SQLITE_STATIC);
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, Utils::span<const long long> values)
+void BaseStatement::bind(int index,
+                         Utils::span<const long long> values,
+                         const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind long long span"_t,
+    NanotraceHR::Tracer tracer{"bind long long span",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index),
@@ -222,12 +226,14 @@ void BaseStatement::bind(int index, Utils::span<const long long> values)
                                          CARRAY_INT64,
                                          SQLITE_STATIC);
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, Utils::span<const double> values)
+void BaseStatement::bind(int index,
+                         Utils::span<const double> values,
+                         const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind double span"_t,
+    NanotraceHR::Tracer tracer{"bind double span",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index),
@@ -241,12 +247,14 @@ void BaseStatement::bind(int index, Utils::span<const double> values)
                                          CARRAY_DOUBLE,
                                          SQLITE_STATIC);
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, Utils::span<const char *> values)
+void BaseStatement::bind(int index,
+                         Utils::span<const char *> values,
+                         const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind const char* span"_t,
+    NanotraceHR::Tracer tracer{"bind const char* span",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index),
@@ -260,12 +268,12 @@ void BaseStatement::bind(int index, Utils::span<const char *> values)
                                          CARRAY_TEXT,
                                          SQLITE_STATIC);
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, Utils::SmallStringView text)
+void BaseStatement::bind(int index, Utils::SmallStringView text, const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind string"_t,
+    NanotraceHR::Tracer tracer{"bind string",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index),
@@ -277,12 +285,12 @@ void BaseStatement::bind(int index, Utils::SmallStringView text)
                                        int(text.size()),
                                        SQLITE_STATIC);
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, BlobView blobView)
+void BaseStatement::bind(int index, BlobView blobView, const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"bind blob"_t,
+    NanotraceHR::Tracer tracer{"bind blob",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("index", index),
@@ -302,77 +310,77 @@ void BaseStatement::bind(int index, BlobView blobView)
     }
 
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 }
 
-void BaseStatement::bind(int index, const Value &value)
+void BaseStatement::bind(int index, const Value &value, const source_location &sourceLocation)
 {
     NanotraceHR::Tracer tracer{
-        "bind value"_t,
+        "bind value",
         sqliteLowLevelCategory(),
         keyValue("sqlite statement", handle()),
     };
 
     switch (value.type()) {
     case ValueType::Integer:
-        bind(index, value.toInteger());
+        bind(index, value.toInteger(), sourceLocation);
         break;
     case ValueType::Float:
-        bind(index, value.toFloat());
+        bind(index, value.toFloat(), sourceLocation);
         break;
     case ValueType::String:
-        bind(index, value.toStringView());
+        bind(index, value.toStringView(), sourceLocation);
         break;
     case ValueType::Blob:
-        bind(index, value.toBlobView());
+        bind(index, value.toBlobView(), sourceLocation);
         break;
     case ValueType::Null:
-        bind(index, NullValue{});
+        bind(index, NullValue{}, sourceLocation);
         break;
     }
 }
 
-void BaseStatement::bind(int index, ValueView value)
+void BaseStatement::bind(int index, ValueView value, const source_location &sourceLocation)
 {
     NanotraceHR::Tracer tracer{
-        "bind value"_t,
+        "bind value",
         sqliteLowLevelCategory(),
         keyValue("sqlite statement", handle()),
     };
 
     switch (value.type()) {
     case ValueType::Integer:
-        bind(index, value.toInteger());
+        bind(index, value.toInteger(), sourceLocation);
         break;
     case ValueType::Float:
-        bind(index, value.toFloat());
+        bind(index, value.toFloat(), sourceLocation);
         break;
     case ValueType::String:
-        bind(index, value.toStringView());
+        bind(index, value.toStringView(), sourceLocation);
         break;
     case ValueType::Blob:
-        bind(index, value.toBlobView());
+        bind(index, value.toBlobView(), sourceLocation);
         break;
     case ValueType::Null:
-        bind(index, NullValue{});
+        bind(index, NullValue{}, sourceLocation);
         break;
     }
 }
 
-void BaseStatement::prepare(Utils::SmallStringView sqlStatement)
+void BaseStatement::prepare(Utils::SmallStringView sqlStatement, const source_location &sourceLocation)
 {
-    NanotraceHR::Tracer tracer{"prepare"_t,
+    NanotraceHR::Tracer tracer{"prepare",
                                sqliteLowLevelCategory(),
                                keyValue("sql statement", sqlStatement)};
 
     if (!m_database.isLocked())
-        throw DatabaseIsNotLocked{};
+        throw DatabaseIsNotLocked{sourceLocation};
 
     int resultCode;
 
     do {
         sqlite3_stmt *sqliteStatement = nullptr;
-        resultCode = sqlite3_prepare_v2(sqliteDatabaseHandle(),
+        resultCode = sqlite3_prepare_v2(sqliteDatabaseHandle(sourceLocation),
                                         sqlStatement.data(),
                                         int(sqlStatement.size()),
                                         &sqliteStatement,
@@ -380,34 +388,35 @@ void BaseStatement::prepare(Utils::SmallStringView sqlStatement)
         m_compiledStatement.reset(sqliteStatement);
 
         if (resultCode == SQLITE_LOCKED) {
-            tracer.tick("wait for unlock"_t);
-            waitForUnlockNotify();
+            tracer.tick("wait for unlock");
+            waitForUnlockNotify(sourceLocation);
         }
 
     } while (resultCode == SQLITE_LOCKED);
 
 
     if (resultCode != SQLITE_OK)
-        Sqlite::throwError(resultCode, sqliteDatabaseHandle());
+        Sqlite::throwError(resultCode, sqliteDatabaseHandle(sourceLocation), sourceLocation);
 
     tracer.end(keyValue("sqlite statement", handle()));
 }
 
-sqlite3 *BaseStatement::sqliteDatabaseHandle() const
+sqlite3 *BaseStatement::sqliteDatabaseHandle(const source_location &sourceLocation) const
 {
-    return m_database.backend().sqliteDatabaseHandle();
+    return m_database.backend().sqliteDatabaseHandle(sourceLocation);
 }
 
-void BaseStatement::checkBindingParameterCount(int bindingParameterCount) const
+void BaseStatement::checkBindingParameterCount(int bindingParameterCount,
+                                               const source_location &sourceLocation) const
 {
     if (bindingParameterCount != sqlite3_bind_parameter_count(m_compiledStatement.get()))
-        throw WrongBindingParameterCount{};
+        throw WrongBindingParameterCount{sourceLocation};
 }
 
-void BaseStatement::checkColumnCount(int columnCount) const
+void BaseStatement::checkColumnCount(int columnCount, const source_location &sourceLocation) const
 {
     if (columnCount != sqlite3_column_count(m_compiledStatement.get()))
-        throw WrongColumnCount{};
+        throw WrongColumnCount{sourceLocation};
 }
 
 bool BaseStatement::isReadOnlyStatement() const
@@ -468,7 +477,7 @@ StringType convertToTextForColumn(sqlite3_stmt *sqlStatment, int column)
 
 Type BaseStatement::fetchType(int column) const
 {
-    NanotraceHR::Tracer tracer{"fetch type"_t,
+    NanotraceHR::Tracer tracer{"fetch type",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("column", column)};
@@ -493,7 +502,7 @@ Type BaseStatement::fetchType(int column) const
 
 int BaseStatement::fetchIntValue(int column) const
 {
-    NanotraceHR::Tracer tracer{"fetch int"_t,
+    NanotraceHR::Tracer tracer{"fetch int",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("column", column)};
@@ -524,7 +533,7 @@ long BaseStatement::fetchValue<long>(int column) const
 
 long long BaseStatement::fetchLongLongValue(int column) const
 {
-    NanotraceHR::Tracer tracer{"fetch long long"_t,
+    NanotraceHR::Tracer tracer{"fetch long long",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("column", column)};
@@ -544,7 +553,7 @@ long long BaseStatement::fetchValue<long long>(int column) const
 
 double BaseStatement::fetchDoubleValue(int column) const
 {
-    NanotraceHR::Tracer tracer{"fetch double"_t,
+    NanotraceHR::Tracer tracer{"fetch double",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("column", column)};
@@ -558,7 +567,7 @@ double BaseStatement::fetchDoubleValue(int column) const
 
 BlobView BaseStatement::fetchBlobValue(int column) const
 {
-    NanotraceHR::Tracer tracer{"fetch blob"_t,
+    NanotraceHR::Tracer tracer{"fetch blob",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("column", column)};
@@ -575,7 +584,7 @@ double BaseStatement::fetchValue<double>(int column) const
 template<typename StringType>
 StringType BaseStatement::fetchValue(int column) const
 {
-    NanotraceHR::Tracer tracer{"fetch string value"_t,
+    NanotraceHR::Tracer tracer{"fetch string value",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("column", column)};
@@ -596,7 +605,7 @@ template SQLITE_EXPORT Utils::PathString BaseStatement::fetchValue<Utils::PathSt
 
 Utils::SmallStringView BaseStatement::fetchSmallStringViewValue(int column) const
 {
-    NanotraceHR::Tracer tracer{"fetch string view"_t,
+    NanotraceHR::Tracer tracer{"fetch string view",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("column", column)};
@@ -610,7 +619,7 @@ Utils::SmallStringView BaseStatement::fetchSmallStringViewValue(int column) cons
 
 ValueView BaseStatement::fetchValueView(int column) const
 {
-    NanotraceHR::Tracer tracer{"fetch value view"_t,
+    NanotraceHR::Tracer tracer{"fetch value view",
                                sqliteLowLevelCategory(),
                                keyValue("sqlite statement", handle()),
                                keyValue("column", column)};
@@ -635,7 +644,7 @@ ValueView BaseStatement::fetchValueView(int column) const
 void BaseStatement::Deleter::operator()(sqlite3_stmt *statement)
 {
     NanotraceHR::Tracer tracer{
-        "finalize"_t,
+        "finalize",
         sqliteLowLevelCategory(),
         keyValue("sqlite statement", reinterpret_cast<std::uintptr_t>(statement)),
     };
