@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -19,7 +19,7 @@ public:
 
     float scale;  // "native" scale, this stays the same through the life time of a state
 
-    QVector<TimelineRenderPass::State *> passes;
+    QList<TimelineRenderPass::State *> passes;
 };
 
 } // namespace Timeline
