@@ -6,6 +6,7 @@
 #include "camelcasecursor.h"
 #include "execmenu.h"
 #include "futuresynchronizer.h"
+#include "fancyiconbutton.h"
 #include "historycompleter.h"
 #include "hostosinfo.h"
 #include "icon.h"
@@ -15,6 +16,7 @@
 #include <solutions/spinner/spinner.h>
 
 #include <QApplication>
+#include <qapplicationstatic.h>
 #include <QFutureWatcher>
 #include <QKeyEvent>
 #include <QKeySequence>
@@ -64,9 +66,6 @@
 
 enum { margin = 6 };
 
-#define ICONBUTTON_HEIGHT 18
-#define FADE_TIME 160
-
 namespace Utils {
 
 static bool camelCaseNavigation = false;
@@ -91,7 +90,7 @@ signals:
 private:
     QKeySequence m_key = Qt::Key_Space | HostOsInfo::controlModifier();
 };
-Q_GLOBAL_STATIC(CompletionShortcut, completionShortcut)
+Q_APPLICATION_STATIC(CompletionShortcut, completionShortcut)
 
 
 // --------- FancyLineEditPrivate
@@ -404,6 +403,12 @@ void FancyLineEdit::setCompletionShortcut(const QKeySequence &shortcut)
     completionShortcut()->setKeySequence(shortcut);
 }
 
+void FancyLineEdit::setValueAlternatives(const QStringList &values)
+{
+    for (const QString &value : values)
+        d->m_historyCompleter->addEntry(value);
+}
+
 void FancyLineEdit::setSpecialCompleter(QCompleter *completer)
 {
     QTC_ASSERT(!d->m_historyCompleter, return);
@@ -664,73 +669,6 @@ QString FancyLineEdit::fixInputString(const QString &string)
     return string;
 }
 
-//
-// IconButton - helper class to represent a clickable icon
-//
-
-FancyIconButton::FancyIconButton(QWidget *parent)
-    : QAbstractButton(parent)
-{
-    setCursor(Qt::ArrowCursor);
-    setFocusPolicy(Qt::NoFocus);
-}
-
-void FancyIconButton::paintEvent(QPaintEvent *)
-{
-    const qreal pixelRatio = window()->windowHandle()->devicePixelRatio();
-    const QPixmap iconPixmap = icon().pixmap(sizeHint(), pixelRatio,
-                                             isEnabled() ? QIcon::Normal : QIcon::Disabled);
-    QStylePainter painter(this);
-    QRect pixmapRect(QPoint(), iconPixmap.size() / iconPixmap.devicePixelRatio());
-    pixmapRect.moveCenter(rect().center());
-
-    if (m_autoHide)
-        painter.setOpacity(m_iconOpacity);
-
-    painter.drawPixmap(pixmapRect, iconPixmap);
-
-    if (hasFocus()) {
-        QStyleOptionFocusRect focusOption;
-        focusOption.initFrom(this);
-        focusOption.rect = pixmapRect;
-        if (HostOsInfo::isMacHost()) {
-            focusOption.rect.adjust(-4, -4, 4, 4);
-            painter.drawControl(QStyle::CE_FocusFrame, focusOption);
-        } else {
-            painter.drawPrimitive(QStyle::PE_FrameFocusRect, focusOption);
-        }
-    }
-}
-
-void FancyIconButton::animateShow(bool visible)
-{
-    QPropertyAnimation *animation = new QPropertyAnimation(this, "iconOpacity");
-    animation->setDuration(FADE_TIME);
-    animation->setEndValue(visible ? 1.0 : 0.0);
-    animation->start(QAbstractAnimation::DeleteWhenStopped);
-}
-
-QSize FancyIconButton::sizeHint() const
-{
-    return icon().actualSize(QSize(32, 16)); // Find flags icon can be wider than 16px
-}
-
-void FancyIconButton::keyPressEvent(QKeyEvent *ke)
-{
-    QAbstractButton::keyPressEvent(ke);
-    if (!ke->modifiers() && (ke->key() == Qt::Key_Enter || ke->key() == Qt::Key_Return))
-        click();
-    // do not forward to line edit
-    ke->accept();
-}
-
-void FancyIconButton::keyReleaseEvent(QKeyEvent *ke)
-{
-    QAbstractButton::keyReleaseEvent(ke);
-    // do not forward to line edit
-    ke->accept();
-}
-
 } // namespace Utils
 
 #include <fancylineedit.moc>
