@@ -3,6 +3,7 @@
 
 #include "layoutbuilder.h"
 
+#include "completingtextedit.h"
 #include "fancylineedit.h"
 #include "filepath.h"
 #include "icon.h"
@@ -213,7 +214,7 @@ private:
             ++indexInRow;
         }
         // Finish the last row.
-        if (!testOnly)
+        if (!testOnly && !itemList.isEmpty())
             setItemGeometries(/*count=*/indexInRow, /*beforeIndex=*/itemList.size(), lineHeight);
 
         return y + lineHeight - rect.y() + bottom;
@@ -316,6 +317,11 @@ Object::Object(std::initializer_list<I> ps)
     apply(this, ps);
 }
 
+void Object::onDestroyed(QObject *guard, const std::function<void()> &func)
+{
+    QObject::connect(access(this), &QObject::destroyed, guard, func);
+}
+
 static QWidget *widgetForItem(QLayoutItem *item)
 {
     if (QWidget *w = item->widget())
@@ -387,6 +393,10 @@ static void addItemToFlowLayout(FlowLayout *layout, const LayoutItem &item)
  */
 
 // Layout
+Layout::Layout(Implementation *w)
+{
+    ptr = w;
+}
 
 void Layout::span(int cols, int rows)
 {
@@ -800,7 +810,9 @@ QWidget *Layout::emerge() const
 
 void Layout::show() const
 {
-    return emerge()->show();
+    auto wdgt = emerge();
+    wdgt->setAttribute(Qt::WidgetAttribute::WA_DeleteOnClose, true);
+    wdgt->show();
 }
 
 // "Widgets"
@@ -811,6 +823,11 @@ Widget::Widget(std::initializer_list<I> ps)
     apply(this, ps);
 }
 
+Widget::Widget(Implementation *w)
+{
+    ptr = w;
+}
+
 void Widget::setSize(int w, int h)
 {
     access(this)->resize(w, h);
@@ -1055,6 +1072,86 @@ void TextEdit::setReadOnly(bool on)
     access(this)->setReadOnly(on);
 }
 
+// CompletingTextEdit
+
+CompletingTextEdit::CompletingTextEdit(std::initializer_list<I> ps)
+{
+    ptr = new Implementation;
+    apply(this, ps);
+}
+
+QString CompletingTextEdit::markdown() const
+{
+    return access(this)->toMarkdown();
+}
+
+QString CompletingTextEdit::text() const
+{
+    return access(this)->toPlainText();
+}
+
+void CompletingTextEdit::setText(const QString &text)
+{
+    access(this)->setPlainText(text);
+}
+
+void CompletingTextEdit::setMarkdown(const QString &markdown)
+{
+    access(this)->setMarkdown(markdown);
+}
+
+void CompletingTextEdit::setReadOnly(bool on)
+{
+    access(this)->setReadOnly(on);
+}
+
+void CompletingTextEdit::setPlaceHolderText(const QString &text)
+{
+    access(this)->setPlaceholderText(text);
+}
+
+void CompletingTextEdit::setRightSideIconPath(const Utils::FilePath &path)
+{
+    access(this)->setRightSideIconPath(path);
+}
+
+void CompletingTextEdit::setCompleter(QCompleter *completer)
+{
+    access(this)->setCompleter(completer);
+}
+
+void CompletingTextEdit::onTextChanged(QObject *guard, const std::function<void(QString)> &func)
+{
+    QObject::connect(access(this), &Implementation::textChanged, guard, [func, this]() {
+        func(access(this)->toPlainText());
+    });
+}
+
+QCompleter *CompletingTextEdit::completer() const
+{
+    return access(this)->completer();
+}
+
+void CompletingTextEdit::onReturnPressed(QObject *guard, const std::function<void()> &func)
+{
+    QObject::connect(access(this), &Utils::CompletingTextEdit::returnPressed, guard, func);
+}
+
+void CompletingTextEdit::onRightSideIconClicked(QObject *guard, const std::function<void()> &func)
+{
+    QObject::connect(access(this), &Utils::CompletingTextEdit::rightSideIconClicked, guard, func);
+}
+
+Utils::CompletingTextEdit::CompletionBehavior CompletingTextEdit::completionBehavior() const
+{
+    return access(this)->completionBehavior();
+}
+
+void CompletingTextEdit::setCompletionBehavior(Utils::CompletingTextEdit::CompletionBehavior behavior)
+{
+    access(this)->setCompletionBehavior(behavior);
+}
+
 // PushButton
 
 PushButton::PushButton(std::initializer_list<I> ps)
@@ -1336,16 +1433,27 @@ void Canvas::setPaintFunction(const CanvasWidget::PaintFunction &paintFunction)
 
 // Special If
 
-If::If(
-    bool condition,
-    const std::initializer_list<Layout::I> ifcase,
-    const std::initializer_list<Layout::I> elsecase)
-    : used(condition ? ifcase : elsecase)
+If::If(bool condition)
+    : condition(condition)
 {}
 
-void addToLayout(Layout *layout, const If &inner)
+If::If(bool condition, const Items &list)
+    : condition(condition), list(list)
+{}
+
+If operator>>(const If &if_, const Then &then_)
 {
-    for (const Layout::I &item : inner.used)
+    return If(if_.condition, if_.condition ? then_.list : If::Items());
+}
+
+If operator>>(const If &if_, const Else &else_)
+{
+    return If(if_.condition, if_.condition ? If::Items() : else_.list);
+}
+
+void addToLayout(Layout *layout, const If &if_)
+{
+    for (const Layout::I &item : if_.list)
         item.apply(layout);
 }
 
