@@ -42,7 +42,7 @@ Q_GLOBAL_STATIC_WITH_ARGS(QString, linkSep, {"::"})
 
 QString OutputLineParser::createLinkTarget(const FilePath &filePath, int line = -1, int column = -1)
 {
-    return *linkPrefix() + filePath.toString() + *linkSep() + QString::number(line)
+    return *linkPrefix() + filePath.toUrlishString() + *linkSep() + QString::number(line)
             + *linkSep() + QString::number(column);
 }
 
@@ -130,7 +130,7 @@ FilePath OutputLineParser::absoluteFilePath(const FilePath &filePath) const
     if (candidates.count() == 1)
         return candidates.first();
 
-    QString fp = filePath.toString();
+    QString fp = filePath.toUrlishString();
     while (fp.startsWith("../"))
         fp.remove(0, 3);
     bool found = false;
@@ -149,7 +149,7 @@ void OutputLineParser::addLinkSpecForAbsoluteFilePath(
     int pos,
     int len)
 {
-    if (filePath.toFileInfo().isAbsolute())
+    if (filePath.isAbsolutePath())
         linkSpecs.append({pos, len, createLinkTarget(filePath, lineNo, column)});
 }
 
@@ -218,8 +218,8 @@ public:
     PostPrintAction postPrintAction;
     bool boldFontEnabled = true;
     bool prependCarriageReturn = false;
-    bool prependLineFeed = false;
     bool forwardStdOutToStdError = false;
+    QColor explicitBackground;
 };
 
 OutputFormatter::OutputFormatter() : d(new Private) { }
@@ -287,17 +287,26 @@ void OutputFormatter::overridePostPrintAction(const PostPrintAction &postPrintAc
     d->postPrintAction = postPrintAction;
 }
 
-static void checkAndFineTuneColors(QTextCharFormat *format)
+static void checkAndFineTuneColors(QTextCharFormat *format, const QColor &background)
 {
     QTC_ASSERT(format, return);
-    const QColor fgColor = StyleHelper::ensureReadableOn(format->background().color(),
+    const QColor bgColor = background.isValid()
+            ? background
+            : (format->hasProperty(QTextCharFormat::BackgroundBrush)
+               ? format->background().color()
+               : Utils::creatorColor(Theme::PaletteBase));
+    const QColor fgColor = StyleHelper::ensureReadableOn(bgColor,
                                                          format->foreground().color());
     format->setForeground(fgColor);
 }
 
-void OutputFormatter::doAppendMessage(const QString &text, OutputFormat format)
+void OutputFormatter::doAppendMessage(const QString &text, OutputFormat format, LineStatus lineStatus)
 {
     QTextCharFormat charFmt = charFormat(format);
+    const auto addNewlineIfApplicable = [&] {
+        if (lineStatus == LineStatus::Complete)
+            append("\n", charFmt);
+    };
 
     QList<FormattedText> formattedText = parseAnsi(text, charFmt);
     const QString cleanLine = std::accumulate(formattedText.begin(), formattedText.end(), QString(),
@@ -314,23 +323,24 @@ void OutputFormatter::doAppendMessage(const QString &text, OutputFormat format)
                 ? *res.formatOverride : outputTypeForParser(involvedParsers.last(), format);
         if (formatForParser != format && cleanLine == text && formattedText.length() == 1) {
             charFmt = charFormat(formatForParser);
-            checkAndFineTuneColors(&charFmt);
+            checkAndFineTuneColors(&charFmt, d->explicitBackground);
             formattedText.first().format = charFmt;
         }
     }
 
     if (res.newContent) {
-        append(res.newContent.value(), charFmt);
+        append(*res.newContent, charFmt);
+        addNewlineIfApplicable();
         return;
     }
 
     const QList<FormattedText> linkified = linkifiedText(formattedText, res.linkSpecs);
     for (FormattedText output : linkified) {
-        checkAndFineTuneColors(&output.format);
+        checkAndFineTuneColors(&output.format, d->explicitBackground);
         append(output.text, output.format);
+        charFmt = output.format;
     }
-    if (linkified.isEmpty())
-        append({}, charFmt); // This might cause insertion of a newline character.
+    addNewlineIfApplicable();
 
     for (OutputLineParser * const p : std::as_const(involvedParsers)) {
         if (d->postPrintAction)
@@ -464,7 +474,6 @@ void OutputFormatter::append(const QString &text, const QTextCharFormat &format)
 {
     if (!plainTextEdit())
         return;
-    flushTrailingNewline();
     int startPos = 0;
     int crPos = -1;
     while ((crPos = text.indexOf('\r', startPos)) >= 0)  {
@@ -528,18 +537,10 @@ void OutputFormatter::initFormats()
 void OutputFormatter::flushIncompleteLine()
 {
     clearLastLine();
-    doAppendMessage(d->incompleteLine.first, d->incompleteLine.second);
+    doAppendMessage(d->incompleteLine.first, d->incompleteLine.second, LineStatus::Incomplete);
     d->incompleteLine.first.clear();
 }
 
-void Utils::OutputFormatter::flushTrailingNewline()
-{
-    if (d->prependLineFeed) {
-        d->cursor.insertText("\n");
-        d->prependLineFeed = false;
-    }
-}
-
 void OutputFormatter::dumpIncompleteLine(const QString &line, OutputFormat format)
 {
     if (line.isEmpty())
@@ -604,11 +605,15 @@ void OutputFormatter::setForwardStdOutToStdError(bool enabled)
     d->forwardStdOutToStdError = enabled;
 }
 
+void Utils::OutputFormatter::setExplicitBackgroundColor(const QColor &color)
+{
+    d->explicitBackground = color;
+}
+
 void OutputFormatter::flush()
 {
     if (!d->incompleteLine.first.isEmpty())
         flushIncompleteLine();
-    flushTrailingNewline();
     d->escapeCodeHandler.endFormatScope();
     for (OutputLineParser * const p : std::as_const(d->lineParsers))
         p->flush();
@@ -684,16 +689,17 @@ void OutputFormatter::appendMessage(const QString &text, OutputFormat format)
 
     // Forward all complete lines to the specialized formatting code, and handle a
     // potential trailing incomplete line the same way as above.
+    d->cursor.beginEditBlock();
     for (int startPos = 0; ;) {
         const int eolPos = out.indexOf('\n', startPos);
         if (eolPos == -1) {
             dumpIncompleteLine(out.mid(startPos), format);
             break;
         }
-        doAppendMessage(out.mid(startPos, eolPos - startPos), format);
-        d->prependLineFeed = true;
+        doAppendMessage(out.mid(startPos, eolPos - startPos), format, LineStatus::Complete);
         startPos = eolPos + 1;
     }
+    d->cursor.endEditBlock();
 }
 
 } // namespace Utils
