@@ -1,5 +1,5 @@
 // Copyright (C) 2020 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -8,19 +8,26 @@
 #include <QWidget>
 
 #include <functional>
+#include <memory>
 
 namespace Utils {
 
+namespace Internal {
+class OverlayWidgetPrivate;
+}
+
 class QTCREATOR_UTILS_EXPORT OverlayWidget : public QWidget
 {
-    Q_OBJECT
 public:
     using PaintFunction = std::function<void(QWidget *, QPainter &, QPaintEvent *)>;
+    using ResizeFunction = std::function<void(QWidget *, QSize)>;
 
     explicit OverlayWidget(QWidget *parent = nullptr);
+    ~OverlayWidget();
 
     void attachToWidget(QWidget *parent);
     void setPaintFunction(const PaintFunction &paint);
+    void setResizeFunction(const ResizeFunction &resize);
 
 protected:
     bool eventFilter(QObject *obj, QEvent *ev) override;
@@ -29,7 +36,7 @@ protected:
 private:
     void resizeToParent();
 
-    PaintFunction m_paint;
+    std::unique_ptr<Internal::OverlayWidgetPrivate> d;
 };
 
 } // namespace Utils
