@@ -227,10 +227,34 @@ ExecutableItem portsFromProcessRecipe(const Storage<PortsInputData> &input,
             const QString stdErr = process.stdErr();
             const QString outputString
                 = stdErr.isEmpty() ? stdErr : Tr::tr("Remote error output was: %1").arg(stdErr);
-            *output = make_unexpected(Utils::joinStrings({errorString, outputString}, '\n'));
+            *output = ResultError(Utils::joinStrings({errorString, outputString}, '\n'));
         }
     };
     return ProcessTask(onSetup, onDone);
 }
 
+PortListAspect::PortListAspect(AspectContainer *container)
+    : StringAspect(container)
+{
+    setDisplayStyle(StringAspect::DisplayStyle::LineEditDisplay);
+    setValidatorFactory([](QObject *parent) {
+        return new QRegularExpressionValidator(QRegularExpression(PortList::regularExpression()), parent);
+    });
+}
+
+void PortListAspect::addToLayoutImpl(Layouting::Layout &parent)
+{
+    StringAspect::addToLayoutImpl(parent);
+}
+
+void PortListAspect::setPortList(const PortList &ports)
+{
+    setValue(ports.toString());
+}
+
+PortList PortListAspect::portList() const
+{
+    return PortList::fromString(value());
+}
+
 } // namespace Utils
