@@ -10,8 +10,6 @@
 
 namespace Utils {
 
-static QtcSettings *s_settings = nullptr;
-
 TerminalCommand::TerminalCommand(const FilePath &command, const QString &openArgs,
                                  const QString &executeArgs, bool needsQuotes)
     : command(command)
@@ -37,11 +35,6 @@ bool TerminalCommand::operator<(const TerminalCommand &other) const
     return command < other.command;
 }
 
-void TerminalCommand::setSettings(QtcSettings *settings)
-{
-    s_settings = settings;
-}
-
 Q_GLOBAL_STATIC_WITH_ARGS(const QList<TerminalCommand>, knownTerminals, (
 {
     {"x-terminal-emulator", "", "-e"},
@@ -110,8 +103,9 @@ const char kTerminalExecuteOptionsKey[] = "General/Terminal/ExecuteOptions";
 TerminalCommand TerminalCommand::terminalEmulator()
 {
     TerminalCommand cmd;
-    if (s_settings && HostOsInfo::isAnyUnixHost() && s_settings->contains(kTerminalCommandKey)) {
-        FilePath command = FilePath::fromSettings(s_settings->value(kTerminalCommandKey));
+    QtcSettings &settings = Utils::userSettings();
+    if (HostOsInfo::isAnyUnixHost() && settings.contains(kTerminalCommandKey)) {
+        FilePath command = FilePath::fromSettings(settings.value(kTerminalCommandKey));
 
         // TODO Remove some time after Qt Creator 11
         // Work around Qt Creator <= 10 writing the default terminal to the settings.
@@ -123,8 +117,8 @@ TerminalCommand TerminalCommand::terminalEmulator()
                 return known.command.fileName() == fileName;
             });
         cmd = {command,
-               s_settings->value(kTerminalOpenOptionsKey).toString(),
-               s_settings->value(kTerminalExecuteOptionsKey).toString(),
+               settings.value(kTerminalOpenOptionsKey).toString(),
+               settings.value(kTerminalExecuteOptionsKey).toString(),
                knownCommand.needsQuotes};
     } else {
         cmd = defaultTerminalEmulator();
@@ -145,16 +139,17 @@ TerminalCommand TerminalCommand::terminalEmulator()
 
 void TerminalCommand::setTerminalEmulator(const TerminalCommand &term)
 {
-    if (s_settings && HostOsInfo::isAnyUnixHost()) {
-        s_settings->setValue(kTerminalVersionKey, kTerminalVersion);
+    if (HostOsInfo::isAnyUnixHost()) {
+        QtcSettings &settings = Utils::userSettings();
+        settings.setValue(kTerminalVersionKey, kTerminalVersion);
         if (term == defaultTerminalEmulator()) {
-            s_settings->remove(kTerminalCommandKey);
-            s_settings->remove(kTerminalOpenOptionsKey);
-            s_settings->remove(kTerminalExecuteOptionsKey);
+            settings.remove(kTerminalCommandKey);
+            settings.remove(kTerminalOpenOptionsKey);
+            settings.remove(kTerminalExecuteOptionsKey);
         } else {
-            s_settings->setValue(kTerminalCommandKey, term.command.toSettings());
-            s_settings->setValue(kTerminalOpenOptionsKey, term.openArgs);
-            s_settings->setValue(kTerminalExecuteOptionsKey, term.executeArgs);
+            settings.setValue(kTerminalCommandKey, term.command.toSettings());
+            settings.setValue(kTerminalOpenOptionsKey, term.openArgs);
+            settings.setValue(kTerminalExecuteOptionsKey, term.executeArgs);
         }
     }
 }
