@@ -5,7 +5,7 @@
 
 #include "../utils_global.h"
 
-#include <utils/expected.h>
+#include <utils/result.h>
 
 #include <QBrush> // QGradientStops
 #include <QObject>
@@ -171,6 +171,7 @@ public:
 
         CodeModel_Error_TextMarkColor,
         CodeModel_Warning_TextMarkColor,
+        CodeModel_Info_TextMarkColor,
 
         /* Output panes */
 
@@ -219,6 +220,7 @@ public:
         Token_Text_Muted,
         Token_Text_Subtle,
         Token_Text_Accent,
+        Token_Text_On_Accent,
         Token_Stroke_Strong,
         Token_Stroke_Muted,
         Token_Stroke_Subtle,
@@ -252,6 +254,7 @@ public:
 
         /* VcsBase Plugin */
         VcsBase_FileStatusUnknown_TextColor,
+        VcsBase_FileUntracked_TextColor,
         VcsBase_FileAdded_TextColor,
         VcsBase_FileModified_TextColor,
         VcsBase_FileDeleted_TextColor,
@@ -308,6 +311,48 @@ public:
         DStextSelectionColor,
         DStextSelectedTextColor,
 
+        /*New Creator Semantics for qtds*/
+
+        DS_base_black,
+        DS_base_white,
+
+        DS_accent_default,
+        DS_accent_muted,
+        DS_accent_subtle,
+
+        DS_background_default,
+        DS_background_muted,
+        DS_background_subtle,
+
+        DS_forground_default,
+        DS_foreground_muted,
+        DS_foreground_subtle,
+
+        DS_text_default,
+        DS_text_muted,
+        DS_text_subtle,
+        DS_text_accent,
+
+        DS_stroke_strong,
+        DS_stroke_muted,
+        DS_stroke_subtle,
+
+        DS_notification_alert_default,
+        DS_notification_alert_muted,
+        DS_notification_alert_subtle,
+
+        DS_notification_neutral_default,
+        DS_notification_neutral_muted,
+        DS_notification_neutral_subtle,
+
+        DS_notification_danger_default,
+        DS_notification_danger_muted,
+        DS_notification_danger_subtle,
+
+        DS_notification_success_default,
+        DS_notification_success_muted,
+        DS_notification_success_subtle,
+
         /*NEW for QtDS 4.0*/
         DScontrolBackground_toolbarIdle,
         DScontrolBackground_toolbarHover,
@@ -401,6 +446,7 @@ public:
         DSactionJIT,
 
         DStableHeaderBackground,
+        DStableCellCurrent,
         DStableHeaderText,
 
         DSdockContainerBackground,
@@ -553,14 +599,15 @@ public:
 
     void readSettings(QSettings &settings);
 
-    static bool systemUsesDarkMode();
+    Qt::ColorScheme colorScheme() const;
+    static Qt::ColorScheme systemColorScheme();
     static QPalette initialPalette();
 
     static void setInitialPalette(Theme *initTheme);
 
     static void setHelpMenu(QMenu *menu);
 
-    static expected_str<Color> colorToken(const QString &token, TokenFlags flags = {});
+    static Result<Color> colorToken(const QString &token, TokenFlags flags = {});
     static Color highlightFor(Color role);
 
 protected:
