@@ -1,33 +1,10 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
 #include "../utils_global.h"
 
-#include <QSharedPointer>
 #include <QObject>
 #include <QPointer>
 #include <QTimer>
@@ -74,13 +51,22 @@ public:
 
     static void show(const QPoint &pos, const QString &content, QWidget *w = nullptr,
                      const QVariant &contextHelp = {}, const QRect &rect = QRect());
-    static void show(const QPoint &pos, const QColor &color, QWidget *w = nullptr,
-                     const QVariant &contextHelp = {}, const QRect &rect = QRect());
+    static void show(const QPoint &pos,
+                     const QString &content,
+                     Qt::TextFormat format,
+                     QWidget *w = nullptr,
+                     const QVariant &contextHelp = {},
+                     const QRect &rect = QRect());
+    static void show(const QPoint &pos,
+                     const QColor &color,
+                     QWidget *w = nullptr,
+                     const QVariant &contextHelp = {},
+                     const QRect &rect = QRect());
     static void show(const QPoint &pos, QWidget *content, QWidget *w = nullptr,
                      const QVariant &contextHelp = {}, const QRect &rect = QRect());
     static void show(const QPoint &pos, QLayout *content, QWidget *w = nullptr,
                      const QVariant &contextHelp = {}, const QRect &rect = QRect());
-    static void move(const QPoint &pos, QWidget *w);
+    static void move(const QPoint &pos);
     static void hide();
     static void hideImmediately();
     static bool isVisible();
@@ -107,7 +93,7 @@ private:
     bool tipChanged(const QPoint &pos, const QVariant &content, int typeId, QWidget *w,
                     const QVariant &contextHelp) const;
     void setTipRect(QWidget *w, const QRect &rect);
-    void placeTip(const QPoint &pos, QWidget *w);
+    void placeTip(const QPoint &pos);
     void showTip();
     void hideTipWithDelay();
 
