@@ -136,15 +136,18 @@ class AndroidPlugin final : public ExtensionSystem::IPlugin
     void askUserAboutAndroidSetup()
     {
         NANOTRACE_SCOPE("Android", "AndroidPlugin::askUserAboutAndroidSetup");
-        if (!Core::ICore::infoBar()->canInfoBeAdded(kSetupAndroidSetting))
+        Utils::InfoBar *infoBar = Core::ICore::popupInfoBar();
+        if (!infoBar->canInfoBeAdded(kSetupAndroidSetting))
             return;
 
         Utils::InfoBarEntry
             info(kSetupAndroidSetting,
-                 Tr::tr("Would you like to configure Android options? This will ensure "
-                        "Android kits can be usable and all essential packages are installed. "
-                        "To do it later, select Edit > Preferences > Devices > Android."),
+                 Tr::tr("Automatically create usable Android kits and install all essential "
+                        "packages. "
+                        "To do this later, select Edit > Preferences > SDKs > Android."),
                  Utils::InfoBarEntry::GlobalSuppression::Enabled);
+        info.setTitle(Tr::tr("Configure Android Options?"));
+        info.setInfoType(Utils::InfoLabel::Information);
         info.addCustomButton(
             Tr::tr("Configure Android"),
             [this] {
@@ -154,7 +157,7 @@ class AndroidPlugin final : public ExtensionSystem::IPlugin
             },
             {},
             Utils::InfoBarEntry::ButtonAction::SuppressPersistently);
-        Core::ICore::infoBar()->addInfo(info);
+        infoBar->addInfo(info);
     }
 };
 
