@@ -16,6 +16,7 @@
 #include <utils/layoutbuilder.h>
 #include <utils/outputformatter.h>
 #include <utils/qtcprocess.h>
+#include <utils/textcodec.h>
 
 #include <QDialogButtonBox>
 #include <QLabel>
@@ -25,7 +26,6 @@
 #include <QPointer>
 #include <QProgressBar>
 #include <QRegularExpression>
-#include <QTextCodec>
 
 namespace {
 Q_LOGGING_CATEGORY(sdkManagerLog, "qtc.android.sdkManager", QtWarningMsg)
@@ -45,8 +45,8 @@ class QuestionProgressDialog : public QDialog
     Q_OBJECT
 
 public:
-    QuestionProgressDialog(QWidget *parent)
-        : QDialog(parent)
+    QuestionProgressDialog()
+        : QDialog(Core::ICore::dialogParent())
         , m_outputTextEdit(new QPlainTextEdit)
         , m_questionLabel(new QLabel(Tr::tr("Do you want to accept the Android SDK license?")))
         , m_answerButtonBox(new QDialogButtonBox)
@@ -158,7 +158,7 @@ static std::optional<int> parseProgress(const QString &out)
 
 struct DialogStorage
 {
-    DialogStorage() { m_dialog.reset(new QuestionProgressDialog(Core::ICore::dialogParent())); };
+    DialogStorage() { m_dialog.reset(new QuestionProgressDialog); };
     std::unique_ptr<QuestionProgressDialog> m_dialog;
 };
 
@@ -190,8 +190,7 @@ static GroupItem licensesRecipe(const Storage<DialogStorage> &dialogStorage)
         OutputData *outputPtr = outputStorage.activeStorage();
         QObject::connect(processPtr, &Process::readyReadStandardOutput, dialog,
                          [processPtr, outputPtr, dialog] {
-            QTextCodec *codec = QTextCodec::codecForLocale();
-            const QString stdOut = codec->toUnicode(processPtr->readAllRawStandardOutput());
+            const QString stdOut = processPtr->readAllStandardOutput();
             outputPtr->buffer += stdOut;
             dialog->appendMessage(stdOut, StdOutFormat);
             const auto progress = parseProgress(stdOut);
@@ -241,15 +240,13 @@ static void setupSdkProcess(const QStringList &args, Process *process,
                          args + AndroidConfig::sdkManagerToolArgs()});
     QObject::connect(process, &Process::readyReadStandardOutput, dialog,
                      [process, dialog, current, total] {
-        QTextCodec *codec = QTextCodec::codecForLocale();
-        const auto progress = parseProgress(codec->toUnicode(process->readAllRawStandardOutput()));
+        const auto progress = parseProgress(process->readAllStandardOutput());
         if (!progress)
             return;
         dialog->setProgress((current * 100.0 + *progress) / total);
     });
     QObject::connect(process, &Process::readyReadStandardError, dialog, [process, dialog] {
-        QTextCodec *codec = QTextCodec::codecForLocale();
-        dialog->appendMessage(codec->toUnicode(process->readAllRawStandardError()), StdErrFormat);
+        dialog->appendMessage(process->readAllStandardError(), StdErrFormat);
     });
 };
 
@@ -358,7 +355,7 @@ public:
     AndroidSdkPackageList m_allPackages;
     FilePath lastSdkManagerPath;
     bool m_packageListingSuccessful = false;
-    TaskTreeRunner m_taskTreeRunner;
+    SingleTaskTreeRunner m_taskTreeRunner;
 };
 
 AndroidSdkManager::AndroidSdkManager() : m_d(new AndroidSdkManagerPrivate(*this)) {}
@@ -571,19 +568,19 @@ void AndroidSdkManagerPrivate::runDialogRecipe(const Storage<DialogStorage> &dia
         return std::make_pair(dialogStorage->m_dialog.get(), &QDialog::accepted);
     };
     const auto onError = [dialogStorage] { dialogStorage->m_dialog->setDone(); };
-    const Group root {
+    const Group recipe {
         dialogStorage,
         Group {
             If (!Group {
-                    licensesRecipe,
-                    Sync([dialogStorage] { dialogStorage->m_dialog->setQuestionVisible(false); }),
-                    continuationRecipe
-                }) >> Then {
+                licensesRecipe,
+                Sync([dialogStorage] { dialogStorage->m_dialog->setQuestionVisible(false); }),
+                continuationRecipe
+            }) >> Then {
                 Sync(onError).withAccept(onAcceptSetup)
             }
         }.withCancel(onCancelSetup)
     };
-    m_taskTreeRunner.start(root, {}, [this](DoneWith) {
+    m_taskTreeRunner.start(recipe, {}, [this] {
         QMetaObject::invokeMethod(&m_sdkManager, &AndroidSdkManager::reloadPackages,
                                   Qt::QueuedConnection);
     });
