@@ -80,7 +80,7 @@ private:
     bool isDefaultNdkSelected() const;
     void validateOpenSsl();
 
-    Tasking::TaskTreeRunner m_sdkDownloader;
+    Tasking::SingleTaskTreeRunner m_sdkDownloader;
     bool m_isInitialReloadDone = false;
 
     SummaryWidget *m_androidSummary = nullptr;
@@ -290,7 +290,6 @@ AndroidSettingsWidget::AndroidSettingsWidget()
     using namespace Layouting;
 
     Column {
-        Tr::tr("All changes on this page take effect immediately."),
         Group {
             title(Tr::tr("Android Settings")),
             Grid {
@@ -334,7 +333,8 @@ AndroidSettingsWidget::AndroidSettingsWidget()
                 Span(4, openSslDetailsWidget)
             }
         },
-        st
+        st,
+        Tr::tr("All changes on this page take effect immediately.")
     }.attachTo(this);
 
     connect(m_sdkLocationPathChooser, &PathChooser::rawPathChanged,
@@ -376,7 +376,7 @@ AndroidSettingsWidget::AndroidSettingsWidget()
     connect(sdkManagerToolButton, &QAbstractButton::clicked, this, &executeAndroidSdkManagerDialog);
     connect(sdkToolsAutoDownloadButton, &QAbstractButton::clicked,
             this, &AndroidSettingsWidget::downloadSdk);
-    connect(&m_sdkDownloader, &Tasking::TaskTreeRunner::done, this, [this](Tasking::DoneWith result) {
+    connect(&m_sdkDownloader, &Tasking::SingleTaskTreeRunner::done, this, [this](Tasking::DoneWith result) {
         if (result != Tasking::DoneWith::Success)
             return;
         // Make sure the sdk path is created before installing packages
@@ -634,7 +634,7 @@ void AndroidSettingsWidget::downloadOpenSslRepo(const bool silent)
 
     connect(openSslProgressDialog, &QProgressDialog::canceled, gitCloner, &QObject::deleteLater);
 
-    const auto failDialog = [=](const QString &msgSuffix = {}) {
+    const auto failDialog = [openSslRepo](const QString &msgSuffix = {}) {
         QStringList sl;
         sl << Tr::tr("OpenSSL prebuilt libraries cloning failed.");
         if (!msgSuffix.isEmpty())
