@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "gtestvisitors.h"
 #include "gtest_utils.h"
@@ -62,7 +62,7 @@ bool GTestVisitor::visit(CPlusPlus::FunctionDefinitionAST *ast)
             testSuiteName = QString::fromUtf8(parameter1.spell());
             testCaseName = QString::fromUtf8(parameter2.spell());
             // test (suite) name needs to be a alpha numerical literal ( _ and $ allowed)
-            const QRegularExpression alnum("^[[:alnum:]_$]+$");
+            static const QRegularExpression alnum("^[[:alnum:]_$]+$");
             // test suite must not start with a number, test case may
             if (!alnum.match(testSuiteName).hasMatch()
                     || (!testSuiteName.isEmpty() && testSuiteName.at(0).isNumber())) {
@@ -91,7 +91,7 @@ bool GTestVisitor::visit(CPlusPlus::FunctionDefinitionAST *ast)
     int line = 0;
     int column = 0;
     unsigned token = id->firstToken();
-    m_document->translationUnit()->getTokenStartPosition(token, &line, &column);
+    m_document->translationUnit()->getTokenPosition(token, &line, &column);
 
     GTestCodeLocationAndType locationAndType;
     locationAndType.m_name = testCaseName;
