@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -9,9 +9,11 @@
 #include <cppeditor/cppworkingcopy.h>
 #include <qmljs/qmljsdocument.h>
 
-#include <QFutureInterface>
+#include <optional>
 
 QT_BEGIN_NAMESPACE
+template <class T>
+class QPromise;
 class QRegularExpression;
 QT_END_NAMESPACE
 
@@ -27,7 +29,7 @@ public:
 
     virtual TestTreeItem *createTestTreeItem() const = 0;
 
-    QVector<TestParseResult *> children;
+    QList<TestParseResult *> children;
     ITestFramework *framework;
     TestTreeItem::Type itemType = TestTreeItem::Root;
     QString displayName;
@@ -38,16 +40,17 @@ public:
     int column = 0;
 };
 
-using TestParseResultPtr = QSharedPointer<TestParseResult>;
-
 class ITestParser
 {
 public:
     explicit ITestParser(ITestFramework *framework) : m_framework(framework) {}
     virtual ~ITestParser() { }
-    virtual void init(const Utils::FilePaths &filesToParse, bool fullParse) = 0;
-    virtual bool processDocument(QFutureInterface<TestParseResultPtr> &futureInterface,
+    virtual void init(const QSet<Utils::FilePath> &filesToParse, bool fullParse) = 0;
+    virtual bool processDocument(QPromise<TestParseResultPtr> &futureInterface,
                                  const Utils::FilePath &fileName) = 0;
+
+    virtual QStringList supportedExtensions() const { return {}; }
+
     virtual void release() = 0;
 
     ITestFramework *framework() const { return m_framework; }
@@ -60,7 +63,7 @@ class CppParser : public ITestParser
 {
 public:
     explicit CppParser(ITestFramework *framework);
-    void init(const Utils::FilePaths &filesToParse, bool fullParse) override;
+    void init(const QSet<Utils::FilePath> &filesToParse, bool fullParse) override;
     static bool selectedForBuilding(const Utils::FilePath &fileName);
     QByteArray getFileContent(const Utils::FilePath &filePath) const;
     void release() override;
@@ -73,6 +76,9 @@ public:
     static bool precompiledHeaderContains(const CPlusPlus::Snapshot &snapshot,
                                           const Utils::FilePath &filePath,
                                           const QRegularExpression &headerFileRegex);
+    // returns all files of the startup project whose ProjectPart has the given \a macroName
+    // set as a project define
+    static std::optional<QSet<Utils::FilePath>> filesContainingMacro(const QByteArray &macroName);
 
 protected:
     CPlusPlus::Snapshot m_cppSnapshot;
