@@ -23,62 +23,49 @@
 #include <projectexplorer/target.h>
 #include <projectexplorer/toolchain.h>
 
+#include <solutions/tasking/barrier.h>
+
 #include <utils/portlist.h>
 #include <utils/qtcprocess.h>
 #include <utils/qtcassert.h>
 
 using namespace Debugger;
 using namespace ProjectExplorer;
+using namespace Tasking;
 using namespace Utils;
 
 namespace BareMetal::Internal {
 
-class BareMetalDebugSupport final : public Debugger::DebuggerRunTool
-{
-public:
-    explicit BareMetalDebugSupport(RunControl *runControl)
-        : Debugger::DebuggerRunTool(runControl)
-    {
-        const auto dev = std::static_pointer_cast<const BareMetalDevice>(runControl->device());
-        if (!dev) {
-            reportFailure(Tr::tr("Cannot debug: Kit has no device."));
-            return;
-        }
-
-        const QString providerId = dev->debugServerProviderId();
-        IDebugServerProvider *p = DebugServerProviderManager::findProvider(providerId);
-        if (!p) {
-            reportFailure(Tr::tr("No debug server provider found for %1").arg(providerId));
-            return;
-        }
-
-        if (RunWorker *runner = p->targetRunner(runControl))
-            addStartDependency(runner);
-    }
-
-private:
-    void start() final
-    {
-        const auto dev = std::static_pointer_cast<const BareMetalDevice>(runControl()->device());
-        QTC_ASSERT(dev, reportFailure(); return);
-        IDebugServerProvider *p = DebugServerProviderManager::findProvider(
-            dev->debugServerProviderId());
-        QTC_ASSERT(p, reportFailure(); return);
-
-        QString errorMessage;
-        if (!p->aboutToRun(this, errorMessage))
-            reportFailure(errorMessage);
-        else
-            DebuggerRunTool::start();
-    }
-};
-
 class BareMetalDebugSupportFactory final : public RunWorkerFactory
 {
 public:
     BareMetalDebugSupportFactory()
     {
-        setProduct<BareMetalDebugSupport>();
+        setId("BareMetalDebugSupportFactory");
+        setRecipeProducer([](RunControl *runControl) -> Group {
+            const auto dev = std::static_pointer_cast<const BareMetalDevice>(runControl->device());
+            if (!dev)
+                return runControl->errorTask(Tr::tr("Cannot debug: Kit has no device."));
+
+            const QString providerId = dev->debugServerProviderId();
+            IDebugServerProvider *p = DebugServerProviderManager::findProvider(providerId);
+            if (!p)
+                return runControl->errorTask(Tr::tr("No debug server provider found for %1").arg(providerId));
+
+            DebuggerRunParameters rp = DebuggerRunParameters::fromRunControl(runControl);
+            if (Result<> res = p->setupDebuggerRunParameters(rp, runControl); !res)
+                return runControl->errorTask(res.error());
+
+            const std::optional<ProcessTask> targetRunner = p->targetProcess(runControl);
+            if (!targetRunner)
+                return debuggerRecipe(runControl, rp);
+
+            return {
+                When (*targetRunner, &Process::started, WorkflowPolicy::StopOnSuccessOrError) >> Do {
+                    debuggerRecipe(runControl, rp)
+                }
+            };
+        });
         addSupportedRunMode(ProjectExplorer::Constants::NORMAL_RUN_MODE);
         addSupportedRunMode(ProjectExplorer::Constants::DEBUG_RUN_MODE);
         addSupportedRunConfig(BareMetal::Constants::BAREMETAL_RUNCONFIG_ID);
