@@ -1,30 +1,10 @@
-/****************************************************************************
-**
-** Copyright (C) 2020 Denis Shienkov <denis.shienkov@gmail.com>
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2020 Denis Shienkov <denis.shienkov@gmail.com>
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "uvtargetdevicemodel.h"
 
+#include <baremetal/baremetaltr.h>
+
 #include <utils/algorithm.h>
 
 #include <QDirIterator>
@@ -34,27 +14,21 @@
 
 using namespace Utils;
 
-namespace BareMetal {
-namespace Internal {
-namespace Uv {
+namespace BareMetal::Internal::Uv {
 
 static QString extractPacksPath(const FilePath &toolsIniFile)
 {
-    QFile f(toolsIniFile.toString());
+    QFile f(toolsIniFile.toFSPathString());
     if (!f.open(QIODevice::ReadOnly))
         return {};
     QTextStream in(&f);
     while (!in.atEnd()) {
         const QByteArray line = f.readLine().trimmed();
-        const auto startIndex = line.indexOf("RTEPATH=\"");
-        const auto stopIndex = line.lastIndexOf('"');
-        if (startIndex != 0 || (stopIndex + 1) != line.size())
+        static constexpr QByteArrayView rtepath = "RTEPATH=\"";
+        if (!line.startsWith(rtepath) || !line.endsWith('"'))
             continue;
-        const QFileInfo path(QString::fromUtf8(line.mid(startIndex + 9,
-                                                        stopIndex - startIndex - 9)));
-        if (!path.exists())
-            return {};
-        return path.absoluteFilePath();
+        const QFileInfo path(QString::fromUtf8(line.mid(rtepath.length()).chopped(1)));
+        return path.exists() ? path.absoluteFilePath() : QString{};
     }
     return {};
 }
@@ -210,7 +184,7 @@ public:
 DeviceSelectionModel::DeviceSelectionModel(QObject *parent)
     : TreeModel<DeviceSelectionItem>(parent)
 {
-    setHeader({tr("Name"), tr("Version"), tr("Vendor")});
+    setHeader({Tr::tr("Name"), Tr::tr("Version"), Tr::tr("Vendor")});
 }
 
 void DeviceSelectionModel::fillAllPacks(const FilePath &toolsIniFile)
@@ -237,7 +211,7 @@ void DeviceSelectionModel::fillAllPacks(const FilePath &toolsIniFile)
 
     if (allPackFiles.isEmpty())
         return;
-    for (const QString &packFile : qAsConst(allPackFiles))
+    for (const QString &packFile : std::as_const(allPackFiles))
         parsePackage(packFile);
 }
 
@@ -500,6 +474,4 @@ DeviceSelection DeviceSelectionView::buildSelection(const DeviceSelectionItem *i
     return selection;
 }
 
-} // namespace Uv
-} // namespace Internal
-} // namespace BareMetal
+} // BareMetal::Internal::Uv
