@@ -1,10 +1,11 @@
 // Copyright (C) 2020 Denis Shienkov <denis.shienkov@gmail.com>
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
 #include <utils/basetreeview.h>
 #include <utils/treemodel.h>
+#include <utils/store.h>
 
 QT_BEGIN_NAMESPACE
 class QComboBox;
@@ -23,8 +24,8 @@ public:
     int index = 0;
     int cpuDllIndex = 0;
 
-    QVariantMap toMap() const;
-    void fromMap(const QVariantMap &map);
+    Utils::Store toMap() const;
+    void fromMap(const Utils::Store &map);
 
     bool operator==(const DriverSelection &other) const;
 };
