@@ -1,9 +1,10 @@
 // Copyright (C) 2016 Lorenz Haas
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "configurationpanel.h"
 
-#include "abstractsettings.h"
+#include "beautifiertool.h"
+#include "beautifiertr.h"
 #include "configurationdialog.h"
 
 #include <utils/layoutbuilder.h>
@@ -16,23 +17,22 @@ namespace Beautifier::Internal {
 ConfigurationPanel::ConfigurationPanel(QWidget *parent)
     : QWidget(parent)
 {
-    resize(595, 23);
-
     m_configurations = new QComboBox;
     m_configurations->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
 
-    m_edit = new QPushButton(tr("Edit"));
-    m_remove = new QPushButton(tr("Remove"));
-    auto add = new QPushButton(tr("Add"));
+    m_edit = new QPushButton(Tr::tr("Edit"));
+    m_remove = new QPushButton(Tr::tr("Remove"));
+    auto add = new QPushButton(Tr::tr("Add"));
 
-    using namespace Utils::Layouting;
+    using namespace Layouting;
 
     Row {
         m_configurations,
         m_edit,
         m_remove,
-        add
-    }.attachTo(this, WithoutMargins);
+        add,
+        noMargin,
+    }.attachTo(this);
 
     connect(add, &QPushButton::clicked, this, &ConfigurationPanel::add);
     connect(m_edit, &QPushButton::clicked, this, &ConfigurationPanel::edit);
@@ -70,7 +70,7 @@ void ConfigurationPanel::remove()
 void ConfigurationPanel::add()
 {
     ConfigurationDialog dialog;
-    dialog.setWindowTitle(tr("Add Configuration"));
+    dialog.setWindowTitle(Tr::tr("Add Configuration"));
     dialog.setSettings(m_settings);
     if (dialog.exec() == QDialog::Accepted) {
         const QString key = dialog.key();
@@ -83,7 +83,7 @@ void ConfigurationPanel::edit()
 {
     const QString key = m_configurations->currentText();
     ConfigurationDialog dialog;
-    dialog.setWindowTitle(tr("Edit Configuration"));
+    dialog.setWindowTitle(Tr::tr("Edit Configuration"));
     dialog.setSettings(m_settings);
     dialog.setKey(key);
     if (dialog.exec() == QDialog::Accepted) {
