@@ -25,6 +25,7 @@
 #include <projectexplorer/headerpath.h>
 
 #include <texteditor/codeassist/assistinterface.h>
+#include <texteditor/codeassist/functionhintproposal.h>
 #include <texteditor/codeassist/genericproposal.h>
 #include <texteditor/codeassist/genericproposalmodel.h>
 #include <texteditor/texteditor.h>
@@ -188,7 +189,7 @@ public:
 private:
     int activeArgument(const QString &prefix) const override
     {
-        const int arg = activeArgumenForPrefix(prefix);
+        const int arg = activeArgumentForPrefix(prefix);
         if (arg < 0)
             return -1;
         m_currentArg = arg;
@@ -203,8 +204,8 @@ private:
         const SignatureInformation signature = m_sigis.signatures().at(index);
         QString label = signature.label();
 
-        const QList<QString> parameters = Utils::transform(signature.parameters().value_or(Parameters()),
-                                                           &ParameterInformation::label);
+        const QStringList parameters = Utils::transform(signature.parameters().value_or(Parameters()),
+                                                        &ParameterInformation::label);
         if (parameters.size() <= m_currentArg)
             return label;
 
@@ -221,13 +222,14 @@ private:
 class ClangdFunctionHintProcessor : public FunctionHintProcessor
 {
 public:
-    ClangdFunctionHintProcessor(ClangdClient *client, int basePosition);
+    ClangdFunctionHintProcessor(ClangdClient *client, int basePosition, bool abortExisting);
 
 private:
     IAssistProposal *perform() override;
     IFunctionHintProposalModel *createModel(const SignatureHelp &signatureHelp) const override;
 
     ClangdClient * const m_client;
+    const bool m_abortExisting;
 };
 
 ClangdCompletionAssistProvider::ClangdCompletionAssistProvider(ClangdClient *client)
@@ -256,7 +258,7 @@ IAssistProcessor *ClangdCompletionAssistProvider::createProcessor(
     case ClangCompletionContextAnalyzer::PassThroughToLibClangAfterLeftParen:
         qCDebug(clangdLogCompletion) << "creating function hint processor";
         return new ClangdFunctionHintProcessor(m_client,
-                                               contextAnalyzer.positionForProposal());
+                                               contextAnalyzer.positionForProposal(), false);
     case ClangCompletionContextAnalyzer::CompletePreprocessorDirective:
         qCDebug(clangdLogCompletion) << "creating macro processor";
         return new CustomAssistProcessor(m_client,
@@ -264,6 +266,10 @@ IAssistProcessor *ClangdCompletionAssistProvider::createProcessor(
                                          contextAnalyzer.positionEndOfExpression(),
                                          contextAnalyzer.completionOperator(),
                                          CustomAssistMode::Preprocessor);
+    case ClangCompletionContextAnalyzer::AbortExisting:
+        qCDebug(clangdLogCompletion) << "aborting existing proposal";
+        return new ClangdFunctionHintProcessor(m_client,
+                                               contextAnalyzer.positionForProposal(), true);
     default:
         break;
     }
@@ -474,7 +480,7 @@ void ClangdCompletionItem::apply(TextEditorWidget *editorWidget,
             editorWidget->setAutoCompleteSkipPosition(editorWidget->textCursor());
     }
 
-    if (auto additionalEdits = item.additionalTextEdits()) {
+    if (const auto additionalEdits = item.additionalTextEdits()) {
         for (const auto &edit : *additionalEdits)
             applyTextEdit(editorWidget, edit);
     }
@@ -608,8 +614,7 @@ QList<AssistProposalItemInterface *> CustomAssistProcessor::completeInclude(
 
     // Make completion for all relevant includes
     HeaderPaths allHeaderPaths = headerPaths;
-    const auto currentFilePath = HeaderPath::makeUser(
-                interface->filePath().toFileInfo().path());
+    const HeaderPath currentFilePath = HeaderPath::makeUser(interface->filePath());
     if (!allHeaderPaths.contains(currentFilePath))
         allHeaderPaths.append(currentFilePath);
 
@@ -618,7 +623,7 @@ QList<AssistProposalItemInterface *> CustomAssistProcessor::completeInclude(
 
     QList<AssistProposalItemInterface *> completions;
     for (const HeaderPath &headerPath : std::as_const(allHeaderPaths)) {
-        QString realPath = headerPath.path;
+        QString realPath = headerPath.path.path();
         if (!directoryPrefix.isEmpty()) {
             realPath += QLatin1Char('/');
             realPath += directoryPrefix;
@@ -733,9 +738,11 @@ QList<AssistProposalItemInterface *> ClangdCompletionAssistProcessor::generateCo
     return itemGenerator(items);
 }
 
-ClangdFunctionHintProcessor::ClangdFunctionHintProcessor(ClangdClient *client, int basePosition)
+ClangdFunctionHintProcessor::ClangdFunctionHintProcessor(ClangdClient *client, int basePosition,
+                                                         bool abortExisting)
     : FunctionHintProcessor(client, basePosition)
     , m_client(client)
+    , m_abortExisting(abortExisting)
 {}
 
 IAssistProposal *ClangdFunctionHintProcessor::perform()
@@ -745,6 +752,10 @@ IAssistProposal *ClangdFunctionHintProcessor::perform()
             emit m_client->proposalReady(proposal);
         });
     }
+    if (m_abortExisting) {
+        FunctionHintProposalModelPtr model(new ClangdFunctionHintProposalModel(SignatureHelp()));
+        return new FunctionHintProposal(0, model);
+    }
     return FunctionHintProcessor::perform();
 }
 
@@ -775,7 +786,10 @@ IAssistProcessor *ClangdFunctionHintProvider::createProcessor(
     ClangCompletionContextAnalyzer contextAnalyzer(interface->textDocument(),
                                                    interface->position(), false, {});
     contextAnalyzer.analyze();
-    return new ClangdFunctionHintProcessor(m_client, contextAnalyzer.positionForProposal());
+    const bool abortExisting
+        = contextAnalyzer.completionAction() == ClangCompletionContextAnalyzer::AbortExisting;
+    return new ClangdFunctionHintProcessor(m_client, contextAnalyzer.positionForProposal(),
+                                           abortExisting);
 }
 
 } // namespace ClangCodeModel::Internal
