@@ -45,7 +45,11 @@ static void adjustFormatStyleForLineBreak(clang::format::FormatStyle &style,
                                           ReplacementsToKeep replacementsToKeep)
 {
     style.MaxEmptyLinesToKeep = 100;
+#if LLVM_VERSION_MAJOR > 20
+    style.SortIncludes = {.Enabled = false};
+#else
     style.SortIncludes = clang::format::FormatStyle::SI_Never;
+#endif
 #if LLVM_VERSION_MAJOR >= 16
     style.SortUsingDeclarations = clang::format::FormatStyle::SUD_Never;
 #else
@@ -424,7 +428,7 @@ static ChangeSet convertReplacements(const QTextDocument *doc,
             continue;
 
         lineColUtf16.column = std::min(lineColUtf16.column, int(lineText.length()));
-        int utf16Offset = Text::positionInText(doc, lineColUtf16.line, lineColUtf16.column + 1);
+        int utf16Offset = Text::positionInText(doc, lineColUtf16.line, lineColUtf16.column);
         int utf16Length = QString::fromUtf8(
                               utf8Buffer.mid(static_cast<int>(replacement.getOffset()),
                                              static_cast<int>(replacement.getLength())))
@@ -464,11 +468,10 @@ static ChangeSet convertReplacements(const QTextDocument *doc,
 
 static QString selectedLines(QTextDocument *doc, const QTextBlock &startBlock, const QTextBlock &endBlock)
 {
-    return Text::textAt(QTextCursor(doc),
-                        startBlock.position(),
-                        std::max(0,
-                                 endBlock.position() + endBlock.length()
-                                     - startBlock.position() - 1));
+    return Text::textAt(
+        doc,
+        startBlock.position(),
+        std::max(0, endBlock.position() + endBlock.length() - startBlock.position() - 1));
 }
 
 static int indentationForBlock(const ChangeSet &toReplace,
@@ -851,7 +854,7 @@ int ClangFormatBaseIndenter::indentFor(const QTextBlock &block,
 }
 
 IndentationForBlock ClangFormatBaseIndenter::indentationForBlocks(
-    const QVector<QTextBlock> &blocks,
+    const QList<QTextBlock> &blocks,
     const TabSettings & /*tabSettings*/,
     int cursorPositionInEditor)
 {
@@ -930,7 +933,7 @@ clang::format::FormatStyle ClangFormatBaseIndenterPrivate::customSettingsStyle(
         return currentQtStyle(preferences);
 
     clang::format::FormatStyle currentSettingsStyle;
-    const Utils::expected_str<void> result = parseConfigurationFile(filePath, currentSettingsStyle);
+    const Utils::Result<> result = parseConfigurationFile(filePath, currentSettingsStyle);
     if (!result) {
         qCWarning(clangIndenterLog)
             << QString{"Failed to parse config %1. Falling back to the Qt style."}.arg(
@@ -987,6 +990,8 @@ const llvm::Expected<clang::format::FormatStyle> getStyleFromProjectFolder(
 
 const clang::format::FormatStyle &ClangFormatBaseIndenterPrivate::styleForFile() const
 {
+    QTC_ASSERT(!m_fileName->isEmpty(), return m_cachedStyle.style);
+
     static const milliseconds cacheTimeout = getCacheTimeout();
 
     if (!(m_overriddenStyle == clang::format::getNoStyle()))
@@ -1031,4 +1036,9 @@ void ClangFormatBaseIndenter::setOverriddenStyle(const clang::format::FormatStyl
     d->m_overriddenStyle = style;
 }
 
+bool ClangFormatBaseIndenter::respectsTabSettings() const
+{
+    return false;
+}
+
 } // namespace ClangFormat
