@@ -8,9 +8,9 @@
 #include <texteditor/tabsettings.h>
 #include <utils/fileutils.h>
 
+#include <QTest>
 #include <QTextCursor>
 #include <QTextDocument>
-#include <QtTest>
 
 #include <optional>
 
@@ -745,12 +745,12 @@ void ClangFormatTest::testIndentInitializeVector()
         "",
         "Test::Test()",
         "{",
-        "    QVector<int> list = {",
+        "    QList<int> list = {",
         "        1,",
         "        2,",
         "        3,",
         "    };",
-        "    QVector<int> list_2 = {",
+        "    QList<int> list_2 = {",
         "        1,",
         "        2,",
         "        3,",
@@ -771,12 +771,12 @@ void ClangFormatTest::testIndentInitializeVector()
                  "",
                  "Test::Test()",
                  "{",
-                 "    QVector<int> list = {",
+                 "    QList<int> list = {",
                  "        1,",
                  "        2,",
                  "        3,",
                  "    };",
-                 "    QVector<int> list_2 = {",
+                 "    QList<int> list_2 = {",
                  "        1,",
                  "        2,",
                  "        3,",
