@@ -3,7 +3,6 @@
 
 #include "documentquickfixfactory.h"
 
-#include "clangfixitsrefactoringchanges.h"
 #include "clangtoolsdiagnostic.h"
 #include "documentclangtoolrunner.h"
 
@@ -36,8 +35,8 @@ using DiagnosticRange = QPair<Link, Link>;
 static Range toRange(const QTextDocument *doc, DiagnosticRange locations)
 {
     Range range;
-    range.start = Text::positionInText(doc, locations.first.targetLine, locations.first.targetColumn);
-    range.end = Text::positionInText(doc, locations.second.targetLine, locations.second.targetColumn);
+    range.start = locations.first.target.toPositionInDocument(doc);
+    range.end = locations.second.target.toPositionInDocument(doc);
     return range;
 }
 
