@@ -1,5 +1,5 @@
 // Copyright (C) 2016 AudioCodes Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "clearcasesubmiteditorwidget.h"
 
@@ -69,7 +69,7 @@ void ClearCaseSubmitEditorWidget::addActivitySelector(bool isUcm)
 
     m_actSelector = new ActivitySelector;
     m_verticalLayout->insertWidget(0, m_actSelector);
-    m_verticalLayout->insertWidget(1, Utils::Layouting::createHr());
+    m_verticalLayout->insertWidget(1, Layouting::createHr());
 }
 
 QString ClearCaseSubmitEditorWidget::commitName() const
