@@ -11,22 +11,17 @@
 #include "cmakespecificsettings.h"
 #include "cmaketoolmanager.h"
 
+#include <coreplugin/icore.h>
 #include <coreplugin/progressmanager/processprogress.h>
+
 #include <projectexplorer/buildsystem.h>
 #include <projectexplorer/projectexplorerconstants.h>
 #include <projectexplorer/taskhub.h>
-#include <projectexplorer/kitchooser.h>
-
-#include <extensionsystem/invoker.h>
-#include <extensionsystem/pluginmanager.h>
 
 #include <utils/algorithm.h>
 #include <utils/macroexpander.h>
 #include <utils/qtcprocess.h>
-#include <utils/processinfo.h>
-#include <utils/processinterface.h>
 #include <utils/stringutils.h>
-#include <utils/stylehelper.h>
 #include <utils/theme/theme.h>
 
 using namespace Core;
@@ -53,12 +48,9 @@ static const int failedToStartExitCode = 0xFF; // See ProcessPrivate::handleDone
 
 void CMakeProcess::run(const BuildDirParameters &parameters, const QStringList &arguments)
 {
-    QTC_ASSERT(!m_process, return);
+    QTC_ASSERT(parameters.isValid(), return);
 
-    CMakeTool *cmake = parameters.cmakeTool();
-    QTC_ASSERT(parameters.isValid() && cmake, return);
-
-    const FilePath cmakeExecutable = cmake->cmakeExecutable();
+    const FilePath cmakeExecutable = parameters.cmakeExecutable;
 
     const QString mountHint = ::CMakeProjectManager::Tr::tr(
         "You may need to add the project directory to the list of directories that are mounted by "
@@ -93,11 +85,11 @@ void CMakeProcess::run(const BuildDirParameters &parameters, const QStringList &
         return;
     }
 
-    if (buildDirectory.needsDevice()) {
-        if (!cmake->cmakeExecutable().isSameDevice(buildDirectory)) {
+    if (!buildDirectory.isLocal()) {
+        if (!cmakeExecutable.isSameDevice(buildDirectory)) {
             const QString msg = ::CMakeProjectManager::Tr::tr(
                   "CMake executable \"%1\" and build directory \"%2\" must be on the same device.")
-                    .arg(cmake->cmakeExecutable().toUserOutput(), buildDirectory.toUserOutput());
+                    .arg(cmakeExecutable.toUserOutput(), buildDirectory.toUserOutput());
             BuildSystem::appendBuildSystemOutput(addCMakePrefix({QString(), msg}).join('\n'));
             emit finished(failedToStartExitCode);
             return;
@@ -106,52 +98,60 @@ void CMakeProcess::run(const BuildDirParameters &parameters, const QStringList &
 
     // Copy the "package-manager" CMake code from the ${IDE:ResourcePath} to the build directory
     if (settings(parameters.project).packageManagerAutoSetup()) {
-        const FilePath localPackageManagerDir = buildDirectory.pathAppended(Constants::PACKAGE_MANAGER_DIR);
-        const FilePath idePackageManagerDir = FilePath::fromString(
-            parameters.expander->expand(QStringLiteral("%{IDE:ResourcePath}/package-manager")));
+        const FilePath idePackageManagerDir = Core::ICore::resourcePath("package-manager");
+        const FilePath localPackageManagerDir = buildDirectory / Constants::PACKAGE_MANAGER_DIR;
 
-        if (!localPackageManagerDir.exists() && idePackageManagerDir.exists())
-            idePackageManagerDir.copyRecursively(localPackageManagerDir);
+        if (!idePackageManagerDir.isDir()) {
+            BuildSystem::appendBuildSystemOutput(
+                Tr::tr("Qt Creator installation is missing the "
+                       "package-manager directory. It was expected here: \"%1\".")
+                    .arg(idePackageManagerDir.toUserOutput()));
+        } else if (!localPackageManagerDir.exists()) {
+            const auto result = idePackageManagerDir.copyRecursively(localPackageManagerDir);
+            if (!result) {
+                BuildSystem::appendBuildSystemOutput(
+                    addCMakePrefix(
+                        {Tr::tr("Failed to copy package-manager folder:"), result.error()})
+                        .join('\n'));
+            }
+        }
     }
 
     const auto parser = new CMakeOutputParser;
-    parser->setSourceDirectory(parameters.sourceDirectory);
+    parser->setSourceDirectories({parameters.sourceDirectory, parameters.buildDirectory});
     m_parser.addLineParsers({new CMakeAutogenParser, parser});
     m_parser.addLineParsers(parameters.outputParsers());
 
     // Always use the sourceDir: If we are triggered because the build directory is getting deleted
     // then we are racing against CMakeCache.txt also getting deleted.
 
-    m_process.reset(new Process);
+    m_process.setWorkingDirectory(buildDirectory);
+    m_process.setEnvironment(parameters.environment);
 
-    m_process->setWorkingDirectory(buildDirectory);
-    m_process->setEnvironment(parameters.environment);
-
-    m_process->setStdOutLineCallback([this](const QString &s) {
+    m_process.setStdOutLineCallback([this](const QString &s) {
         BuildSystem::appendBuildSystemOutput(addCMakePrefix(stripTrailingNewline(s)));
         emit stdOutReady(s);
     });
 
-    m_process->setStdErrLineCallback([this](const QString &s) {
+    m_process.setStdErrLineCallback([this](const QString &s) {
         m_parser.appendMessage(s, StdErrFormat);
         BuildSystem::appendBuildSystemOutput(addCMakePrefix(stripTrailingNewline(s)));
     });
 
-    connect(m_process.get(), &Process::done, this, [this] {
-        if (m_process->result() != ProcessResult::FinishedWithSuccess) {
-            const QString message = m_process->exitMessage();
+    connect(&m_process, &Process::done, this, [this] {
+        if (m_process.result() != ProcessResult::FinishedWithSuccess) {
+            const QString message = m_process.exitMessage();
             BuildSystem::appendBuildSystemOutput(addCMakePrefix({{}, message}).join('\n'));
-            TaskHub::addTask(BuildSystemTask(Task::Error, message));
+            TaskHub::addTask<CMakeTask>(Task::Error, message);
         }
 
-        emit finished(m_process->exitCode());
+        emit finished(m_process.exitCode());
 
         const QString elapsedTime = Utils::formatElapsedTime(m_elapsed.elapsed());
         BuildSystem::appendBuildSystemOutput(addCMakePrefix({{}, elapsedTime}).join('\n'));
     });
 
-    CommandLine commandLine(cmakeExecutable);
-    commandLine.addArgs(
+    CommandLine commandLine(cmakeExecutable,
         {"-S",
          CMakeToolManager::mappedFilePath(parameters.project, sourceDirectory).path(),
          "-B",
@@ -164,18 +164,17 @@ void CMakeProcess::run(const BuildDirParameters &parameters, const QStringList &
         addCMakePrefix(::CMakeProjectManager::Tr::tr("Running %1 in %2.")
                            .arg(commandLine.toUserOutput(), buildDirectory.toUserOutput())));
 
-    ProcessProgress *progress = new ProcessProgress(m_process.get());
+    ProcessProgress *progress = new ProcessProgress(&m_process);
     progress->setDisplayName(::CMakeProjectManager::Tr::tr("Configuring \"%1\"")
                              .arg(parameters.projectName));
-    m_process->setCommand(commandLine);
+    m_process.setCommand(commandLine);
     m_elapsed.start();
-    m_process->start();
+    m_process.start();
 }
 
 void CMakeProcess::stop()
 {
-    if (m_process)
-        m_process->stop();
+    m_process.stop();
 }
 
 QString addCMakePrefix(const QString &str)
