@@ -5,12 +5,11 @@
 
 #include <qtsupport/qtprojectimporter.h>
 
-#include <utils/temporarydirectory.h>
+#include <utils/temporaryfile.h>
 
 namespace CMakeProjectManager {
 
 class CMakeProject;
-class CMakeTool;
 
 namespace Internal {
 
@@ -27,6 +26,7 @@ public:
     bool filter(ProjectExplorer::Kit *k) const final;
 
     Utils::FilePaths presetCandidates();
+
 private:
     QList<void *> examineDirectory(const Utils::FilePath &importPath,
                                    QString *warningMessage) const final;
@@ -34,21 +34,12 @@ private:
     ProjectExplorer::Kit *createKit(void *directoryData) const final;
     const QList<ProjectExplorer::BuildInfo> buildInfoList(void *directoryData) const final;
 
-    struct CMakeToolData {
-        bool isTemporary = false;
-        CMakeTool *cmakeTool = nullptr;
-    };
-    CMakeToolData findOrCreateCMakeTool(const Utils::FilePath &cmakeToolPath) const;
-
     void deleteDirectoryData(void *directoryData) const final;
 
-    void cleanupTemporaryCMake(ProjectExplorer::Kit *k, const QVariantList &vl);
-    void persistTemporaryCMake(ProjectExplorer::Kit *k, const QVariantList &vl);
-
     void ensureBuildDirectory(DirectoryData &data, const ProjectExplorer::Kit *k) const;
 
     const CMakeProject *m_project;
-    Utils::TemporaryDirectory m_presetsTempDir;
+    std::unique_ptr<Utils::TemporaryFilePath> m_presetsTempDir;
 };
 
 #ifdef WITH_TESTS
