@@ -95,10 +95,9 @@ Wizard *BaseFileWizardFactory::runWizardImpl(const FilePath &path, Id platform,
 */
 
 /*!
-    \fn Core::BaseFileWizard *Core::BaseFileWizardFactory::create(QWidget *parent,
-                                                                  const Core::WizardDialogParameters &parameters) const
+    \fn Core::BaseFileWizard *Core::BaseFileWizardFactory::create(const Core::WizardDialogParameters &parameters) const
 
-    Creates the wizard on the \a parent with the \a parameters.
+    Creates the wizard with the \a parameters.
 */
 
 /*!
@@ -175,11 +174,11 @@ Result<> BaseFileWizardFactory::postGenerateOpenEditors(const GeneratedFiles &l)
     Performs an overwrite check on a set of \a files. Checks if the file exists and
     can be overwritten at all, and then prompts the user with a summary.
 
-    Returns \a errorMessage if the file cannot be overwritten.
+    Returns whether the file can be overwritten.
 */
 
-BaseFileWizardFactory::OverwriteResult BaseFileWizardFactory::promptOverwrite(GeneratedFiles *files,
-                                                                QString *errorMessage)
+Result<BaseFileWizardFactory::OverwriteResult>
+    BaseFileWizardFactory::promptOverwrite(GeneratedFiles *files)
 {
     if (debugWizard)
         qDebug() << Q_FUNC_INFO << files;
@@ -201,7 +200,7 @@ BaseFileWizardFactory::OverwriteResult BaseFileWizardFactory::promptOverwrite(Ge
     // Before prompting to overwrite existing files, loop over files and check
     // if there is anything blocking overwriting them (like them being links or folders).
     // Format a file list message as ( "<file1> [readonly], <file2> [folder]").
-    const FilePath commonExistingPath = FileUtils::commonPath(existingFiles);
+    const FilePath commonExistingPath = existingFiles.commonPath();
     const int commonPrefixLen = commonExistingPath.toUserOutput().size() + 1;
     QString fileNamesMsgPart;
     for (const FilePath &filePath : std::as_const(existingFiles)) {
@@ -229,9 +228,9 @@ BaseFileWizardFactory::OverwriteResult BaseFileWizardFactory::promptOverwrite(Ge
     }
 
     if (oddStuffFound) {
-        *errorMessage = Tr::tr("The project directory %1 contains files which cannot be overwritten:\n%2.")
-                            .arg(commonExistingPath.toUserOutput(), fileNamesMsgPart);
-        return OverwriteError;
+        return ResultError(
+            Tr::tr("The project directory %1 contains files which cannot be overwritten:\n%2.")
+                .arg(commonExistingPath.toUserOutput(), fileNamesMsgPart));
     }
     // Prompt to overwrite existing files.
     PromptOverwriteDialog overwriteDialog;
