@@ -3,6 +3,7 @@
 
 #include "coreplugin.h"
 #include "coreplugintr.h"
+#include "customlanguagemodels.h"
 #include "designmode.h"
 #include "dialogs/ioptionspage.h"
 #include "editmode.h"
@@ -21,6 +22,7 @@
 #include "actionmanager/actionmanager.h"
 #include "coreconstants.h"
 #include "documentmanager.h"
+#include "editormanager/editormanager_p.h"
 #include "fileutils.h"
 #include "find/findplugin.h"
 #include "locator/locator.h"
@@ -58,7 +60,9 @@
 #include <QLabel>
 #include <QMenu>
 #include <QMessageBox>
+#include <QMetaEnum>
 #include <QPushButton>
+#include <QStandardPaths>
 #include <QUuid>
 
 #include <cstdlib>
@@ -246,6 +250,22 @@ static void addToPathChooserContextMenu(PathChooser *pathChooser, QMenu *menu)
         menu->insertSeparator(firstAction);
 }
 
+static void registerStandardLocation(MacroExpander *expander,
+                                                 QStandardPaths::StandardLocation location)
+{
+    static const QMetaEnum metaEnum = QMetaEnum::fromType<QStandardPaths::StandardLocation>();
+    const QLatin1String key(metaEnum.valueToKey(location));
+    expander->registerFileVariables(
+        QByteArray("HostOs:") + key.latin1(),
+        Tr::tr("QStandardPaths::%1 location on the local filesystem.").arg(key),
+        [location] {
+            const QStringList locations =
+                QStandardPaths::standardLocations(location);
+            return locations.isEmpty() ? FilePath()
+                                       : FilePath::fromUserInput(locations.first());
+        });
+}
+
 Result<> CorePlugin::initialize(const QStringList &arguments)
 {
     initTAndCAcceptDialog();
@@ -277,11 +297,17 @@ Result<> CorePlugin::initialize(const QStringList &arguments)
         Constants::SETTINGS_CATEGORY_CORE,
         Tr::tr("Environment"),
         ":/core/images/settingscategory_core.png");
+    IOptionsPage::registerCategory(
+        Constants::SETTINGS_CATEGORY_AI,
+        Tr::tr("AI"),
+        ":/core/images/settingscategory_ai.png");
 
     // Shared by Help and ScreenRecorder
     IOptionsPage::registerCategory(
         Constants::HELP_CATEGORY, Tr::tr("Help"), ":/core/images/settingscategory_help.png");
 
+    setupCustomLanguageModels();
+
     IWizardFactory::initialize();
 
     // Make sure we respect the process's umask when creating new files
@@ -346,17 +372,31 @@ Result<> CorePlugin::initialize(const QStringList &arguments)
                                Tr::tr("The directory where %1 puts custom user data.")
                                    .arg(QGuiApplication::applicationDisplayName()),
                                [] { return ICore::userResourcePath().toUrlishString(); });
-    expander->registerPrefix("CurrentDate:", Tr::tr("The current date (QDate formatstring)."),
-                             [](const QString &fmt) { return QDate::currentDate().toString(fmt); });
-    expander->registerPrefix("CurrentTime:", Tr::tr("The current time (QTime formatstring)."),
-                             [](const QString &fmt) { return QTime::currentTime().toString(fmt); });
+    expander->registerPrefix(
+        "CurrentDate:",
+        "dd.MM.yyyy",
+        Tr::tr("The current date (QDate formatstring)."),
+        [](const QString &fmt) { return QDate::currentDate().toString(fmt); });
+    expander->registerPrefix(
+        "CurrentTime:",
+        "hh:mm:ss",
+        Tr::tr("The current time (QTime formatstring)."),
+        [](const QString &fmt) { return QTime::currentTime().toString(fmt); });
     expander->registerVariable("UUID", Tr::tr("Generate a new UUID."),
                                [] { return QUuid::createUuid().toString(); });
 
-    expander->registerPrefix("#:", Tr::tr("A comment."), [](const QString &) { return QString(); });
-    expander->registerPrefix("Asciify:",
-                             Tr::tr("Convert string to pure ASCII."),
-                             [expander](const QString &s) { return asciify(expander->expand(s)); });
+    expander->registerPrefix("#:", "<comment>", Tr::tr("A comment."), [](const QString &) {
+        return QString();
+    });
+    expander->registerPrefix(
+        "Asciify:", "éΩ", Tr::tr("Convert string to pure ASCII."), [expander](const QString &s) {
+            return asciify(expander->expand(s));
+        });
+
+    registerStandardLocation(expander, QStandardPaths::DocumentsLocation);
+    registerStandardLocation(expander, QStandardPaths::GenericDataLocation);
+    registerStandardLocation(expander, QStandardPaths::HomeLocation);
+    registerStandardLocation(expander, QStandardPaths::TempLocation);
 
     Utils::PathChooser::setAboutToShowContextMenuHandler(&addToPathChooserContextMenu);
 
@@ -370,7 +410,8 @@ Result<> CorePlugin::initialize(const QStringList &arguments)
 #endif
 
 #ifdef WITH_TESTS
-    addTestCreator(&createVcsManagerTest);
+    addTestCreator(createVcsManagerTest);
+    addTestCreator(createTabbedEditorTest);
 #endif
 
     return ResultOk;
@@ -505,7 +546,8 @@ void CorePlugin::checkSettings()
 
 void CorePlugin::warnAboutCrashReporing()
 {
-    if (!ICore::infoBar()->canInfoBeAdded(kWarnCrashReportingSetting))
+    InfoBar *infoBar = ICore::popupInfoBar();
+    if (!infoBar->canInfoBeAdded(kWarnCrashReportingSetting))
         return;
 
     QString warnStr = ICore::settings()->value("CrashReportingEnabled", false).toBool()
@@ -526,6 +568,7 @@ void CorePlugin::warnAboutCrashReporing()
     Utils::InfoBarEntry info(kWarnCrashReportingSetting, warnStr,
                              Utils::InfoBarEntry::GlobalSuppression::Enabled);
     info.setTitle(Tr::tr("Crash Reporting"));
+    info.setInfoType(InfoLabel::Information);
     info.addCustomButton(
         ICore::msgShowOptionsDialog(),
         [] { ICore::showOptionsDialog(Core::Constants::SETTINGS_ID_SYSTEM); },
@@ -541,7 +584,7 @@ void CorePlugin::warnAboutCrashReporing()
         label->setContentsMargins(0, 0, 0, 8);
         return label;
     });
-    ICore::infoBar()->addInfo(info);
+    infoBar->addInfo(info);
 }
 
 // static
