@@ -34,8 +34,6 @@
 #include <QTreeView>
 #include <QVariantMap>
 
-Q_DECLARE_METATYPE(Core::IWizardFactory*)
-
 using namespace Utils;
 
 namespace Core {
@@ -544,7 +542,7 @@ static void runWizard(IWizardFactory *wizard, const FilePath &defaultLocation, I
                       const QVariantMap &variables)
 {
     const FilePath path = wizard->runPath(defaultLocation);
-    wizard->runWizard(path, ICore::dialogParent(), platform, variables);
+    wizard->runWizard(path, platform, variables);
 }
 
 void NewDialogWidget::accept()
