@@ -59,7 +59,7 @@ protected:
 
 struct EditorToolBarPrivate
 {
-    explicit EditorToolBarPrivate(QWidget *parent, EditorToolBar *q);
+    explicit EditorToolBarPrivate(EditorToolBar *q);
 
     QComboBox *m_editorList;
     QToolButton *m_closeEditorButton;
@@ -86,22 +86,22 @@ struct EditorToolBarPrivate
     bool m_isStandalone;
 };
 
-EditorToolBarPrivate::EditorToolBarPrivate(QWidget *parent, EditorToolBar *q)
+EditorToolBarPrivate::EditorToolBarPrivate(EditorToolBar *q)
     : m_editorList(new QComboBox(q))
     , m_closeEditorButton(new QToolButton(q))
     , m_lockButton(new QToolButton(q))
     , m_dragHandle(new QToolButton(q))
     , m_dragHandleMenu(nullptr)
-    , m_goBackAction(new QAction(Utils::Icons::PREV_TOOLBAR.icon(), Tr::tr("Go Back"), parent))
-    , m_goForwardAction(new QAction(Utils::Icons::NEXT_TOOLBAR.icon(), Tr::tr("Go Forward"), parent))
+    , m_goBackAction(new QAction(Utils::Icons::PREV_TOOLBAR.icon(), Tr::tr("Go Back"), q))
+    , m_goForwardAction(new QAction(Utils::Icons::NEXT_TOOLBAR.icon(), Tr::tr("Go Forward"), q))
     , m_backButton(new ButtonWithMenu(q))
     , m_forwardButton(new ButtonWithMenu(q))
     , m_splitButton(new QToolButton(q))
     , m_horizontalSplitAction(
-          new QAction(Utils::Icons::SPLIT_HORIZONTAL.icon(), Tr::tr("Split"), parent))
+          new QAction(Utils::Icons::SPLIT_HORIZONTAL.icon(), Tr::tr("Split"), q))
     , m_verticalSplitAction(
-          new QAction(Utils::Icons::SPLIT_VERTICAL.icon(), Tr::tr("Split Side by Side"), parent))
-    , m_splitNewWindowAction(new QAction(Tr::tr("Open in New Window"), parent))
+          new QAction(Utils::Icons::SPLIT_VERTICAL.icon(), Tr::tr("Split Side by Side"), q))
+    , m_splitNewWindowAction(new QAction(Tr::tr("Open in New Window"), q))
     , m_closeSplitButton(new QToolButton(q))
     , m_activeToolBar(nullptr)
     , m_toolBarPlaceholder(new QWidget(q))
@@ -114,7 +114,7 @@ EditorToolBarPrivate::EditorToolBarPrivate(QWidget *parent, EditorToolBar *q)
   Mimic the look of the text editor toolbar as defined in e.g. EditorView::EditorView
   */
 EditorToolBar::EditorToolBar(QWidget *parent) :
-        Utils::StyledBar(parent), d(new EditorToolBarPrivate(parent, this))
+        Utils::StyledBar(parent), d(new EditorToolBarPrivate(this))
 {
     auto toolBarLayout = new QHBoxLayout(this);
     toolBarLayout->setContentsMargins(0, 0, 0, 0);
@@ -198,8 +198,10 @@ EditorToolBar::EditorToolBar(QWidget *parent) :
     connect(d->m_dragHandleMenu, &QMenu::aboutToHide, this, [this] {
         // Remove actions from context menu, to avoid any shortcuts set on them
         // for the display in the menu interfering with global actions
+        // This must be queued, so the QActions in the menu aren't deleted before they
+        // are triggered
         d->m_dragHandleMenu->clear();
-    });
+    }, Qt::QueuedConnection);
     connect(d->m_lockButton, &QAbstractButton::clicked, this, &EditorToolBar::makeEditorWritable);
     connect(d->m_closeEditorButton, &QAbstractButton::clicked,
             this, &EditorToolBar::closeEditor, Qt::QueuedConnection);
@@ -375,6 +377,12 @@ void EditorToolBar::setGoForwardMenu(QMenu *menu)
     d->m_forwardButton->setMenu(menu);
 }
 
+void EditorToolBar::setDocumentDropdownVisible(bool visible)
+{
+    d->m_editorList->setVisible(visible);
+    d->m_closeEditorButton->setVisible(visible);
+}
+
 void EditorToolBar::updateActionShortcuts()
 {
     d->m_closeEditorButton->setToolTip(ActionManager::command(Constants::CLOSE)->stringWithAppendedShortcut(Tr::tr("Close Document")));
@@ -426,9 +434,7 @@ void EditorToolBar::updateDocumentStatus(IDocument *document)
     else
         d->m_dragHandle->setIcon(Utils::FileIconProvider::icon(document->filePath()));
 
-    d->m_editorList->setToolTip(document->filePath().isEmpty()
-                                ? document->displayName()
-                                : document->filePath().toUserOutput());
+    d->m_editorList->setToolTip(document->toolTip());
 }
 
 bool EditorToolBar::eventFilter(QObject *obj, QEvent *event)
