@@ -1,10 +1,11 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
-#include "dialogs/ioptionspage.h"
 #include "generalsettings.h"
 #include "coreconstants.h"
 #include "coreplugintr.h"
+#include "dialogs/ioptionspage.h"
+#include "editormanager/editormanager_p.h"
 #include "icore.h"
 #include "themechooser.h"
 
@@ -17,6 +18,7 @@
 #include <utils/layoutbuilder.h>
 #include <utils/qtcolorbutton.h>
 #include <utils/stylehelper.h>
+#include <utils/textcodec.h>
 
 #include <QApplication>
 #include <QCheckBox>
@@ -29,7 +31,6 @@
 #include <QPushButton>
 #include <QSettings>
 #include <QStyleHints>
-#include <QTextCodec>
 
 using namespace Utils;
 using namespace Layouting;
@@ -73,6 +74,17 @@ GeneralSettings::GeneralSettings()
                "not displayed properly, you can use the cursors provided by %1.")
             .arg(QGuiApplication::applicationDisplayName()));
 
+    preferInfoBarOverPopup.setSettingsKey("General/PreferInfoBarOverPopup");
+    preferInfoBarOverPopup.setDefaultValue(false);
+    preferInfoBarOverPopup.setLabelText(Tr::tr("Prefer banner style info bars over pop-ups"));
+
+    useTabsInEditorViews.setSettingsKey("General/UseTabsInEditorViews");
+    useTabsInEditorViews.setDefaultValue(false);
+    useTabsInEditorViews.setLabelText(Tr::tr("Use tabbed editors"));
+    useTabsInEditorViews.addOnChanged(EditorManagerPrivate::instance(), [this] {
+        EditorManagerPrivate::setShowingTabs(useTabsInEditorViews.value());
+    });
+
     readSettings();
 }
 
@@ -181,10 +193,13 @@ GeneralSettingsWidget::GeneralSettingsWidget()
         }
     }
 
+    form.flush();
+    form.addRow({Tr::tr("Text codec for tools:"), m_codecBox, st});
     form.addRow({empty, generalSettings().showShortcutsInContextMenus});
     form.addRow({empty, generalSettings().provideSplitterCursors});
+    form.addRow({empty, generalSettings().preferInfoBarOverPopup});
+    form.addRow({empty, generalSettings().useTabsInEditorViews});
     form.addRow({Row{m_resetWarningsButton, st}});
-    form.addRow({Tr::tr("Text codec for tools:"), m_codecBox, st});
     Column{Group{title(Tr::tr("User Interface")), form}}.attachTo(this);
 
     fillLanguageBox();
@@ -355,10 +370,9 @@ void GeneralSettingsWidget::fillCodecBox() const
 {
     const QByteArray currentCodec = codecForLocale();
 
-    const QByteArrayList codecs = Utils::sorted(QTextCodec::availableCodecs());
-    for (const QByteArray &codec : codecs) {
-        m_codecBox->addItem(QString::fromLocal8Bit(codec));
-        if (codec == currentCodec)
+    for (const TextEncoding &encoding : TextEncoding::availableEncodings()) {
+        m_codecBox->addItem(encoding.displayName());
+        if (encoding.name() == currentCodec)
             m_codecBox->setCurrentIndex(m_codecBox->count() - 1);
     }
 }
@@ -368,7 +382,7 @@ QByteArray GeneralSettingsWidget::codecForLocale()
     QtcSettings *settings = ICore::settings();
     QByteArray codec = settings->value(settingsKeyCodecForLocale).toByteArray();
     if (codec.isEmpty())
-        codec = QTextCodec::codecForLocale()->name();
+        codec = TextEncoding::encodingForLocale().name();
     return codec;
 }
 
@@ -376,7 +390,7 @@ void GeneralSettingsWidget::setCodecForLocale(const QByteArray &codec)
 {
     QtcSettings *settings = ICore::settings();
     settings->setValueWithDefault(settingsKeyCodecForLocale, codec, {});
-    QTextCodec::setCodecForLocale(QTextCodec::codecForName(codec));
+    TextEncoding::setEncodingForLocale(codec);
 }
 
 StyleHelper::ToolbarStyle toolbarStylefromSettings()
