@@ -8,7 +8,6 @@
 #include "actionmanager/command.h"
 #include "coreicons.h"
 #include "coreplugintr.h"
-#include "coreplugintr.h"
 #include "dialogs/externaltoolconfig.h"
 #include "dialogs/ioptionspage.h"
 #include "dialogs/settingsdialog.h"
@@ -25,6 +24,7 @@
 #include "fileutils.h"
 #include "find/basetextfind.h"
 #include "findplaceholder.h"
+#include "generalsettings.h"
 #include "helpmanager.h"
 #include "icore.h"
 #include "idocumentfactory.h"
@@ -39,6 +39,7 @@
 #include "navigationwidget.h"
 #include "outputpanemanager.h"
 #include "plugindialog.h"
+#include "plugininstallwizard.h"
 #include "progressmanager/progressmanager_p.h"
 #include "progressmanager/progressview.h"
 #include "rightpane.h"
@@ -231,8 +232,7 @@ const char windowGeometryKey[] = "WindowGeometry";
 const char windowStateKey[] = "WindowState";
 const char modeSelectorLayoutKey[] = "ModeSelectorLayout";
 const char menubarVisibleKey[] = "MenubarVisible";
-
-const char DEFAULT_ALT_BUTTON_TEXT[] = QT_TRANSLATE_NOOP("QtC::Core", "Later");
+const char colorDialogKey[] = "QColorDialog/CustomColor/";
 
 namespace Internal {
 
@@ -292,6 +292,7 @@ public:
     void saveWindowSettings();
 
     MainWindow *m_mainwindow = nullptr;
+    InfoBar m_infoBar;
     QTimer m_trimTimer;
     QString m_prependAboutInformation;
     QStringList m_aboutInformation;
@@ -375,15 +376,20 @@ ICore::ICore()
     d = new ICorePrivate;
     d->init(); // Separation needed for now as the call triggers other MainWindow calls.
 
-    connect(PluginManager::instance(), &PluginManager::testsFinished,
-            this, [this](int failedTests) {
-        emit coreAboutToClose();
+    connect(PluginManager::instance(), &PluginManager::testsFinished, this, [this](int failedTests) {
+        const bool keepOpenAfterTest = qtcEnvironmentVariableIsSet("QTC_KEEP_OPEN_AFTER_TEST");
+        if (!keepOpenAfterTest)
+            emit coreAboutToClose();
         if (failedTests != 0)
             qWarning("Test run was not successful: %d test(s) failed.", failedTests);
-        QCoreApplication::exit(failedTests);
+        if (!keepOpenAfterTest) {
+            EditorManager::closeAllEditors(false);
+            QCoreApplication::exit(failedTests);
+        }
     });
     connect(PluginManager::instance(), &PluginManager::scenarioFinished,
             this, [this](int exitCode) {
+        EditorManager::closeAllEditors(false);
         emit coreAboutToClose();
         QCoreApplication::exit(exitCode);
     });
@@ -391,7 +397,6 @@ ICore::ICore()
     Utils::setDialogParentGetter(&ICore::dialogParent);
 
     d->m_progressManager->init(); // needs the status bar manager
-    MessageManager::init();
     OutputPaneManager::create();
 }
 
@@ -565,9 +570,9 @@ bool ICore::showWarningWithOptions(const QString &title, const QString &text,
 QtcSettings *ICore::settings(QSettings::Scope scope)
 {
     if (scope == QSettings::UserScope)
-        return PluginManager::settings();
+        return &Utils::userSettings();
     else
-        return PluginManager::globalSettings();
+        return &Utils::installSettings();
 }
 
 /*!
@@ -685,7 +690,7 @@ FilePath ICore::clangIncludeDirectory(const QString &clangVersion,
 /*!
     \internal
 */
-static expected_str<FilePath> clangBinary(
+static Result<FilePath> clangBinary(
     const QString &binaryBaseName, const FilePath &clangBinDirectory)
 {
     FilePath executable =
@@ -703,7 +708,7 @@ static expected_str<FilePath> clangBinary(
     if (!fromPath.isEmpty())
         return fromPath;
 
-    return make_unexpected(Tr::tr("Could not find %1 executable in %2")
+    return ResultError(Tr::tr("Could not find %1 executable in %2")
                                .arg(binaryBaseName)
                                .arg(clangBinDirectory.toUserOutput()));
 }
@@ -711,7 +716,7 @@ static expected_str<FilePath> clangBinary(
 /*!
     \internal
 */
-expected_str<FilePath> ICore::clangExecutable(const FilePath &clangBinDirectory)
+Result<FilePath> ICore::clangExecutable(const FilePath &clangBinDirectory)
 {
     return clangBinary("clang", clangBinDirectory);
 }
@@ -719,7 +724,7 @@ expected_str<FilePath> ICore::clangExecutable(const FilePath &clangBinDirectory)
 /*!
     \internal
 */
-expected_str<FilePath> ICore::clangdExecutable(const FilePath &clangBinDirectory)
+Result<FilePath> ICore::clangdExecutable(const FilePath &clangBinDirectory)
 {
     return clangBinary("clangd", clangBinDirectory);
 }
@@ -727,7 +732,7 @@ expected_str<FilePath> ICore::clangdExecutable(const FilePath &clangBinDirectory
 /*!
     \internal
 */
-expected_str<FilePath> ICore::clangTidyExecutable(const FilePath &clangBinDirectory)
+Result<FilePath> ICore::clangTidyExecutable(const FilePath &clangBinDirectory)
 {
     return clangBinary("clang-tidy", clangBinDirectory);
 }
@@ -735,7 +740,7 @@ expected_str<FilePath> ICore::clangTidyExecutable(const FilePath &clangBinDirect
 /*!
     \internal
 */
-expected_str<FilePath> ICore::clazyStandaloneExecutable(const FilePath &clangBinDirectory)
+Result<FilePath> ICore::clazyStandaloneExecutable(const FilePath &clangBinDirectory)
 {
     return clangBinary("clazy-standalone", clangBinDirectory);
 }
@@ -743,39 +748,11 @@ expected_str<FilePath> ICore::clazyStandaloneExecutable(const FilePath &clangBin
 /*!
     \internal
  */
-expected_str<FilePath> ICore::lldbExecutable(const Utils::FilePath &lldbBinDirectory)
+Result<FilePath> ICore::lldbExecutable(const Utils::FilePath &lldbBinDirectory)
 {
     return clangBinary("lldb", lldbBinDirectory);
 }
 
-static QString compilerString()
-{
-#if defined(Q_CC_CLANG) // must be before GNU, because clang claims to be GNU too
-    QString platformSpecific;
-#if defined(__apple_build_version__) // Apple clang has other version numbers
-    platformSpecific = QLatin1String(" (Apple)");
-#elif defined(Q_CC_MSVC)
-    platformSpecific = QLatin1String(" (clang-cl)");
-#endif
-    return QLatin1String("Clang " ) + QString::number(__clang_major__) + QLatin1Char('.')
-            + QString::number(__clang_minor__) + platformSpecific;
-#elif defined(Q_CC_GNU)
-    return QLatin1String("GCC " ) + QLatin1String(__VERSION__);
-#elif defined(Q_CC_MSVC)
-    if (_MSC_VER > 1999)
-        return QLatin1String("MSVC <unknown>");
-    if (_MSC_VER >= 1930)
-        return QLatin1String("MSVC 2022");
-    if (_MSC_VER >= 1920)
-        return QLatin1String("MSVC 2019");
-    if (_MSC_VER >= 1910)
-        return QLatin1String("MSVC 2017");
-    if (_MSC_VER >= 1900)
-        return QLatin1String("MSVC 2015");
-#endif
-    return QLatin1String("<unknown compiler>");
-}
-
 /*!
     Returns a string with the IDE's name and version, in the form "\QC X.Y.Z".
     Use this for "Generated by" strings and similar tasks.
@@ -868,7 +845,26 @@ QStatusBar *ICore::statusBar()
 */
 Utils::InfoBar *ICore::infoBar()
 {
-    return d->m_modeStack->infoBar();
+    if (qtcEnvironmentVariableIsSet("QTC_DEBUG_POPUPNOTIFICATION"))
+        return ProgressManagerPrivate::popupInfoBar();
+    return &d->m_infoBar;
+}
+
+InfoBar *ICore::popupInfoBar()
+{
+    if (generalSettings().preferInfoBarOverPopup())
+        return infoBar();
+    return ProgressManagerPrivate::popupInfoBar();
+}
+
+static void setRestartRequested(bool restart)
+{
+    qApp->setProperty("restart", restart);
+}
+
+static bool isRestartRequested()
+{
+    return qApp->property("restart").toBool();
 }
 
 /*!
@@ -884,17 +880,19 @@ Utils::InfoBar *ICore::infoBar()
 */
 bool ICore::askForRestart(const QString &text, const QString &altButtonText)
 {
+    if (isRestartRequested())
+        return true;
     QMessageBox mb(dialogParent());
     mb.setWindowTitle(Tr::tr("Restart Required"));
     mb.setText(text);
     mb.setIcon(QMessageBox::Information);
 
-    QString translatedAltButtonText = altButtonText.isEmpty() ? Tr::tr(DEFAULT_ALT_BUTTON_TEXT) : altButtonText;
+    QString translatedAltButtonText = altButtonText.isEmpty() ? Tr::tr("Later") : altButtonText;
 
     mb.addButton(translatedAltButtonText, QMessageBox::NoRole);
     mb.addButton(Tr::tr("Restart Now"), QMessageBox::YesRole);
 
-    mb.connect(&mb, &QDialog::accepted, ICore::instance(), &ICore::restart, Qt::QueuedConnection);
+    mb.connect(&mb, &QDialog::accepted, ICore::instance(), &ICore::restart);
     mb.exec();
 
     return mb.buttonRole(mb.clickedButton()) == QMessageBox::YesRole;
@@ -1018,6 +1016,10 @@ QString uiConfigInformation()
     info.append(QString("Color: %1\n").arg(StyleHelper::requestedBaseColor().name()));
     info.append(QString("Theme: %1 \"%2\"\n").arg(creatorTheme()->id())
                            .arg(creatorTheme()->displayName()));
+    info.append(QString("Theme color scheme: Qt::ColorScheme::%1\n")
+                .arg(QVariant::fromValue(creatorTheme()->colorScheme()).toString()));
+    info.append(QString("System color scheme: Qt::ColorScheme::%1\n")
+                .arg(QVariant::fromValue(Theme::systemColorScheme()).toString()));
     const QString toolbarStyle =
         StyleHelper::toolbarStyle() == StyleHelper::ToolbarStyle::Compact ? "Compact" : "Relaxed";
     info.append(QString("Toolbar style: Utils::StyleHelper::ToolbarStyle%1\n").arg(toolbarStyle));
@@ -1121,20 +1123,46 @@ void ICore::setupScreenShooter(const QString &name, QWidget *w, const QRect &rc)
         new ScreenShooter(w, name, rc);
 }
 
-static void setRestart(bool restart)
-{
-    qApp->setProperty("restart", restart);
-}
-
 /*!
     Restarts \QC and restores the last session.
 */
 void ICore::restart()
 {
-    setRestart(true);
+    if (isRestartRequested())
+        return;
+    setRestartRequested(true);
     exit();
 }
 
+/*!
+    Asks the user if they want to enable the \a plugins and their dependencies.
+    If the user agrees, the plugins are enabled.
+    If all plugins are soft loadable without restart, they get loaded directly.
+    Otherwise the "Restart Required" dialog is shown.
+
+    Returns whether the user agreed to enabling the plugins.
+*/
+bool ICore::enablePlugins(const QSet<ExtensionSystem::PluginSpec *> &plugins)
+{
+    std::optional<QSet<PluginSpec *>> additionalPlugins
+        = PluginManager::askForEnablingPlugins(dialogParent(), plugins, /*enable=*/true);
+    if (!additionalPlugins) // canceled
+        return false;
+    const QSet<PluginSpec *> affectedPlugins = plugins + *additionalPlugins;
+    bool softloadable = true;
+    for (PluginSpec *spec : affectedPlugins) {
+        spec->setEnabledBySettings(true);
+        softloadable = softloadable && spec->isSoftLoadable();
+    }
+    ExtensionSystem::PluginManager::writeSettings();
+    if (softloadable) {
+        PluginManager::loadPluginsAtRuntime(affectedPlugins);
+    } else {
+        ICore::askForRestart(msgPluginChangesRequireRestart());
+    }
+    return true;
+}
+
 /*!
     \internal
 */
@@ -1162,17 +1190,26 @@ void ICore::saveSettings(SaveSettingsReason reason)
     emit m_core->saveSettingsRequested(reason);
 
     QtcSettings *settings = PluginManager::settings();
-    settings->beginGroup(settingsGroup);
+    settings->withGroup(settingsGroup, [](QtcSettings *settings) {
+        if (!(s_overrideColor.isValid() && StyleHelper::baseColor() == s_overrideColor))
+            settings->setValueWithDefault(
+                colorKey,
+                StyleHelper::requestedBaseColor(),
+                QColor(StyleHelper::DEFAULT_BASE_COLOR));
 
-    if (!(s_overrideColor.isValid() && StyleHelper::baseColor() == s_overrideColor))
-        settings->setValueWithDefault(colorKey,
-                                      StyleHelper::requestedBaseColor(),
-                                      QColor(StyleHelper::DEFAULT_BASE_COLOR));
+        if (d->m_mainwindow->isVisible() && Internal::globalMenuBar()
+            && !Internal::globalMenuBar()->isNativeMenuBar()) {
+            settings->setValue(menubarVisibleKey, Internal::globalMenuBar()->isVisible());
+        }
 
-    if (Internal::globalMenuBar() && !Internal::globalMenuBar()->isNativeMenuBar())
-        settings->setValue(menubarVisibleKey, Internal::globalMenuBar()->isVisible());
-
-    settings->endGroup();
+        for (int i = 0; i < QColorDialog::customCount(); ++i) {
+            const auto key = Key(colorDialogKey + QByteArray::number(i));
+            const QColor color = QColorDialog::customColor(i);
+            const QString name = color.name(QColor::HexArgb);
+            // #ff000000 is default and also the name for invalid colors
+            settings->setValueWithDefault(key, name, QString("#ff000000"));
+        }
+    });
 
     DocumentManager::saveSettings();
     ActionManager::saveSettings();
@@ -1234,8 +1271,10 @@ QString ICore::aboutInformationCompact()
 {
     QString information = QString("Product: %1\n").arg(versionString());
     information += QString("Based on: Qt %1 (%2, %3)\n")
-                       .arg(QLatin1String(qVersion()), compilerString(),
-                            QSysInfo::buildCpuArchitecture());
+                       .arg(
+                           QLatin1String(qVersion()),
+                           Utils::compilerString(),
+                           QSysInfo::buildCpuArchitecture());
 #ifdef QTC_SHOW_BUILD_DATE
     information += QString("Built on: %1 %2\n").arg(QLatin1String(__DATE__),
                                                     QLatin1String(__TIME__));
@@ -1252,9 +1291,6 @@ QString ICore::aboutInformationCompact()
 */
 QString ICore::aboutInformationHtml()
 {
-    const QString buildCompatibilityString = Tr::tr("Based on Qt %1 (%2, %3)")
-                                                 .arg(QLatin1String(qVersion()), compilerString(),
-                                                      QSysInfo::buildCpuArchitecture());
     const AppInfo &appInfo = Utils::appInfo();
     QString ideRev;
     if (!appInfo.revision.isEmpty())
@@ -1263,10 +1299,21 @@ QString ICore::aboutInformationHtml()
                               ? appInfo.revision
                               : QString::fromLatin1("<a href=\"%1\">%2</a>")
                                     .arg(appInfo.revisionUrl, appInfo.revision));
-    QString buildDateInfo;
+    QString buildInfo;
 #ifdef QTC_SHOW_BUILD_DATE
-    buildDateInfo = Tr::tr("<br/>Built on %1 %2<br/>").arg(QLatin1String(__DATE__),
-                                                           QLatin1String(__TIME__));
+    //: Built on <date> <time> based on Qt <version> (<compiler>, <arch>)
+    buildInfo = Tr::tr("Built on %1 %2 based on Qt %3 (%4, %5)")
+                    .arg(
+                        QLatin1String(__DATE__),
+                        QLatin1String(__TIME__),
+                        QLatin1String(qVersion()),
+                        Utils::compilerString(),
+                        QSysInfo::buildCpuArchitecture());
+#else
+    buildInfo
+        //: Based on Qt <version> (<compiler>, <arch>)
+        = Tr::tr("Based on Qt %1 (%2, %3)")
+              .arg(QLatin1String(qVersion()), Utils::compilerString(), QSysInfo::buildCpuArchitecture());
 #endif
 
     static const QString br = QLatin1String("<br/>");
@@ -1278,18 +1325,16 @@ QString ICore::aboutInformationHtml()
                   "%2"
                   "%3"
                   "%4"
-                  "%5"
-                  "%6")
+                  "%5")
               .arg(
                   ICore::versionString(),
-                  buildCompatibilityString + br,
-                  buildDateInfo,
+                  wrapBr(buildInfo),
                   ideRev,
                   wrapBr(additionalInfo),
                   wrapBr(appInfo.copyright))
           + br
           + Tr::tr("The Qt logo, axivion stopping software erosion logo, Qt Group logo, as well as "
-                   "Qt®, Axivion®, avixion stopping software erosion®, Boot to Qt®, Built with "
+                   "Qt®, Axivion®, axivion stopping software erosion®, Boot to Qt®, Built with "
                    "Qt®, Coco®, froglogic®, Qt Cloud Services®, Qt Developer Days®, Qt Embedded®, "
                    "Qt Enterprise®, Qt Group®, Qt Mobile®, Qt Quick®, Qt Quick Compiler®, Squish® "
                    "are registered trademarks of The Qt Company Ltd. or its subsidiaries.");
@@ -1339,6 +1384,7 @@ void ICorePrivate::init()
     m_jsExpander = JsExpander::createGlobalJsExpander();
     m_vcsManager = new VcsManager;
     m_modeStack = new FancyTabWidget(m_mainwindow);
+    m_modeStack->setInfoBar(&m_infoBar);
 
     setupShortcutSettings();
     setupExternalToolSettings();
@@ -1449,7 +1495,6 @@ ICorePrivate::~ICorePrivate()
 
     delete m_externalToolManager;
     m_externalToolManager = nullptr;
-    MessageManager::destroy();
     delete m_vcsManager;
     m_vcsManager = nullptr;
     //we need to delete editormanager and statusbarmanager explicitly before the end of the destructor,
@@ -1509,7 +1554,7 @@ void ICore::aboutToShutdown()
 {
     disconnect(qApp, &QApplication::focusChanged, d, &ICorePrivate::updateFocusWidget);
     for (auto contextsPair : d->m_contextWidgets) {
-        for (auto context : contextsPair.second)
+        for (auto context : std::as_const(contextsPair.second))
             disconnect(context, &QObject::destroyed, d->m_mainwindow, nullptr);
     }
     d->m_activeContext.clear();
@@ -1528,7 +1573,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 {
     const auto cancelClose = [event] {
         event->ignore();
-        setRestart(false);
+        setRestartRequested(false);
     };
 
     // work around QTBUG-43344
@@ -1538,12 +1583,13 @@ void MainWindow::closeEvent(QCloseEvent *event)
         return;
     }
 
-    if (systemSettings().askBeforeExit()
-        && (QMessageBox::question(this,
-                                  Tr::tr("Exit %1?").arg(QGuiApplication::applicationDisplayName()),
-                                  Tr::tr("Exit %1?").arg(QGuiApplication::applicationDisplayName()),
-                                  QMessageBox::Yes | QMessageBox::No,
-                                  QMessageBox::No)
+    if (systemSettings().askBeforeExit() && !isRestartRequested()
+        && (QMessageBox::question(
+                this,
+                Tr::tr("Exit %1?").arg(QGuiApplication::applicationDisplayName()),
+                Tr::tr("Exit %1?").arg(QGuiApplication::applicationDisplayName()),
+                QMessageBox::Yes | QMessageBox::No,
+                QMessageBox::No)
             == QMessageBox::No)) {
         event->ignore();
         return;
@@ -1636,6 +1682,23 @@ void ICorePrivate::registerDefaultContainers()
     medit->appendGroup(Constants::G_EDIT_FIND);
     medit->appendGroup(Constants::G_EDIT_OTHER);
 
+    ActionContainer *advancedMenu = ActionManager::createMenu(Constants::M_EDIT_ADVANCED);
+    medit->addMenu(advancedMenu, Constants::G_EDIT_ADVANCED);
+    advancedMenu->menu()->setTitle(::Core::Tr::tr("Ad&vanced"));
+    advancedMenu->appendGroup(Constants::G_EDIT_FORMAT);
+    advancedMenu->appendGroup(Constants::G_EDIT_TEXT);
+    advancedMenu->appendGroup(Constants::G_EDIT_COLLAPSING);
+    advancedMenu->appendGroup(Constants::G_EDIT_BLOCKS);
+    advancedMenu->appendGroup(Constants::G_EDIT_FONT);
+    advancedMenu->appendGroup(Constants::G_EDIT_EDITOR);
+
+    advancedMenu->addSeparator(Constants::G_EDIT_TEXT);
+    advancedMenu->addSeparator(Constants::G_EDIT_COLLAPSING);
+    advancedMenu->addSeparator(Constants::G_EDIT_BLOCKS);
+    advancedMenu->addSeparator(Constants::G_EDIT_FONT);
+    advancedMenu->addSeparator(Constants::G_EDIT_EDITOR);
+
+    // View Menu
     ActionContainer *mview = ActionManager::createMenu(Constants::M_VIEW);
     menubar->addMenu(mview, Constants::G_VIEW);
     mview->menu()->setTitle(Tr::tr("&View"));
@@ -1757,6 +1820,8 @@ void ICorePrivate::registerDefaultActions()
     openAction.addToContainer(Constants::M_FILE, Constants::G_FILE_OPEN);
     openAction.addOnTriggered(this, [] { openFile(); });
 
+    ActionManager::createCommand(Constants::OPEN_PROJECT);
+
     // Open With Action
     ActionBuilder openWithAction(this, Constants::OPEN_WITH);
     openWithAction.setText(Tr::tr("Open File &With..."));
@@ -1882,6 +1947,7 @@ void ICorePrivate::registerDefaultActions()
     zoomInAction.setText(Tr::tr("Zoom In"));
     zoomInAction.setIcon(Icon::fromTheme("zoom-in"));
     zoomInAction.setDefaultKeySequence(QKeySequence(Tr::tr("Ctrl++")));
+    zoomInAction.addToContainer(Constants::M_EDIT_ADVANCED, Constants::G_EDIT_FONT);
     zoomInAction.setEnabled(false);
 
     // Zoom Out Action
@@ -1892,6 +1958,7 @@ void ICorePrivate::registerDefaultActions()
         zoomOutAction.setDefaultKeySequences({QKeySequence(Tr::tr("Ctrl+-")), QKeySequence(Tr::tr("Ctrl+Shift+-"))});
     else
         zoomOutAction.setDefaultKeySequence(Tr::tr("Ctrl+-"));
+    zoomOutAction.addToContainer(Constants::M_EDIT_ADVANCED, Constants::G_EDIT_FONT);
     zoomOutAction.setEnabled(false);
 
     // Zoom Reset Action
@@ -1899,6 +1966,7 @@ void ICorePrivate::registerDefaultActions()
     zoomOriginalAction.setText(Tr::tr("Original Size"));
     zoomOriginalAction.setIcon(Icon::fromTheme("zoom-original"));
     zoomOriginalAction.setDefaultKeySequence(Tr::tr("Meta+0"), Tr::tr("Ctrl+0"));
+    zoomOriginalAction.addToContainer(Constants::M_EDIT_ADVANCED, Constants::G_EDIT_FONT);
     zoomOriginalAction.setEnabled(false);
 
     // Debug Qt Creator menu
@@ -1963,7 +2031,7 @@ void ICorePrivate::registerDefaultActions()
     // Show Left Sidebar Action
     ActionBuilder toggleLeftSideBarAction(this, Constants::TOGGLE_LEFT_SIDEBAR);
     toggleLeftSideBarAction.setIcon(Utils::Icons::TOGGLE_LEFT_SIDEBAR.icon());
-    toggleLeftSideBarAction.setText(Tr::tr(Constants::TR_SHOW_LEFT_SIDEBAR));
+    toggleLeftSideBarAction.setText(msgShowLeftSideBar());
     toggleLeftSideBarAction.setCheckable(true);
     toggleLeftSideBarAction.setCommandAttribute(Command::CA_UpdateText);
     toggleLeftSideBarAction.setDefaultKeySequence(Tr::tr("Ctrl+0"), Tr::tr("Alt+0"));
@@ -1979,7 +2047,7 @@ void ICorePrivate::registerDefaultActions()
     // Show Right Sidebar Action
     ActionBuilder toggleRightSideBarAction(this, Constants::TOGGLE_RIGHT_SIDEBAR);
     toggleRightSideBarAction.setIcon(Utils::Icons::TOGGLE_RIGHT_SIDEBAR.icon());
-    toggleRightSideBarAction.setText(Tr::tr(Constants::TR_SHOW_RIGHT_SIDEBAR));
+    toggleRightSideBarAction.setText(msgShowRightSideBar());
     toggleRightSideBarAction.setCheckable(true);
     toggleRightSideBarAction.setCommandAttribute(Command::CA_UpdateText);
     toggleRightSideBarAction.setDefaultKeySequence(Tr::tr("Ctrl+Shift+0"), Tr::tr("Alt+Shift+0"));
@@ -2017,7 +2085,6 @@ void ICorePrivate::registerDefaultActions()
                     "Locator.Actions from the menu");
 
                 CheckableMessageBox::information(
-                    Core::ICore::dialogParent(),
                     Tr::tr("Hide Menu Bar"),
                     Tr::tr("This will hide the menu bar completely. "
                            "You can show it again by typing %1."
@@ -2103,19 +2170,23 @@ static IDocumentFactory *findDocumentFactory(const QList<IDocumentFactory*> &fil
 } // Internal
 
 /*!
- * \internal
- * Either opens \a filePaths with editors or loads a project.
- *
- *  \a flags can be used to stop on first failure, indicate that a file name
- *  might include line numbers and/or switch mode to edit mode.
- *
- *  \a workingDirectory is used when files are opened by a remote client, since
- *  the file names are relative to the client working directory.
- *
- *  Returns the first opened document. Required to support the \c -block flag
- *  for client mode.
- *
- *  \sa IPlugin::remoteArguments()
+    \internal
+
+    Either opens \a filePaths with editors or loads a project.
+
+    \a flags can be used to stop on first failure, indicate that a file name
+    might include line numbers and/or switch mode to edit mode.
+
+    \a workingDirectory is used when files are opened by a remote client, since
+    the file names are relative to the client working directory.
+
+    Returns the first opened document. Required to support the \c -block flag
+    for client mode.
+
+    The first document is also the only that is actually opened. All further documents
+    are added as suspended documents.
+
+    \sa IPlugin::remoteArguments()
  */
 
 IDocument *ICore::openFiles(const FilePaths &filePaths,
@@ -2147,7 +2218,7 @@ IDocument *ICore::openFiles(const FilePaths &filePaths,
                 emFlags |= EditorManager::SwitchSplitIfAlreadyVisible;
             IEditor *editor = nullptr;
             if (flags & ICore::CanContainLineAndColumnNumbers) {
-                const Link &link = Link::fromString(absoluteFilePath.toString(), true);
+                const Link &link = Link::fromString(absoluteFilePath.toUrlishString(), true);
                 editor = EditorManager::openEditorAt(link, {}, emFlags);
             } else {
                 editor = EditorManager::openEditor(absoluteFilePath, {}, emFlags);
@@ -2324,40 +2395,47 @@ void ICorePrivate::updateContextObject(const QList<IContext *> &context)
 void ICorePrivate::readSettings()
 {
     QtcSettings *settings = PluginManager::settings();
-    settings->beginGroup(settingsGroup);
-
-    if (s_overrideColor.isValid()) {
-        StyleHelper::setBaseColor(s_overrideColor);
-        // Get adapted base color.
-        s_overrideColor = StyleHelper::baseColor();
-    } else {
-        StyleHelper::setBaseColor(settings->value(colorKey,
-                                  QColor(StyleHelper::DEFAULT_BASE_COLOR)).value<QColor>());
-    }
-
-    {
-        ModeManager::Style modeStyle =
-                ModeManager::Style(settings->value(modeSelectorLayoutKey, int(ModeManager::Style::IconsAndText)).toInt());
-
-        // Migrate legacy setting from Qt Creator 4.6 and earlier
-        static const char modeSelectorVisibleKey[] = "ModeSelectorVisible";
-        if (!settings->contains(modeSelectorLayoutKey) && settings->contains(modeSelectorVisibleKey)) {
-            bool visible = settings->value(modeSelectorVisibleKey, true).toBool();
-            modeStyle = visible ? ModeManager::Style::IconsAndText : ModeManager::Style::Hidden;
+    settings->withGroup(settingsGroup, [this](QtcSettings *settings) {
+        if (s_overrideColor.isValid()) {
+            StyleHelper::setBaseColor(s_overrideColor);
+            // Get adapted base color.
+            s_overrideColor = StyleHelper::baseColor();
+        } else {
+            StyleHelper::setBaseColor(
+                settings->value(colorKey, QColor(StyleHelper::DEFAULT_BASE_COLOR)).value<QColor>());
         }
 
-        ModeManager::setModeStyle(modeStyle);
-    }
+        {
+            ModeManager::Style modeStyle = ModeManager::Style(
+                settings->value(modeSelectorLayoutKey, int(ModeManager::Style::IconsAndText))
+                    .toInt());
 
-    if (globalMenuBar() && !globalMenuBar()->isNativeMenuBar()) {
-        const bool isVisible = settings->value(menubarVisibleKey, true).toBool();
+            // Migrate legacy setting from Qt Creator 4.6 and earlier
+            static const char modeSelectorVisibleKey[] = "ModeSelectorVisible";
+            if (!settings->contains(modeSelectorLayoutKey)
+                && settings->contains(modeSelectorVisibleKey)) {
+                bool visible = settings->value(modeSelectorVisibleKey, true).toBool();
+                modeStyle = visible ? ModeManager::Style::IconsAndText : ModeManager::Style::Hidden;
+            }
 
-        globalMenuBar()->setVisible(isVisible);
-        if (m_toggleMenubarAction)
-            m_toggleMenubarAction->setChecked(isVisible);
-    }
+            ModeManager::setModeStyle(modeStyle);
+        }
 
-    settings->endGroup();
+        if (globalMenuBar() && !globalMenuBar()->isNativeMenuBar()) {
+            const bool isVisible = settings->value(menubarVisibleKey, true).toBool();
+
+            globalMenuBar()->setVisible(isVisible);
+            if (m_toggleMenubarAction)
+                m_toggleMenubarAction->setChecked(isVisible);
+        }
+
+        for (int i = 0; i < QColorDialog::customCount(); ++i) {
+            QColorDialog::setCustomColor(
+                i,
+                QColor::fromString(
+                    settings->value(Key(colorDialogKey + QByteArray::number(i))).toString()));
+        }
+    });
 
     EditorManagerPrivate::readSettings();
     m_leftNavigationWidget->restoreSettings(settings);
@@ -2401,9 +2479,9 @@ void ICorePrivate::updateContext()
     if (coreLog().isDebugEnabled()) {
         qCDebug(coreLog) << "Context changed:";
         qCDebug(coreLog) << "    "
-                         << Utils::transform<QList<QString>>(uniquecontexts, &Id::toString);
+                         << Utils::transform<QStringList>(uniquecontexts, &Id::toString);
         qCDebug(coreLog) << "    "
-                         << Utils::transform<QList<QString>>(m_activeContext, [](IContext *c) {
+                         << Utils::transform<QStringList>(m_activeContext, [](IContext *c) {
                                 return QString("%1: %2").arg(
                                     QString::fromUtf8(c->metaObject()->className()),
                                     c->widget()
@@ -2439,7 +2517,7 @@ void ICorePrivate::aboutToShowRecentFiles()
     // add the Clear Menu item
     if (hasRecentFiles) {
         menu->addSeparator();
-        QAction *action = menu->addAction(Tr::tr(Constants::TR_CLEAR_MENU));
+        QAction *action = menu->addAction(msgClearMenu());
         connect(action, &QAction::triggered,
                 DocumentManager::instance(), &DocumentManager::clearRecentFiles);
     }
@@ -2488,7 +2566,7 @@ void ICorePrivate::changeLog()
 
     auto versionCombo = new QComboBox;
     versionCombo->setMinimumWidth(80);
-    for (const VersionFilePair &f : versionedFiles)
+    for (const VersionFilePair &f : std::as_const(versionedFiles))
         versionCombo->addItem(f.first.toString());
     dialog = new LogDialog(ICore::dialogParent());
     auto showInExplorer = new QPushButton(FileUtils::msgGraphicalShellAction());
@@ -2549,9 +2627,9 @@ void ICorePrivate::changeLog()
     connect(showInExplorer, &QPushButton::clicked, this, [versionCombo, versionedFiles] {
         const int index = versionCombo->currentIndex();
         if (index >= 0 && index < versionedFiles.size())
-            FileUtils::showInGraphicalShell(ICore::dialogParent(), versionedFiles.at(index).second);
+            FileUtils::showInGraphicalShell(versionedFiles.at(index).second);
         else
-            FileUtils::showInGraphicalShell(ICore::dialogParent(), ICore::resourcePath("changelog"));
+            FileUtils::showInGraphicalShell(ICore::resourcePath("changelog"));
     });
 
     dialog->show();
