@@ -15,6 +15,8 @@
 #include <QJSEngine>
 #include <QPair>
 #include <QPointer>
+#include <QTimer>
+#include <QWaitCondition>
 
 #include <chrono>
 
@@ -342,7 +344,7 @@ private:
     JavaScriptOutput m_output;
 };
 
-using JavaScriptRequestTask = SimpleCustomTask<JavaScriptRequest>;
+using JavaScriptRequestTask = CustomTask<JavaScriptRequest>;
 
 namespace Core::Internal {
 
