@@ -1,14 +1,14 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "locatormanager.h"
 
 #include "ilocatorfilter.h"
 #include "locator.h"
 #include "locatorwidget.h"
+#include "../icore.h"
 
 #include <aggregation/aggregate.h>
-#include <coreplugin/icore.h>
 #include <extensionsystem/pluginmanager.h>
 #include <utils/qtcassert.h>
 
@@ -64,9 +64,8 @@ QWidget *LocatorManager::createLocatorInputWidget(QWidget *window)
 {
     auto locatorWidget = createStaticLocatorWidget(Locator::instance());
     // register locator widget for this window
-    auto agg = new Aggregation::Aggregate;
-    agg->add(window);
-    agg->add(locatorWidget);
+    Aggregation::aggregate({window, locatorWidget});
+
     return locatorWidget;
 }
 
