@@ -77,19 +77,15 @@ public:
     void cache(IVersionControl *vc, const FilePath &topLevel, const FilePath &dir)
     {
         QTC_ASSERT(dir.isAbsolutePath(), return);
-
-        const QString topLevelString = topLevel.toUrlishString();
         QTC_ASSERT(dir.isChildOf(topLevel) || topLevel == dir || topLevel.isEmpty(), return);
         QTC_ASSERT((topLevel.isEmpty() && !vc) || (!topLevel.isEmpty() && vc), return);
 
-        FilePath tmpDir = dir;
-        while (tmpDir.toUrlishString().size() >= topLevelString.size() && !tmpDir.isEmpty()) {
+        for (const FilePath &tmpDir : PathAndParents(dir, topLevel)) {
             m_cachedMatches.insert(tmpDir, {vc, topLevel});
             // if no vc was found, this might mean we're inside a repo internal directory (.git)
             // Cache only input directory, not parents
             if (!vc)
                 break;
-            tmpDir = tmpDir.parentDir();
         }
     }
 
@@ -136,9 +132,8 @@ void VcsManager::extensionsInitialized()
     const QList<IVersionControl *> vcs = versionControls();
     for (IVersionControl *vc : vcs) {
         connect(vc, &IVersionControl::filesChanged, DocumentManager::instance(),
-                [](const QStringList &fileNames) {
-            DocumentManager::notifyFilesChangedInternally(
-                        FileUtils::toFilePathList(fileNames));
+                [](const FilePaths &filePaths) {
+            DocumentManager::notifyFilesChangedInternally(filePaths);
         });
         connect(vc, &IVersionControl::repositoryChanged,
                 m_instance, &VcsManager::repositoryChanged);
@@ -217,7 +212,7 @@ static void askForDisabledVcsPlugins(const FilePath &inputDirectory)
         return;
 
     const Id vcsSuggestion = Id("VcsManager.Suggestion.").withSuffix(spec->id());
-    InfoBar *infoBar = ICore::infoBar();
+    InfoBar *infoBar = ICore::popupInfoBar();
     if (!infoBar->canInfoBeAdded(vcsSuggestion))
         return;
 
@@ -227,13 +222,13 @@ static void askForDisabledVcsPlugins(const FilePath &inputDirectory)
         Tr::tr("A directory under version control was detected that is supported by the %1 plugin.")
             .arg(pluginDisplayName),
         Utils::InfoBarEntry::GlobalSuppression::Enabled);
-    info.addCustomButton(Tr::tr("Enable %1").arg(pluginDisplayName), [vcsSuggestion, spec] {
+    info.addCustomButton(Tr::tr("Enable %1").arg(pluginDisplayName), [vcsSuggestion, spec, infoBar] {
         // TODO In case the plugin is actually loaded during runtime (softloadable),
         // we'd need to restructure findVersionControlForDirectory below to take the new plugin
         // into account.
         // At the moment softloadable VCS plugins are not supported though.
         if (ICore::enablePlugins({spec}))
-            ICore::infoBar()->removeInfo(vcsSuggestion);
+            infoBar->removeInfo(vcsSuggestion);
     });
 
     info.setDetailsWidgetCreator([toplevel, pluginDisplayName]() -> QWidget * {
@@ -246,7 +241,7 @@ static void askForDisabledVcsPlugins(const FilePath &inputDirectory)
         label->setContentsMargins(0, 0, 0, 8);
         return label;
     });
-    ICore::infoBar()->addInfo(info);
+    infoBar->addInfo(info);
 };
 
 IVersionControl* VcsManager::findVersionControlForDirectory(const FilePath &inputDirectory,
@@ -548,7 +543,7 @@ void VcsManager::handleConfigurationChanges(IVersionControl *vc)
 
 #ifdef WITH_TESTS
 
-#include <QtTest>
+#include <QTest>
 
 #include <extensionsystem/pluginmanager.h>
 
