@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "cppautocompleter.h"
 
@@ -12,17 +12,17 @@
 
 #ifdef WITH_TESTS
 #include "cppeditorconstants.h"
-#include "cppeditorplugin.h"
 #include "cppeditorwidget.h"
 
 #include <coreplugin/editormanager/editormanager.h>
 #include <texteditor/icodestylepreferences.h>
+#include <texteditor/syntaxhighlighter.h>
 #include <texteditor/textdocument.h>
 #include <texteditor/texteditor.h>
 #include <texteditor/texteditorsettings.h>
-#include <utils/executeondestruction.h>
 
-#include <QtTest>
+#include <QScopeGuard>
+#include <QTest>
 
 #endif // WITH_TESTS
 
@@ -182,14 +182,19 @@ static QChar closingChar(QChar c)
     return QChar();
 }
 
-static QTextCursor openEditor(const QString &text)
+static TextEditor::BaseTextEditor *creteCppEditor(const QString &text)
 {
-    QTextCursor tc;
     QString name(QLatin1String("auto_complete_test"));
     Core::IEditor *editor =  Core::EditorManager::openEditorWithContents(
-                Constants::CPPEDITOR_ID, &name, text.toLocal8Bit());
+        Constants::CPPEDITOR_ID, &name, text.toLocal8Bit());
+
+    return qobject_cast<TextEditor::BaseTextEditor *>(editor);
+}
+
+static QTextCursor openEditor(TextEditor::BaseTextEditor *cppEditor)
+{
+    QTextCursor tc;
 
-    const auto cppEditor = qobject_cast<TextEditor::BaseTextEditor *>(editor);
     if (cppEditor == 0)
         return tc;
     tc = cppEditor->editorWidget()->textCursor();
@@ -267,10 +272,13 @@ void AutoCompleterTest::testAutoComplete()
 
     QVERIFY(text.contains(QLatin1Char('|')));
 
-    Utils::ExecuteOnDestruction guard([](){
-        Core::EditorManager::closeAllEditors(false);
-    });
-    QTextCursor tc = openEditor(text);
+    const QScopeGuard cleanup([] { Core::EditorManager::closeAllEditors(false); });
+
+    TextEditor::BaseTextEditor *cppEditor = creteCppEditor(text);
+    QVERIFY(cppEditor);
+    QTRY_VERIFY(cppEditor->textDocument()->syntaxHighlighter()->syntaxHighlighterUpToDate());
+    QTextCursor tc = openEditor(cppEditor);
+    QTRY_VERIFY(cppEditor->textDocument()->syntaxHighlighter()->syntaxHighlighterUpToDate());
 
     QVERIFY(!tc.isNull());
 
@@ -328,10 +336,12 @@ void AutoCompleterTest::testSurroundWithSelection()
 
     QVERIFY(text.count(QLatin1Char('|')) == 2);
 
-    Utils::ExecuteOnDestruction guard([](){
-        Core::EditorManager::closeAllEditors(false);
-    });
-    QTextCursor tc = openEditor(text);
+    const QScopeGuard cleanup([] { Core::EditorManager::closeAllEditors(false); });
+    TextEditor::BaseTextEditor *cppEditor = creteCppEditor(text);
+    QVERIFY(cppEditor);
+    QTRY_VERIFY(cppEditor->textDocument()->syntaxHighlighter()->syntaxHighlighterUpToDate());
+    QTextCursor tc = openEditor(cppEditor);
+    QTRY_VERIFY(cppEditor->textDocument()->syntaxHighlighter()->syntaxHighlighterUpToDate());
 
     QVERIFY(!tc.isNull());
 
@@ -363,10 +373,12 @@ void AutoCompleterTest::testAutoBackspace()
 
     QVERIFY(text.contains(QLatin1Char('|')));
 
-    Utils::ExecuteOnDestruction guard([](){
-        Core::EditorManager::closeAllEditors(false);
-    });
-    QTextCursor tc = openEditor(text);
+    const QScopeGuard cleanup([] { Core::EditorManager::closeAllEditors(false); });
+    TextEditor::BaseTextEditor *cppEditor = creteCppEditor(text);
+    QVERIFY(cppEditor);
+    QTRY_VERIFY(cppEditor->textDocument()->syntaxHighlighter()->syntaxHighlighterUpToDate());
+    QTextCursor tc = openEditor(cppEditor);
+    QTRY_VERIFY(cppEditor->textDocument()->syntaxHighlighter()->syntaxHighlighterUpToDate());
 
     QVERIFY(!tc.isNull());
 
@@ -405,10 +417,12 @@ void AutoCompleterTest::testInsertParagraph()
 
     QVERIFY(text.contains(QLatin1Char('|')));
 
-    Utils::ExecuteOnDestruction guard([](){
-        Core::EditorManager::closeAllEditors(false);
-    });
-    QTextCursor tc = openEditor(text);
+    const QScopeGuard cleanup([] { Core::EditorManager::closeAllEditors(false); });
+    TextEditor::BaseTextEditor *cppEditor = creteCppEditor(text);
+    QVERIFY(cppEditor);
+    QTRY_VERIFY(cppEditor->textDocument()->syntaxHighlighter()->syntaxHighlighterUpToDate());
+    QTextCursor tc = openEditor(cppEditor);
+    QTRY_VERIFY(cppEditor->textDocument()->syntaxHighlighter()->syntaxHighlighterUpToDate());
 
     QVERIFY(!tc.isNull());
 
