@@ -11,9 +11,9 @@
 #include "cppeditortr.h"
 #include "cppeditorwidget.h"
 #include "cppfilesettingspage.h"
+#include "cppheadersource.h"
 #include "cpphighlighter.h"
 #include "cppincludehierarchy.h"
-#include "cppheadersource.h"
 #include "cppmodelmanager.h"
 #include "cppoutline.h"
 #include "cppprojectupdater.h"
@@ -30,6 +30,7 @@
 #include "cppcodegen_test.h"
 #include "cppcompletion_test.h"
 #include "cppdoxygen_test.h"
+#include "cppfollowsymbolundercursor.h"
 #include "cppincludehierarchy_test.h"
 #include "cpplocalsymbols_test.h"
 #include "cpplocatorfilter_test.h"
@@ -51,7 +52,6 @@
 #include <coreplugin/actionmanager/actionmanager.h>
 #include <coreplugin/actionmanager/command.h>
 #include <coreplugin/coreconstants.h>
-#include <coreplugin/coreplugintr.h>
 #include <coreplugin/documentmanager.h>
 #include <coreplugin/editormanager/editormanager.h>
 #include <coreplugin/editormanager/ieditorfactory.h>
@@ -63,6 +63,7 @@
 
 #include <extensionsystem/iplugin.h>
 
+#include <projectexplorer/devicesupport/idevice.h>
 #include <projectexplorer/project.h>
 #include <projectexplorer/projectnodes.h>
 #include <projectexplorer/projectexplorerconstants.h>
@@ -77,6 +78,8 @@
 #include <texteditor/texteditorsettings.h>
 
 #include <utils/algorithm.h>
+#include <utils/async.h>
+#include <utils/clangutils.h>
 #include <utils/fileutils.h>
 #include <utils/fsengine/fileiconprovider.h>
 #include <utils/hostosinfo.h>
@@ -115,7 +118,7 @@ public:
     CppEditorFactory()
     {
         setId(Constants::CPPEDITOR_ID);
-        setDisplayName(::Core::Tr::tr("C++ Editor"));
+        setDisplayName(Tr::tr("C++ Editor"));
         addMimeType(Utils::Constants::C_SOURCE_MIMETYPE);
         addMimeType(Utils::Constants::C_HEADER_MIMETYPE);
         addMimeType(Utils::Constants::CPP_SOURCE_MIMETYPE);
@@ -146,6 +149,21 @@ public:
     }
 };
 
+class ClangdToolFactory : public DeviceToolAspectFactory
+{
+public:
+    ClangdToolFactory()
+    {
+        setToolId(Constants::CLANGD_TOOL_ID);
+        setToolType(DeviceToolAspect::SourceTool);
+        setFilePattern({"clangd"});
+        setLabelText(Tr::tr("Clangd executable:"));
+        setChecker([](const DeviceConstRef &, const FilePath &candidate) {
+            return checkClangdVersion(candidate);
+        });
+    }
+};
+
 ///////////////////////////////// CppEditorPlugin //////////////////////////////////
 
 class CppEditorPluginPrivate : public QObject
@@ -161,6 +179,7 @@ public:
 
     CppModelManager modelManager;
     CppToolsSettings settings;
+    ClangdToolFactory clangdToolFactory;
 };
 
 class CppEditorPlugin final : public ExtensionSystem::IPlugin
@@ -356,6 +375,27 @@ void CppEditorPlugin::addPerSymbolActions()
     addSymbolActionToMenus(TextEditor::Constants::FOLLOW_SYMBOL_TO_TYPE);
     addSymbolActionToMenus(TextEditor::Constants::FOLLOW_SYMBOL_TO_TYPE_IN_NEXT_SPLIT);
 
+    ActionBuilder followToParentImpl(this, "CppEditor.FollowToParentImpl");
+    followToParentImpl.setText(Tr::tr("Follow Virtual Function to Base Class Implementation"));
+    followToParentImpl.setContext(context);
+    followToParentImpl.setScriptable(true);
+    followToParentImpl.addToContainers(menus, Constants::G_SYMBOL);
+    followToParentImpl.addOnTriggered(this, [] {
+        if (CppEditorWidget *editorWidget = currentCppEditorWidget())
+            editorWidget->goToParentImpl(/*inNextSplit*/ false);
+    });
+
+    ActionBuilder followToParentImplSplit(this, "CppEditor.FollowToParentImplInNextSplit");
+    followToParentImplSplit.setText(
+        Tr::tr("Follow Virtual Function to Base Class Implementation in Next Split"));
+    followToParentImplSplit.setContext(context);
+    followToParentImplSplit.setScriptable(true);
+    followToParentImplSplit.addToContainers(menus, Constants::G_SYMBOL);
+    followToParentImplSplit.addOnTriggered(this, [] {
+        if (CppEditorWidget *editorWidget = currentCppEditorWidget())
+            editorWidget->goToParentImpl(/*inNextSplit*/ true);
+    });
+
     ActionBuilder switchDeclDef(this, Constants::SWITCH_DECLARATION_DEFINITION);
     switchDeclDef.setText(Tr::tr("Switch Between Function Declaration/Definition"));
     switchDeclDef.setContext(context);
@@ -531,6 +571,7 @@ void CppEditorPlugin::registerTests()
     addTest<CodegenTest>();
     addTest<CompilerOptionsBuilderTest>();
     addTest<CompletionTest>();
+    addTestCreator(createFindParentImplTest);
     addTest<FunctionUtilsTest>();
     addTest<HeaderPathFilterTest>();
     addTestCreator(createCppHeaderSourceTest);
