@@ -1,5 +1,5 @@
 // Copyright (C) 2016 Przemyslaw Gorszkowski <pgorszkowski@gmail.com>
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -8,8 +8,7 @@
 
 #include <QSet>
 
-namespace CppEditor {
-namespace Internal {
+namespace CppEditor::Internal {
 
 class CppIncludeHierarchyItem;
 
@@ -25,8 +24,8 @@ public:
     QStringList mimeTypes() const override;
     QMimeData *mimeData(const QModelIndexList &indexes) const override;
 
-    void buildHierarchy(const QString &filePath);
-    QString editorFilePath() const { return m_editorFilePath; }
+    void buildHierarchy(const Utils::FilePath &filePath);
+    const Utils::FilePath &editorFilePath() const { return m_editorFilePath; }
     void setSearching(bool on);
     QString toString() const;
 
@@ -37,22 +36,12 @@ public:
 
 private:
     friend class CppIncludeHierarchyItem;
-    QString m_editorFilePath;
-    QSet<QString> m_seen;
+    Utils::FilePath m_editorFilePath;
+    QSet<Utils::FilePath> m_seen;
     bool m_searching = false;
 };
 
-class CppIncludeHierarchyFactory : public Core::INavigationWidgetFactory
-{
-    Q_OBJECT
+void openCppIncludeHierarchy();
+void setupCppIncludeHierarchy();
 
-public:
-    CppIncludeHierarchyFactory();
-
-    Core::NavigationView createWidget() override;
-    void saveSettings(Utils::QtcSettings *settings, int position, QWidget *widget) override;
-    void restoreSettings(QSettings *settings, int position, QWidget *widget) override;
-};
-
-} // namespace Internal
-} // namespace CppEditor
+} // CppEditor::Internal
