@@ -16,7 +16,7 @@
 #include <cplusplus/CppDocument.h>
 #include <utils/fileutils.h>
 
-#include <QtTest>
+#include <QTest>
 
 using namespace CPlusPlus;
 using namespace ProjectExplorer;
@@ -24,7 +24,7 @@ using namespace Utils;
 
 using Include = Document::Include;
 using CppEditor::Tests::TestCase;
-using CppEditor::Tests::Internal::TestIncludePaths;
+using namespace CppEditor::Tests::Internal;
 
 namespace CppEditor::Internal {
 
