@@ -37,12 +37,12 @@ static CppFileSettings fileSettings()
 
 static QString fileName(const QString &path, const QString &extension)
 {
-    return Utils::FilePath::fromStringWithExtension(path, extension).toString();
+    return Utils::FilePath::fromStringWithExtension(path, extension).toUrlishString();
 }
 
 QString CppToolsJsExtension::headerGuard(const QString &in) const
 {
-    return Utils::headerGuard(in);
+    return fileSettings().headerGuard(Utils::FilePath::fromString(in));
 }
 
 QString CppToolsJsExtension::licenseTemplate() const
@@ -98,11 +98,6 @@ QString CppToolsJsExtension::classToFileName(const QString &klass, const QString
     return finalPath + name + ext;
 }
 
-QString CppToolsJsExtension::classToHeaderGuard(const QString &klass, const QString &extension) const
-{
-    return Utils::headerGuard(fileName(className(klass), extension), namespaces(klass));
-}
-
 QString CppToolsJsExtension::openNamespaces(const QString &klass) const
 {
     QString result;
@@ -154,8 +149,8 @@ bool CppToolsJsExtension::hasQObjectParent(const QString &klassName) const
     const WorkingCopy workingCopy = CppModelManager::workingCopy();
     std::optional<QByteArray> source = workingCopy.source(item->filePath());
     if (!source) {
-        const Utils::expected_str<QByteArray> contents = item->filePath().fileContents();
-        QTC_ASSERT_EXPECTED(contents, return false);
+        const Utils::Result<QByteArray> contents = item->filePath().fileContents();
+        QTC_ASSERT_RESULT(contents, return false);
         source = *contents;
     }
     const auto doc = snapshot.preprocessedDocument(*source, item->filePath());
