@@ -9,7 +9,8 @@
 #include "../cpprefactoringchanges.h"
 #include "cppquickfix.h"
 
-#include <QTextDecoder>
+#include <cplusplus/Overview.h>
+#include <utils/textcodec.h>
 
 #ifdef WITH_TESTS
 #include "cppquickfix_test.h"
@@ -303,15 +304,13 @@ public:
             return;
         }
 
-        QTextCodec *utf8codec = QTextCodec::codecForName("UTF-8");
-        QScopedPointer<QTextDecoder> decoder(utf8codec->makeDecoder());
         ChangeSet changes;
 
         bool replace = true;
         for (const QByteArray &chunk : std::as_const(newContents)) {
-            const QString str = decoder->toUnicode(chunk);
+            const QString str = QString::fromUtf8(chunk);
             const QByteArray utf8buf = str.toUtf8();
-            if (!utf8codec->canEncode(str) || chunk != utf8buf)
+            if (chunk != utf8buf)
                 return;
             if (replace)
                 changes.replace(startPos + 1, endPos - 1, str);
