@@ -29,7 +29,7 @@
 #include <coreplugin/editormanager/editormanager.h>
 #include <projectexplorer/kitmanager.h>
 #include <texteditor/textdocument.h>
-#include <QtTest>
+#include <QTest>
 #endif // WITH_TESTS
 
 using namespace CPlusPlus;
@@ -257,15 +257,14 @@ private:
             if (!link.hasValidTarget())
                 return;
             if (symbol->filePath() == link.targetFilePath) {
-                const int linkPos = Text::positionInText(doc, link.targetLine,
-                                                         link.targetColumn + 1);
+                const int linkPos = link.target.toPositionInDocument(doc);
                 if (linkPos == symbolPos)
                     return;
             }
             const CppRefactoringFilePtr refactoringFile
                 = getRefactoringFile(link.targetFilePath, state);
             const QList<AST *> astPath = ASTPath(
-                refactoringFile->cppDocument())(link.targetLine, link.targetColumn);
+                refactoringFile->cppDocument())(link.target.line, link.target.column);
             const bool isTemplate = symbol->asTemplate();
             const bool isFunction = symbol->type()->asFunctionType();
             for (auto it = astPath.rbegin(); it != astPath.rend(); ++it) {
@@ -305,6 +304,8 @@ private:
     {
         for (int i = 0; i < klass->memberCount(); ++i) {
             Symbol * const member = klass->memberAt(i);
+            if (member->isGenerated())
+                continue;
             if (member->asForwardClassDeclaration() || member->asTemplate()) {
                 lookupSymbol(member, state);
                 continue;
@@ -355,11 +356,6 @@ private:
             mustCreateSourceFile = dlg.createSourceFile();
             mustNotCreateSourceFile = !dlg.createSourceFile();
         }
-        const auto fileListForDisplay = [](const FilePaths &files) {
-            return Utils::transform<QStringList>(files, [](const FilePath &fp) {
-                       return '"' + fp.toUserOutput() + '"';
-                   }).join(", ");
-        };
         FilePaths existingFiles;
         if (headerFilePath.exists())
             existingFiles << headerFilePath;
@@ -368,7 +364,7 @@ private:
         if (!existingFiles.isEmpty()) {
             MessageManager::writeDisrupting(
                 Tr::tr("Refusing to overwrite the following files: %1\n")
-                    .arg(fileListForDisplay(existingFiles)));
+                    .arg(existingFiles.toUserOutput(", ")));
             return;
         }
         const QString headerFileName = headerFilePath.fileName();
@@ -412,7 +408,7 @@ private:
             ChangeSet changes;
             if (isDeclFile) {
                 const FilePath baseDir = refactoringFile->filePath().parentDir();
-                const QString relInclude = headerFilePath.relativePathFromDir(baseDir).path();
+                const QString relInclude = headerFilePath.relativePathFromDir(baseDir);
                 insertNewIncludeDirective('"' + relInclude + '"', refactoringFile,
                                           refactoringFile->cppDocument(), changes);
             }
@@ -457,7 +453,7 @@ private:
         if (!notAdded.isEmpty()) {
             MessageManager::writeDisrupting(
                 Tr::tr("Failed to add to project file \"%1\": %2")
-                    .arg(projectNode->filePath().toUserOutput(), fileListForDisplay(notAdded)));
+                    .arg(projectNode->filePath().toUserOutput(), notAdded.toUserOutput(", ")));
         }
 
         if (state->interactive)
