@@ -225,11 +225,31 @@ void LldbEngine::handleLldbStarted()
     showStatusMessage(Tr::tr("Setting up inferior..."));
 
     const DebuggerRunParameters &rp = runParameters();
+    const auto setupDumper = [this](const FilePath &debugHelperDir) {
+        QString dumperPath = debugHelperDir.path();
+        executeCommand("script sys.path.insert(1, '" + dumperPath + "')");
+        // This triggers reportState("enginesetupok") or "enginesetupfailed":
+        executeCommand("script from lldbbridge import *");
+    };
 
-    QString dumperPath = ICore::resourcePath("debugger").path();
-    executeCommand("script sys.path.insert(1, '" + dumperPath + "')");
-    // This triggers reportState("enginesetupok") or "enginesetupfailed":
-    executeCommand("script from lldbbridge import *");
+    const auto runPythonCommand = [this](const DebuggerCommand &command) {
+        // To simplify we only implement a subset of the DebuggerCommand functionality.
+        QTC_CHECK(command.args.isNull() || command.args.isUndefined());
+        QTC_CHECK(!command.callback);
+        QTC_CHECK(!command.flags);
+        QTC_CHECK(!command.postTime);
+
+        const QString function = QString("script ") + command.function;
+        showMessage(function + "\n", LogInput);
+        executeCommand(function);
+    };
+
+    if (const Result<> res = initDebugHelper("lldbbridge", setupDumper, runPythonCommand); !res) {
+        AsynchronousMessageBox::critical(
+            Tr::tr("Cannot Set Up Debugger Helper Scripts"), res.error());
+        notifyEngineSetupFailed();
+        return;
+    }
 
     QString commands = nativeStartupCommands();
     if (!commands.isEmpty())
@@ -317,7 +337,7 @@ void LldbEngine::handleLldbStarted()
                                                                  : rp.deviceSymbolsRoot());
             cmd2.arg("remotechannel", ((rp.startMode() == AttachToRemoteProcess
                                         || rp.startMode() == AttachToRemoteServer)
-                                           ? rp.remoteChannel().toString(): QString()));
+                                           ? rp.remoteChannel() : QString()));
             QTC_CHECK(
                 !rp.continueAfterAttach()
                 || (rp.startMode() == AttachToRemoteProcess || rp.startMode() == AttachToLocalProcess
@@ -522,7 +542,7 @@ void LldbEngine::insertBreakpoint(const Breakpoint &bp)
         QTC_CHECK(bp && bp->state() == BreakpointInsertionProceeding);
         updateBreakpointData(bp, response.data, true);
     };
-    bp->addToCommand(&cmd);
+    bp->addToCommand(runParameters().buildDirectory(), &cmd);
     notifyBreakpointInsertProceeding(bp);
     runCommand(cmd);
 }
@@ -536,7 +556,7 @@ void LldbEngine::updateBreakpoint(const Breakpoint &bp)
         QTC_CHECK(bp && bp->state() == BreakpointUpdateProceeding);
         updateBreakpointData(bp, response.data, false);
     };
-    bp->addToCommand(&cmd);
+    bp->addToCommand(runParameters().buildDirectory(), &cmd);
     notifyBreakpointChangeProceeding(bp);
     runCommand(cmd);
 }
@@ -591,7 +611,11 @@ void LldbEngine::updateBreakpointData(const Breakpoint &bp, const GdbMi &bkpt, b
     bp->setIgnoreCount(bkpt["ignorecount"].toInt());
     bp->setCondition(fromHex(bkpt["condition"].data()));
     bp->setHitCount(bkpt["hitcount"].toInt());
-    bp->setFileName(FilePath::fromUserInput(bkpt["file"].data()));
+
+    const FilePath file = runParameters().buildDirectory().withNewPath(
+        FilePath::fromUserInput(bkpt["file"].data()).path());
+
+    bp->setFileName(file.localSource().value_or(file));
     bp->setTextPosition({bkpt["line"].toInt(), -1});
 
     GdbMi locations = bkpt["locations"];
@@ -1144,4 +1168,4 @@ DebuggerEngine *createLldbEngine()
     return new LldbEngine;
 }
 
-} // Debugger::Internal
+} // namespace Debugger::Internal
