@@ -20,6 +20,7 @@
 
 #include <utils/async.h>
 #include <utils/mathutils.h>
+#include <utils/plaintextedit/texteditorlayout.h>
 #include <utils/tooltip/tooltip.h>
 
 #include <QMenu>
@@ -449,7 +450,7 @@ void SideDiffEditorWidget::paintSeparator(QPainter &painter,
     const QString elidedText = fontMetrics().elidedText(text,
                                                         Qt::ElideRight,
                                                         viewport()->width() - x);
-    QTextLayout *layout = block.layout();
+    QTextLayout *layout = editorLayout()->blockLayout(block);
     QTextLine textLine = layout->lineAt(0);
     QRectF lineRect = textLine.naturalTextRect().translated(offset.x(), top);
     QRect clipRect = contentsRect();
