@@ -18,6 +18,7 @@
 #include "logchangedialog.h"
 #include "remotedialog.h"
 #include "stashdialog.h"
+#include "temporarypatchfile.h"
 
 #include "gerrit/gerritplugin.h"
 
@@ -58,7 +59,6 @@
 #include <vcsbase/vcsbaseconstants.h>
 #include <vcsbase/vcsbaseeditor.h>
 #include <vcsbase/vcsbaseplugin.h>
-#include <vcsbase/vcsbasetr.h>
 #include <vcsbase/vcscommand.h>
 #include <vcsbase/vcsoutputwindow.h>
 
@@ -66,6 +66,7 @@
 
 #include <QAction>
 #include <QApplication>
+#include <QClipboard>
 #include <QDebug>
 #include <QDir>
 #include <QFileDialog>
@@ -81,6 +82,7 @@
 Q_DECLARE_METATYPE(Git::Internal::FileStates)
 
 using namespace Core;
+using namespace Tasking;
 using namespace TextEditor;
 using namespace Utils;
 using namespace VcsBase;
@@ -90,7 +92,7 @@ namespace Git::Internal {
 
 static Q_LOGGING_CATEGORY(log, "qtc.vcs.git", QtWarningMsg);
 
-using GitClientMemberFunc = void (GitClient::*)(const FilePath &) const;
+using GitClientMemberFunc = void (GitClient::*)(const FilePath &);
 
 class GitReflogEditorWidget : public GitEditorWidget
 {
@@ -172,10 +174,7 @@ public:
     void vcsDescribe(const FilePath &source, const QString &id) final { gitClient().show(source, id); }
     QString vcsTopic(const FilePath &directory) final;
 
-    VcsCommand *createInitialCheckoutCommand(const QString &url,
-                                             const FilePath &baseDirectory,
-                                             const QString &localName,
-                                             const QStringList &extraArgs) final;
+    Tasking::ExecutableItem cloneTask(const CloneTaskData &data) const final;
 
     void fillLinkContextMenu(QMenu *menu,
                              const FilePath &workingDirectory,
@@ -243,7 +242,9 @@ public:
     void cleanProjectDirectory();
     void cleanRepository();
     void updateSubmodules();
+    void createPatchesFromCommits();
     void applyCurrentFilePatch();
+    void applyClipboardPatch();
     void promptApplyPatch();
 
     void stash(bool unstagedOnly = false);
@@ -336,59 +337,53 @@ public:
 
     GitGrep gitGrep;
 
-    VcsEditorFactory svnLogEditorFactory {{
-        OtherContent,
-        Git::Constants::GIT_SVN_LOG_EDITOR_ID,
-        VcsBase::Tr::tr("Git SVN Log Editor"),
-        "text/vnd.qtcreator.git.svnlog",
-        [] { return new GitEditorWidget; },
-        std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)
-    }};
+    VcsEditorFactory svnLogEditorFactory{
+        {OtherContent,
+         Git::Constants::GIT_SVN_LOG_EDITOR_ID,
+         Tr::tr("Git SVN Log Editor"),
+         "text/vnd.qtcreator.git.svnlog",
+         [] { return new GitEditorWidget; },
+         std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)}};
 
-    VcsEditorFactory logEditorFactory {{
-        LogOutput,
-        Git::Constants::GIT_LOG_EDITOR_ID,
-        VcsBase::Tr::tr("Git Log Editor"),
-        "text/vnd.qtcreator.git.log",
-        [] { return new GitLogEditorWidgetT<GitEditorWidget>; },
-        std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)
-    }};
+    VcsEditorFactory logEditorFactory{
+        {LogOutput,
+         Git::Constants::GIT_LOG_EDITOR_ID,
+         Tr::tr("Git Log Editor"),
+         "text/vnd.qtcreator.git.log",
+         [] { return new GitLogEditorWidgetT<GitEditorWidget>; },
+         std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)}};
 
-    VcsEditorFactory reflogEditorFactory {{
-        LogOutput,
-        Git::Constants::GIT_REFLOG_EDITOR_ID,
-        VcsBase::Tr::tr("Git Reflog Editor"),
-        "text/vnd.qtcreator.git.reflog",
-        [] { return new GitLogEditorWidgetT<GitReflogEditorWidget>; },
-        std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)
-    }};
+    VcsEditorFactory reflogEditorFactory{
+        {LogOutput,
+         Git::Constants::GIT_REFLOG_EDITOR_ID,
+         Tr::tr("Git Reflog Editor"),
+         "text/vnd.qtcreator.git.reflog",
+         [] { return new GitLogEditorWidgetT<GitReflogEditorWidget>; },
+         std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)}};
 
-    VcsEditorFactory blameEditorFactory {{
-        AnnotateOutput,
-        Git::Constants::GIT_BLAME_EDITOR_ID,
-        VcsBase::Tr::tr("Git Annotation Editor"),
-        "text/vnd.qtcreator.git.annotation",
-        [] { return new GitEditorWidget; },
-        std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)
-    }};
+    VcsEditorFactory blameEditorFactory{
+        {AnnotateOutput,
+         Git::Constants::GIT_BLAME_EDITOR_ID,
+         Tr::tr("Git Annotation Editor"),
+         "text/vnd.qtcreator.git.annotation",
+         [] { return new GitEditorWidget; },
+         std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)}};
 
-    VcsEditorFactory commitTextEditorFactory {{
-        OtherContent,
-        Git::Constants::GIT_COMMIT_TEXT_EDITOR_ID,
-        VcsBase::Tr::tr("Git Commit Editor"),
-        "text/vnd.qtcreator.git.commit",
-        [] { return new GitEditorWidget; },
-        std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)
-    }};
+    VcsEditorFactory commitTextEditorFactory{
+        {OtherContent,
+         Git::Constants::GIT_COMMIT_TEXT_EDITOR_ID,
+         Tr::tr("Git Commit Editor"),
+         "text/vnd.qtcreator.git.commit",
+         [] { return new GitEditorWidget; },
+         std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)}};
 
-    VcsEditorFactory rebaseEditorFactory {{
-        OtherContent,
-        Git::Constants::GIT_REBASE_EDITOR_ID,
-        VcsBase::Tr::tr("Git Rebase Editor"),
-        "text/vnd.qtcreator.git.rebase",
-        [] { return new GitEditorWidget; },
-        std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)
-    }};
+    VcsEditorFactory rebaseEditorFactory{
+        {OtherContent,
+         Git::Constants::GIT_REBASE_EDITOR_ID,
+         Tr::tr("Git Rebase Editor"),
+         "text/vnd.qtcreator.git.rebase",
+         [] { return new GitEditorWidget; },
+         std::bind(&GitPluginPrivate::vcsDescribe, this, _1, _2)}};
 
 private:
     QStringList lineRange(int &firstLine, bool allowSingleLine = false) const;
@@ -557,6 +552,7 @@ GitPluginPrivate::GitPluginPrivate()
 
     Utils::globalMacroExpander()->registerPrefix(
         "Git:Config",
+        "user.name",
         Tr::tr("Access git config variables."),
         [this](const QString &value) {
             return gitClient().readConfigValue(currentState().topLevel(), value);
@@ -836,12 +832,20 @@ GitPluginPrivate::GitPluginPrivate()
     patchMenu->menu()->setTitle(Tr::tr("&Patch"));
     localRepositoryMenu->addMenu(patchMenu);
 
+    createRepositoryAction(patchMenu, Tr::tr("Create from Commits..."),
+                           "Git.CreatePatch", context, true,
+                           std::bind(&GitPluginPrivate::createPatchesFromCommits, this));
+
     // Apply current file as patch is handled specially.
     m_applyCurrentFilePatchAction
             = createParameterAction(patchMenu,
                                     Tr::tr("Apply from Editor"), Tr::tr("Apply \"%1\""),
                                     "Git.ApplyCurrentFilePatch",
                                     context, true, std::bind(&GitPluginPrivate::applyCurrentFilePatch, this));
+
+    createRepositoryAction(patchMenu, Tr::tr("Apply from Clipboard"), "Git.ApplyClipboardPatch",
+                           context, true, std::bind(&GitPluginPrivate::applyClipboardPatch, this));
+
     createRepositoryAction(patchMenu, Tr::tr("Apply from File..."), "Git.ApplyPatch",
                            context, true, std::bind(&GitPluginPrivate::promptApplyPatch, this));
 
@@ -908,7 +912,7 @@ GitPluginPrivate::GitPluginPrivate()
                            context, false, &GitClient::subversionLog);
 
     createRepositoryAction(subversionMenu, "Fetch", "Git.Subversion.Fetch",
-                           context, false, &GitClient::synchronousSubversionFetch);
+                           context, false, &GitClient::subversionFetch);
 
     createRepositoryAction(subversionMenu, Tr::tr("DCommit"), "Git.Subversion.DCommit",
                            context, false, &GitClient::subversionDeltaCommit);
@@ -1010,13 +1014,15 @@ GitPluginPrivate::GitPluginPrivate()
 
     m_instantBlame.setup();
 
-    setupVcsSubmitEditor(this, {
-        Git::Constants::SUBMIT_MIMETYPE,
-        Git::Constants::GITSUBMITEDITOR_ID,
-        VcsBase::Tr::tr("Git Submit Editor"),
-        VcsBaseSubmitEditorParameters::DiffRows,
-        [] { return new GitSubmitEditor; },
-    });
+    setupVcsSubmitEditor(
+        this,
+        {
+            Git::Constants::SUBMIT_MIMETYPE,
+            Git::Constants::GITSUBMITEDITOR_ID,
+            Tr::tr("Git Submit Editor"),
+            VcsBaseSubmitEditorParameters::DiffRows,
+            [] { return new GitSubmitEditor; },
+        });
 }
 
 void GitPluginPrivate::diffCurrentFile(GitClient::DiffMode diffMode)
@@ -1193,6 +1199,21 @@ protected:
     }
 };
 
+class PatchItemDelegate : public IconItemDelegate
+{
+public:
+    PatchItemDelegate(LogChangeWidget *widget)
+        : IconItemDelegate(widget, Icons::PLUS)
+    {
+    }
+
+protected:
+    bool hasIcon(int row) const override
+    {
+        return isRowSelected(row);
+    }
+};
+
 void GitPluginPrivate::resetRepository()
 {
     if (!DocumentManager::saveAllModifiedDocuments())
@@ -1201,7 +1222,7 @@ void GitPluginPrivate::resetRepository()
     QTC_ASSERT(state.hasTopLevel(), return);
     FilePath topLevel = state.topLevel();
 
-    LogChangeDialog dialog(true, ICore::dialogParent());
+    LogChangeDialog dialog(LogChangeDialog::Reset, ICore::dialogParent());
     ResetItemDelegate delegate(dialog.widget());
     dialog.setWindowTitle(Tr::tr("Undo Changes to %1").arg(topLevel.toUserOutput()));
     if (dialog.runDialog(topLevel, {}, LogChangeWidget::IncludeRemotes))
@@ -1234,7 +1255,7 @@ void GitPluginPrivate::startRebaseFromCommit(const FilePath &workingDirectory, Q
         return;
 
     if (commit.isEmpty()) {
-        LogChangeDialog dialog(false, ICore::dialogParent());
+        LogChangeDialog dialog(LogChangeDialog::Select, ICore::dialogParent());
         RebaseItemDelegate delegate(dialog.widget());
         dialog.setWindowTitle(Tr::tr("Interactive Rebase"));
         if (!dialog.runDialog(workingDirectory))
@@ -1309,7 +1330,7 @@ void GitPluginPrivate::unstageFile()
 {
     const VcsBasePluginState state = currentState();
     QTC_ASSERT(state.hasFile(), return);
-    gitClient().synchronousReset(state.currentFileTopLevel(), {state.relativeCurrentFile()});
+    gitClient().reset(state.currentFileTopLevel(), {state.relativeCurrentFile()});
 }
 
 void GitPluginPrivate::gitkForCurrentFile()
@@ -1371,7 +1392,7 @@ void GitPluginPrivate::startCommit(CommitType commitType)
     if (raiseSubmitEditor())
         return;
     if (isCommitEditorOpen()) {
-        VcsOutputWindow::appendWarning(Tr::tr("Another submit is currently being executed."));
+        VcsOutputWindow::appendWarning({}, Tr::tr("Another submit is currently being executed."));
         return;
     }
 
@@ -1380,7 +1401,7 @@ void GitPluginPrivate::startCommit(CommitType commitType)
 
     const Result<CommitData> res = gitClient().getCommitData(commitType, state.topLevel());
     if (!res) {
-        VcsOutputWindow::appendError(res.error());
+        VcsOutputWindow::appendError(state.topLevel(), res.error());
         return;
     }
     const CommitData data = res.value();
@@ -1397,7 +1418,7 @@ void GitPluginPrivate::startCommit(CommitType commitType)
     saver.setAutoRemove(false);
     saver.write(data.commitTemplate.toLocal8Bit());
     if (const Result<> res = saver.finalize(); !res) {
-        VcsOutputWindow::appendError(res.error());
+        VcsOutputWindow::appendError(m_submitRepository, res.error());
         return;
     }
     m_commitMessageFileName = saver.filePath();
@@ -1573,6 +1594,21 @@ void GitPluginPrivate::updateSubmodules()
     gitClient().updateSubmodulesIfNeeded(state.topLevel(), false);
 }
 
+void GitPluginPrivate::createPatchesFromCommits()
+{
+    const VcsBasePluginState state = currentState();
+    QTC_ASSERT(state.hasTopLevel(), return);
+
+    LogChangeDialog dialog(LogChangeDialog::Select, Core::ICore::dialogParent());
+    PatchItemDelegate delegate(dialog.widget());
+    dialog.setContiguousSelectionEnabled(true);
+    dialog.setWindowTitle(Tr::tr("Select Commits for Patch Creation"));
+
+    const Utils::FilePath topLevel = state.topLevel();
+    if (dialog.runDialog(topLevel, {}, LogChangeWidget::None))
+        gitClient().formatPatch(topLevel, dialog.patchRange());
+}
+
 // If the file is modified in an editor, make sure it is saved.
 static bool ensureFileSaved(const QString &fileName)
 {
@@ -1590,6 +1626,20 @@ void GitPluginPrivate::applyCurrentFilePatch()
     applyPatch(state.topLevel(), patchFile);
 }
 
+void GitPluginPrivate::applyClipboardPatch()
+{
+    const VcsBasePluginState state = currentState();
+    QTC_ASSERT(state.hasTopLevel(), return);
+
+    QClipboard *clipboard = QApplication::clipboard();
+    const QString patch = clipboard->text();
+    if (patch.isEmpty())
+        return;
+
+    const TemporaryPatchFile patchFile(patch);
+    applyPatch(state.topLevel(), patchFile.filePath().toUrlishString());
+}
+
 void GitPluginPrivate::promptApplyPatch()
 {
     const VcsBasePluginState state = currentState();
@@ -1615,12 +1665,13 @@ void GitPluginPrivate::applyPatch(const FilePath &workingDirectory, QString file
     QString errorMessage;
     if (gitClient().synchronousApplyPatch(workingDirectory, file, &errorMessage)) {
         if (errorMessage.isEmpty())
-            VcsOutputWindow::appendMessage(Tr::tr("Patch %1 successfully applied to %2")
-                                           .arg(file, workingDirectory.toUserOutput()));
+            VcsOutputWindow::appendMessage(workingDirectory,
+                                           Tr::tr("Patch %1 successfully applied to %2")
+                                               .arg(file, workingDirectory.toUserOutput()));
         else
-            VcsOutputWindow::appendError(errorMessage);
+            VcsOutputWindow::appendError(workingDirectory, errorMessage);
     } else {
-        VcsOutputWindow::appendError(errorMessage);
+        VcsOutputWindow::appendError(workingDirectory, errorMessage);
     }
     gitClient().endStashScope(workingDirectory);
 }
@@ -1872,9 +1923,7 @@ bool GitPluginPrivate::vcsDelete(const FilePath &filePath)
 
 bool GitPluginPrivate::vcsMove(const FilePath &from, const FilePath &to)
 {
-    const QFileInfo fromInfo = from.toFileInfo();
-    const QFileInfo toInfo = to.toFileInfo();
-    return gitClient().synchronousMove(from.absolutePath(), fromInfo.absoluteFilePath(), toInfo.absoluteFilePath());
+    return gitClient().synchronousMove(from.absolutePath(), from, to);
 }
 
 bool GitPluginPrivate::vcsCreateRepository(const FilePath &directory)
@@ -1891,17 +1940,15 @@ QString GitPluginPrivate::vcsTopic(const FilePath &directory)
     return topic;
 }
 
-VcsCommand *GitPluginPrivate::createInitialCheckoutCommand(const QString &url,
-                                                           const FilePath &baseDirectory,
-                                                           const QString &localName,
-                                                           const QStringList &extraArgs)
+ExecutableItem GitPluginPrivate::cloneTask(const CloneTaskData &data) const
 {
-    auto command = VcsBaseClient::createVcsCommand(baseDirectory,
-                                                   gitClient().processEnvironment(baseDirectory));
-    command->addFlags(RunFlags::SuppressStdErr);
-    command->addJob({gitClient().vcsBinary(baseDirectory),
-                     {"clone", "--progress", extraArgs, url, localName}}, -1);
-    return command;
+    const CommandLine command{gitClient().vcsBinary(data.baseDirectory),
+                              {"clone", "--progress", data.extraArgs, data.url, data.localName}};
+    return vcsProcessTask({.runData = {command, data.baseDirectory,
+                            gitClient().processEnvironment(data.baseDirectory)},
+                           .flags = RunFlags::SuppressStdErr,
+                           .stdOutHandler = data.stdOutHandler,
+                           .stdErrHandler = data.stdErrHandler});
 }
 
 GitPluginPrivate::RepoUrl GitPluginPrivate::getRepoUrl(const QString &location) const
@@ -1943,9 +1990,9 @@ void GitPluginPrivate::vcsAnnotate(const FilePath &filePath, int line)
 
 // "Internal API"
 
-void emitFilesChanged(const QStringList &l)
+void emitFilesChanged(const FilePaths &files)
 {
-    emit dd->filesChanged(l);
+    emit dd->filesChanged(files);
 }
 
 void emitRepositoryChanged(const FilePath &r)
