@@ -85,6 +85,8 @@ const char profileTeamIdTag[] = "TeamIdentifier";
 static const QString xcodePlistPath = QDir::homePath() + "/Library/Preferences/com.apple.dt.Xcode.plist";
 static const QString provisioningProfileDirPath = QDir::homePath() + "/Library/MobileDevice/Provisioning Profiles";
 
+const char iosDetectionSource[] = "iosdetectionsource";
+
 static Id deviceId(const QString &sdkName)
 {
     if (sdkName.startsWith("iphoneos", Qt::CaseInsensitive))
@@ -112,9 +114,8 @@ static QList<GccToolchain *> autoDetectedIosToolchains()
 {
     const QList<GccToolchain *> toolchains = clangToolchains(ToolchainManager::toolchains());
     return filtered(toolchains, [](GccToolchain *toolChain) {
-        return toolChain->isAutoDetected()
-               && (toolChain->displayName().startsWith("iphone")
-                   || toolChain->displayName().startsWith("Apple Clang")); // TODO tool chains should be marked directly
+        const DetectionSource ds = toolChain->detectionSource();
+        return ds.isAutoDetected() && ds.id == iosDetectionSource;
     });
 }
 
@@ -156,7 +157,7 @@ static QSet<Kit *> existingAutoDetectedIosKits()
 {
     return toSet(filtered(KitManager::kits(), [](Kit *kit) -> bool {
         Id deviceKind = RunDeviceTypeKitAspect::deviceTypeId(kit);
-        return kit->isAutoDetected() && (deviceKind == Constants::IOS_DEVICE_TYPE
+        return kit->detectionSource().isAutoDetected() && (deviceKind == Constants::IOS_DEVICE_TYPE
                                          || deviceKind == Constants::IOS_SIMULATOR_TYPE);
     }));
 }
@@ -287,7 +288,7 @@ void IosConfigurations::updateAutomaticKitList()
                 } else {
                     qCDebug(kitSetupLog) << "    - Setting up new kit";
                     const auto init = [&](Kit *k) {
-                        k->setAutoDetected(true);
+                        k->setDetectionSource({DetectionSource::FromSystem, iosDetectionSource});
                         const QString baseDisplayName = isSimulatorDeviceId(pDeviceType)
                                 ? Tr::tr("%1 Simulator").arg(qtVersion->unexpandedDisplayName())
                                 : qtVersion->unexpandedDisplayName();
@@ -623,16 +624,16 @@ Toolchains IosToolchainFactory::autoDetect(const ToolchainDetector &detector) co
                 if (!toolChain) {
                     toolChain = new GccToolchain(ProjectExplorer::Constants::CLANG_TOOLCHAIN_TYPEID,
                                                  GccToolchain::Clang);
-                    toolChain->setPriority(Toolchain::PriorityLow);
-                    toolChain->setDetection(Toolchain::AutoDetection);
                     toolChain->setLanguage(l);
-                    toolChain->setDisplayName(target.name);
                     toolChain->setPlatformCodeGenFlags(target.backendFlags);
                     toolChain->setPlatformLinkerFlags(target.backendFlags);
                     toolChain->resetToolchain(l == ProjectExplorer::Constants::CXX_LANGUAGE_ID ?
                                                   platform.cxxCompilerPath : platform.cCompilerPath);
                     existingClangToolchains.append(toolChain);
                 }
+                toolChain->setPriority(Toolchain::PriorityLow);
+                toolChain->setDetectionSource({DetectionSource::FromSystem, iosDetectionSource});
+                toolChain->setDisplayName(target.name);
                 toolchains.append(toolChain);
             };
 
