@@ -15,8 +15,8 @@
 #include "languageclientoutline.h"
 #include "languageclientquickfix.h"
 #include "languageclientsymbolsupport.h"
-#include "languageclientutils.h"
 #include "languageclienttr.h"
+#include "languageclientutils.h"
 #include "progressmanager.h"
 #include "semantichighlightsupport.h"
 
@@ -25,6 +25,8 @@
 #include <coreplugin/idocument.h>
 #include <coreplugin/messagemanager.h>
 
+#include <extensionsystem/pluginmanager.h>
+
 #include <languageserverprotocol/completion.h>
 #include <languageserverprotocol/diagnostics.h>
 #include <languageserverprotocol/initializemessages.h>
@@ -50,6 +52,7 @@
 #include <utils/appinfo.h>
 #include <utils/mimeutils.h>
 #include <utils/qtcprocess.h>
+#include <utils/stringutils.h>
 
 #include <QDebug>
 #include <QGuiApplication>
@@ -345,7 +348,6 @@ public:
     SymbolSupport m_symbolSupport;
     MessageId m_runningFindLinkRequest;
     ProgressManager m_progressManager;
-    bool m_activateDocAutomatically = false;
     SemanticTokenSupport m_tokenSupport;
     QString m_serverName;
     QString m_serverVersion;
@@ -379,8 +381,13 @@ QString Client::name() const
     if (d->m_bc) {
         const QString projectDisplayName = d->m_bc->project()->displayName();
         if (!projectDisplayName.isEmpty()) {
-            //: <language client> for <project>
-            return Tr::tr("%1 for %2").arg(d->m_displayName, projectDisplayName);
+            //: for example: MyServer for MyProject (Qt 1.2.3, Release)
+            return Tr::tr("%1 for %2 (%3, %4)")
+                .arg(
+                    d->m_displayName,
+                    projectDisplayName,
+                    d->m_bc->target()->displayName(),
+                    d->m_bc->displayName());
         }
     }
     return d->m_displayName;
@@ -472,7 +479,7 @@ static ClientCapabilities generateClientCapabilities()
     TextDocumentClientCapabilities::CodeActionCapabilities::CodeActionLiteralSupport literalSupport;
     literalSupport.setCodeActionKind(
         TextDocumentClientCapabilities::CodeActionCapabilities::CodeActionLiteralSupport::
-            CodeActionKind(QList<QString>{"*"}));
+            CodeActionKind(QStringList{"*"}));
     codeActionCapabilities.setCodeActionLiteralSupport(literalSupport);
     documentCapabilities.setCodeAction(codeActionCapabilities);
 
@@ -969,16 +976,9 @@ void ClientPrivate::requestDocumentHighlightsNow(TextEditor::TextEditorWidget *w
                     widget, adjustedCursor);
                 for (const Text::Range &range : extraRanges) {
                     QTextEdit::ExtraSelection selection{widget->textCursor(), format};
-                    const Text::Position &startPos = range.begin;
-                    const Text::Position &endPos = range.end;
-                    const int start = Text::positionInText(document, startPos.line,
-                                                           startPos.column + 1);
-                    const int end = Text::positionInText(document, endPos.line,
-                                                         endPos.column + 1);
-                    if (start < 0 || end < 0 || start >= end)
+                    selection.cursor = range.toTextCursor(document);
+                    if (!selection.cursor.hasSelection())
                         continue;
-                    selection.cursor.setPosition(start);
-                    selection.cursor.setPosition(end, QTextCursor::KeepAnchor);
                     static const auto cmp = [](const QTextEdit::ExtraSelection &s1,
                                         const QTextEdit::ExtraSelection &s2) {
                         return s1.cursor.position() < s2.cursor.position();
@@ -1572,11 +1572,36 @@ bool Client::canOpenProject(Project *project)
 void Client::updateConfiguration(const QJsonValue &configuration)
 {
     d->m_configuration = configuration;
-    if (reachable() && !configuration.isNull()
+
+    QJsonValue mergedConfig;
+    for (ExtensionSystem::PluginSpec *plugin : ExtensionSystem::PluginManager::plugins()) {
+        if (!plugin->isEffectivelyEnabled())
+            continue;
+
+        QJsonValue lcValue = plugin->metaData().value("languageclient");
+        if (lcValue.isUndefined())
+            continue;
+        QTC_ASSERT(lcValue.isObject(), continue);
+        QJsonObject lspConfig = lcValue.toObject();
+
+        QJsonValue workspaceConfigValue = lspConfig.value("WorkspaceConfig");
+        if (workspaceConfigValue.isUndefined())
+            continue;
+        QTC_ASSERT(workspaceConfigValue.isObject(), continue);
+        applyJsonPatch(mergedConfig, workspaceConfigValue);
+    }
+    if (configuration.isObject())
+        applyJsonPatch(mergedConfig, configuration);
+
+    qCDebug(LOGLSPCLIENT).noquote()
+        << "Merged configuration for" << name() << ":"
+        << QJsonDocument(mergedConfig.toObject()).toJson(QJsonDocument::Indented);
+
+    if (reachable() && !mergedConfig.toObject().isEmpty()
         && d->m_dynamicCapabilities.isRegistered(DidChangeConfigurationNotification::methodName)
                .value_or(true)) {
         DidChangeConfigurationParams params;
-        params.setSettings(configuration);
+        params.setSettings(mergedConfig);
         DidChangeConfigurationNotification notification(params);
         sendMessage(notification);
     }
@@ -1758,7 +1783,7 @@ bool ClientPrivate::reset()
 
 void Client::setError(const QString &message)
 {
-    log(message);
+    log(QtMsgType::QtCriticalMsg, message);
     switch (d->m_state) {
     case Uninitialized:
     case InitializeRequested:
@@ -1793,15 +1818,38 @@ void Client::handleMessage(const LanguageServerProtocol::JsonRpcMessage &message
         d->handleMethod(method, id, message);
 }
 
-void Client::log(const QString &message) const
+void Client::log(QtMsgType msgType, const QString &message) const
 {
     switch (d->m_logTarget) {
     case LogTarget::Ui:
-        Core::MessageManager::writeFlashing(QString("LanguageClient %1: %2").arg(name(), message));
+        switch (msgType) {
+        case QtMsgType::QtDebugMsg:
+        case QtMsgType::QtInfoMsg:
+            qCDebug(LOGLSPCLIENT) << message;
+            break;
+        case QtMsgType::QtWarningMsg:
+        case QtMsgType::QtCriticalMsg:
+        case QtMsgType::QtFatalMsg:
+            Core::MessageManager::writeFlashing(
+                QString("LanguageClient %1: %2").arg(name(), message));
+        }
         break;
     case LogTarget::Console:
-        qCDebug(LOGLSPCLIENT) << message;
-        break;
+        switch (msgType) {
+        case QtMsgType::QtDebugMsg:
+            qCDebug(LOGLSPCLIENT) << message;
+            break;
+        case QtMsgType::QtInfoMsg:
+            qCInfo(LOGLSPCLIENT) << message;
+            break;
+        case QtMsgType::QtWarningMsg:
+            qCWarning(LOGLSPCLIENT) << message;
+            break;
+        case QtMsgType::QtCriticalMsg:
+        case QtMsgType::QtFatalMsg:
+            qCCritical(LOGLSPCLIENT) << message;
+        }
+    break;
     }
 }
 
@@ -1862,7 +1910,7 @@ SemanticTokenSupport *Client::semanticTokenSupport()
 
 void ClientPrivate::log(const ShowMessageParams &message)
 {
-    q->log(message.toString());
+    q->log(message.qtMsgType(), message.toString());
 }
 
 LanguageClientValue<MessageActionItem> ClientPrivate::showMessageBox(
@@ -1872,16 +1920,19 @@ LanguageClientValue<MessageActionItem> ClientPrivate::showMessageBox(
     box.setWindowTitle(q->name());
     box.setText(message.toString());
     switch (message.type()) {
-    case Error:
+    case ShowMessageParams::MessageType::Error:
         box.setIcon(QMessageBox::Critical);
         break;
-    case Warning:
+    case ShowMessageParams::MessageType::Warning:
         box.setIcon(QMessageBox::Warning);
         break;
-    case Info:
+    case ShowMessageParams::MessageType::Info:
         box.setIcon(QMessageBox::Information);
         break;
-    case Log:
+    case ShowMessageParams::MessageType::Log:
+        box.setIcon(QMessageBox::NoIcon);
+        break;
+    case ShowMessageParams::MessageType::Debug:
         box.setIcon(QMessageBox::NoIcon);
         break;
     }
@@ -2022,21 +2073,21 @@ void ClientPrivate::handleMethod(const QString &method, const MessageId &id, con
         if (params.isValid())
             q->handleDiagnostics(params);
         else
-            q->log(invalidParamsErrorMessage(params));
+            q->log(QtMsgType::QtCriticalMsg, invalidParamsErrorMessage(params));
     } else if (method == LogMessageNotification::methodName) {
         auto params = LogMessageNotification(message.toJsonObject()).params().value_or(
             LogMessageParams());
         if (params.isValid())
             log(params);
         else
-            q->log(invalidParamsErrorMessage(params));
+            q->log(QtMsgType::QtCriticalMsg, invalidParamsErrorMessage(params));
     } else if (method == ShowMessageNotification::methodName) {
         auto params = ShowMessageNotification(message.toJsonObject()).params().value_or(
             ShowMessageParams());
         if (params.isValid())
             log(params);
         else
-            q->log(invalidParamsErrorMessage(params));
+            q->log(QtMsgType::QtCriticalMsg, invalidParamsErrorMessage(params));
     } else if (method == ShowMessageRequest::methodName) {
         auto request = ShowMessageRequest(message.toJsonObject());
         ShowMessageRequest::Response response(id);
@@ -2045,7 +2096,7 @@ void ClientPrivate::handleMethod(const QString &method, const MessageId &id, con
             response.setResult(showMessageBox(params));
         } else {
             const QString errorMessage = invalidParamsErrorMessage(params);
-            q->log(errorMessage);
+            q->log(QtMsgType::QtCriticalMsg, errorMessage);
             response.setError(createInvalidParamsError<std::nullptr_t>(errorMessage));
         }
         sendResponse(response);
@@ -2057,7 +2108,7 @@ void ClientPrivate::handleMethod(const QString &method, const MessageId &id, con
             sendResponse(createDefaultResponse());
         } else {
             const QString errorMessage = invalidParamsErrorMessage(params);
-            q->log(invalidParamsErrorMessage(params));
+            q->log(QtMsgType::QtCriticalMsg, invalidParamsErrorMessage(params));
             RegisterCapabilityRequest::Response response(id);
             response.setError(createInvalidParamsError<std::nullptr_t>(errorMessage));
             sendResponse(response);
@@ -2070,7 +2121,7 @@ void ClientPrivate::handleMethod(const QString &method, const MessageId &id, con
             sendResponse(createDefaultResponse());
         } else {
             const QString errorMessage = invalidParamsErrorMessage(params);
-            q->log(invalidParamsErrorMessage(params));
+            q->log(QtMsgType::QtCriticalMsg, invalidParamsErrorMessage(params));
             UnregisterCapabilityRequest::Response response(id);
             response.setError(createInvalidParamsError<std::nullptr_t>(errorMessage));
             sendResponse(response);
@@ -2085,7 +2136,7 @@ void ClientPrivate::handleMethod(const QString &method, const MessageId &id, con
             response.setResult(result);
         } else {
             const QString errorMessage = invalidParamsErrorMessage(params);
-            q->log(errorMessage);
+            q->log(QtMsgType::QtCriticalMsg, errorMessage);
             response.setError(createInvalidParamsError<std::nullptr_t>(errorMessage));
         }
         sendResponse(response);
@@ -2113,7 +2164,7 @@ void ClientPrivate::handleMethod(const QString &method, const MessageId &id, con
         if (std::optional<ProgressParams> params
             = ProgressNotification(message.toJsonObject()).params()) {
             if (!params->isValid())
-                q->log(invalidParamsErrorMessage(*params));
+                q->log(QtMsgType::QtCriticalMsg, invalidParamsErrorMessage(*params));
             m_progressManager.handleProgress(*params);
             if (ProgressManager::isProgressEndMessage(*params))
                 emit q->workDone(params->token());
@@ -2221,14 +2272,18 @@ void ClientPrivate::initializeCallback(const InitializeRequest::Response &initRe
     }
     if (const std::optional<InitializeResult> &result = initResponse.result()) {
         if (!result->isValid()) { // continue on ill formed result
-            q->log(QJsonDocument(*result).toJson(QJsonDocument::Indented) + '\n'
-                + Tr::tr("Initialize result is invalid."));
+            q->log(
+                QtMsgType::QtCriticalMsg,
+                QJsonDocument(*result).toJson(QJsonDocument::Indented) + '\n'
+                    + Tr::tr("Initialize result is invalid."));
         }
         const std::optional<ServerInfo> serverInfo = result->serverInfo();
         if (serverInfo) {
             if (!serverInfo->isValid()) {
-                q->log(QJsonDocument(*result).toJson(QJsonDocument::Indented) + '\n'
-                    + Tr::tr("Server Info is invalid."));
+                q->log(
+                    QtMsgType::QtCriticalMsg,
+                    QJsonDocument(*result).toJson(QJsonDocument::Indented) + '\n'
+                        + Tr::tr("Server Info is invalid."));
             } else {
                 m_serverName = serverInfo->name();
                 if (const std::optional<QString> version = serverInfo->version())
@@ -2238,7 +2293,7 @@ void ClientPrivate::initializeCallback(const InitializeRequest::Response &initRe
 
         m_serverCapabilities = result->capabilities();
     } else {
-        q->log(Tr::tr("No initialize result."));
+        q->log(QtMsgType::QtCriticalMsg, Tr::tr("No initialize result."));
     }
 
     if (auto completionProvider = qobject_cast<LanguageClientCompletionAssistProvider *>(
