@@ -203,7 +203,7 @@ void SemanticTokenSupport::queueDocumentReload(TextEditor::TextDocument *doc)
         Qt::QueuedConnection);
 }
 
-void SemanticTokenSupport::clearHighlight(TextEditor::TextDocument *doc)
+void SemanticTokenSupport::deactivateDocument(TextEditor::TextDocument *doc)
 {
     if (m_tokens.contains(doc->filePath())){
         if (TextEditor::SyntaxHighlighter *highlighter = doc->syntaxHighlighter())
@@ -211,6 +211,11 @@ void SemanticTokenSupport::clearHighlight(TextEditor::TextDocument *doc)
     }
 }
 
+void SemanticTokenSupport::clearCache(TextEditor::TextDocument *doc)
+{
+    m_tokens.remove(doc->filePath());
+}
+
 void SemanticTokenSupport::rehighlight()
 {
     for (auto it = m_tokens.cbegin(); it != m_tokens.cend(); ++it)
