@@ -17,7 +17,9 @@
 #include <utils/infobar.h>
 #include <utils/processinterface.h>
 
+#include <QCoreApplication>
 #include <QDesktopServices>
+#include <QStandardPaths>
 #include <QTimer>
 #include <QUuid>
 
@@ -195,7 +197,7 @@ void setupUtilsModule()
                 const auto locationsStrings = QStandardPaths::standardLocations(
                     static_cast<QStandardPaths::StandardLocation>(location));
 
-                QList<FilePath> locationsPaths;
+                FilePaths locationsPaths;
                 std::transform(locationsStrings.constBegin(), locationsStrings.constEnd(),
                                std::back_inserter(locationsPaths), &FilePath::fromString);
                 return locationsPaths;
@@ -329,7 +331,7 @@ void setupUtilsModule()
 
 InfoBarCleaner::~InfoBarCleaner()
 {
-    for (const auto &id : openInfoBars)
+    for (const auto &id : std::as_const(openInfoBars))
         Core::ICore::infoBar()->removeInfo(id);
 }
 
