@@ -8,8 +8,6 @@
 
 #include <coreplugin/icore.h>
 
-#include <extensionsystem/extensionsystemtr.h>
-
 #include <utils/algorithm.h>
 #include <utils/appinfo.h>
 
@@ -29,7 +27,7 @@ class LuaScriptPluginPrivate
 {
 public:
     QString name;
-    QList<QString> cppDepends;
+    QStringList cppDepends;
     sol::function setup;
     sol::environment pluginEnvironment;
 };
