@@ -1,10 +1,9 @@
 // Copyright (C) 2020 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "mcusupportdevice.h"
 #include "mcusupportconstants.h"
-
-#include <projectexplorer/runcontrol.h>
+#include "mcusupporttr.h"
 
 using namespace ProjectExplorer;
 using namespace Utils;
@@ -16,7 +15,7 @@ McuSupportDevice::McuSupportDevice()
 {
     setupId(IDevice::AutoDetected, Constants::DEVICE_ID);
     setType(Constants::DEVICE_TYPE);
-    const QString displayNameAndType = tr("MCU Device");
+    const QString displayNameAndType = Tr::tr("MCU Device");
     setDefaultDisplayName(displayNameAndType);
     setDisplayType(displayNameAndType);
     setDeviceState(IDevice::DeviceStateUnknown);
@@ -33,7 +32,7 @@ ProjectExplorer::IDevice::Ptr McuSupportDevice::create()
 McuSupportDeviceFactory::McuSupportDeviceFactory()
     : ProjectExplorer::IDeviceFactory(Constants::DEVICE_TYPE)
 {
-    setDisplayName(McuSupportDevice::tr("MCU Device"));
+    setDisplayName(Tr::tr("MCU Device"));
     setCombinedIcon(":/mcusupport/images/mcusupportdevicesmall.png",
                     ":/mcusupport/images/mcusupportdevice.png");
     setConstructionFunction(&McuSupportDevice::create);
