@@ -1,17 +1,16 @@
 // Copyright (C) 2020 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
 #include <projectexplorer/devicesupport/desktopdevice.h>
+#include <projectexplorer/devicesupport/idevicefactory.h>
 
 namespace McuSupport {
 namespace Internal {
 
 class McuSupportDevice final : public ProjectExplorer::DesktopDevice
 {
-    Q_DECLARE_TR_FUNCTIONS(McuSupport::Internal::McuSupportDevice)
-
 public:
     static ProjectExplorer::IDevice::Ptr create();
 
