@@ -31,10 +31,7 @@ namespace ProjectExplorer {
 class BuildDirectoryAspect::Private
 {
 public:
-    Private(Target *target) : target(target) {}
-
     FilePath sourceDir;
-    Target * const target;
     FilePath savedShadowBuildDir;
     QString specialProblem;
     QLabel *genericProblemSpacer;
@@ -43,9 +40,9 @@ public:
     QPointer<InfoLabel> specialProblemLabel;
 };
 
-BuildDirectoryAspect::BuildDirectoryAspect(AspectContainer *container, const BuildConfiguration *bc)
-    : FilePathAspect(container),
-      d(new Private(bc->target()))
+BuildDirectoryAspect::BuildDirectoryAspect(BuildConfiguration *bc)
+    : FilePathAspect(bc),
+      d(new Private)
 {
     setSettingsKey("ProjectExplorer.BuildConfiguration.BuildDirectory");
     setLabelText(Tr::tr("Build directory:"));
@@ -58,14 +55,14 @@ BuildDirectoryAspect::BuildDirectoryAspect(AspectContainer *container, const Bui
 
         const QString problem = updateProblemLabelsHelper(text);
         if (!problem.isEmpty())
-            return QtFuture::makeReadyFuture(expected_str<QString>(make_unexpected(problem)));
+            return QtFuture::makeReadyFuture(Result<QString>(make_unexpected(problem)));
 
         const FilePath newPath = FilePath::fromUserInput(text);
-        const auto buildDevice = BuildDeviceKitAspect::device(d->target->kit());
+        const auto buildDevice = BuildDeviceKitAspect::device(buildConfiguration()->kit());
 
         if (buildDevice && buildDevice->type() != ProjectExplorer::Constants::DESKTOP_DEVICE_TYPE
             && !buildDevice->rootPath().ensureReachable(newPath)) {
-            return QtFuture::makeReadyFuture((Utils::expected_str<QString>(make_unexpected(
+            return QtFuture::makeReadyFuture((Utils::Result<QString>(make_unexpected(
                 Tr::tr("The build directory is not reachable from the build device.")))));
         }
 
@@ -76,8 +73,8 @@ BuildDirectoryAspect::BuildDirectoryAspect(AspectContainer *container, const Bui
         Core::FileUtils::openTerminal(expandedValue(), bc->environment());
     });
 
-    connect(ProjectExplorerPlugin::instance(), &ProjectExplorerPlugin::settingsChanged,
-            this, &BuildDirectoryAspect::validateInput);
+    ProjectExplorerSettings::registerCallback(
+        this, &ProjectExplorerSettings::warnAgainstNonAsciiBuildDir, [this] { validateInput(); });
 }
 
 BuildDirectoryAspect::~BuildDirectoryAspect()
@@ -150,13 +147,20 @@ void BuildDirectoryAspect::addToLayoutImpl(Layouting::Layout &parent)
         });
     }
 
-    const auto buildDevice = BuildDeviceKitAspect::device(d->target->kit());
+    const auto buildDevice = BuildDeviceKitAspect::device(buildConfiguration()->kit());
     if (buildDevice && buildDevice->type() != ProjectExplorer::Constants::DESKTOP_DEVICE_TYPE)
         pathChooser()->setAllowPathFromDevice(true);
     else
         pathChooser()->setAllowPathFromDevice(false);
 }
 
+void BuildDirectoryAspect::announceChanges(Changes changes, Announcement howToAnnounce)
+{
+    if (changes.bufferFromInternal && isCheckable())
+        setChecked(d->sourceDir != expandedValue());
+    FilePathAspect::announceChanges(changes, howToAnnounce);
+}
+
 FilePath BuildDirectoryAspect::fixupDir(const FilePath &dir)
 {
     if (!dir.isLocal())
@@ -190,7 +194,7 @@ QString BuildDirectoryAspect::updateProblemLabelsHelper(const QString &value)
 
     QString genericProblem;
     QString genericProblemLabelString;
-    if (projectExplorerSettings().warnAgainstNonAsciiBuildDir) {
+    if (ProjectExplorerSettings::get(this).warnAgainstNonAsciiBuildDir()) {
         const auto isInvalid = [](QChar c) { return c.isSpace() || !isascii(c.toLatin1()); };
         if (const auto invalidChar = Utils::findOr(value, std::nullopt, isInvalid)) {
             genericProblem = Tr::tr(
@@ -220,6 +224,11 @@ QString BuildDirectoryAspect::updateProblemLabelsHelper(const QString &value)
     return genericProblem + '\n' + d->specialProblem;
 }
 
+BuildConfiguration *BuildDirectoryAspect::buildConfiguration() const
+{
+    return qobject_cast<BuildConfiguration *>(container());
+}
+
 SeparateDebugInfoAspect::SeparateDebugInfoAspect(AspectContainer *container)
     : TriStateAspect(container)
 {
