@@ -72,6 +72,8 @@ class BuildEnvironmentWidget : public QWidget
 public:
     explicit BuildEnvironmentWidget(BuildConfiguration *bc)
     {
+        setWindowTitle(Tr::tr("Build Environment"));
+
         auto clearBox = new QCheckBox(Tr::tr("Clear system environment"), this);
         clearBox->setChecked(!bc->useSystemEnvironment());
 
@@ -113,21 +115,23 @@ class CustomParsersBuildWidget : public QWidget
 public:
     CustomParsersBuildWidget(BuildConfiguration *bc)
     {
-        const auto layout = new QVBoxLayout(this);
-        layout->setContentsMargins(0, 0, 0, 0);
+        setWindowTitle(Tr::tr("Custom Output Parsers"));
 
         const auto pasteStdOutCB = new QCheckBox(Tr::tr("Parse standard output during build"), this);
         pasteStdOutCB->setToolTip(Tr::tr("Makes output parsers look for diagnostics "
                                      "on stdout rather than stderr."));
         pasteStdOutCB->setChecked(bc->parseStdOut());
-        layout->addWidget(pasteStdOutCB);
-
         connect(pasteStdOutCB, &QCheckBox::clicked, bc, &BuildConfiguration::setParseStdOut);
+
         const auto selectionWidget =
                 new CustomParsersSelectionWidget(CustomParsersSelectionWidget::InBuildConfig, this);
+
+        const auto layout = new QVBoxLayout(this);
+        layout->setContentsMargins(0, 0, 0, 0);
+        layout->addWidget(pasteStdOutCB);
         layout->addWidget(selectionWidget);
 
-        QList<Utils::Id> parsers = bc->customParsers();
+        QList<Id> parsers = bc->customParsers();
         for (const auto &s : ProjectExplorerPlugin::customParsers()) {
             if (s.buildDefault && !parsers.contains(s.id))
                 parsers.append(s.id);
@@ -166,11 +170,11 @@ public:
     bool m_parseStdOut = false;
     QList<Utils::Id> m_customParsers;
     Store m_extraData;
-    BuildSystem *m_buildSystem = nullptr;
-    QList<DeployConfiguration *> m_deployConfigurations;
-    DeployConfiguration *m_activeDeployConfiguration = nullptr;
-    QList<RunConfiguration *> m_runConfigurations;
-    RunConfiguration* m_activeRunConfiguration = nullptr;
+    QPointer<BuildSystem> m_buildSystem;
+    QList<QPointer<DeployConfiguration>> m_deployConfigurations;
+    QPointer<DeployConfiguration> m_activeDeployConfiguration;
+    QList<QPointer<RunConfiguration>> m_runConfigurations;
+    QPointer<RunConfiguration> m_activeRunConfiguration;
 
     ProjectConfigurationModel m_deployConfigurationModel;
     ProjectConfigurationModel m_runConfigurationModel;
@@ -191,9 +195,10 @@ BuildConfiguration::BuildConfiguration(Target *target, Utils::Id id)
     MacroExpander *expander = macroExpander();
     expander->setDisplayName(Tr::tr("Build Settings"));
     expander->setAccumulating(true);
-    expander->registerSubProvider([this] { return kit()->macroExpander(); });
+    expander->registerSubProvider({this, [this] { return kit()->macroExpander(); }});
     expander->registerVariable("sourceDir", Tr::tr("Source directory"),
-                               [this] { return project()->projectDirectory().toUserOutput(); });
+                               [this] { return project()->projectDirectory().toUserOutput(); },
+                               false);
     expander->registerVariable("BuildSystem:Name", Tr::tr("Build system"), [this] {
         return buildSystem()->name();
     });
@@ -201,15 +206,20 @@ BuildConfiguration::BuildConfiguration(Target *target, Utils::Id id)
         return project()->displayName();
     });
     expander->registerVariable("buildDir", Tr::tr("Build directory"),
-            [this] { return buildDirectory().toUserOutput(); });
+            [this] { return buildDirectory().toUserOutput(); }, false);
     expander->registerFileVariables("BuildConfig:BuildDirectory",
                                     Tr::tr("Build directory"),
                                     [this] { return buildDirectory(); });
+    expander->registerFileVariables("Project", Tr::tr("Main file of the project"), [this] {
+        return project()->projectFilePath();
+    });
     expander->registerVariable("BuildConfig:Name", Tr::tr("Name of the build configuration"),
             [this] { return displayName(); });
-    expander->registerPrefix("BuildConfig:Env",
-                             Tr::tr("Variables in the build configuration's environment"),
-                             [this](const QString &var) { return environment().expandedValueForKey(var); });
+    expander->registerPrefix(
+        "BuildConfig:Env",
+        "USER",
+        Tr::tr("Variables in the build configuration's environment"),
+        [this](const QString &var) { return environment().expandedValueForKey(var); });
 
     connect(Core::ICore::instance(), &Core::ICore::systemEnvironmentChanged,
             this, &BuildConfiguration::updateCacheAndEmitEnvironmentChanged);
@@ -223,7 +233,7 @@ BuildConfiguration::BuildConfiguration(Target *target, Utils::Id id)
     connect(ProjectTree::instance(), &ProjectTree::currentProjectChanged,
             this, &BuildConfiguration::updateCacheAndEmitEnvironmentChanged);
 
-    d->m_buildDirectoryAspect.setBaseFileName(project()->projectDirectory());
+    d->m_buildDirectoryAspect.setBaseDirectory(project()->projectDirectory());
     d->m_buildDirectoryAspect.setEnvironment(environment());
     connect(&d->m_buildDirectoryAspect, &StringAspect::changed,
             this, &BuildConfiguration::emitBuildDirectoryChanged);
@@ -280,11 +290,6 @@ FilePath BuildConfiguration::buildDirectory() const
     return project()->projectDirectory().resolvePath(path);
 }
 
-FilePath BuildConfiguration::rawBuildDirectory() const
-{
-    return d->m_buildDirectoryAspect();
-}
-
 void BuildConfiguration::setBuildDirectory(const FilePath &dir)
 {
     if (dir == d->m_buildDirectoryAspect())
@@ -296,17 +301,28 @@ void BuildConfiguration::setBuildDirectory(const FilePath &dir)
     emitBuildDirectoryChanged();
 }
 
-void BuildConfiguration::addConfigWidgets(const WidgetAdder &adder)
+QList<QWidget *> BuildConfiguration::createConfigWidgets()
 {
-    if (QWidget *generalConfigWidget = createConfigWidget())
-        adder(generalConfigWidget, d->m_configWidgetDisplayName);
+    QList<QWidget *> result;
+    if (QWidget *generalConfigWidget = createConfigWidget()) {
+        generalConfigWidget->setWindowTitle(d->m_configWidgetDisplayName);
+        result.append(generalConfigWidget);
+    }
 
-    //: %1 is the name returned by BuildStepList::displayName
-    const QString title = Tr::tr("%1 Steps");
-    adder(new Internal::BuildStepListWidget(buildSteps()), title.arg(buildSteps()->displayName()));
-    adder(new Internal::BuildStepListWidget(cleanSteps()), title.arg(cleanSteps()->displayName()));
+    result.append(new Internal::BuildStepListWidget(buildSteps()));
+    result.append(new Internal::BuildStepListWidget(cleanSteps()));
 
-    addSubConfigWidgets(adder);
+    result.append(createSubConfigWidgets());
+
+    return result;
+}
+
+QList<QWidget *> BuildConfiguration::createSubConfigWidgets()
+{
+    return {
+        new Internal::BuildEnvironmentWidget(this),
+        new Internal::CustomParsersBuildWidget(this)
+    };
 }
 
 void BuildConfiguration::doInitialize(const BuildInfo &info)
@@ -327,6 +343,8 @@ void BuildConfiguration::doInitialize(const BuildInfo &info)
 
     if (d->m_initializer)
         d->m_initializer(info);
+
+    project()->syncRunConfigurations(true);
 }
 
 bool BuildConfiguration::createBuildDirectory()
@@ -409,7 +427,7 @@ bool BuildConfiguration::addConfigurationsFromMap(
         RunConfiguration *rc = RunConfigurationFactory::restore(this, valueMap);
         if (!rc)
             continue;
-        addRunConfiguration(rc);
+        addRunConfiguration(rc, NameHandling::Keep);
         if (i == activeRc)
             setActiveRunConfiguration(rc);
     }
@@ -491,12 +509,6 @@ QWidget *BuildConfiguration::createConfigWidget()
     return named;
 }
 
-void BuildConfiguration::addSubConfigWidgets(const WidgetAdder &adder)
-{
-    adder(new Internal::BuildEnvironmentWidget(this), Tr::tr("Build Environment"));
-    adder(new Internal::CustomParsersBuildWidget(this), Tr::tr("Custom Output Parsers"));
-}
-
 BuildSystem *BuildConfiguration::buildSystem() const
 {
     return d->m_buildSystem;
@@ -578,7 +590,10 @@ bool BuildConfiguration::removeDeployConfiguration(DeployConfiguration *dc)
 
 const QList<DeployConfiguration *> BuildConfiguration::deployConfigurations() const
 {
-    return d->m_deployConfigurations;
+    return transform(d->m_deployConfigurations, [](const QPointer<DeployConfiguration> &dc) {
+        QTC_CHECK(dc.get());
+        return dc.get();
+    });
 }
 
 DeployConfiguration *BuildConfiguration::activeDeployConfiguration() const
@@ -624,7 +639,9 @@ void BuildConfiguration::updateDefaultDeployConfigurations()
 {
     const QList<DeployConfigurationFactory *> dcFactories = DeployConfigurationFactory::find(
         target());
-    QTC_ASSERT(!dcFactories.isEmpty(), qDebug() << target()->id(); return);
+    QTC_ASSERT(!dcFactories.isEmpty(),
+               qDebug() << "No deploy configuration factories found for target:" << target()->id();
+               return);
 
     QList<Utils::Id> dcIds;
     for (const DeployConfigurationFactory *dcFactory : dcFactories)
@@ -640,6 +657,7 @@ void BuildConfiguration::updateDefaultDeployConfigurations()
             removeDeployConfiguration(dc);
     }
 
+    DeployConfiguration *preferredDc = activeDeployConfiguration();
     for (Utils::Id id : std::as_const(toCreate)) {
         for (DeployConfigurationFactory *dcFactory : dcFactories) {
             if (dcFactory->creationId() == id) {
@@ -647,10 +665,17 @@ void BuildConfiguration::updateDefaultDeployConfigurations()
                 if (dc) {
                     QTC_CHECK(dc->id() == id);
                     addDeployConfiguration(dc);
+                    // Prefer a deploy configuration that specifically supports the target
+                    // over the generic DefaultDeployConfiguration:
+                    if (!preferredDc && !dcFactory->supportedTargetDeviceTypes().isEmpty()) {
+                        preferredDc = dc;
+                    }
                 }
             }
         }
     }
+    if (preferredDc)
+        setActiveDeployConfiguration(preferredDc);
 }
 
 void BuildConfiguration::updateDefaultRunConfigurations()
@@ -679,25 +704,28 @@ void BuildConfiguration::updateDefaultRunConfigurations()
     // that produce already existing RCs
     QList<RunConfiguration *> toRemove;
     QList<RunConfigurationCreationInfo> existing;
-    for (RunConfiguration *rc : std::as_const(existingConfigured)) {
-        bool present = false;
-        for (const RunConfigurationCreationInfo &item : creators) {
-            QString buildKey = rc->buildKey();
-            if (item.factory->runConfigurationId() == rc->id() && item.buildKey == buildKey) {
-                existing.append(item);
-                present = true;
+    if (buildSystem()->hasParsingData()) {
+        for (RunConfiguration *rc : std::as_const(existingConfigured)) {
+            bool present = false;
+            for (const RunConfigurationCreationInfo &item : creators) {
+                if (item.factory->runConfigurationId() == rc->id()
+                    && item.buildKey == rc->buildKey()) {
+                    existing.append(item);
+                    present = true;
+                    break;
+                }
+            }
+            if (!present
+                && ProjectExplorerSettings::get(this).automaticallyCreateRunConfigurations()
+                && !rc->isCustomized()) {
+                toRemove.append(rc);
             }
-        }
-        if (!present &&
-            projectExplorerSettings().automaticallyCreateRunConfigurations &&
-            !rc->isCustomized()) {
-            toRemove.append(rc);
         }
     }
     configuredCount -= toRemove.count();
 
     bool removeExistingUnconfigured = false;
-    if (projectExplorerSettings().automaticallyCreateRunConfigurations) {
+    if (ProjectExplorerSettings::get(this).automaticallyCreateRunConfigurations()) {
         // Create new "automatic" RCs and put them into newConfigured/newUnconfigured
         for (const RunConfigurationCreationInfo &item : creators) {
             if (item.creationMode == RunConfigurationCreationInfo::ManualCreationOnly)
@@ -738,9 +766,9 @@ void BuildConfiguration::updateDefaultRunConfigurations()
 
     // Do actual changes:
     for (RunConfiguration *rc : std::as_const(newConfigured))
-        addRunConfiguration(rc);
+        addRunConfiguration(rc, NameHandling::Uniquify);
     for (RunConfiguration *rc : std::as_const(newUnconfigured))
-        addRunConfiguration(rc);
+        addRunConfiguration(rc, NameHandling::Uniquify);
 
     // Generate complete list of RCs to remove later:
     QList<RunConfiguration *> removalList;
@@ -756,7 +784,7 @@ void BuildConfiguration::updateDefaultRunConfigurations()
 
     // Make sure a configured RC will be active after we delete the RCs:
     RunConfiguration *active = activeRunConfiguration();
-    if (active && (removalList.contains(active) || !active->isEnabled(Constants::NORMAL_RUN_MODE))) {
+    if (active && removalList.contains(active)) {
         RunConfiguration *newConfiguredDefault = newConfigured.isEmpty() ? nullptr : newConfigured.at(0);
 
         RunConfiguration *rc = Utils::findOrDefault(existingConfigured, [](RunConfiguration *rc) {
@@ -783,23 +811,28 @@ void BuildConfiguration::updateDefaultRunConfigurations()
     for (RunConfiguration *rc : std::as_const(removalList))
         removeRunConfiguration(rc);
 
+    if (!newConfigured.isEmpty() || !newUnconfigured.isEmpty())
+        project()->syncRunConfigurations(true);
     emit runConfigurationsUpdated();
     runConfigurationModel()->triggerUpdate();
 }
 
 const QList<RunConfiguration *> BuildConfiguration::runConfigurations() const
 {
-    return d->m_runConfigurations;
+    return transform(d->m_runConfigurations, [](const QPointer<RunConfiguration> &rc) {
+        QTC_CHECK(rc.get());
+        return rc.get();
+    });
 }
 
-void BuildConfiguration::addRunConfiguration(RunConfiguration *rc)
+void BuildConfiguration::addRunConfiguration(RunConfiguration *rc, NameHandling nameHandling)
 {
     QTC_ASSERT(rc && !d->m_runConfigurations.contains(rc), return);
     Q_ASSERT(rc->target() == target());
 
     // Check that we don't have a configuration with the same displayName
     QString configurationDisplayName = rc->displayName();
-    if (!configurationDisplayName.isEmpty()) {
+    if (!configurationDisplayName.isEmpty() && nameHandling == NameHandling::Uniquify) {
         QStringList displayNames = Utils::transform(d->m_runConfigurations,
                                                     &RunConfiguration::displayName);
         configurationDisplayName = Utils::makeUniquelyNumbered(configurationDisplayName,
@@ -843,11 +876,12 @@ void BuildConfiguration::removeRunConfiguration(RunConfiguration *rc)
 
 void BuildConfiguration::removeAllRunConfigurations()
 {
-    QList<RunConfiguration *> runConfigs = d->m_runConfigurations;
+    QList<QPointer<RunConfiguration>> runConfigs = d->m_runConfigurations;
     d->m_runConfigurations.clear();
     setActiveRunConfiguration(nullptr);
     while (!runConfigs.isEmpty()) {
         RunConfiguration * const rc = runConfigs.takeFirst();
+        QTC_CHECK(rc);
         emit removedRunConfiguration(rc);
         if (this == target()->activeBuildConfiguration())
             emit target()->removedRunConfiguration(rc);
@@ -868,8 +902,7 @@ void BuildConfiguration::setActiveRunConfiguration(RunConfiguration *rc)
         return;
 
     if ((!rc && d->m_runConfigurations.isEmpty()) ||
-        (rc && d->m_runConfigurations.contains(rc) &&
-         rc != d->m_activeRunConfiguration)) {
+        (rc && d->m_runConfigurations.contains(rc) && rc != d->m_activeRunConfiguration)) {
         d->m_activeRunConfiguration = rc;
         emit activeRunConfigurationChanged(d->m_activeRunConfiguration);
         if (this == target()->activeBuildConfiguration())
@@ -1166,7 +1199,7 @@ void BuildConfiguration::setupBuildDirMacroExpander(
                          Tr::tr("Type of the project's active build configuration"),
                          [buildType] { return buildTypeName(buildType); }, true, !documentationOnly);
     if (kit)
-        exp.registerSubProvider([kit] { return kit->macroExpander(); });
+        exp.registerSubProvider({qApp, [kit] { return kit->macroExpander(); }}); // FIXME: Find a better guard.
 }
 
 FilePath BuildConfiguration::buildDirectoryFromTemplate(const FilePath &projectDir,
@@ -1277,27 +1310,37 @@ const Tasks BuildConfigurationFactory::reportIssues(Kit *kit, const FilePath &pr
     return issues;
 }
 
-const QList<BuildInfo> BuildConfigurationFactory::allAvailableBuilds(const Target *parent) const
+QList<BuildInfo> BuildConfigurationFactory::buildListHelper(const Kit *kit,
+                                                            const FilePath &projectPath,
+                                                            bool forSetup) const
 {
     QTC_ASSERT(m_buildGenerator, return {});
-    QList<BuildInfo> list = m_buildGenerator(parent->kit(), parent->project()->projectFilePath(), false);
+    auto buildDevice = BuildDeviceKitAspect::device(kit);
+    if (!buildDevice)
+        return {};
+
+    FilePath buildRoot = buildDevice->rootPath();
+    if (!buildDevice->ensureReachable(projectPath))
+        return {};
+
+    QList<BuildInfo> list = m_buildGenerator(kit, projectPath, forSetup);
     for (BuildInfo &info : list) {
         info.factory = this;
-        info.kitId = parent->kit()->id();
+        info.kitId = kit->id();
     }
     return list;
 }
 
-const QList<BuildInfo>
-    BuildConfigurationFactory::allAvailableSetups(const Kit *k, const FilePath &projectPath) const
+const QList<BuildInfo> BuildConfigurationFactory::allAvailableBuilds(const Target *target) const
 {
-    QTC_ASSERT(m_buildGenerator, return {});
-    QList<BuildInfo> list = m_buildGenerator(k, projectPath, /* forSetup = */ true);
-    for (BuildInfo &info : list) {
-        info.factory = this;
-        info.kitId = k->id();
-    }
-    return list;
+    const FilePath projectPath = target->project()->projectFilePath();
+    return buildListHelper(target->kit(), projectPath, /* forSetup = */ false);
+}
+
+const QList<BuildInfo>
+    BuildConfigurationFactory::allAvailableSetups(const Kit *kit, const FilePath &projectPath) const
+{
+    return buildListHelper(kit, projectPath, /* forSetup = */ true);
 }
 
 bool BuildConfigurationFactory::supportsTargetDeviceType(Utils::Id id) const
@@ -1355,7 +1398,7 @@ void BuildConfigurationFactory::addSupportedTargetDeviceType(Utils::Id id)
 
 bool BuildConfigurationFactory::canHandle(const Target *target) const
 {
-    if (m_supportedProjectType.isValid() && m_supportedProjectType != target->project()->id())
+    if (m_supportedProjectType.isValid() && m_supportedProjectType != target->project()->type())
         return false;
 
     if (containsType(target->project()->projectIssues(target->kit()), Task::TaskType::Error))
@@ -1426,4 +1469,29 @@ BuildConfiguration *activeBuildConfigForCurrentProject()
     return activeBuildConfig(ProjectTree::currentProject());
 }
 
+QString msgBuildConfigurationBuild()
+{
+    return Tr::tr("Build");
+}
+
+QString msgBuildConfigurationDefault()
+{
+    return Tr::tr("Default");
+}
+
+QString msgBuildConfigurationDebug()
+{
+    return Tr::tr("Debug");
+}
+
+QString msgBuildConfigurationRelease()
+{
+    return Tr::tr("Release");
+}
+
+QString msgBuildConfigurationProfile()
+{
+    return Tr::tr("Profile");
+}
+
 } // namespace ProjectExplorer
