@@ -69,6 +69,7 @@ IDevice::Ptr IDeviceFactory::create() const
     IDevice::Ptr device = m_creator();
     if (!device) // e.g. Cancel used on the dialog to create a device
         return {};
+    device->init();
     return device;
 }
 
@@ -80,6 +81,7 @@ IDevice::Ptr IDeviceFactory::construct() const
     IDevice::Ptr device = m_constructor();
     QTC_ASSERT(device, return {});
     device->setDisplayName(displayName());
+    device->init();
     return device;
 }
 
@@ -137,6 +139,16 @@ void IDeviceFactory::setDisplayName(const QString &displayName)
     m_displayName = displayName;
 }
 
+void IDeviceFactory::setExecutionTypeId(Utils::Id executionType)
+{
+    m_executionType = executionType;
+}
+
+Utils::Id IDeviceFactory::executionTypeId() const
+{
+    return m_executionType;
+}
+
 IDeviceFactory::~IDeviceFactory()
 {
     g_deviceFactories.removeOne(this);
