@@ -8,7 +8,6 @@
 
 #include <QDir>
 #include <QString>
-#include <QVector>
 
 namespace ProjectExplorer {
 
@@ -24,10 +23,10 @@ class HeaderPath
 public:
     HeaderPath() = default;
     HeaderPath(const QString &path, HeaderPathType type)
-        : path(QDir::fromNativeSeparators(path)), type(type) { }
-    HeaderPath(const char *path, HeaderPathType type) : HeaderPath(QLatin1String(path), type) {}
+        : path(Utils::FilePath::fromUserInput(path)), type(type)
+    {}
     HeaderPath(const Utils::FilePath &path, HeaderPathType type)
-        : HeaderPath(path.path(), type)
+        : path(path), type(type)
     {}
 
     bool operator==(const HeaderPath &other) const
@@ -40,33 +39,33 @@ public:
         return !(*this == other);
     }
 
-    template<typename F> static HeaderPath makeUser(const F &fp)
+    static HeaderPath makeUser(const Utils::FilePath &fp)
     {
         return {fp, HeaderPathType::User};
     }
-    template<typename F> static HeaderPath makeBuiltIn(const F &fp)
+    static  HeaderPath makeBuiltIn(const Utils::FilePath &fp)
     {
         return {fp, HeaderPathType::BuiltIn};
     }
-    template<typename F> static HeaderPath makeSystem(const F &fp)
+    static HeaderPath makeSystem(const Utils::FilePath &fp)
     {
         return {fp, HeaderPathType::System};
     }
-    template<typename F> static HeaderPath makeFramework(const F &fp)
+    static HeaderPath makeFramework(const Utils::FilePath &fp)
     {
         return {fp, HeaderPathType::Framework};
     }
 
-    friend auto qHash(const HeaderPath &key, uint seed = 0)
+    friend size_t qHash(const HeaderPath &key, size_t seed = 0)
     {
-        return ((qHash(key.path) << 2) | uint(key.type)) ^ seed;
+        return ((qHash(key.path) << 2) | size_t(key.type)) ^ seed;
     }
 
-    QString path;
+    Utils::FilePath path;
     HeaderPathType type = HeaderPathType::User;
 };
 
-using HeaderPaths = QVector<HeaderPath>;
+using HeaderPaths = QList<HeaderPath>;
 template<typename C> HeaderPaths toHeaderPaths(const C &list, HeaderPathType type)
 {
     return Utils::transform<HeaderPaths>(list, [type](const auto &fp) {
