@@ -1,19 +1,24 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "kit.h"
 
+#include "devicesupport/devicekitaspects.h"
 #include "devicesupport/idevice.h"
 #include "devicesupport/idevicefactory.h"
-#include "kitinformation.h"
+#include "kitaspect.h"
 #include "kitmanager.h"
 #include "ioutputparser.h"
 #include "osparser.h"
+#include "project.h"
 #include "projectexplorerconstants.h"
+#include "projectexplorertr.h"
+#include "projectmanager.h"
+#include "projecttree.h"
 
 #include <utils/algorithm.h>
 #include <utils/displayname.h>
-#include <utils/filepath.h>
+#include <utils/fileutils.h>
 #include <utils/icon.h>
 #include <utils/macroexpander.h>
 #include <utils/qtcassert.h>
@@ -22,7 +27,6 @@
 
 #include <QIcon>
 #include <QTextStream>
-#include <QUuid>
 
 #include <numeric>
 #include <optional>
@@ -41,6 +45,7 @@ const char ICON_KEY[] = "PE.Profile.Icon";
 const char DEVICE_TYPE_FOR_ICON_KEY[] = "PE.Profile.DeviceTypeForIcon";
 const char MUTABLE_INFO_KEY[] = "PE.Profile.MutableInfo";
 const char STICKY_INFO_KEY[] = "PE.Profile.StickyInfo";
+const char RELEVANT_ASPECTS_KEY[] = "PE.Kit.RelevantAspects";
 const char IRRELEVANT_ASPECTS_KEY[] = "PE.Kit.IrrelevantAspects";
 
 namespace ProjectExplorer {
@@ -53,60 +58,42 @@ namespace Internal {
 
 class KitPrivate
 {
-    Q_DECLARE_TR_FUNCTIONS(ProjectExplorer::Kit)
-
 public:
     KitPrivate(Id id, Kit *kit) :
         m_id(id)
     {
         if (!id.isValid())
-            m_id = Id::fromString(QUuid::createUuid().toString());
+            m_id = Id::generate();
 
-        m_unexpandedDisplayName.setDefaultValue(QCoreApplication::translate("ProjectExplorer::Kit",
-                                                                            "Unnamed"));
+        m_unexpandedDisplayName.setDefaultValue(Tr::tr("Unnamed"));
 
-        m_macroExpander.setDisplayName(tr("Kit"));
+        m_macroExpander.setDisplayName(Tr::tr("Kit"));
         m_macroExpander.setAccumulating(true);
-        m_macroExpander.registerVariable("Kit:Id", tr("Kit ID"),
+        m_macroExpander.registerVariable("Kit:Id", Tr::tr("Kit ID"),
             [kit] { return kit->id().toString(); });
-        m_macroExpander.registerVariable("Kit:FileSystemName", tr("Kit filesystem-friendly name"),
+        m_macroExpander.registerVariable("Kit:FileSystemName", Tr::tr("Kit filesystem-friendly name"),
             [kit] { return kit->fileSystemFriendlyName(); });
-        for (KitAspect *aspect : KitManager::kitAspects())
-            aspect->addToMacroExpander(kit, &m_macroExpander);
+        for (KitAspectFactory *factory : KitManager::kitAspectFactories())
+            factory->addToMacroExpander(kit, &m_macroExpander);
 
-        // TODO: Remove the "Current" variants in ~4.16
-        m_macroExpander.registerVariable("CurrentKit:Name",
-            tr("The name of the currently active kit."),
-            [kit] { return kit->displayName(); },
-            false);
         m_macroExpander.registerVariable("Kit:Name",
-            tr("The name of the kit."),
+            Tr::tr("The name of the kit."),
             [kit] { return kit->displayName(); });
 
-        m_macroExpander.registerVariable("CurrentKit:FileSystemName",
-            tr("The name of the currently active kit in a filesystem-friendly version."),
-            [kit] { return kit->fileSystemFriendlyName(); },
-            false);
         m_macroExpander.registerVariable("Kit:FileSystemName",
-            tr("The name of the kit in a filesystem-friendly version."),
+            Tr::tr("The name of the kit in a filesystem-friendly version."),
             [kit] { return kit->fileSystemFriendlyName(); });
 
-        m_macroExpander.registerVariable("CurrentKit:Id",
-            tr("The ID of the currently active kit."),
-            [kit] { return kit->id().toString(); },
-            false);
         m_macroExpander.registerVariable("Kit:Id",
-            tr("The ID of the kit."),
+            Tr::tr("The ID of the kit."),
             [kit] { return kit->id().toString(); });
     }
 
     DisplayName m_unexpandedDisplayName;
     QString m_fileSystemFriendlyName;
-    QString m_autoDetectionSource;
+    DetectionSource m_detectionSource;
     Id m_id;
     int m_nestedBlockingLevel = 0;
-    bool m_autodetected = false;
-    bool m_sdkProvided = false;
     bool m_hasError = false;
     bool m_hasWarning = false;
     bool m_hasValidityInfo = false;
@@ -119,6 +106,7 @@ public:
     QSet<Id> m_sticky;
     QSet<Id> m_mutable;
     std::optional<QSet<Id>> m_irrelevantAspects;
+    std::optional<QSet<Id>> m_relevantAspects;
     MacroExpander m_macroExpander;
 };
 
@@ -138,41 +126,50 @@ Kit::Kit(Id id)
 {
 }
 
-Kit::Kit(const QVariantMap &data) :
-    d(std::make_unique<Internal::KitPrivate>(Id(), this))
+Kit::Kit(const Store &data)
+    : d(std::make_unique<Internal::KitPrivate>(Id(), this))
 {
-    d->m_id = Id::fromSetting(data.value(QLatin1String(ID_KEY)));
+    d->m_id = Id::fromSetting(data.value(ID_KEY));
 
-    d->m_autodetected = data.value(QLatin1String(AUTODETECTED_KEY)).toBool();
-    d->m_autoDetectionSource = data.value(QLatin1String(AUTODETECTIONSOURCE_KEY)).toString();
+    const bool autoDetected = data.value(AUTODETECTED_KEY).toBool();
+    const QString autoDetectionSource = data.value(AUTODETECTIONSOURCE_KEY).toString();
 
     // if we don't have that setting assume that autodetected implies sdk
-    QVariant value = data.value(QLatin1String(SDK_PROVIDED_KEY));
-    if (value.isValid())
-        d->m_sdkProvided = value.toBool();
-    else
-        d->m_sdkProvided = d->m_autodetected;
+    QVariant value = data.value(SDK_PROVIDED_KEY);
+    const bool sdkProvided = value.isValid() ? value.toBool() : autoDetected;
+
+    DetectionSource::DetectionType detectionType = [&]() {
+        if (sdkProvided)
+            return DetectionSource::FromSdk;
+        if (autoDetected)
+            return DetectionSource::FromSystem;
+        return DetectionSource::Manual;
+    }();
+
+    d->m_detectionSource = DetectionSource(detectionType, autoDetectionSource);
 
     d->m_unexpandedDisplayName.fromMap(data, DISPLAYNAME_KEY);
-    d->m_fileSystemFriendlyName = data.value(QLatin1String(FILESYSTEMFRIENDLYNAME_KEY)).toString();
-    d->m_iconPath = FilePath::fromString(data.value(QLatin1String(ICON_KEY),
-                                                    d->m_iconPath.toString()).toString());
+    d->m_fileSystemFriendlyName = data.value(FILESYSTEMFRIENDLYNAME_KEY).toString();
+    d->m_iconPath = FilePath::fromString(data.value(ICON_KEY, d->m_iconPath.toUrlishString()).toString());
     d->m_deviceTypeForIcon = Id::fromSetting(data.value(DEVICE_TYPE_FOR_ICON_KEY));
-    const auto it = data.constFind(IRRELEVANT_ASPECTS_KEY);
-    if (it != data.constEnd())
+    if (const auto it = data.constFind(RELEVANT_ASPECTS_KEY); it != data.constEnd())
+        d->m_relevantAspects = transform<QSet<Id>>(it.value().toList(), &Id::fromSetting);
+    if (const auto it = data.constFind(IRRELEVANT_ASPECTS_KEY); it != data.constEnd())
         d->m_irrelevantAspects = transform<QSet<Id>>(it.value().toList(), &Id::fromSetting);
 
-    QVariantMap extra = data.value(QLatin1String(DATA_KEY)).toMap();
+    Store extra = storeFromVariant(data.value(DATA_KEY));
     d->m_data.clear(); // remove default values
-    const QVariantMap::ConstIterator cend = extra.constEnd();
-    for (QVariantMap::ConstIterator it = extra.constBegin(); it != cend; ++it)
-        d->m_data.insert(Id::fromString(it.key()), it.value());
+    const Store::ConstIterator cend = extra.constEnd();
+    for (Store::ConstIterator it = extra.constBegin(); it != cend; ++it) {
+        d->m_data.insert(Id::fromString(stringFromKey(it.key())),
+                         mapEntryFromStoreEntry(it.value()));
+    }
 
-    const QStringList mutableInfoList = data.value(QLatin1String(MUTABLE_INFO_KEY)).toStringList();
+    const QStringList mutableInfoList = data.value(MUTABLE_INFO_KEY).toStringList();
     for (const QString &mutableInfo : mutableInfoList)
         d->m_mutable.insert(Id::fromString(mutableInfo));
 
-    const QStringList stickyInfoList = data.value(QLatin1String(STICKY_INFO_KEY)).toStringList();
+    const QStringList stickyInfoList = data.value(STICKY_INFO_KEY).toStringList();
     for (const QString &stickyInfo : stickyInfoList)
         d->m_sticky.insert(Id::fromString(stickyInfo));
 }
@@ -201,6 +198,7 @@ void Kit::copyKitCommon(Kit *target, const Kit *source)
     target->d->m_cachedIcon = source->d->m_cachedIcon;
     target->d->m_sticky = source->d->m_sticky;
     target->d->m_mutable = source->d->m_mutable;
+    target->d->m_relevantAspects = source->d->m_relevantAspects;
     target->d->m_irrelevantAspects = source->d->m_irrelevantAspects;
     target->d->m_hasValidityInfo = false;
 }
@@ -213,7 +211,7 @@ Kit *Kit::clone(bool keepName) const
         k->d->m_unexpandedDisplayName = d->m_unexpandedDisplayName;
     else
         k->d->m_unexpandedDisplayName.setValue(newKitName(KitManager::kits()));
-    k->d->m_autodetected = false;
+    k->d->m_detectionSource = DetectionSource::Manual;
     // Do not clone m_fileSystemFriendlyName, needs to be unique
     k->d->m_hasError = d->m_hasError;  // TODO: Is this intentionally not done for copyFrom()?
     return k;
@@ -222,8 +220,7 @@ Kit *Kit::clone(bool keepName) const
 void Kit::copyFrom(const Kit *k)
 {
     copyKitCommon(this, k);
-    d->m_autodetected = k->d->m_autodetected;
-    d->m_autoDetectionSource = k->d->m_autoDetectionSource;
+    d->m_detectionSource = k->d->m_detectionSource;
     d->m_unexpandedDisplayName = k->d->m_unexpandedDisplayName;
     d->m_fileSystemFriendlyName = k->d->m_fileSystemFriendlyName;
 }
@@ -250,30 +247,35 @@ bool Kit::hasWarning() const
 Tasks Kit::validate() const
 {
     Tasks result;
-    for (KitAspect *aspect : KitManager::kitAspects())
-        result.append(aspect->validate(this));
+    for (KitAspectFactory *factory : KitManager::kitAspectFactories()) {
+        if (isAspectRelevant(factory->id()))
+            result.append(factory->validate(this));
+    }
 
     d->m_hasError = containsType(result, Task::TaskType::Error);
     d->m_hasWarning = containsType(result, Task::TaskType::Warning);
 
-    Utils::sort(result);
     d->m_hasValidityInfo = true;
-    return result;
+    return Utils::sorted(std::move(result));
 }
 
 void Kit::fix()
 {
     KitGuard g(this);
-    for (KitAspect *aspect : KitManager::kitAspects())
-        aspect->fix(this);
+    for (KitAspectFactory *factory : KitManager::kitAspectFactories()) {
+        if (isAspectRelevant(factory->id()))
+            factory->fix(this);
+    }
 }
 
 void Kit::setup()
 {
     KitGuard g(this);
-    const QList<KitAspect *> aspects = KitManager::kitAspects();
-    for (KitAspect * const aspect : aspects)
-        aspect->setup(this);
+    const QList<KitAspectFactory *> aspects = KitManager::kitAspectFactories();
+    for (KitAspectFactory * const factory : aspects) {
+        if (isAspectRelevant(factory->id()))
+            factory->setup(this);
+    }
 }
 
 void Kit::upgrade()
@@ -281,8 +283,8 @@ void Kit::upgrade()
     KitGuard g(this);
     // Process the KitAspects in reverse order: They may only be based on other information
     // lower in the stack.
-    for (KitAspect *aspect : KitManager::kitAspects())
-        aspect->upgrade(this);
+    for (KitAspectFactory *factory : KitManager::kitAspectFactories())
+        factory->upgrade(this);
 }
 
 QString Kit::unexpandedDisplayName() const
@@ -332,17 +334,17 @@ QString Kit::fileSystemFriendlyName() const
 
 bool Kit::isAutoDetected() const
 {
-    return d->m_autodetected;
+    return d->m_detectionSource.isAutoDetected();
 }
 
 QString Kit::autoDetectionSource() const
 {
-    return d->m_autoDetectionSource;
+    return d->m_detectionSource.id;
 }
 
 bool Kit::isSdkProvided() const
 {
-    return d->m_sdkProvided;
+    return d->m_detectionSource.isSdkProvided();
 }
 
 Id Kit::id() const
@@ -350,12 +352,17 @@ Id Kit::id() const
     return d->m_id;
 }
 
+DetectionSource Kit::detectionSource() const
+{
+    return d->m_detectionSource;
+}
+
 int Kit::weight() const
 {
-    const QList<KitAspect *> &aspects = KitManager::kitAspects();
+    const QList<KitAspectFactory *> &aspects = KitManager::kitAspectFactories();
     return std::accumulate(aspects.begin(), aspects.end(), 0,
-                           [this](int sum, const KitAspect *aspect) {
-        return sum + aspect->weight(this);
+                           [this](int sum, const KitAspectFactory *factory) {
+        return sum + factory->weight(this);
     });
 }
 
@@ -374,12 +381,12 @@ QIcon Kit::icon() const
         return d->m_cachedIcon;
 
     if (!d->m_deviceTypeForIcon.isValid() && !d->m_iconPath.isEmpty() && d->m_iconPath.exists()) {
-        d->m_cachedIcon = QIcon(d->m_iconPath.toString());
+        d->m_cachedIcon = QIcon(d->m_iconPath.toUrlishString());
         return d->m_cachedIcon;
     }
 
     const Utils::Id deviceType = d->m_deviceTypeForIcon.isValid()
-            ? d->m_deviceTypeForIcon : DeviceTypeKitAspect::deviceTypeId(this);
+            ? d->m_deviceTypeForIcon : RunDeviceTypeKitAspect::deviceTypeId(this);
     const QIcon deviceTypeIcon = iconForDeviceType(deviceType);
     if (!deviceTypeIcon.isNull()) {
         d->m_cachedIcon = deviceTypeIcon;
@@ -496,60 +503,85 @@ bool Kit::isEqual(const Kit *other) const
             && d->m_deviceTypeForIcon == other->d->m_deviceTypeForIcon
             && d->m_unexpandedDisplayName == other->d->m_unexpandedDisplayName
             && d->m_fileSystemFriendlyName == other->d->m_fileSystemFriendlyName
+            && d->m_relevantAspects == other->d->m_relevantAspects
             && d->m_irrelevantAspects == other->d->m_irrelevantAspects
             && d->m_mutable == other->d->m_mutable;
 }
 
-QVariantMap Kit::toMap() const
+Store Kit::toMap() const
 {
     using IdVariantConstIt = QHash<Id, QVariant>::ConstIterator;
 
-    QVariantMap data;
+    Store data;
     d->m_unexpandedDisplayName.toMap(data, DISPLAYNAME_KEY);
-    data.insert(QLatin1String(ID_KEY), QString::fromLatin1(d->m_id.name()));
-    data.insert(QLatin1String(AUTODETECTED_KEY), d->m_autodetected);
+    data.insert(ID_KEY, QString::fromLatin1(d->m_id.name()));
+    data.insert(AUTODETECTED_KEY, d->m_detectionSource.isAutoDetected());
     if (!d->m_fileSystemFriendlyName.isEmpty())
-        data.insert(QLatin1String(FILESYSTEMFRIENDLYNAME_KEY), d->m_fileSystemFriendlyName);
-    data.insert(QLatin1String(AUTODETECTIONSOURCE_KEY), d->m_autoDetectionSource);
-    data.insert(QLatin1String(SDK_PROVIDED_KEY), d->m_sdkProvided);
-    data.insert(QLatin1String(ICON_KEY), d->m_iconPath.toString());
+        data.insert(FILESYSTEMFRIENDLYNAME_KEY, d->m_fileSystemFriendlyName);
+    data.insert(AUTODETECTIONSOURCE_KEY, d->m_detectionSource.id);
+    data.insert(SDK_PROVIDED_KEY, d->m_detectionSource.isSdkProvided());
+    data.insert(ICON_KEY, d->m_iconPath.toUrlishString());
     data.insert(DEVICE_TYPE_FOR_ICON_KEY, d->m_deviceTypeForIcon.toSetting());
 
     QStringList mutableInfo;
     for (const Id id : std::as_const(d->m_mutable))
         mutableInfo << id.toString();
-    data.insert(QLatin1String(MUTABLE_INFO_KEY), mutableInfo);
+    data.insert(MUTABLE_INFO_KEY, mutableInfo);
 
     QStringList stickyInfo;
     for (const Id id : std::as_const(d->m_sticky))
         stickyInfo << id.toString();
-    data.insert(QLatin1String(STICKY_INFO_KEY), stickyInfo);
+    data.insert(STICKY_INFO_KEY, stickyInfo);
 
+    if (d->m_relevantAspects) {
+        data.insert(RELEVANT_ASPECTS_KEY, transform<QVariantList>(d->m_relevantAspects.value(),
+                                                                  &Id::toSetting));
+    }
     if (d->m_irrelevantAspects) {
         data.insert(IRRELEVANT_ASPECTS_KEY, transform<QVariantList>(d->m_irrelevantAspects.value(),
                                                                     &Id::toSetting));
     }
 
-    QVariantMap extra;
+    Store extra;
 
     const IdVariantConstIt cend = d->m_data.constEnd();
     for (IdVariantConstIt it = d->m_data.constBegin(); it != cend; ++it)
-        extra.insert(QString::fromLatin1(it.key().name().constData()), it.value());
-    data.insert(QLatin1String(DATA_KEY), extra);
+        extra.insert(keyFromString(QString::fromLatin1(it.key().name().constData())), it.value());
+    data.insert(DATA_KEY, variantFromStore(extra));
 
     return data;
 }
 
 void Kit::addToBuildEnvironment(Environment &env) const
 {
-    for (KitAspect *aspect : KitManager::kitAspects())
-        aspect->addToBuildEnvironment(this, env);
+    for (KitAspectFactory *factory : KitManager::kitAspectFactories())
+        factory->addToBuildEnvironment(this, env);
 }
 
 void Kit::addToRunEnvironment(Environment &env) const
 {
-    for (KitAspect *aspect : KitManager::kitAspects())
-        aspect->addToRunEnvironment(this, env);
+    for (KitAspectFactory *factory : KitManager::kitAspectFactories())
+        factory->addToRunEnvironment(this, env);
+}
+
+template<typename T> static T getInfo(const Kit *k, const Id request, const QVariant &input)
+{
+    for (KitAspectFactory *factory : KitManager::kitAspectFactories()) {
+        const QVariant module = factory->getInfo(k, request, input);
+        if (module.isValid())
+            return module.value<T>();
+    }
+    return {};
+}
+
+QString Kit::moduleForHeader(const QString &headerFileName) const
+{
+    return getInfo<QString>(this, "moduleForHeader", headerFileName);
+}
+
+bool Kit::supportsQtCategoryFilter() const
+{
+    return getInfo<bool>(this, "supportsQtCategoryFilter", {});
 }
 
 Environment Kit::buildEnvironment() const
@@ -562,7 +594,7 @@ Environment Kit::buildEnvironment() const
 
 Environment Kit::runEnvironment() const
 {
-    IDevice::ConstPtr device = DeviceKitAspect::device(this);
+    IDevice::ConstPtr device = RunDeviceKitAspect::device(this);
     Environment env = device ? device->systemEnvironment() : Environment::systemEnvironment();
     addToRunEnvironment(env);
     return env;
@@ -571,8 +603,8 @@ Environment Kit::runEnvironment() const
 QList<OutputLineParser *> Kit::createOutputParsers() const
 {
     QList<OutputLineParser *> parsers{new OsParser};
-    for (KitAspect *aspect : KitManager::kitAspects())
-        parsers << aspect->createOutputParsers(this);
+    for (KitAspectFactory *factory : KitManager::kitAspectFactories())
+        parsers << factory->createOutputParsers(this);
     return parsers;
 }
 
@@ -590,11 +622,13 @@ QString Kit::toHtml(const Tasks &additional, const QString &extraText) const
         str << "<p>" << ProjectExplorer::toHtml(additional + validate()) << "</p>";
 
     str << "<dl style=\"white-space:pre\">";
-    for (KitAspect *aspect : KitManager::kitAspects()) {
-        const KitAspect::ItemList list = aspect->toUserOutput(this);
-        for (const KitAspect::Item &j : list) {
+    for (KitAspectFactory *factory : KitManager::kitAspectFactories()) {
+        if (!isAspectRelevant(factory->id()))
+            continue;
+        const KitAspectFactory::ItemList list = factory->toUserOutput(this);
+        for (const KitAspectFactory::Item &j : list) {
             QString contents = j.second;
-            if (contents.count() > 256) {
+            if (contents.size() > 256) {
                 int pos = contents.lastIndexOf("<br>", 256);
                 if (pos < 0) // no linebreak, so cut early.
                     pos = 80;
@@ -609,35 +643,30 @@ QString Kit::toHtml(const Tasks &additional, const QString &extraText) const
     return result;
 }
 
+void Kit::setDetectionSource(const DetectionSource &source)
+{
+    if (d->m_detectionSource == source)
+        return;
+    d->m_detectionSource = source;
+    kitUpdated();
+}
+
 void Kit::setAutoDetected(bool detected)
 {
-    if (d->m_autodetected == detected)
-        return;
-    d->m_autodetected = detected;
-    kitUpdated();
+    setDetectionSource(DetectionSource(
+        detected ? DetectionSource::FromSystem : DetectionSource::Manual, d->m_detectionSource.id));
 }
 
 void Kit::setAutoDetectionSource(const QString &autoDetectionSource)
 {
-    if (d->m_autoDetectionSource == autoDetectionSource)
-        return;
-    d->m_autoDetectionSource = autoDetectionSource;
-    kitUpdated();
-}
-
-void Kit::setSdkProvided(bool sdkProvided)
-{
-    if (d->m_sdkProvided == sdkProvided)
-        return;
-    d->m_sdkProvided = sdkProvided;
-    kitUpdated();
+    setDetectionSource(DetectionSource(d->m_detectionSource.type, autoDetectionSource));
 }
 
 void Kit::makeSticky()
 {
-    for (KitAspect *aspect : KitManager::kitAspects()) {
-        if (hasValue(aspect->id()))
-            setSticky(aspect->id(), true);
+    for (KitAspectFactory *factory : KitManager::kitAspectFactories()) {
+        if (hasValue(factory->id()))
+            setSticky(factory->id(), true);
     }
 }
 
@@ -675,9 +704,23 @@ void Kit::setMutable(Id id, bool b)
 
 bool Kit::isMutable(Id id) const
 {
+    if (id == RunDeviceKitAspect::id())
+        return RunDeviceTypeKitAspect::deviceTypeId(this) != Constants::DESKTOP_DEVICE_TYPE;
     return d->m_mutable.contains(id);
 }
 
+void Kit::setRelevantAspects(const QSet<Utils::Id> &relevant)
+{
+    d->m_relevantAspects = relevant;
+}
+
+QSet<Id> Kit::relevantAspects() const
+{
+    if (d->m_relevantAspects)
+        return *d->m_relevantAspects;
+    return {};
+}
+
 void Kit::setIrrelevantAspects(const QSet<Id> &irrelevant)
 {
     d->m_irrelevantAspects = irrelevant;
@@ -688,11 +731,17 @@ QSet<Id> Kit::irrelevantAspects() const
     return d->m_irrelevantAspects.value_or(KitManager::irrelevantAspects());
 }
 
+bool Kit::isAspectRelevant(const Utils::Id &aspect) const
+{
+    return d->m_relevantAspects ? d->m_relevantAspects->contains(aspect)
+                                : !irrelevantAspects().contains(aspect);
+}
+
 QSet<Id> Kit::supportedPlatforms() const
 {
     QSet<Id> platforms;
-    for (const KitAspect *aspect : KitManager::kitAspects()) {
-        const QSet<Id> ip = aspect->supportedPlatforms(this);
+    for (const KitAspectFactory *factory : KitManager::kitAspectFactories()) {
+        const QSet<Id> ip = factory->supportedPlatforms(this);
         if (ip.isEmpty())
             continue;
         if (platforms.isEmpty())
@@ -706,8 +755,10 @@ QSet<Id> Kit::supportedPlatforms() const
 QSet<Id> Kit::availableFeatures() const
 {
     QSet<Id> features;
-    for (const KitAspect *aspect : KitManager::kitAspects())
-        features |= aspect->availableFeatures(this);
+    for (const KitAspectFactory *factory : KitManager::kitAspectFactories()) {
+        if (relevantAspects().isEmpty() || relevantAspects().contains(factory->id()))
+            features |= factory->availableFeatures(this);
+    }
     return features;
 }
 
@@ -729,8 +780,8 @@ QString Kit::newKitName(const QList<Kit *> &allKits) const
 QString Kit::newKitName(const QString &name, const QList<Kit *> &allKits)
 {
     const QString baseName = name.isEmpty()
-            ? QCoreApplication::translate("ProjectExplorer::Kit", "Unnamed")
-            : QCoreApplication::translate("ProjectExplorer::Kit", "Clone of %1").arg(name);
+            ? Tr::tr("Unnamed")
+            : Tr::tr("Clone of %1").arg(name);
     return Utils::makeUniquelyNumbered(baseName, transform(allKits, &Kit::unexpandedDisplayName));
 }
 
@@ -749,14 +800,24 @@ void Kit::kitUpdated()
 
 static Id replacementKey() { return "IsReplacementKit"; }
 
-void ProjectExplorer::Kit::makeReplacementKit()
-{
-    setValueSilently(replacementKey(), true);
-}
-
 bool Kit::isReplacementKit() const
 {
     return value(replacementKey()).toBool();
 }
 
+Kit *activeKit(const Project *project)
+{
+    return project ? project->activeKit() : nullptr;
+}
+
+Kit *activeKitForActiveProject()
+{
+    return activeKit(ProjectManager::startupProject());
+}
+
+Kit *activeKitForCurrentProject()
+{
+    return activeKit(ProjectTree::currentProject());
+}
+
 } // namespace ProjectExplorer
