@@ -3,6 +3,7 @@
 
 #pragma once
 
+#include "kitaspect.h"
 #include "projectexplorer_export.h"
 #include "task.h"
 
@@ -21,6 +22,7 @@ class OutputLineParser;
 } // namespace Utils
 
 namespace ProjectExplorer {
+class Project;
 
 namespace Internal {
 class KitManagerPrivate;
@@ -65,9 +67,11 @@ public:
     QString customFileSystemFriendlyName() const;
     void setCustomFileSystemFriendlyName(const QString &fileSystemFriendlyName);
 
-    bool isAutoDetected() const;
-    QString autoDetectionSource() const;
-    bool isSdkProvided() const;
+    [[deprecated("Use detectionSource().isAutoDetected() instead")]] bool isAutoDetected() const;
+    [[deprecated("Use detectionSource().id instead")]] QString autoDetectionSource() const;
+    [[deprecated("Use detectionSource().isSdkProvided() instead")]] bool isSdkProvided() const;
+    DetectionSource detectionSource() const;
+
     Utils::Id id() const;
 
     // The higher the weight, the more aspects have sensible values for this kit.
@@ -101,14 +105,18 @@ public:
     Utils::Environment runEnvironment() const;
 
     QList<Utils::OutputLineParser *> createOutputParsers() const;
+    QString moduleForHeader(const QString &className) const;
+    bool supportsQtCategoryFilter() const;
 
     QString toHtml(const Tasks &additional = Tasks(), const QString &extraText = QString()) const;
     Kit *clone(bool keepName = false) const;
     void copyFrom(const Kit *k);
 
     // Note: Stickyness is *not* saved!
-    void setAutoDetected(bool detected);
-    void setAutoDetectionSource(const QString &autoDetectionSource);
+    void setDetectionSource(const DetectionSource &source);
+    [[deprecated("Use setDetectionSource() instead")]] void setAutoDetected(bool detected);
+    [[deprecated("Use setDetectionSource() instead")]] void setAutoDetectionSource(const QString &autoDetectionSource);
+
     void makeSticky();
     void setSticky(Utils::Id id, bool b);
     void makeUnSticky();
@@ -132,17 +140,16 @@ public:
     QString newKitName(const QList<Kit *> &allKits) const;
     static QString newKitName(const QString &name, const QList<Kit *> &allKits);
 
+    Utils::Store toMap() const;
+
 private:
     static void copyKitCommon(Kit *target, const Kit *source);
-    void setSdkProvided(bool sdkProvided);
 
     Kit(const Kit &other) = delete;
     void operator=(const Kit &other) = delete;
 
     void kitUpdated();
 
-    Utils::Store toMap() const;
-
     const std::unique_ptr<Internal::KitPrivate> d;
 
     friend class KitAspectFactory;
@@ -164,6 +171,10 @@ private:
 
 using TasksGenerator = std::function<Tasks(const Kit *)>;
 
+PROJECTEXPLORER_EXPORT Kit *activeKit(const Project *project);
+PROJECTEXPLORER_EXPORT Kit *activeKitForActiveProject();
+PROJECTEXPLORER_EXPORT Kit *activeKitForCurrentProject();
+
 } // namespace ProjectExplorer
 
 Q_DECLARE_METATYPE(ProjectExplorer::Kit *)
