@@ -3,8 +3,8 @@
 
 #include "msvctoolchain.h"
 
-#include "devicesupport/idevice.h"
 #include "abiwidget.h"
+#include "devicesupport/idevice.h"
 #include "gcctoolchain.h"
 #include "msvcparser.h"
 #include "projectexplorer.h"
@@ -422,7 +422,9 @@ static Abi findAbiOfMsvc(MsvcToolchain::Type type,
         else if (version == QLatin1String("v7.0A") || version == QLatin1String("v7.1"))
             msvcVersionString = QLatin1String("10.0");
     }
-    if (msvcVersionString.startsWith(QLatin1String("17.")))
+    if (msvcVersionString.startsWith(QLatin1String("18.")))
+        flavor = Abi::WindowsMsvc2026Flavor;
+    else if (msvcVersionString.startsWith(QLatin1String("17.")))
         flavor = Abi::WindowsMsvc2022Flavor;
     else if (msvcVersionString.startsWith(QLatin1String("16.")))
         flavor = Abi::WindowsMsvc2019Flavor;
@@ -784,7 +786,7 @@ void MsvcToolchain::initEnvModWatcher(const QFuture<GenerateEnvResult> &future)
                         Tr::tr("Falling back to use the cached environment for \"%1\" after:")
                                 .arg(displayName()) + '\n');
                 }
-                TaskHub::addTask(CompileTask(severity, errorMessage));
+                TaskHub::addTask<CompileTask>(severity, errorMessage);
             }
         } else {
             updateEnvironmentModifications(result.environmentItems);
@@ -826,7 +828,7 @@ Utils::Environment MsvcToolchain::readEnvironmentSetting(const Utils::Environmen
             if (result.error) {
                 const QString &errorMessage = *result.error;
                 if (!errorMessage.isEmpty())
-                    TaskHub::addTask(CompileTask(Task::Error, errorMessage));
+                    TaskHub::addTask<CompileTask>(Task::Error, errorMessage);
             } else {
                 resultEnv.modify(result.environmentItems);
             }
@@ -944,6 +946,10 @@ QStringList MsvcToolchain::suggestedMkspecList() const
         return {"win32-msvc",
                 "win32-msvc2022",
                 "win32-arm64-msvc"};
+    case Abi::WindowsMsvc2026Flavor:
+        return {"win32-msvc",
+                "win32-msvc2026",
+                "win32-arm64-msvc"};
     default:
         break;
     }
@@ -955,6 +961,14 @@ Abis MsvcToolchain::supportedAbis() const
     Abi abi = targetAbi();
     Abis abis = {abi};
     switch (abi.osFlavor()) {
+    case Abi::WindowsMsvc2026Flavor:
+        abis << Abi(abi.architecture(),
+                    abi.os(),
+                    Abi::WindowsMsvc2022Flavor,
+                    abi.binaryFormat(),
+                    abi.wordWidth(),
+                    abi.param());
+        Q_FALLTHROUGH();
     case Abi::WindowsMsvc2022Flavor:
         abis << Abi(abi.architecture(),
                     abi.os(),
@@ -1148,6 +1162,15 @@ Toolchain::BuiltInHeaderPathsRunner MsvcToolchain::createBuiltInHeaderPathsRunne
     };
 }
 
+static void prependPathEnvironmentVariable(Utils::Environment &result, const Utils::Environment &env)
+{
+    QSet<FilePath> resultPathSet = Utils::toSet(result.path());
+    for (const FilePath &path : env.path()) {
+        if (Utils::insert(resultPathSet, path))
+            result.prependOrSetPath(path);
+    }
+}
+
 void MsvcToolchain::addToEnvironment(Utils::Environment &env) const
 {
     // We cache the full environment (incoming + modifications by setup script).
@@ -1157,6 +1180,10 @@ void MsvcToolchain::addToEnvironment(Utils::Environment &env) const
         m_resultEnvironment = readEnvironmentSetting(env);
     }
     env = m_resultEnvironment;
+
+    // readEnvironmentSetting will set the PATH environment
+    // make sure to prepend any PATH changes that we had before
+    prependPathEnvironmentVariable(env, m_lastEnvironment);
 }
 
 static FilePath wrappedMakeCommand(const FilePath &command)
@@ -1175,7 +1202,7 @@ static FilePath wrappedMakeCommand(const FilePath &command)
 
 FilePath MsvcToolchain::makeCommand(const Environment &environment) const
 {
-    const bool useJom = projectExplorerSettings().useJom;
+    const bool useJom = globalProjectExplorerSettings().useJom();
     const QString jom("jom.exe");
     const QString nmake("nmake.exe");
     Utils::FilePath tmp;
@@ -1588,9 +1615,10 @@ static const MsvcToolchain *selectMsvcToolChain(const QString &displayedVarsBat,
     QTC_CHECK(displayedVarsBat.isEmpty());
     const ClangClInfo clangClInfo = ClangClInfo::getInfo(clangClPath);
     QList<Abi::OSFlavor> flavors;
-    if (clangClInfo.version().majorVersion() >= 6)
-        flavors << Abi::WindowsMsvc2022Flavor << Abi::WindowsMsvc2019Flavor
-                << Abi::WindowsMsvc2017Flavor;
+    if (clangClInfo.version().majorVersion() >= 6) {
+        flavors << Abi::WindowsMsvc2026Flavor << Abi::WindowsMsvc2022Flavor
+                << Abi::WindowsMsvc2019Flavor << Abi::WindowsMsvc2017Flavor;
+    }
     flavors << Abi::WindowsMsvc2015Flavor << Abi::WindowsMsvc2013Flavor;
     for (const Abi::OSFlavor flavor : std::as_const(flavors)) {
         if (const auto tc = Utils::findOrDefault(g_availableMsvcToolchains,
@@ -1642,7 +1670,7 @@ static Toolchains detectClangClToolChainInPath(const FilePath &clangClPath,
         auto cltc = new ClangClToolchain;
         cltc->setClangPath(clangClPath);
         cltc->setDisplayName(name);
-        cltc->setDetection(Toolchain::AutoDetection);
+        cltc->setDetectionSource(DetectionSource::FromSystem);
         cltc->setLanguage(language);
         cltc->setupVarsBat(toolChain->targetAbi(), toolChain->varsBat(), toolChain->varsBatArg());
         res << cltc;
@@ -1935,7 +1963,7 @@ static void detectCppBuildTools2015(Toolchains *list)
             auto tc = new MsvcToolchain(Constants::MSVC_TOOLCHAIN_TYPEID);
             tc->setupVarsBat(abi, vcVarsBat, QLatin1String(e.varsBatArg));
             tc->setDisplayName(name + QLatin1String(e.postFix));
-            tc->setDetection(Toolchain::AutoDetection);
+            tc->setDetectionSource(DetectionSource::FromSystem);
             tc->setLanguage(language);
             list->append(tc);
         }
@@ -2039,7 +2067,7 @@ Toolchains MsvcToolchainFactory::autoDetect(const ToolchainDetector &detector) c
     detectCppBuildTools2015(&results);
 
     for (Toolchain *tc : std::as_const(results))
-        tc->setDetection(Toolchain::AutoDetection);
+        tc->setDetectionSource(DetectionSource::FromSystem);
 
     return results;
 }
