@@ -1,15 +1,16 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
-#if defined(WITH_TESTS)
+#ifdef WITH_TESTS
 
 #include "projectexplorer_export.h"
 
-#include "ioutputparser.h"
 #include "task.h"
 
+#include <utils/outputformatter.h>
+
 namespace ProjectExplorer {
 
 class TestTerminator;
@@ -28,11 +29,10 @@ public:
     ~OutputParserTester();
 
     // test functions:
-    void testParsing(const QString &lines, Channel inputChannel,
+    void testParsing(const QString &input, Channel inputChannel,
                      Tasks tasks,
-                     const QString &childStdOutLines,
-                     const QString &childStdErrLines,
-                     const QString &outputLines);
+                     const QStringList &childStdOutLines,
+                     const QStringList &childStdErrLines);
 
     void setDebugEnabled(bool);
 
@@ -44,26 +44,14 @@ private:
 
     bool m_debug = false;
 
-    QString m_receivedStdErrChildLine;
-    QString m_receivedStdOutChildLine;
+    QStringList m_receivedStdErrChildLines;
+    QStringList m_receivedStdOutChildLines;
     Tasks m_receivedTasks;
-    QString m_receivedOutput;
 
     friend class TestTerminator;
 };
 
-class TestTerminator : public OutputTaskParser
-{
-    Q_OBJECT
-
-public:
-    explicit TestTerminator(OutputParserTester *t);
-
-private:
-    Result handleLine(const QString &line, Utils::OutputFormat type) override;
-
-    OutputParserTester *m_tester = nullptr;
-};
+QObject *createOutputParserTest();
 
 } // namespace ProjectExplorer
 
