@@ -6,19 +6,23 @@
 #include "abi.h"
 #include "buildconfiguration.h"
 #include "buildsystem.h"
-#include "kitaspects.h"
+#include "devicesupport/devicekitaspects.h"
 #include "project.h"
 #include "target.h"
+#include "sysrootkitaspect.h"
+#include "toolchainkitaspect.h"
 
 #include <ios/iosconstants.h>
 
 #include <utils/algorithm.h>
 
+using namespace Utils;
+
 namespace ProjectExplorer {
 
 RawProjectPartFlags::RawProjectPartFlags(const Toolchain *toolChain,
                                          const QStringList &commandLineFlags,
-                                         const Utils::FilePath &includeFileBaseDir)
+                                         const FilePath &includeFileBaseDir)
 {
     // Keep the following cheap/non-blocking for the ui thread. Expensive
     // operations are encapsulated in ToolchainInfo as "runners".
@@ -26,8 +30,7 @@ RawProjectPartFlags::RawProjectPartFlags(const Toolchain *toolChain,
     if (toolChain) {
         warningFlags = toolChain->warningFlags(commandLineFlags);
         languageExtensions = toolChain->languageExtensions(commandLineFlags);
-        includedFiles = Utils::transform(toolChain->includedFiles(commandLineFlags, includeFileBaseDir),
-                                         &Utils::FilePath::toFSPathString);
+        includedFiles = toolChain->includedFiles(commandLineFlags, includeFileBaseDir);
     }
 }
 
@@ -36,7 +39,7 @@ void RawProjectPart::setDisplayName(const QString &displayName)
     this->displayName = displayName;
 }
 
-void RawProjectPart::setFiles(const QStringList &files,
+void RawProjectPart::setFiles(const FilePaths &files,
                               const FileIsActive &fileIsActive,
                               const GetMimeType &getMimeType)
 {
@@ -45,34 +48,24 @@ void RawProjectPart::setFiles(const QStringList &files,
     this->getMimeType = getMimeType;
 }
 
-static QString trimTrailingSlashes(const QString &path)
-{
-    QString p = path;
-    while (p.endsWith('/') && p.size() > 1) {
-        p.chop(1);
-    }
-    return p;
-}
-
 HeaderPath RawProjectPart::frameworkDetectionHeuristic(const HeaderPath &header)
 {
-    QString path = trimTrailingSlashes(header.path);
-
-    if (path.endsWith(".framework"))
-        return HeaderPath::makeFramework(path.left(path.lastIndexOf('/')));
+    QTC_CHECK(!header.path.endsWith("/"));
+    if (header.path.endsWith(".framework"))
+        return HeaderPath::makeFramework(header.path.parentDir());
     return header;
 }
 
-void RawProjectPart::setProjectFileLocation(const Utils::FilePath &projectFile, int line, int column)
+void RawProjectPart::setProjectFileLocation(const FilePath &projectFile, int line, int column)
 {
     this->projectFile = projectFile;
     projectFileLine = line;
     projectFileColumn = column;
 }
 
-void RawProjectPart::setConfigFileName(const QString &configFileName)
+void RawProjectPart::setConfigFilePath(const FilePath &configFilePath)
 {
-    this->projectConfigFile = configFileName;
+    projectConfigFile = configFilePath;
 }
 
 void RawProjectPart::setBuildSystemTarget(const QString &target)
@@ -85,7 +78,7 @@ void RawProjectPart::setCallGroupId(const QString &id)
     callGroupId = id;
 }
 
-void RawProjectPart::setQtVersion(Utils::QtMajorVersion qtVersion)
+void RawProjectPart::setQtVersion(QtMajorVersion qtVersion)
 {
     this->qtVersion = qtVersion;
 }
@@ -100,19 +93,19 @@ void RawProjectPart::setHeaderPaths(const HeaderPaths &headerPaths)
     this->headerPaths = headerPaths;
 }
 
-void RawProjectPart::setIncludePaths(const QStringList &includePaths)
+void RawProjectPart::setIncludePaths(const FilePaths &includePaths)
 {
-    this->headerPaths = Utils::transform<QVector>(includePaths, [](const QString &path) {
+    this->headerPaths = Utils::transform<QList>(includePaths, [](const FilePath &path) {
         return RawProjectPart::frameworkDetectionHeuristic(HeaderPath::makeUser(path));
     });
 }
 
-void RawProjectPart::setPreCompiledHeaders(const QStringList &preCompiledHeaders)
+void RawProjectPart::setPreCompiledHeaders(const FilePaths &preCompiledHeaders)
 {
     this->precompiledHeaders = preCompiledHeaders;
 }
 
-void RawProjectPart::setIncludedFiles(const QStringList &files)
+void RawProjectPart::setIncludedFiles(const FilePaths &files)
 {
      includedFiles = files;
 }
@@ -156,8 +149,8 @@ bool KitInfo::isValid() const
 }
 
 ToolchainInfo::ToolchainInfo(const Toolchain *toolChain,
-                             const Utils::FilePath &sysRootPath,
-                             const Utils::Environment &env)
+                             const FilePath &sysRootPath,
+                             const Environment &env)
 {
     if (toolChain) {
         // Keep the following cheap/non-blocking for the ui thread...
@@ -186,7 +179,7 @@ void provideCppSettingsRetriever(const CppSettingsRetriever &retriever)
 
 ProjectUpdateInfo::ProjectUpdateInfo(Project *project,
                                      const KitInfo &kitInfo,
-                                     const Utils::Environment &env,
+                                     const Environment &env,
                                      const RawProjectParts &rawProjectParts,
                                      const RppGenerator &rppGenerator)
     : rawProjectParts(rawProjectParts)
@@ -199,8 +192,8 @@ ProjectUpdateInfo::ProjectUpdateInfo(Project *project,
     if (project) {
         projectName = project->displayName();
         projectFilePath = project->projectFilePath();
-        if (project->activeTarget() && project->activeTarget()->activeBuildConfiguration())
-            buildRoot = project->activeTarget()->activeBuildConfiguration()->buildDirectory();
+        if (project->activeBuildConfiguration())
+            buildRoot = project->activeBuildConfiguration()->buildDirectory();
     }
 }
 
@@ -208,7 +201,7 @@ ProjectUpdateInfo::ProjectUpdateInfo(Project *project,
 void addTargetFlagForIos(QStringList &cFlags, QStringList &cxxFlags, const BuildSystem *bs,
                          const std::function<QString ()> &getDeploymentTarget)
 {
-    const Utils::Id deviceType = DeviceTypeKitAspect::deviceTypeId(bs->target()->kit());
+    const Id deviceType = RunDeviceTypeKitAspect::deviceTypeId(bs->kit());
     if (deviceType != Ios::Constants::IOS_DEVICE_TYPE
             && deviceType != Ios::Constants::IOS_SIMULATOR_TYPE) {
         return;
