@@ -58,7 +58,6 @@ public:
         : m_kit(k)
     { }
 
-    QIcon m_overlayIcon;
     QList<BuildConfiguration *> m_buildConfigurations;
     QPointer<BuildConfiguration> m_activeBuildConfiguration;
     Kit *const m_kit;
@@ -77,11 +76,6 @@ Target::Target(Project *project, Kit *k) :
     d(std::make_unique<TargetPrivate>(k))
 {
     QTC_CHECK(d->m_kit);
-    connect(DeviceManager::instance(), &DeviceManager::updated, this, &Target::updateDeviceState);
-    KitManager *km = KitManager::instance();
-    connect(km, &KitManager::kitUpdated, this, &Target::handleKitUpdates);
-    connect(km, &KitManager::kitRemoved, this, &Target::handleKitRemoval);
-
 }
 
 Target::~Target()
@@ -89,24 +83,12 @@ Target::~Target()
     qDeleteAll(d->m_buildConfigurations);
 }
 
-void Target::handleKitUpdates(Kit *k)
+void Target::handleKitUpdated()
 {
-    if (k != d->m_kit)
-        return;
-
-    updateDeviceState(); // in case the device changed...
-
     emit iconChanged();
     emit kitChanged();
 }
 
-void Target::handleKitRemoval(Kit *k)
-{
-    if (k != d->m_kit)
-        return;
-    project()->removeTarget(this);
-}
-
 void Target::markAsShuttingDown()
 {
     d->m_shuttingDown = true;
@@ -207,6 +189,7 @@ void Target::addBuildConfiguration(BuildConfiguration *bc)
     }
 
     bc->updateDefaultDeployConfigurations();
+    bc->updateDefaultRunConfigurations();
 
     // add it
     d->m_buildConfigurations.push_back(bc);
@@ -297,12 +280,9 @@ QIcon Target::icon() const
 
 QIcon Target::overlayIcon() const
 {
-    return d->m_overlayIcon;
-}
-
-void Target::setOverlayIcon(const QIcon &icon)
-{
-    d->m_overlayIcon = icon;
+    static const QIcon disconnected = Icons::DEVICE_DISCONNECTED_INDICATOR_OVERLAY.icon();
+    IDevice::ConstPtr current = RunDeviceKitAspect::device(kit());
+    return current ? current->overlayIcon() : disconnected;
 }
 
 QString Target::overlayIconToolTip()
@@ -364,51 +344,11 @@ void Target::updateDefaultBuildConfigurations()
     QTC_CHECK(!d->m_buildConfigurations.isEmpty());
 }
 
-void Target::updateDefaultRunConfigurations()
-{
-    for (BuildConfiguration * const bc : std::as_const(d->m_buildConfigurations))
-        bc->updateDefaultRunConfigurations();
-}
-
 ProjectConfigurationModel *Target::buildConfigurationModel() const
 {
     return &d->m_buildConfigurationModel;
 }
 
-void Target::updateDeviceState()
-{
-    IDevice::ConstPtr current = RunDeviceKitAspect::device(kit());
-
-    QIcon overlay;
-    static const QIcon disconnected = Icons::DEVICE_DISCONNECTED_INDICATOR_OVERLAY.icon();
-    if (!current) {
-        overlay = disconnected;
-    } else {
-        switch (current->deviceState()) {
-        case IDevice::DeviceStateUnknown:
-            overlay = QIcon();
-            return;
-        case IDevice::DeviceReadyToUse: {
-            static const QIcon ready = Icons::DEVICE_READY_INDICATOR_OVERLAY.icon();
-            overlay = ready;
-            break;
-        }
-        case IDevice::DeviceConnected: {
-            static const QIcon connected = Icons::DEVICE_CONNECTED_INDICATOR_OVERLAY.icon();
-            overlay = connected;
-            break;
-        }
-        case IDevice::DeviceDisconnected:
-            overlay = disconnected;
-            break;
-        default:
-            break;
-        }
-    }
-
-    setOverlayIcon(overlay);
-}
-
 bool Target::fromMap(const Store &map)
 {
     QTC_ASSERT(d->m_kit == KitManager::kit(id()), return false);
