@@ -35,6 +35,7 @@ const char DETECTION_SOURCE_KEY[] = "ProjectExplorer.ToolChain.DetectionSource";
 const char LANGUAGE_KEY_V1[] = "ProjectExplorer.ToolChain.Language"; // For QtCreator <= 4.2
 const char LANGUAGE_KEY_V2[] = "ProjectExplorer.ToolChain.LanguageV2"; // For QtCreator > 4.2
 const char CODE_MODEL_TRIPLE_KEY[] = "ExplicitCodeModelTargetTriple";
+const char MANUALLY_PROVIDED_CXX_KEY[] = "ManuallyProvidedCxxPath";
 
 QList<ToolchainFactory *> &toolchainFactories()
 {
@@ -49,8 +50,6 @@ QList<ToolchainFactory *> &toolchainFactories()
 class ToolchainPrivate
 {
 public:
-    using Detection = Toolchain::Detection;
-
     explicit ToolchainPrivate(Id typeId) :
         m_id(QUuid::createUuid().toByteArray()),
         m_typeId(typeId),
@@ -72,8 +71,7 @@ public:
     QString m_typeDisplayName;
     Id m_typeId;
     Id m_language;
-    Detection m_detection = Toolchain::UninitializedDetection;
-    QString m_detectionSource;
+    DetectionSource m_detectionSource;
     QString m_explicitCodeModelTargetTriple;
 
     Toolchain::MacrosCache m_predefinedMacrosCache;
@@ -85,6 +83,7 @@ public:
 
     std::optional<bool> m_isValid;
     bool m_hasError = false;
+    bool m_isManuallyProvidedCxxPath = false;
 };
 
 
@@ -170,17 +169,7 @@ void Toolchain::setDisplayName(const QString &name)
     toolChainUpdated();
 }
 
-bool Toolchain::isAutoDetected() const
-{
-    return detection() == AutoDetection || detection() == AutoDetectionFromSdk;
-}
-
-Toolchain::Detection Toolchain::detection() const
-{
-    return d->m_detection;
-}
-
-QString Toolchain::detectionSource() const
+DetectionSource Toolchain::detectionSource() const
 {
     return d->m_detectionSource;
 }
@@ -202,7 +191,7 @@ Id Toolchain::bundleId() const
     return d->m_bundleId;
 }
 
-void Toolchain::setBundleId(Utils::Id id)
+void Toolchain::setBundleId(Id id)
 {
     d->m_bundleId = id;
 }
@@ -215,7 +204,7 @@ bool Toolchain::canShareBundle(const Toolchain &other) const
 
     if (int(factory()->supportedLanguages().size()) == 1)
         return false;
-    if (detection() != other.detection())
+    if (detectionSource().type != other.detectionSource().type)
         return false;
 
     if (typeId() != Constants::MSVC_TOOLCHAIN_TYPEID
@@ -272,7 +261,7 @@ bool Toolchain::operator == (const Toolchain &tc) const
 
     // We ignore displayname
     return typeId() == tc.typeId()
-            && isAutoDetected() == tc.isAutoDetected()
+            && detectionSource().isAutoDetected() == tc.detectionSource().isAutoDetected() // FIXME: intended?
             && language() == tc.language();
 }
 
@@ -306,9 +295,10 @@ void Toolchain::toMap(Store &result) const
     result.insert(ID_KEY, idToSave);
     result.insert(BUNDLE_ID_KEY, d->m_bundleId.toSetting());
     result.insert(DISPLAY_NAME_KEY, displayName());
-    result.insert(AUTODETECT_KEY, isAutoDetected());
-    result.insert(DETECTION_SOURCE_KEY, d->m_detectionSource);
+    result.insert(AUTODETECT_KEY, d->m_detectionSource.isAutoDetected());
+    result.insert(DETECTION_SOURCE_KEY, d->m_detectionSource.id);
     result.insert(CODE_MODEL_TRIPLE_KEY, d->m_explicitCodeModelTargetTriple);
+    result.insert(MANUALLY_PROVIDED_CXX_KEY, d->m_isManuallyProvidedCxxPath);
     // <Compatibility with QtC 4.2>
     int oldLanguageId = -1;
     if (language() == ProjectExplorer::Constants::C_LANGUAGE_ID)
@@ -333,12 +323,7 @@ void Toolchain::toolChainUpdated()
     ToolchainManager::notifyAboutUpdate(this);
 }
 
-void Toolchain::setDetection(Toolchain::Detection de)
-{
-    d->m_detection = de;
-}
-
-void Toolchain::setDetectionSource(const QString &source)
+void Toolchain::setDetectionSource(const DetectionSource &source)
 {
     d->m_detectionSource = source;
 }
@@ -411,6 +396,16 @@ bool Toolchain::matchesCompilerCommand(const FilePath &command) const
     return compilerCommand().isSameExecutable(command);
 }
 
+void Toolchain::setIsManuallyProvidedCxxCompiler(bool manuallyProvided)
+{
+    d->m_isManuallyProvidedCxxPath = manuallyProvided;
+}
+
+bool Toolchain::isManuallyProvidedCxxCompiler() const
+{
+    return d->m_isManuallyProvidedCxxPath;
+}
+
 void Toolchain::setCompilerCommandKey(const Key &commandKey)
 {
     d->m_compilerCommandKey = commandKey;
@@ -453,10 +448,12 @@ void Toolchain::fromMap(const Store &data)
     d->m_bundleId = Id::fromSetting(data.value(BUNDLE_ID_KEY));
 
     const bool autoDetect = data.value(AUTODETECT_KEY, false).toBool();
-    d->m_detection = autoDetect ? AutoDetection : ManualDetection;
-    d->m_detectionSource = data.value(DETECTION_SOURCE_KEY).toString();
+    d->m_detectionSource.type = autoDetect ? DetectionSource::FromSystem
+                                           : DetectionSource::Manual;
+    d->m_detectionSource.id = data.value(DETECTION_SOURCE_KEY).toString();
 
     d->m_explicitCodeModelTargetTriple = data.value(CODE_MODEL_TRIPLE_KEY).toString();
+    d->m_isManuallyProvidedCxxPath = data.value(MANUALLY_PROVIDED_CXX_KEY).toBool();
 
     if (data.contains(LANGUAGE_KEY_V2)) {
         // remove hack to trim language id in 4.4: This is to fix up broken language
@@ -775,12 +772,6 @@ Id ToolchainFactory::supportedToolchainType() const
     return m_supportedToolchainType;
 }
 
-std::optional<AsyncToolchainDetector> ToolchainFactory::asyncAutoDetector(
-    const ToolchainDetector &) const
-{
-    return {};
-}
-
 void ToolchainFactory::setSupportedToolchainType(const Id &supportedToolchainType)
 {
     m_supportedToolchainType = supportedToolchainType;
@@ -872,39 +863,6 @@ BadToolchains BadToolchains::fromVariant(const QVariant &v)
             [](const QVariant &e) { return BadToolchain::fromMap(storeFromVariant(e)); });
 }
 
-AsyncToolchainDetector::AsyncToolchainDetector(
-    const ToolchainDetector &detector,
-    const std::function<Toolchains(const ToolchainDetector &)> &func,
-    const std::function<bool(const Toolchain *, const Toolchains &)> &alreadyRegistered)
-    : m_detector(detector)
-    , m_func(func)
-    , m_alreadyRegistered(alreadyRegistered)
-{
-}
-
-void AsyncToolchainDetector::run()
-{
-    auto watcher = new QFutureWatcher<Toolchains>();
-    QObject::connect(watcher,
-                     &QFutureWatcher<Toolchains>::finished,
-                     [watcher,
-                      alreadyRegistered = m_alreadyRegistered]() {
-                         Toolchains existingTcs = ToolchainManager::toolchains();
-                         Toolchains toRegister;
-                         for (Toolchain *tc : watcher->result()) {
-                             if (tc->isValid() && !alreadyRegistered(tc, existingTcs)) {
-                                 toRegister << tc;
-                                 existingTcs << tc;
-                             } else {
-                                 delete tc;
-                             }
-                         }
-                         ToolchainManager::registerToolchains(toRegister);
-                         watcher->deleteLater();
-                     });
-    watcher->setFuture(Utils::asyncRun(m_func, m_detector));
-}
-
 /*
  * PRE:
  *   - The list of toolchains is not empty.
@@ -966,7 +924,7 @@ QList<ToolchainBundle> ToolchainBundle::collectBundles(
         toolchainsPerBundleId.erase(unbundled);
     }
 
-    for (const Toolchains &tcs : toolchainsPerBundleId)
+    for (const Toolchains &tcs : std::as_const(toolchainsPerBundleId))
         bundles.emplaceBack(tcs, handleMissing);
     return bundles;
 }
@@ -979,7 +937,7 @@ ToolchainFactory *ToolchainBundle::factory() const
 
 QString ToolchainBundle::displayName() const
 {
-    if (!isAutoDetected() || !dynamic_cast<GccToolchain *>(m_toolchains.first()))
+    if (!detectionSource().isSdkProvided() || !dynamic_cast<GccToolchain *>(m_toolchains.first()))
         return get(&Toolchain::displayName);
 
     // Auto-detected GCC toolchains encode language and compiler command in their display names.
@@ -1039,7 +997,7 @@ QList<ToolchainBundle> ToolchainBundle::bundleUnbundledToolchains(const Toolchai
             if (nextBundle.isEmpty())
                 break;
             const Id newBundleId = Id::generate();
-            for (Toolchain * const tc : nextBundle)
+            for (Toolchain * const tc : std::as_const(nextBundle))
                 tc->setBundleId(newBundleId);
             bundles.emplaceBack(nextBundle, handleMissing);
         }
@@ -1058,6 +1016,16 @@ void ToolchainBundle::setCompilerCommand(Utils::Id language, const Utils::FilePa
     }
 }
 
+void ToolchainBundle::setCxxCompilerIsManuallyProvided(bool manuallyProvided)
+{
+    for (Toolchain *const tc : std::as_const(m_toolchains)) {
+        if (tc->language() == Constants::CXX_LANGUAGE_ID) {
+            tc->setIsManuallyProvidedCxxCompiler(manuallyProvided);
+            break;
+        }
+    }
+}
+
 FilePath ToolchainBundle::compilerCommand(Utils::Id language) const
 {
     for (Toolchain *const tc : std::as_const(m_toolchains)) {
