@@ -1,19 +1,19 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "qbsprojectmanagerplugin.h"
 
 #include "qbsbuildconfiguration.h"
 #include "qbsbuildstep.h"
 #include "qbscleanstep.h"
+#include "qbseditor.h"
 #include "qbsinstallstep.h"
-#include "qbskitinformation.h"
 #include "qbsnodes.h"
-#include "qbsprofilemanager.h"
 #include "qbsprofilessettingspage.h"
 #include "qbsproject.h"
 #include "qbsprojectmanagerconstants.h"
 #include "qbsprojectmanagertr.h"
+#include "qbssession.h"
 #include "qbssettings.h"
 
 #include <coreplugin/actionmanager/actioncontainer.h>
@@ -26,31 +26,29 @@
 #include <coreplugin/icore.h>
 #include <coreplugin/idocument.h>
 
+#include <extensionsystem/iplugin.h>
+
 #include <projectexplorer/buildmanager.h>
+#include <projectexplorer/devicesupport/idevice.h>
 #include <projectexplorer/project.h>
 #include <projectexplorer/projectexplorer.h>
 #include <projectexplorer/projectexplorerconstants.h>
 #include <projectexplorer/projectexplorericons.h>
 #include <projectexplorer/projectmanager.h>
+#include <projectexplorer/projectmanager.h>
 #include <projectexplorer/projecttree.h>
-#include <projectexplorer/runcontrol.h>
-#include <projectexplorer/session.h>
 #include <projectexplorer/target.h>
 
-#include <qtsupport/qtsupportconstants.h>
-#include <qmljstools/qmljstoolsconstants.h>
-
-#include <utils/fileutils.h>
+#include <utils/action.h>
 #include <utils/fsengine/fileiconprovider.h>
+#include <utils/mimeconstants.h>
 #include <utils/qtcassert.h>
 #include <utils/utilsicons.h>
 
-#include <QAction>
-
 using namespace ProjectExplorer;
+using namespace Utils;
 
-namespace QbsProjectManager {
-namespace Internal {
+namespace QbsProjectManager::Internal {
 
 static Node *currentEditorNode()
 {
@@ -61,20 +59,92 @@ static Node *currentEditorNode()
 static QbsProject *currentEditorProject()
 {
     Core::IDocument *doc = Core::EditorManager::currentDocument();
-    return doc ? qobject_cast<QbsProject *>(SessionManager::projectForFile(doc->filePath())) : nullptr;
+    return doc ? qobject_cast<QbsProject *>(ProjectManager::projectForFile(doc->filePath())) : nullptr;
 }
 
+class QbsToolFactory : public DeviceToolAspectFactory
+{
+public:
+    QbsToolFactory()
+    {
+        setToolId(Constants::QBS_TOOL_ID);
+        setToolType(DeviceToolAspect::BuildTool);
+        setFilePattern({"qbs"});
+        setLabelText(Tr::tr("Qbs executable:"));
+    }
+};
+
 class QbsProjectManagerPluginPrivate
 {
 public:
-    QbsProfileManager manager;
     QbsBuildConfigurationFactory buildConfigFactory;
     QbsBuildStepFactory buildStepFactory;
     QbsCleanStepFactory cleanStepFactory;
     QbsInstallStepFactory installStepFactory;
     QbsSettingsPage settingsPage;
     QbsProfilesSettingsPage profilesSetttingsPage;
-    QbsKitAspect qbsKitAspect;
+    QbsEditorFactory editorFactory;
+    QbsToolFactory toolFactory;
+};
+
+class QbsProjectManagerPlugin final : public ExtensionSystem::IPlugin
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QtCreatorPlugin" FILE "QbsProjectManager.json")
+
+public:
+    static void runStepsForProducts(QbsProject *project,
+                                    const QStringList &products,
+                                    const QList<Id> &stepTypes);
+
+private:
+    ~QbsProjectManagerPlugin() final;
+
+    void initialize() final;
+
+    void projectChanged(QbsProject *project);
+
+    void buildFileContextMenu();
+    void buildFile();
+    void buildProductContextMenu();
+    void cleanProductContextMenu();
+    void rebuildProductContextMenu();
+    void runStepsForProductContextMenu(const QList<Id> &stepTypes);
+    void buildProduct();
+    void cleanProduct();
+    void rebuildProduct();
+    void runStepsForProduct(const QList<Id> &stepTypes);
+    void buildSubprojectContextMenu();
+    void cleanSubprojectContextMenu();
+    void rebuildSubprojectContextMenu();
+    void runStepsForSubprojectContextMenu(const QList<Id> &stepTypes);
+
+    void reparseSelectedProject();
+    void reparseCurrentProject();
+    void reparseProject(QbsProject *project);
+
+    void updateContextActions(ProjectExplorer::Node *node);
+    void updateReparseQbsAction();
+    void updateBuildActions();
+
+    void buildFiles(QbsProject *project, const QStringList &files,
+                    const QStringList &activeFileTags);
+    void buildSingleFile(QbsProject *project, const QString &file);
+
+    QbsProjectManagerPluginPrivate *d = nullptr;
+    QAction *m_reparseQbs = nullptr;
+    QAction *m_reparseQbsCtx = nullptr;
+    QAction *m_buildFileCtx = nullptr;
+    QAction *m_buildProductCtx = nullptr;
+    QAction *m_cleanProductCtx = nullptr;
+    QAction *m_rebuildProductCtx = nullptr;
+    QAction *m_buildSubprojectCtx = nullptr;
+    QAction *m_cleanSubprojectCtx = nullptr;
+    QAction *m_rebuildSubprojectCtx = nullptr;
+    Action *m_buildFile = nullptr;
+    Action *m_buildProduct = nullptr;
+    QAction *m_cleanProduct = nullptr;
+    QAction *m_rebuildProduct = nullptr;
 };
 
 QbsProjectManagerPlugin::~QbsProjectManagerPlugin()
@@ -82,19 +152,21 @@ QbsProjectManagerPlugin::~QbsProjectManagerPlugin()
     delete d;
 }
 
-bool QbsProjectManagerPlugin::initialize(const QStringList &arguments, QString *errorMessage)
+void QbsProjectManagerPlugin::initialize()
 {
-    Q_UNUSED(arguments)
-    Q_UNUSED(errorMessage)
-
     d = new QbsProjectManagerPluginPrivate;
 
+    Core::IOptionsPage::registerCategory(
+        Constants::QBS_SETTINGS_CATEGORY,
+        Tr::tr(Constants::QBS_SETTINGS_TR_CATEGORY),
+        ":/qbsprojectmanager/images/settingscategory_qbsprojectmanager.png");
+
     const Core::Context projectContext(::QbsProjectManager::Constants::PROJECT_ID);
 
     Utils::FileIconProvider::registerIconOverlayForSuffix(ProjectExplorer::Constants::FILEOVERLAY_QT, "qbs");
     Core::HelpManager::registerDocumentation({Core::HelpManager::documentationPath() + "/qbs.qch"});
 
-    ProjectManager::registerProjectType<QbsProject>(QmlJSTools::Constants::QBS_MIMETYPE);
+    ProjectManager::registerProjectType<QbsProject>(Utils::Constants::QBS_MIMETYPE);
 
     //menus
     // Build Menu:
@@ -133,8 +205,8 @@ bool QbsProjectManagerPlugin::initialize(const QStringList &arguments, QString *
     connect(m_buildFileCtx, &QAction::triggered,
             this, &QbsProjectManagerPlugin::buildFileContextMenu);
 
-    m_buildFile = new Utils::ParameterAction(Tr::tr("Build File"), Tr::tr("Build File \"%1\""),
-                                                   Utils::ParameterAction::AlwaysEnabled, this);
+    m_buildFile = new Utils::Action(Tr::tr("Build File"), Tr::tr("Build File \"%1\""),
+                                                   Utils::Action::AlwaysEnabled, this);
     command = Core::ActionManager::registerAction(m_buildFile, Constants::ACTION_BUILD_FILE);
     command->setAttribute(Core::Command::CA_Hide);
     command->setAttribute(Core::Command::CA_UpdateText);
@@ -150,8 +222,8 @@ bool QbsProjectManagerPlugin::initialize(const QStringList &arguments, QString *
     connect(m_buildProductCtx, &QAction::triggered,
             this, &QbsProjectManagerPlugin::buildProductContextMenu);
 
-    m_buildProduct = new Utils::ParameterAction(Tr::tr("Build Product"), Tr::tr("Build Product \"%1\""),
-                                                Utils::ParameterAction::AlwaysEnabled, this);
+    m_buildProduct = new Utils::Action(Tr::tr("Build Product"), Tr::tr("Build Product \"%1\""),
+                                                Utils::Action::AlwaysEnabled, this);
     command = Core::ActionManager::registerAction(m_buildProduct, Constants::ACTION_BUILD_PRODUCT);
     command->setAttribute(Core::Command::CA_Hide);
     command->setAttribute(Core::Command::CA_UpdateText);
@@ -230,13 +302,11 @@ bool QbsProjectManagerPlugin::initialize(const QStringList &arguments, QString *
     connect(Core::EditorManager::instance(), &Core::EditorManager::currentEditorChanged,
             this, &QbsProjectManagerPlugin::updateBuildActions);
 
-    connect(SessionManager::instance(), &SessionManager::targetAdded,
-            this, &QbsProjectManagerPlugin::targetWasAdded);
-    connect(SessionManager::instance(), &SessionManager::targetRemoved,
+    connect(ProjectManager::instance(), &ProjectManager::currentBuildConfigurationChanged,
             this, &QbsProjectManagerPlugin::updateBuildActions);
-    connect(SessionManager::instance(), &SessionManager::startupProjectChanged,
+    connect(ProjectManager::instance(), &ProjectManager::startupProjectChanged,
             this, &QbsProjectManagerPlugin::updateReparseQbsAction);
-    connect(SessionManager::instance(), &SessionManager::projectAdded,
+    connect(ProjectManager::instance(), &ProjectManager::projectAdded,
             this, [this](Project *project) {
         auto qbsProject = qobject_cast<QbsProject *>(project);
         connect(project, &Project::anyParsingStarted,
@@ -249,27 +319,14 @@ bool QbsProjectManagerPlugin::initialize(const QStringList &arguments, QString *
     updateContextActions(ProjectTree::currentNode());
     updateReparseQbsAction();
     updateBuildActions();
-
-    return true;
-}
-
-void QbsProjectManagerPlugin::targetWasAdded(Target *target)
-{
-    if (!qobject_cast<QbsProject *>(target->project()))
-        return;
-
-    connect(target, &Target::parsingStarted,
-            this, std::bind(&QbsProjectManagerPlugin::projectChanged, this, nullptr));
-    connect(target, &Target::parsingFinished,
-            this, std::bind(&QbsProjectManagerPlugin::projectChanged, this, nullptr));
 }
 
 void QbsProjectManagerPlugin::updateContextActions(Node *node)
 {
     auto project = qobject_cast<Internal::QbsProject *>(ProjectTree::currentProject());
     bool isEnabled = !BuildManager::isBuilding(project)
-            && project && project->activeTarget()
-            && !project->activeTarget()->buildSystem()->isParsing()
+            && project && project->activeBuildSystem()
+            && !project->activeBuildSystem()->isParsing()
             && node && node->isEnabled();
 
     const bool isFile = project && node && node->asFileNode();
@@ -289,11 +346,11 @@ void QbsProjectManagerPlugin::updateContextActions(Node *node)
 
 void QbsProjectManagerPlugin::updateReparseQbsAction()
 {
-    auto project = qobject_cast<QbsProject *>(SessionManager::startupProject());
+    auto project = qobject_cast<QbsProject *>(ProjectManager::startupProject());
     m_reparseQbs->setEnabled(project
                              && !BuildManager::isBuilding(project)
-                             && project && project->activeTarget()
-                             && !project->activeTarget()->buildSystem()->isParsing());
+                             && project && project->activeBuildSystem()
+                             && !project->activeBuildSystem()->isParsing());
 }
 
 void QbsProjectManagerPlugin::updateBuildActions()
@@ -323,8 +380,8 @@ void QbsProjectManagerPlugin::updateBuildActions()
 
         if (QbsProject *editorProject = currentEditorProject()) {
             enabled = !BuildManager::isBuilding(editorProject)
-                    && editorProject->activeTarget()
-                    && !editorProject->activeTarget()->buildSystem()->isParsing();
+                    && editorProject->activeBuildSystem()
+                    && !editorProject->activeBuildSystem()->isParsing();
             fileVisible = productNode
                     || dynamic_cast<QbsProjectNode *>(parentProjectNode)
                     || dynamic_cast<QbsGroupNode *>(parentProjectNode);
@@ -348,7 +405,7 @@ void QbsProjectManagerPlugin::projectChanged(QbsProject *project)
 {
     auto qbsProject = qobject_cast<QbsProject *>(project);
 
-    if (!qbsProject || qbsProject == SessionManager::startupProject())
+    if (!qbsProject || qbsProject == ProjectManager::startupProject())
         updateReparseQbsAction();
 
     if (!qbsProject || qbsProject == ProjectTree::currentProject())
@@ -362,9 +419,9 @@ void QbsProjectManagerPlugin::buildFileContextMenu()
 {
     const Node *node = ProjectTree::currentNode();
     QTC_ASSERT(node, return);
-    auto project = dynamic_cast<QbsProject *>(ProjectTree::currentProject());
+    auto project = qobject_cast<QbsProject *>(ProjectTree::currentProject());
     QTC_ASSERT(project, return);
-    buildSingleFile(project, node->filePath().toString());
+    buildSingleFile(project, node->filePath().toUrlishString());
 }
 
 void QbsProjectManagerPlugin::buildFile()
@@ -374,7 +431,7 @@ void QbsProjectManagerPlugin::buildFile()
     if (!project || !node)
         return;
 
-    buildSingleFile(project, node->filePath().toString());
+    buildSingleFile(project, node->filePath().toUrlishString());
 }
 
 void QbsProjectManagerPlugin::buildProductContextMenu()
@@ -397,7 +454,7 @@ void QbsProjectManagerPlugin::runStepsForProductContextMenu(const QList<Utils::I
 {
     const Node *node = ProjectTree::currentNode();
     QTC_ASSERT(node, return);
-    auto project = dynamic_cast<QbsProject *>(ProjectTree::currentProject());
+    auto project = qobject_cast<QbsProject *>(ProjectTree::currentProject());
     QTC_ASSERT(project, return);
 
     const auto * const productNode = dynamic_cast<const QbsProductNode *>(node);
@@ -460,7 +517,7 @@ void QbsProjectManagerPlugin::runStepsForSubprojectContextMenu(const QList<Utils
 {
     const Node *node = ProjectTree::currentNode();
     QTC_ASSERT(node, return);
-    auto project = dynamic_cast<QbsProject *>(ProjectTree::currentProject());
+    auto project = qobject_cast<QbsProject *>(ProjectTree::currentProject());
     QTC_ASSERT(project, return);
 
     const auto subProject = dynamic_cast<const QbsProjectNode *>(node);
@@ -479,10 +536,7 @@ void QbsProjectManagerPlugin::buildFiles(QbsProject *project, const QStringList
     QTC_ASSERT(project, return);
     QTC_ASSERT(!files.isEmpty(), return);
 
-    Target *t = project->activeTarget();
-    if (!t)
-        return;
-    auto bc = qobject_cast<QbsBuildConfiguration *>(t->activeBuildConfiguration());
+    auto bc = qobject_cast<QbsBuildConfiguration *>(project->activeBuildConfiguration());
     if (!bc)
         return;
 
@@ -511,10 +565,7 @@ void QbsProjectManagerPlugin::runStepsForProducts(QbsProject *project,
     QTC_ASSERT(project, return);
     QTC_ASSERT(!products.isEmpty(), return);
 
-    Target *t = project->activeTarget();
-    if (!t)
-        return;
-    auto bc = qobject_cast<QbsBuildConfiguration *>(t->activeBuildConfiguration());
+    auto bc = qobject_cast<QbsBuildConfiguration *>(project->activeBuildConfiguration());
     if (!bc)
         return;
 
@@ -538,12 +589,12 @@ void QbsProjectManagerPlugin::runStepsForProducts(QbsProject *project,
 
 void QbsProjectManagerPlugin::reparseSelectedProject()
 {
-    reparseProject(dynamic_cast<QbsProject *>(ProjectTree::currentProject()));
+    reparseProject(qobject_cast<QbsProject *>(ProjectTree::currentProject()));
 }
 
 void QbsProjectManagerPlugin::reparseCurrentProject()
 {
-    reparseProject(dynamic_cast<QbsProject *>(SessionManager::startupProject()));
+    reparseProject(qobject_cast<QbsProject *>(ProjectManager::startupProject()));
 }
 
 void QbsProjectManagerPlugin::reparseProject(QbsProject *project)
@@ -551,27 +602,18 @@ void QbsProjectManagerPlugin::reparseProject(QbsProject *project)
     if (!project)
         return;
 
-    Target *t = project->activeTarget();
-    if (!t)
-        return;
-
-    QbsBuildSystem *bs = static_cast<QbsBuildSystem *>(t->buildSystem());
-    if (!bs)
-        return;
-
-    // Qbs does update the build graph during the build. So we cannot
-    // start to parse while a build is running or we will lose information.
-    if (BuildManager::isBuilding(project))
-        bs->scheduleParsing();
-    else
-        bs->parseCurrentBuildConfiguration();
+    if (auto bs = qobject_cast<QbsBuildSystem *>(project->activeBuildSystem());
+        bs && bs->session()->apiLevel() >= 8) {
+        bs->scheduleParsing({{Constants::QBS_RESTORE_BEHAVIOR_KEY, "restore-and-resolve"}});
+    }
 }
 
-void QbsProjectManagerPlugin::buildNamedProduct(QbsProject *project, const QString &product)
+void buildNamedProduct(QbsProject *project, const QString &product)
 {
     QbsProjectManagerPlugin::runStepsForProducts(
         project, QStringList(product), {Utils::Id(ProjectExplorer::Constants::BUILDSTEPS_BUILD)});
 }
 
-} // namespace Internal
-} // namespace QbsProjectManager
+} // QbsProjectManager::Internal
+
+#include "qbsprojectmanagerplugin.moc"
