@@ -28,6 +28,7 @@
 
 #include <utils/algorithm.h>
 #include <utils/async.h>
+#include <utils/filepath.h>
 #include <utils/filesystemwatcher.h>
 #include <utils/fileutils.h>
 #include <utils/mimeconstants.h>
@@ -39,7 +40,6 @@
 
 #include <QLoggingCategory>
 #include <QMessageBox>
-#include <QTextCodec>
 #include <QXmlStreamWriter>
 
 using namespace Core;
@@ -47,6 +47,7 @@ using namespace ProjectExplorer;
 using namespace QmakeProjectManager;
 using namespace QmakeProjectManager::Internal;
 using namespace QMakeInternal;
+using namespace Tasking;
 using namespace Utils;
 
 namespace QmakeProjectManager {
@@ -63,7 +64,7 @@ Q_LOGGING_CATEGORY(qmakeNodesLog, "qtc.qmake.nodes", QtWarningMsg)
 class QmakeEvalInput
 {
 public:
-    QString projectDir;
+    FilePath projectDir;
     FilePath projectFilePath;
     FilePath buildDirectory;
     FilePath sysroot;
@@ -108,7 +109,7 @@ public:
     EvalResultState state;
     ProjectType projectType;
 
-    QStringList subProjectsNotToDeploy;
+    FilePaths subProjectsNotToDeploy;
     QSet<FilePath> exactSubdirs;
     QmakeIncludedPriFile includedFiles;
     TargetInformation targetInformation;
@@ -442,9 +443,9 @@ bool QmakePriFile::folderChanged(const QString &changedFolder, const QSet<FilePa
     return true;
 }
 
-bool QmakePriFile::deploysFolder(const QString &folder) const
+bool QmakePriFile::deploysFolder(const FilePath &folder) const
 {
-    QString f = folder;
+    QString f = folder.toUrlishString();
     const QChar slash = QLatin1Char('/');
     if (!f.endsWith(slash))
         f.append(slash);
@@ -599,7 +600,7 @@ bool QmakePriFile::canRenameFile(const FilePath &oldFilePath, const FilePath &ne
     if (newFilePath.isEmpty())
         return false;
 
-    bool changeProFileOptional = deploysFolder(oldFilePath.absolutePath().toUrlishString());
+    bool changeProFileOptional = deploysFolder(oldFilePath.absolutePath());
     if (changeProFileOptional)
         return true;
 
@@ -611,7 +612,7 @@ bool QmakePriFile::renameFile(const FilePath &oldFilePath, const FilePath &newFi
     if (newFilePath.isEmpty())
         return false;
 
-    bool changeProFileOptional = deploysFolder(oldFilePath.absolutePath().toUrlishString());
+    bool changeProFileOptional = deploysFolder(oldFilePath.absolutePath());
     if (renameFile(oldFilePath, newFilePath, Change::Save))
         return true;
     return changeProFileOptional;
@@ -712,23 +713,23 @@ FilePaths QmakePriFile::formResources(const FilePath &formFile) const
     if (reader.hasError())
         qWarning() << "Could not read form file:" << formFile;
 
-    return FileUtils::toFilePathList(resourceFiles);
+    return FilePaths::fromStrings(resourceFiles);
 }
 
-bool QmakePriFile::ensureWriteableProFile(const QString &file)
+bool QmakePriFile::ensureWriteableProFile(const FilePath &file)
 {
     // Ensure that the file is not read only
-    QFileInfo fi(file);
-    if (!fi.isWritable()) {
+    if (!file.isWritableFile()) {
         // Try via vcs manager
         Core::IVersionControl *versionControl =
-            Core::VcsManager::findVersionControlForDirectory(FilePath::fromString(fi.absolutePath()));
-        if (!versionControl || !versionControl->vcsOpen(FilePath::fromString(file))) {
-            bool makeWritable = QFile::setPermissions(file, fi.permissions() | QFile::WriteUser);
+            Core::VcsManager::findVersionControlForDirectory(file.parentDir());
+        if (!versionControl || !versionControl->vcsOpen(file)) {
+            Result<> makeWritable = file.setPermissions(file.permissions() | QFile::WriteUser);
             if (!makeWritable) {
                 QMessageBox::warning(Core::ICore::dialogParent(),
                                      Tr::tr("Failed"),
-                                     Tr::tr("Could not write project file %1.").arg(file));
+                                     Tr::tr("Could not write project file %1: %2")
+                                        .arg(file.toUserOutput(), makeWritable.error()));
                 return false;
             }
         }
@@ -738,38 +739,28 @@ bool QmakePriFile::ensureWriteableProFile(const QString &file)
 
 QPair<ProFile *, QStringList> QmakePriFile::readProFile()
 {
-    QStringList lines;
-    ProFile *includeFile = nullptr;
-    {
-        QString contents;
-        {
-            const TextFileFormat::ReadResult result =
-                TextFileFormat::readFile(filePath(),
-                                         Core::EditorManager::defaultTextCodec(),
-                                         &contents,
-                                         &m_textFormat);
-            if (result.code != TextFileFormat::ReadSuccess) {
-                QmakeBuildSystem::proFileParseError(result.error, filePath());
-                return {includeFile, lines};
-            }
-            lines = contents.split('\n');
-        }
-
-        QMakeVfs vfs;
-        QtSupport::ProMessageHandler handler;
-        QMakeParser parser(nullptr, &vfs, &handler);
-        includeFile = parser.parsedProBlock(deviceRoot(),
-                                            QStringView(contents),
-                                            0,
-                                            filePath().toUrlishString(),
-                                            1);
+    TextFileFormat::ReadResult result =
+            m_textFormat.readFile(filePath(), EditorManager::defaultTextEncoding());
+    if (result.code != TextFileFormat::ReadSuccess) {
+        QmakeBuildSystem::proFileParseError(result.error, filePath());
+        return {nullptr, {}};
     }
-    return {includeFile, lines};
+
+    QMakeVfs vfs;
+    QtSupport::ProMessageHandler handler;
+    QMakeParser parser(nullptr, &vfs, &handler);
+    ProFile *includeFile = parser.parsedProBlock(deviceRoot(),
+                                                 QStringView(result.content),
+                                                 0,
+                                                 filePath().path(),
+                                                 1);
+
+    return {includeFile, result.content.split('\n')};
 }
 
 bool QmakePriFile::prepareForChange()
 {
-    return saveModifiedEditors() && ensureWriteableProFile(filePath().toUrlishString());
+    return saveModifiedEditors() && ensureWriteableProFile(filePath());
 }
 
 bool QmakePriFile::renameFile(const FilePath &oldFilePath, const FilePath &newFilePath, Change mode)
@@ -784,12 +775,11 @@ bool QmakePriFile::renameFile(const FilePath &oldFilePath, const FilePath &newFi
     if (!includeFile)
         return false;
 
-    QDir priFileDir = QDir(m_qmakeProFile->directoryPath().toFSPathString());
     ProWriter::VarLocations removedLocations;
     const QStringList notChanged = ProWriter::removeFiles(includeFile,
                                                           &lines,
-                                                          priFileDir,
-                                                          {oldFilePath.path()},
+                                                          m_qmakeProFile->directoryPath(),
+                                                          {oldFilePath},
                                                           varNamesForRemoving(),
                                                           &removedLocations);
 
@@ -860,12 +850,11 @@ void QmakePriFile::changeFiles(const QString &mimeType,
                             continuationIndent());
         notChanged->clear();
     } else { // RemoveFromProFile
-        QDir priFileDir = QDir(m_qmakeProFile->directoryPath().toUrlishString());
-        *notChanged = FileUtils::toFilePathList(
+        *notChanged = FilePaths::fromStrings(
             ProWriter::removeFiles(includeFile,
                                    &lines,
-                                   priFileDir,
-                                   Utils::transform(filePaths, &FilePath::toUrlishString),
+                                   m_qmakeProFile->directoryPath(),
+                                   filePaths,
                                    varNamesForRemoving()));
     }
 
@@ -913,7 +902,7 @@ bool QmakePriFile::setProVariable(const QString &var, const QStringList &values,
 void QmakePriFile::save(const QStringList &lines)
 {
     {
-        QTC_ASSERT(m_textFormat.codec(), return);
+        QTC_ASSERT(m_textFormat.encoding().isValid(), return);
         FileChangeBlocker changeGuard(filePath());
         if (const Result<> res = m_textFormat.writeFile(filePath(), lines.join('\n')); !res)
             QMessageBox::critical(Core::ICore::dialogParent(), Tr::tr("File Error"), res.error());
@@ -1164,35 +1153,10 @@ QmakeProFile::QmakeProFile(const FilePath &filePath) : QmakePriFile(filePath) {
 QmakeProFile::~QmakeProFile()
 {
     qDeleteAll(m_extraCompilers);
-    cleanupFutureWatcher();
+    m_taskTreeRunner.reset();
     cleanupProFileReaders();
 }
 
-void QmakeProFile::cleanupFutureWatcher()
-{
-    if (!m_parseFutureWatcher)
-        return;
-
-    m_parseFutureWatcher->disconnect();
-    m_parseFutureWatcher->cancel();
-    m_parseFutureWatcher->waitForFinished();
-    m_parseFutureWatcher->deleteLater();
-    m_parseFutureWatcher = nullptr;
-    m_buildSystem->decrementPendingEvaluateFutures();
-}
-
-void QmakeProFile::setupFutureWatcher()
-{
-    QTC_ASSERT(!m_parseFutureWatcher, return);
-
-    m_parseFutureWatcher = new QFutureWatcher<Internal::QmakeEvalResultPtr>;
-    QObject::connect(m_parseFutureWatcher, &QFutureWatcherBase::finished, [this] {
-        applyEvaluate(m_parseFutureWatcher->result());
-        cleanupFutureWatcher();
-    });
-    m_buildSystem->incrementPendingEvaluateFutures();
-}
-
 bool QmakeProFile::isParent(QmakeProFile *node)
 {
     while ((node = dynamic_cast<QmakeProFile *>(node->parent()))) {
@@ -1236,6 +1200,13 @@ QString QmakeProFile::singleVariableValue(const Variable var) const
     return values.isEmpty() ? QString() : values.first();
 }
 
+FilePaths QmakeProFile::filePathsValue(const Variable var) const
+{
+    return transform(variableValue(var), [this](const QString &fileName) {
+        return m_filePath.withNewPath(fileName);
+    });
+}
+
 void QmakeProFile::setParseInProgressRecursive(bool b)
 {
     setParseInProgress(b);
@@ -1279,16 +1250,35 @@ void QmakeProFile::scheduleUpdate(QmakeProFile::AsyncUpdateDelay delay)
 
 void QmakeProFile::asyncUpdate()
 {
-    cleanupFutureWatcher();
-    setupFutureWatcher();
     setupReader();
     if (!includedInExactParse())
         m_readerExact->setExact(false);
-    QmakeEvalInput input = evalInput();
-    QFuture<QmakeEvalResultPtr> future = Utils::asyncRun(ProjectExplorerPlugin::sharedThreadPool(),
-                                                         QThread::LowestPriority,
-                                                         &QmakeProFile::asyncEvaluate, this, input);
-    m_parseFutureWatcher->setFuture(future);
+
+    struct EvaluationController
+    {
+        EvaluationController(const QPointer<QmakeBuildSystem> &bs)
+            : m_buildSystem(bs)
+        { m_buildSystem->incrementPendingEvaluateFutures(); }
+        ~EvaluationController()
+        { m_buildSystem->decrementPendingEvaluateFutures(); }
+    private:
+        QPointer<QmakeBuildSystem> m_buildSystem;
+    };
+
+    const auto onSetup = [input = evalInput()](Async<QmakeEvalResultPtr> &task) {
+        task.setFutureSynchronizer(nullptr); // Reason: m_readerExact and m_readerCumulative magic.
+        task.setThreadPool(ProjectExplorerPlugin::sharedThreadPool());
+        task.setPriority(QThread::LowestPriority);
+        task.setConcurrentCallData(&QmakeProFile::evaluate, input);
+    };
+    const auto onDone = [this](const Async<QmakeEvalResultPtr> &task) {
+        if (task.isResultAvailable())
+            applyEvaluate(task.result());
+    };
+    m_taskTreeRunner.start({
+        Storage<EvaluationController>(m_buildSystem),
+        AsyncTask<QmakeEvalResultPtr>(onSetup, onDone)
+    });
 }
 
 bool QmakeProFile::isFileFromWildcard(const QString &filePath) const
@@ -1302,7 +1292,7 @@ bool QmakeProFile::isFileFromWildcard(const QString &filePath) const
 QmakeEvalInput QmakeProFile::evalInput() const
 {
     QmakeEvalInput input;
-    input.projectDir = directoryPath().path();
+    input.projectDir = directoryPath();
     input.projectFilePath = filePath();
     input.buildDirectory = m_buildSystem->buildDir(m_filePath);
     input.sysroot = m_buildSystem->qmakeSysroot();
@@ -1366,8 +1356,10 @@ static bool evaluateOne(const QmakeEvalInput &input, ProFile *pro,
     return true;
 }
 
-QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
+void QmakeProFile::evaluate(QPromise<QmakeEvalResultPtr> &promise, const QmakeEvalInput &input)
 {
+    if (promise.isCanceled())
+        return;
     QmakeEvalResultPtr result(new QmakeEvalResult);
     QtSupport::ProFileReader *exactBuildPassReader = nullptr;
     QtSupport::ProFileReader *cumulativeBuildPassReader = nullptr;
@@ -1382,8 +1374,18 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
         result->state = QmakeEvalResult::EvalFail;
     }
 
-    if (result->state == QmakeEvalResult::EvalFail)
-        return result;
+    const auto cleanup = qScopeGuard([input, exactBuildPassReader, cumulativeBuildPassReader] {
+        if (exactBuildPassReader && exactBuildPassReader != input.readerExact)
+            delete exactBuildPassReader;
+        if (cumulativeBuildPassReader && cumulativeBuildPassReader != input.readerCumulative)
+            delete cumulativeBuildPassReader;
+
+    });
+
+    if (result->state == QmakeEvalResult::EvalFail) {
+        promise.addResult(result);
+        return;
+    }
 
     result->includedFiles.proFile = pro;
     result->includedFiles.name = input.projectFilePath;
@@ -1402,6 +1404,8 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
             result->errors.append(errors);
 
             for (const FilePath &subDirName : subDirs) {
+                if (promise.isCanceled())
+                    return;
                 auto subDir = new QmakeIncludedPriFile;
                 subDir->proFile = nullptr;
                 subDir->name = subDirName;
@@ -1415,12 +1419,16 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
         QHash<ProFile *, QList<ProFile *>> includeFiles = input.readerExact->includeFiles();
         QList<QmakeIncludedPriFile *> toBuild = {&result->includedFiles};
         while (!toBuild.isEmpty()) {
+            if (promise.isCanceled())
+                return;
             QmakeIncludedPriFile *current = toBuild.takeFirst();
             if (!current->proFile)
                 continue;  // Don't attempt to map subdirs here
             const QList<ProFile *> children = includeFiles.value(current->proFile);
             for (ProFile *child : children) {
-                const FilePath childName = FilePath::fromString(child->fileName());
+                if (promise.isCanceled())
+                    return;
+                const FilePath childName = child->fullName();
                 auto it = current->children.find(childName);
                 if (it == current->children.end()) {
                     auto childTree = new QmakeIncludedPriFile;
@@ -1434,9 +1442,14 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
         }
     }
 
+    if (promise.isCanceled())
+        return;
+
     if (result->projectType == ProjectType::SubDirsTemplate) {
         const FilePaths subDirs = subDirsPaths(input.readerCumulative, input.projectDir, nullptr, nullptr);
         for (const FilePath &subDirName : subDirs) {
+            if (promise.isCanceled())
+                return;
             auto it = result->includedFiles.children.find(subDirName);
             if (it == result->includedFiles.children.end()) {
                 auto subDir = new QmakeIncludedPriFile;
@@ -1451,12 +1464,16 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
     QHash<ProFile *, QList<ProFile *>> includeFiles = input.readerCumulative->includeFiles();
     QList<QmakeIncludedPriFile *> toBuild = {&result->includedFiles};
     while (!toBuild.isEmpty()) {
+        if (promise.isCanceled())
+            return;
         QmakeIncludedPriFile *current = toBuild.takeFirst();
         if (!current->proFile)
             continue;  // Don't attempt to map subdirs here
         const QList<ProFile *> children = includeFiles.value(current->proFile);
         for (ProFile *child : children) {
-            const FilePath childName = FilePath::fromString(child->fileName());
+            if (promise.isCanceled())
+                return;
+            const FilePath childName = child->fullName();
             auto it = current->children.find(childName);
             if (it == current->children.end()) {
                 auto childTree = new QmakeIncludedPriFile;
@@ -1470,6 +1487,9 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
         toBuild.append(current->children.values());
     }
 
+    if (promise.isCanceled())
+        return;
+
     auto exactReader = exactBuildPassReader ? exactBuildPassReader : input.readerExact;
     auto cumulativeReader = cumulativeBuildPassReader ? cumulativeBuildPassReader : input.readerCumulative;
 
@@ -1478,27 +1498,31 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
 
     const QString &device = input.qmakeGlobals->device_root;
     const QStringList baseVPathsExact
-            = baseVPaths(exactReader, input.projectDir, input.buildDirectory.path());
+            = baseVPaths(exactReader, input.projectDir.path(), input.buildDirectory.path());
     const QStringList baseVPathsCumulative
-            = baseVPaths(cumulativeReader, input.projectDir, input.buildDirectory.path());
+            = baseVPaths(cumulativeReader, input.projectDir.path(), input.buildDirectory.path());
 
     for (int i = 0; i < static_cast<int>(FileType::FileTypeSize); ++i) {
+        if (promise.isCanceled())
+            return;
         const auto type = static_cast<FileType>(i);
         const QStringList qmakeVariables = varNames(type, exactReader);
         for (const QString &qmakeVariable : qmakeVariables) {
+            if (promise.isCanceled())
+                return;
             QHash<ProString, bool> handled;
             if (result->state == QmakeEvalResult::EvalOk) {
                 const QStringList vPathsExact = fullVPaths(
-                            baseVPathsExact, exactReader, qmakeVariable, input.projectDir);
+                            baseVPathsExact, exactReader, qmakeVariable, input.projectDir.path());
                 auto sourceFiles = exactReader->absoluteFileValues(
-                            qmakeVariable, input.projectDir, vPathsExact, &handled, result->directoriesWithWildcards);
+                            qmakeVariable, input.projectDir.path(), vPathsExact, &handled, result->directoriesWithWildcards);
                 exactSourceFiles[qmakeVariable] = sourceFiles;
                 extractSources(device, proToResult, &result->includedFiles.result, sourceFiles, type, false);
             }
             const QStringList vPathsCumulative = fullVPaths(
-                        baseVPathsCumulative, cumulativeReader, qmakeVariable, input.projectDir);
+                        baseVPathsCumulative, cumulativeReader, qmakeVariable, input.projectDir.path());
             auto sourceFiles = cumulativeReader->absoluteFileValues(
-                        qmakeVariable, input.projectDir, vPathsCumulative, &handled, result->directoriesWithWildcards);
+                        qmakeVariable, input.projectDir.path(), vPathsCumulative, &handled, result->directoriesWithWildcards);
             cumulativeSourceFiles[qmakeVariable] = sourceFiles;
             extractSources(device, proToResult, &result->includedFiles.result, sourceFiles, type, true);
         }
@@ -1511,10 +1535,13 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
     //   failed, to at least have a best-effort result.
     result->installsList = installsList(exactBuildPassReader,
                                         input.projectFilePath.path(),
-                                        input.projectDir,
+                                        input.projectDir.path(),
                                         input.buildDirectory.path());
     extractInstalls(device, proToResult, &result->includedFiles.result, result->installsList);
 
+    if (promise.isCanceled())
+        return;
+
     if (result->state == QmakeEvalResult::EvalOk) {
         result->targetInformation = targetInformation(input.readerExact, exactBuildPassReader,
                                                       input.buildDirectory, input.projectFilePath);
@@ -1522,7 +1549,7 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
         // update other variables
         result->newVarValues[Variable::Defines] = exactReader->values(QLatin1String("DEFINES"));
         result->newVarValues[Variable::IncludePath] = includePaths(exactReader, input.sysroot,
-                                                            input.buildDirectory, input.projectDir);
+                                                            input.buildDirectory, input.projectDir.path());
         result->newVarValues[Variable::CppFlags] = exactReader->values(QLatin1String("QMAKE_CXXFLAGS"));
         result->newVarValues[Variable::CFlags] = exactReader->values(QLatin1String("QMAKE_CFLAGS"));
         result->newVarValues[Variable::ExactSource] =
@@ -1541,13 +1568,13 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
         result->newVarValues[Variable::CumulativeResource] = fileListForVar(cumulativeSourceFiles, QLatin1String("RESOURCES"));
         result->newVarValues[Variable::PkgConfig] = exactReader->values(QLatin1String("PKGCONFIG"));
         result->newVarValues[Variable::PrecompiledHeader] = ProFileEvaluator::sourcesToFiles(exactReader->fixifiedValues(
-                    QLatin1String("PRECOMPILED_HEADER"), input.projectDir, input.buildDirectory.path(), false));
+                    QLatin1String("PRECOMPILED_HEADER"), input.projectDir.path(), input.buildDirectory.path(), false));
         result->newVarValues[Variable::LibDirectories] = libDirectories(exactReader);
         result->newVarValues[Variable::Config] = exactReader->values(QLatin1String("CONFIG"));
         result->newVarValues[Variable::QmlImportPath] = exactReader->absolutePathValues(
-                    QLatin1String("QML_IMPORT_PATH"), input.projectDir);
+                    QLatin1String("QML_IMPORT_PATH"), input.projectDir.path());
         result->newVarValues[Variable::QmlDesignerImportPath] = exactReader->absolutePathValues(
-                    QLatin1String("QML_DESIGNER_IMPORT_PATH"), input.projectDir);
+                    QLatin1String("QML_DESIGNER_IMPORT_PATH"), input.projectDir.path());
         result->newVarValues[Variable::Makefile] = exactReader->values(QLatin1String("MAKEFILE"));
         result->newVarValues[Variable::Qt] = exactReader->values(QLatin1String("QT"));
         result->newVarValues[Variable::ObjectExt] = exactReader->values(QLatin1String("QMAKE_EXT_OBJ"));
@@ -1575,28 +1602,31 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
 
         QList<QmakeIncludedPriFile *> toExtract = {&result->includedFiles};
         while (!toExtract.isEmpty()) {
+            if (promise.isCanceled())
+                return;
             QmakeIncludedPriFile *current = toExtract.takeFirst();
             processValues(current->result);
             toExtract.append(current->children.values());
         }
     }
 
-    if (exactBuildPassReader && exactBuildPassReader != input.readerExact)
-        delete exactBuildPassReader;
-    if (cumulativeBuildPassReader && cumulativeBuildPassReader != input.readerCumulative)
-        delete cumulativeBuildPassReader;
-
     QList<QPair<QmakePriFile *, QmakeIncludedPriFile *>>
             toCompare{{nullptr, &result->includedFiles}};
     while (!toCompare.isEmpty()) {
+        if (promise.isCanceled())
+            return;
         QmakePriFile *pn = toCompare.first().first;
         QmakeIncludedPriFile *tree = toCompare.first().second;
         toCompare.pop_front();
 
         // Loop prevention: Make sure that exact same node is not in our parent chain
         for (QmakeIncludedPriFile *priFile : std::as_const(tree->children)) {
+            if (promise.isCanceled())
+                return;
             bool loop = input.parentFilePaths.contains(priFile->name);
             for (const QmakePriFile *n = pn; n && !loop; n = n->parent()) {
+                if (promise.isCanceled())
+                    return;
                 if (n->filePath() == priFile->name)
                     loop = true;
             }
@@ -1626,13 +1656,9 @@ QmakeEvalResultPtr QmakeProFile::evaluate(const QmakeEvalInput &input)
             }
         }
     }
-
-    return result;
-}
-
-void QmakeProFile::asyncEvaluate(QPromise<QmakeEvalResultPtr> &promise, QmakeEvalInput input)
-{
-    promise.addResult(evaluate(input));
+    if (promise.isCanceled())
+        return;
+    promise.addResult(result);
 }
 
 bool sortByParserNodes(Node *a, Node *b)
@@ -1714,9 +1740,7 @@ void QmakeProFile::applyEvaluate(const QmakeEvalResultPtr &result)
         // update TargetInformation
         m_qmakeTargetInformation = result->targetInformation;
 
-        m_subProjectsNotToDeploy
-                = Utils::transform(result->subProjectsNotToDeploy,
-                                   [](const QString &s) { return FilePath::fromString(s); });
+        m_subProjectsNotToDeploy = result->subProjectsNotToDeploy;
         m_installsList = result->installsList;
 
         if (m_varValues != result->newVarValues)
@@ -1840,8 +1864,24 @@ QStringList QmakeProFile::includePaths(QtSupport::ProFileReader *reader, const F
 
     // These paths should not be checked for existence, to ensure consistent include path lists
     // before and after building.
-    const QString mocDir = mocDirPath(reader, buildDir);
-    const QString uiDir = uiDirPath(reader, buildDir);
+    const FilePath mocDir = FilePath::fromString(mocDirPath(reader, buildDir));
+    const FilePath uiDir = FilePath::fromString(uiDirPath(reader, buildDir));
+
+    /* We need to make a full valid Utils::FilePath to make sure that remote paths are compared
+     * correctly. E.g. we may need to compare paths:
+     *   "/C/Users/Admin/DEV/project/build"
+     * and
+     *   "C:/__qtc_devices__/docker/builder_container.latest/C/Users/Admin/DEV/project/build"
+     * Due to buildDir being remote we are sure that the first path of these two must have the same
+     * device but it does not. In such cases device from buildDir is added to the path.
+     */
+    auto createFullFilePath = [&buildDir](QString path) ->FilePath {
+        FilePath result = FilePath::fromString(path);
+        if (!buildDir.isLocal() && result.isLocal()){
+            result.setParts(buildDir.scheme(), buildDir.host(), result.path());
+        }
+        return result;
+    };
 
     const QList<ProFileEvaluator::SourceFile> elList = reader->fixifiedValues(
                 QLatin1String("INCLUDEPATH"), projectDir, buildDir.path(), false);
@@ -1849,9 +1889,10 @@ QStringList QmakeProFile::includePaths(QtSupport::ProFileReader *reader, const F
         const QString sysrootifiedPath = sysrootify(el.fileName, sysroot.path(),
                                                     projectDir,
                                                     buildDir.path());
-        if (IoUtils::isAbsolutePath({}, sysrootifiedPath)
-                && (IoUtils::exists({}, sysrootifiedPath) || sysrootifiedPath == mocDir
-                    || sysrootifiedPath == uiDir)) {
+        const FilePath sysrootifiedFilePath = createFullFilePath(sysrootifiedPath);
+        if (sysrootifiedFilePath.isAbsolutePath()
+                && (sysrootifiedFilePath.exists() || sysrootifiedFilePath == mocDir
+                    || sysrootifiedFilePath == uiDir)) {
             paths << sysrootifiedPath;
         } else {
             tryUnfixified = true;
@@ -1865,7 +1906,8 @@ QStringList QmakeProFile::includePaths(QtSupport::ProFileReader *reader, const F
         for (const QString &p : rawValues) {
             const QString sysrootifiedPath = sysrootify(QDir::cleanPath(p), sysroot.toUrlishString(),
                                                         projectDir, buildDir.toUrlishString());
-            if (IoUtils::isAbsolutePath({}, sysrootifiedPath) && IoUtils::exists({}, sysrootifiedPath))
+            const FilePath sysrootifiedFilePath = createFullFilePath(sysrootifiedPath);
+            if (sysrootifiedFilePath.isAbsolutePath() && sysrootifiedFilePath.exists())
                 paths << sysrootifiedPath;
         }
     }
@@ -1886,8 +1928,8 @@ QStringList QmakeProFile::libDirectories(QtSupport::ProFileReader *reader)
 }
 
 FilePaths QmakeProFile::subDirsPaths(QtSupport::ProFileReader *reader,
-                                            const QString &projectDir,
-                                            QStringList *subProjectsNotToDeploy,
+                                            const FilePath &projectDir,
+                                            FilePaths *subProjectsNotToDeploy,
                                             QStringList *errors)
 {
     FilePaths subProjectPaths;
@@ -1901,29 +1943,26 @@ FilePaths QmakeProFile::subDirsPaths(QtSupport::ProFileReader *reader,
         //   "SUBDIR = subid
         //    subid.file = realdir/realfile.pro"
 
-        QString realDir;
+        FilePath realDir;
         const QString subDirKey = subDirVar + QLatin1String(".subdir");
         const QString subDirFileKey = subDirVar + QLatin1String(".file");
         if (reader->contains(subDirKey))
-            realDir = reader->value(subDirKey);
+            realDir = FilePath::fromString(reader->value(subDirKey));
         else if (reader->contains(subDirFileKey))
-            realDir = reader->value(subDirFileKey);
+            realDir = FilePath::fromString(reader->value(subDirFileKey));
         else
-            realDir = subDirVar;
-        QFileInfo info(realDir);
-        if (!info.isAbsolute())
-            info.setFile(projectDir + QLatin1Char('/') + realDir);
-        realDir = info.filePath();
+            realDir = FilePath::fromString(subDirVar);
+        if (!realDir.isAbsolutePath())
+            realDir = projectDir / realDir.path();
 
-        QString realFile;
-        if (info.isDir())
-            realFile = QString::fromLatin1("%1/%2.pro").arg(realDir, info.fileName());
+        FilePath realFile;
+        if (realDir.isDir())
+            realFile = realDir.pathAppended(realDir.fileName() + ".pro");
         else
             realFile = realDir;
 
-        if (QFileInfo::exists(realFile)) {
-            realFile = QDir::cleanPath(realFile);
-            subProjectPaths << FilePath::fromString(realFile);
+        if (realFile.exists()) {
+            subProjectPaths << realFile;
             if (subProjectsNotToDeploy && !subProjectsNotToDeploy->contains(realFile)
                     && reader->values(subDirVar + QLatin1String(".CONFIG"))
                         .contains(QLatin1String("no_default_target"))) {
@@ -1932,7 +1971,7 @@ FilePaths QmakeProFile::subDirsPaths(QtSupport::ProFileReader *reader,
         } else {
             if (errors)
                 errors->append(Tr::tr("Could not find .pro file for subdirectory \"%1\" in \"%2\".")
-                               .arg(subDirVar).arg(realDir));
+                               .arg(subDirVar).arg(realDir.toUserOutput()));
         }
     }
 
@@ -1957,8 +1996,7 @@ TargetInformation QmakeProFile::targetInformation(QtSupport::ProFileReader *read
     // BUILD DIR
     result.buildDir = buildDir;
 
-    if (readerBuildPass->contains(QLatin1String("DESTDIR")))
-        result.destDir = FilePath::fromString(readerBuildPass->value(QLatin1String("DESTDIR")));
+    result.destDir = result.buildDir.resolvePath(readerBuildPass->value(QLatin1String("DESTDIR")));
 
     // Target
     result.target = readerBuildPass->value(QLatin1String("TARGET"));
@@ -2057,7 +2095,7 @@ FilePaths QmakeProFile::generatedFiles(const FilePath &buildDir,
         FilePath location;
         auto it = m_varValues.constFind(Variable::UiDir);
         if (it != m_varValues.constEnd() && !it.value().isEmpty())
-            location = FilePath::fromString(it.value().front());
+            location = buildDir.resolvePath(it.value().front());
         else
             location = buildDir;
         if (location.isEmpty())
