@@ -1,5 +1,5 @@
 // Copyright (C) 2019 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 #include "treeview.h"
 #include "curveeditormodel.h"
 #include "curveitem.h"
@@ -26,7 +26,7 @@ TreeView::TreeView(CurveEditorModel *model, QWidget *parent)
 
     setModel(model);
 
-    auto expandItems = [this]() { expandAll(); };
+    auto expandItems = [this] { expandAll(); };
     connect(model, &QAbstractItemModel::modelReset, expandItems);
 
     setItemDelegate(new TreeItemDelegate(model->style(), this));
@@ -37,6 +37,8 @@ TreeView::TreeView(CurveEditorModel *model, QWidget *parent)
 
     setStyle(model->style());
 
+    header()->setMinimumSectionSize(20);
+
     header()->setSectionResizeMode(0, QHeaderView::Stretch);
     header()->setSectionResizeMode(1, QHeaderView::Fixed);
     header()->setSectionResizeMode(2, QHeaderView::Fixed);
