@@ -16,6 +16,7 @@
 #include <coreplugin/icore.h>
 #include <projectexplorer/kitaspect.h>
 #include <projectexplorer/target.h>
+#include <qmldesigner/qmldesignerconstants.h>
 #include <qmldesigner/qmldesignerplugin.h>
 #include <qtsupport/qtkitaspect.h>
 
@@ -40,7 +41,7 @@ DeviceManager::DeviceManager(QObject *parent)
     initUdpDiscovery();
 
     connect(&m_resourceGenerator,
-            &QmlDesigner::ResourceGenerator::errorOccurred,
+            &QmlProjectManager::QmlProjectExporter::ResourceGenerator::errorOccurred,
             this,
             [this](const QString &error) {
                 qCDebug(deviceSharePluginLog) << "ResourceGenerator error:" << error;
@@ -48,7 +49,7 @@ DeviceManager::DeviceManager(QObject *parent)
             });
 
     connect(&m_resourceGenerator,
-            &QmlDesigner::ResourceGenerator::qmlrcCreated,
+            &QmlProjectManager::QmlProjectExporter::ResourceGenerator::qmlrcCreated,
             this,
             &DeviceManager::projectPacked);
 }
@@ -94,7 +95,9 @@ void DeviceManager::incomingDatagram()
             if (device->deviceInfo().selfId() == id) {
                 found = true;
                 if (device->deviceSettings().ipAddress() != ip) {
-                    qCDebug(deviceSharePluginLog) << "Updating IP address for device" << id;
+                    qCDebug(deviceSharePluginLog)
+                        << "Updating IP address for device" << id << "from"
+                        << device->deviceSettings().ipAddress() << "to" << ip;
                     setDeviceIP(device->deviceSettings().deviceId(), ip);
                 }
             }
@@ -196,6 +199,9 @@ std::optional<bool> DeviceManager::deviceIsConnected(const QString &deviceId) co
 
 void DeviceManager::setDeviceAlias(const QString &deviceId, const QString &alias)
 {
+    QmlDesigner::QmlDesignerPlugin::emitUsageStatistics(
+        QmlDesigner::Constants::EVENT_DEVICE_MANAGER_ANDROID_SET_ALIAS);
+
     auto device = findDevice(deviceId);
     if (!device)
         return;
@@ -214,6 +220,8 @@ void DeviceManager::setDeviceAlias(const QString &deviceId, const QString &alias
 
 void DeviceManager::setDeviceActive(const QString &deviceId, const bool active)
 {
+    QmlDesigner::QmlDesignerPlugin::emitUsageStatistics(
+        QmlDesigner::Constants::EVENT_DEVICE_MANAGER_ANDROID_SET_ACTIVE);
     auto device = findDevice(deviceId);
     if (!device)
         return;
@@ -231,6 +239,8 @@ void DeviceManager::setDeviceActive(const QString &deviceId, const bool active)
 
 void DeviceManager::setDeviceIP(const QString &deviceId, const QString &ip)
 {
+    QmlDesigner::QmlDesignerPlugin::emitUsageStatistics(
+        QmlDesigner::Constants::EVENT_DEVICE_MANAGER_ANDROID_SET_DEVICE_IP);
     auto device = findDevice(deviceId);
     if (!device)
         return;
@@ -257,6 +267,8 @@ QString DeviceManager::generateDeviceAlias() const
 
 bool DeviceManager::addDevice(const QString &ip)
 {
+    QmlDesigner::QmlDesignerPlugin::emitUsageStatistics(
+        QmlDesigner::Constants::EVENT_DEVICE_MANAGER_ANDROID_ADD_DEVICE);
     if (ip.isEmpty())
         return false;
 
@@ -352,6 +364,8 @@ void DeviceManager::deviceInfoReceived(const QString &deviceId)
 
 void DeviceManager::removeDevice(const QString &deviceId)
 {
+    QmlDesigner::QmlDesignerPlugin::emitUsageStatistics(
+        QmlDesigner::Constants::EVENT_DEVICE_MANAGER_ANDROID_REMOVE_DEVICE);
     auto device = findDevice(deviceId);
     if (!device)
         return;
@@ -405,6 +419,8 @@ void DeviceManager::handleError(const ErrTypes &errType, const QString &deviceId
 
 void DeviceManager::runProject(const QString &deviceId)
 {
+    QmlDesigner::QmlDesignerPlugin::emitUsageStatistics(
+        QmlDesigner::Constants::EVENT_DEVICE_MANAGER_ANDROID_RUN_PROJECT);
     auto device = findDevice(deviceId);
     if (!device) {
         handleError(ErrTypes::InternalError, deviceId, "Device not found");
@@ -425,7 +441,7 @@ void DeviceManager::runProject(const QString &deviceId)
 
     m_currentState = OpTypes::Packing;
     m_currentDeviceId = deviceId;
-    m_resourceGenerator.createQmlrcAsyncWithName();
+    m_resourceGenerator.createQmlrcAsync(ProjectExplorer::ProjectManager::startupProject());
     emit projectPacking(deviceId);
     qCDebug(deviceSharePluginLog) << "Packing project for device" << deviceId;
 }
@@ -433,9 +449,13 @@ void DeviceManager::runProject(const QString &deviceId)
 void DeviceManager::projectPacked(const Utils::FilePath &filePath)
 {
     qCDebug(deviceSharePluginLog) << "Project packed" << filePath.toUserOutput();
-    emit projectSendingProgress(m_currentDeviceId, 0);
 
-    m_currentState = OpTypes::Sending;
+    // it is possible that the device was disconnected while the project was being packed
+    if (m_currentDeviceId.isEmpty()) {
+        qCDebug(deviceSharePluginLog) << "Device disconnected while project was being packed";
+        return;
+    }
+
     qCDebug(deviceSharePluginLog) << "Sending project file to device" << m_currentDeviceId;
     QFile file(filePath.toFSPathString());
 
@@ -450,14 +470,25 @@ void DeviceManager::projectPacked(const Utils::FilePath &filePath)
             m_currentQtKitVersion = qtVer->qtVersion().toString();
     }
 
-    if (!findDevice(m_currentDeviceId)->sendProjectData(file.readAll(), m_currentQtKitVersion)) {
+    auto device = findDevice(m_currentDeviceId);
+    if (!device) {
+        handleError(ErrTypes::InternalError, m_currentDeviceId, "Device not found");
+        return;
+    }
+
+    if (!device->sendProjectData(file.readAll(), m_currentQtKitVersion)) {
         handleError(ErrTypes::ProjectSendingError, m_currentDeviceId, "Failed to send project file");
         return;
     }
+
+    m_currentState = OpTypes::Sending;
+    emit projectSendingProgress(m_currentDeviceId, 0);
 }
 
 void DeviceManager::stopProject()
 {
+    QmlDesigner::QmlDesignerPlugin::emitUsageStatistics(
+        QmlDesigner::Constants::EVENT_DEVICE_MANAGER_ANDROID_STOP_PROJECT);
     auto device = findDevice(m_currentDeviceId);
     if (!device) {
         handleError(ErrTypes::InternalError, m_currentDeviceId, "Device not found");
