@@ -7,12 +7,13 @@
 #include "assetslibrarywidget.h"
 #include "formeditorscene.h"
 #include "formeditorview.h"
-#include "materialutils.h"
 #include "qmldesignerconstants.h"
+#include <designeractionmanager.h>
 #include <itemlibraryentry.h>
 #include <modelnodeoperations.h>
 #include <nodehints.h>
 #include <rewritingexception.h>
+#include <utils3d.h>
 
 #include <utils/qtcassert.h>
 
@@ -176,7 +177,7 @@ void DragTool::clearMoveDelay()
 {
     if (m_blockMove) {
         m_blockMove = false;
-        if (!m_dragNodes.isEmpty())
+        if (!m_dragNodes.isEmpty() && m_dragNodes.first().isValid())
             beginWithPoint(m_startPoint);
     }
 }
@@ -206,9 +207,18 @@ static ItemLibraryEntry itemLibraryEntryFromMimeData(const QMimeData *mimeData)
     return itemLibraryEntry;
 }
 
-static bool canBeDropped(const QMimeData *mimeData)
+static bool canBeDropped(const QMimeData *mimeData, Model *model)
 {
-    return NodeHints::fromItemLibraryEntry(itemLibraryEntryFromMimeData(mimeData)).canBeDroppedInFormEditor();
+    if (AbstractFormEditorTool::hasDroppableAsset(mimeData))
+        return true;
+#ifdef QDS_USE_PROJECTSTORAGE
+    auto itemLibraryEntry = itemLibraryEntryFromMimeData(mimeData);
+    NodeMetaInfo metaInfo{itemLibraryEntry.typeId(), model->projectStorage()};
+    return metaInfo.canBeDroppedInFormEditor() == FlagIs::True;
+#else
+    return NodeHints::fromItemLibraryEntry(itemLibraryEntryFromMimeData(mimeData), model)
+        .canBeDroppedInFormEditor();
+#endif
 }
 
 static bool hasItemLibraryInfo(const QMimeData *mimeData)
@@ -218,7 +228,7 @@ static bool hasItemLibraryInfo(const QMimeData *mimeData)
 
 void DragTool::dropEvent(const QList<QGraphicsItem *> &itemList, QGraphicsSceneDragDropEvent *event)
 {
-    if (canBeDropped(event->mimeData())) {
+    if (canBeDropped(event->mimeData(), view()->model())) {
         event->accept();
         end(generateUseSnapping(event->modifiers()));
 
@@ -274,10 +284,23 @@ void DragTool::dropEvent(const QList<QGraphicsItem *> &itemList, QGraphicsSceneD
                         nodeList.append(node);
                 }
                 view()->setSelectedModelNodes(nodeList);
+
+                bool itemLibraryJustCreated = hasItemLibraryInfo(event->mimeData())
+                                              && nodeList.size() == 1;
+                if (itemLibraryJustCreated)
+                    view()->emitCustomNotification("item_library_created_by_drop", nodeList);
             }
             m_dragNodes.clear();
         }
 
+        if (qApp->keyboardModifiers().testFlag(Qt::AltModifier)) {
+            if (auto *actionInterface = DesignerActionManager::instance().actionByMenuId(
+                    ComponentCoreConstants::anchorsFillCommandId);
+                actionInterface) {
+                actionInterface->action()->trigger();
+            }
+        }
+
         view()->changeToSelectionTool();
         view()->model()->endDrag();
     }
@@ -285,7 +308,7 @@ void DragTool::dropEvent(const QList<QGraphicsItem *> &itemList, QGraphicsSceneD
 
 void DragTool::dragEnterEvent(const QList<QGraphicsItem *> &/*itemList*/, QGraphicsSceneDragDropEvent *event)
 {
-    if (canBeDropped(event->mimeData())) {
+    if (canBeDropped(event->mimeData(), view()->model())) {
         m_blockMove = false;
 
         if (hasItemLibraryInfo(event->mimeData())) {
@@ -301,7 +324,7 @@ void DragTool::dragEnterEvent(const QList<QGraphicsItem *> &/*itemList*/, QGraph
 
 void DragTool::dragLeaveEvent(const QList<QGraphicsItem *> &/*itemList*/, QGraphicsSceneDragDropEvent *event)
 {
-    if (canBeDropped(event->mimeData())) {
+    if (canBeDropped(event->mimeData(), view()->model())) {
         event->accept();
 
         m_moveManipulator.end();
@@ -358,10 +381,8 @@ void DragTool::dragMoveEvent(const QList<QGraphicsItem *> &itemList, QGraphicsSc
                                                      ->data(Constants::MIME_TYPE_ASSETS)).split(',');
     QString assetType = AssetsLibraryWidget::getAssetTypeAndData(assetPaths[0]).first;
 
-    if (!m_blockMove
-            && !m_isAborted
-            && canBeDropped(event->mimeData())
-            && assetType != Constants::MIME_TYPE_ASSET_EFFECT) {
+    if (!m_blockMove && !m_isAborted && canBeDropped(event->mimeData(), view()->model())
+        && assetType != Constants::MIME_TYPE_ASSET_EFFECT) {
         event->accept();
         if (!m_dragNodes.isEmpty()) {
             if (targetContainerItem) {
@@ -382,7 +403,7 @@ void DragTool::dragMoveEvent(const QList<QGraphicsItem *> &itemList, QGraphicsSc
     }
 }
 
-void  DragTool::end()
+void DragTool::end()
 {
     m_moveManipulator.end();
     clear();
@@ -436,7 +457,7 @@ void DragTool::handleView3dDrop()
             const QList<ModelNode> models = dragNode.modelNode().subModelNodesOfType(
                 model->qtQuick3DModelMetaInfo());
             QTC_ASSERT(models.size() == 1, return);
-            MaterialUtils::assignMaterialTo3dModel(view(), models.at(0));
+            Utils3D::assignMaterialTo3dModel(view(), models.at(0));
         }
     }
 }
