@@ -2,9 +2,7 @@
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "timelinewidget.h"
-#include "bindingproperty.h"
 #include "curvesegment.h"
-#include "easingcurve.h"
 #include "easingcurvedialog.h"
 #include "timelineconstants.h"
 #include "timelinegraphicsscene.h"
@@ -45,6 +43,8 @@
 
 #include <cmath>
 
+using namespace Core;
+
 namespace QmlDesigner {
 
 class Eventfilter : public QObject
@@ -66,9 +66,7 @@ public:
 
 static qreal next(const QVector<qreal> &vector, qreal current)
 {
-    auto iter = std::find_if(vector.cbegin(), vector.cend(), [&](qreal val) {
-        return val > current;
-    });
+    auto iter = std::ranges::find_if(vector, [&](qreal val) { return val > current; });
     if (iter != vector.end())
         return *iter;
     return current;
@@ -76,9 +74,8 @@ static qreal next(const QVector<qreal> &vector, qreal current)
 
 static qreal previous(const QVector<qreal> &vector, qreal current)
 {
-    auto iter = std::find_if(vector.rbegin(), vector.rend(), [&](qreal val) {
-        return val < current;
-    });
+    auto iter = std::find_if(vector.rbegin(), vector.rend(),
+                             [&](qreal val) { return val < current; });
     if (iter != vector.rend())
         return *iter;
     return current;
@@ -113,7 +110,7 @@ TimelineWidget::TimelineWidget(TimelineView *view)
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
     m_toolbar->setStyleSheet(Theme::replaceCssColors(
-        QString::fromUtf8(Utils::FileReader::fetchQrc(":/qmldesigner/stylesheet.css"))));
+        Utils::FileUtils::fetchQrc(":/qmldesigner/stylesheet.css")));
     m_scrollbar->setOrientation(Qt::Horizontal);
 
     QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Preferred);
@@ -221,10 +218,10 @@ TimelineWidget::TimelineWidget(TimelineView *view)
 
     {
         QPalette timelinePalette;
-        timelinePalette.setColor(QPalette::Text, Utils::creatorTheme()->color(
+        timelinePalette.setColor(QPalette::Text, Utils::creatorColor(
                                      Utils::Theme::DStextColor));
         timelinePalette.setColor(QPalette::WindowText, timelinePalette.color(QPalette::Text));
-        timelinePalette.setColor(QPalette::Window, Utils::creatorTheme()->color(
+        timelinePalette.setColor(QPalette::Window, Utils::creatorColor(
                                      Utils::Theme::QmlDesigner_BackgroundColorDarkAlternate));
 
         onboardingTopLabel->setPalette(timelinePalette);
@@ -281,6 +278,9 @@ TimelineWidget::TimelineWidget(TimelineView *view)
     connect(m_playbackAnimation, &QVariantAnimation::finished, onFinish);
 
     TimeLineNS::TimelineScrollAreaSupport::support(m_graphicsView, m_scrollbar);
+
+    IContext::attach(this, Context(TimelineConstants::C_QMLTIMELINE),
+                    [this](const IContext::HelpCallback &callback) { contextHelp(callback); });
 }
 
 void TimelineWidget::connectToolbar()
@@ -461,7 +461,7 @@ void TimelineWidget::contextHelp(const Core::IContext::HelpCallback &callback) c
 
 void TimelineWidget::init(int zoom)
 {
-    QmlTimeline currentTimeline = m_timelineView->timelineForState(m_timelineView->currentState());
+    QmlTimeline currentTimeline = m_timelineView->timelineForState(m_timelineView->currentStateNode());
     if (currentTimeline.isValid()) {
         setTimelineId(currentTimeline.modelNode().id());
         m_statusBar->setText(
@@ -501,7 +501,7 @@ TimelineToolBar *TimelineWidget::toolBar() const
 void TimelineWidget::invalidateTimelineDuration(const QmlTimeline &timeline)
 {
     if (timelineView() && timelineView()->model()) {
-        QmlTimeline currentTimeline = timelineView()->currentTimeline();
+        QmlTimeline currentTimeline = timelineView()->currentTimelineNode();
         if (currentTimeline.isValid() && currentTimeline == timeline) {
             m_toolbar->setStartFrame(timeline.startKeyframe());
             m_toolbar->setEndFrame(timeline.endKeyframe());
@@ -525,7 +525,7 @@ void TimelineWidget::invalidateTimelineDuration(const QmlTimeline &timeline)
 void TimelineWidget::invalidateTimelinePosition(const QmlTimeline &timeline)
 {
     if (timelineView() && timelineView()->model()) {
-        QmlTimeline currentTimeline = timelineView()->currentTimeline();
+        QmlTimeline currentTimeline = timelineView()->currentTimelineNode();
         if (currentTimeline.isValid() && currentTimeline == timeline) {
             qreal frame = getcurrentFrame(timeline);
             m_toolbar->setCurrentFrame(frame);
@@ -551,7 +551,7 @@ void TimelineWidget::setupScrollbar(int min, int max, int current)
 
 void TimelineWidget::setTimelineId(const QString &id)
 {
-    auto currentState = m_timelineView->currentState();
+    QmlModelState currentState = m_timelineView->currentStateNode();
     auto timelineOfState = m_timelineView->timelineForState(currentState.modelNode());
 
     bool active = false;
@@ -606,7 +606,7 @@ void TimelineWidget::showEvent([[maybe_unused]] QShowEvent *event)
 {
     int zoom = m_toolbar->scaleFactor();
 
-    m_timelineView->setEnabled(true);
+    QmlDesignerPlugin::viewManager().showView(*m_timelineView);
 
     graphicsScene()->setWidth(m_graphicsView->viewport()->width());
     graphicsScene()->invalidateScene();
@@ -629,7 +629,7 @@ void TimelineWidget::resizeEvent(QResizeEvent *event)
 
 void TimelineWidget::hideEvent(QHideEvent *event)
 {
-    m_timelineView->setEnabled(false);
+    QmlDesignerPlugin::viewManager().hideView(*m_timelineView);
     QWidget::hideEvent(event);
 }
 
