@@ -1,10 +1,12 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "openuiqmlfiledialog.h"
 
 #include <qmldesignerplugin.h>
 
+#include <qmldesignerbase/settings/designersettings.h>
+
 #include <utils/layoutbuilder.h>
 
 #include <QCheckBox>
@@ -30,7 +32,7 @@ OpenUiQmlFileDialog::OpenUiQmlFileDialog(QWidget *parent) :
 
     m_listWidget = new QListWidget;
 
-    using namespace Utils::Layouting;
+    using namespace Layouting;
 
     Column {
         tr("You are opening a .qml file in the designer. Do you want to open a .ui.qml file instead?"),
