@@ -24,6 +24,8 @@ public:
     QmlDesignerBasePlugin();
     ~QmlDesignerBasePlugin();
 
+    static QmlDesignerBasePlugin &instance();
+
     static class DesignerSettings &settings();
     static QStyle *style();
     static class StudioConfigSettingsPage *studioConfigSettingsPage();
@@ -31,12 +33,16 @@ public:
     static bool experimentalFeaturesEnabled();
     static QByteArray experimentalFeaturesSettingsKey();
 
+    static void enableLiteMode();
+    static bool isLiteModeEnabled();
+
 private:
-    bool initialize(const QStringList &arguments, QString *errorMessage) override;
+    Utils::Result<> initialize(const QStringList &arguments) final;
 
 private:
     class Data;
     std::unique_ptr<Data> d;
+    bool m_enableLiteMode = false;
 };
 
 } // namespace QmlDesigner
