@@ -70,7 +70,7 @@ public:
     void currentEditorChanged(IEditor *editor);
     void runSemanticScan();
     void checkCurrentEditorSemanticInfoUpToDate();
-    void autoFormatOnSave(IDocument *document);
+    void autoFormatOnSave(IDocument *document, IDocument::SaveOption option);
 
     Command *addToolAction(QAction *a, Context &context, Id id,
                            ActionContainer *c1, const QString &keySequence);
@@ -277,7 +277,7 @@ static FormatResult reformatByBuiltInFormatter(QPointer<QmlJSEditorDocument> doc
         return FormatResult::Failed;
 
     QmlJSTools::QmlJSCodeStylePreferences *codeStyle
-        = QmlJSTools::QmlJSToolsSettings::globalCodeStyle();
+        = QmlJSTools::globalQmlJSCodeStyle();
     TextEditor::TabSettings tabSettings = codeStyle->currentTabSettings();
     const QString newText = QmlJS::reformat(
         documentPtr,
@@ -368,8 +368,7 @@ FormatResult QmlJSEditorPluginPrivate::reformatFile()
         return FormatResult::Failed;
     }
 
-    QmlJSTools::QmlJSCodeStylePreferences *codeStyle
-        = QmlJSTools::QmlJSToolsSettings::globalCodeStyle();
+    QmlJSTools::QmlJSCodeStylePreferences *codeStyle = QmlJSTools::globalQmlJSCodeStyle();
     const QmlJSCodeStyleSettings settings = codeStyle->currentCodeStyleSettings();
 
     const auto tryReformat = [this, codeStyle](auto formatterFunction) {
@@ -446,9 +445,9 @@ void QmlJSEditorPluginPrivate::checkCurrentEditorSemanticInfoUpToDate()
     m_reformatFileAction->setEnabled(semanticInfoUpToDate);
 }
 
-void QmlJSEditorPluginPrivate::autoFormatOnSave(IDocument *document)
+void QmlJSEditorPluginPrivate::autoFormatOnSave(IDocument *document, IDocument::SaveOption option)
 {
-    if (!settings().autoFormatOnSave())
+    if (!settings().autoFormatOnSave() || option == IDocument::SaveOption::DisableFormatOnSave)
         return;
 
     // Check that we are dealing with a QML/JS editor
