@@ -31,12 +31,11 @@ Group qmlProfilerRecipe(RunControl *runControl)
     const auto onSetup = [runControl](Barrier &barrier) {
         QmlProfilerTool::instance()->finalizeRunControl(runControl);
         QmlProfilerClientManager *clientManager = QmlProfilerTool::instance()->clientManager();
-        RunInterface *iface = runStorage().activeStorage();
         QObject::connect(clientManager, &QmlProfilerClientManager::connectionFailed,
                          &barrier, [barrier = &barrier] { barrier->stopWithResult(DoneResult::Error); });
         QObject::connect(clientManager, &QmlProfilerClientManager::connectionClosed,
                          &barrier, &Barrier::advance);
-        QObject::connect(iface, &RunInterface::canceled, &barrier, [barrier = &barrier] {
+        QObject::connect(runControl, &RunControl::canceled, &barrier, [barrier = &barrier] {
             if (QmlProfilerTool::instance() == nullptr) {
                 barrier->stopWithResult(DoneResult::Error);
                 return;
@@ -56,7 +55,7 @@ Group qmlProfilerRecipe(RunControl *runControl)
         });
         clientManager->setServer(runControl->qmlChannel());
         clientManager->connectToServer();
-        emit iface->started();
+        runControl->reportStarted();
     };
     const auto onDone = [] {
         if (QmlProfilerTool::instance() == nullptr)
@@ -69,9 +68,8 @@ Group qmlProfilerRecipe(RunControl *runControl)
     return { BarrierTask(onSetup, onDone) };
 }
 
-RunWorker *createLocalQmlProfilerWorker(RunControl *runControl)
+Group localQmlProfilerRecipe(RunControl *runControl)
 {
-    auto profiler = new RunWorker(runControl, qmlProfilerRecipe(runControl));
     runControl->requestQmlChannel();
 
     const auto modifier = [runControl](Process &process) {
@@ -90,14 +88,46 @@ RunWorker *createLocalQmlProfilerWorker(RunControl *runControl)
         CommandLine cmd = runControl->commandLine();
         cmd.prependArgs(arguments, CommandLine::Raw);
         process.setCommand(cmd.toLocal());
+
+        QmlProfilerTool::instance()->finalizeRunControl(runControl);
+        QmlProfilerClientManager *clientManager = QmlProfilerTool::instance()->clientManager();
+
+        const auto handleDone = [runControl, process = &process] {
+            if (QmlProfilerTool::instance()) {
+                QmlProfilerTool::instance()->handleStop();
+                QmlProfilerStateManager *stateManager = QmlProfilerTool::instance()->stateManager();
+                if (stateManager && stateManager->currentState() == QmlProfilerStateManager::AppRunning)
+                    stateManager->setCurrentState(QmlProfilerStateManager::AppStopRequested);
+            }
+            if (process->isRunning())
+                runControl->handleProcessCancellation(process);
+        };
+
+        QObject::connect(clientManager, &QmlProfilerClientManager::connectionFailed,
+                         &process, [handleDone] { handleDone(); });
+        QObject::connect(clientManager, &QmlProfilerClientManager::connectionClosed,
+                         &process, [handleDone] { handleDone(); });
+        QObject::connect(&process, &Process::done, &process, [handleDone] { handleDone(); });
+        QObject::connect(runControl, &RunControl::canceled, &process, [handleDone, process = &process] {
+            QmlProfilerStateManager *stateManager = QmlProfilerTool::instance()
+                ? QmlProfilerTool::instance()->stateManager() : nullptr;
+            if (stateManager == nullptr) {
+                handleDone();
+                return;
+            }
+            if (stateManager->currentState() == QmlProfilerStateManager::AppRunning)
+                stateManager->setCurrentState(QmlProfilerStateManager::AppStopRequested);
+            QObject::connect(stateManager, &QmlProfilerStateManager::stateChanged,
+                             process, [handleDone, stateManager] {
+                if (stateManager->currentState() == QmlProfilerStateManager::Idle)
+                    handleDone();
+            });
+        });
+        clientManager->setServer(runControl->qmlChannel());
+        clientManager->connectToServer();
     };
 
-    auto worker = createProcessWorker(runControl, modifier);
-    worker->addStopDependency(profiler);
-    // We need to open the local server before the application tries to connect.
-    // In the TCP case, it doesn't hurt either to start the profiler before.
-    worker->addStartDependency(profiler);
-    return worker;
+    return { runControl->processRecipe(modifier, {false, false}) };
 }
 
 // Factories
@@ -108,6 +138,7 @@ class QmlProfilerRunWorkerFactory final : public RunWorkerFactory
 public:
     QmlProfilerRunWorkerFactory()
     {
+        setId("QmlProfilerRunWorkerFactory");
         setRecipeProducer(qmlProfilerRecipe);
         addSupportedRunMode(ProjectExplorer::Constants::QML_PROFILER_RUNNER);
     }
@@ -120,7 +151,7 @@ public:
     LocalQmlProfilerRunWorkerFactory()
     {
         setId(ProjectExplorer::Constants::QML_PROFILER_RUN_FACTORY);
-        setProducer(&createLocalQmlProfilerWorker);
+        setRecipeProducer(&localQmlProfilerRecipe);
         addSupportedRunMode(ProjectExplorer::Constants::QML_PROFILER_RUN_MODE);
         addSupportedDeviceType(ProjectExplorer::Constants::DESKTOP_DEVICE_TYPE);
 
