@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "qmlprofilermodelmanager.h"
 #include "qmlprofilerstatisticsmodel.h"
@@ -86,7 +86,7 @@ void QmlProfilerStatisticsModel::restrictToFeatures(quint64 features)
     m_modelManager->replayQmlEvents(filter(std::bind(&QmlProfilerStatisticsModel::loadEvent, this,
                                                      std::placeholders::_1, std::placeholders::_2)),
                                     std::bind(&QmlProfilerStatisticsModel::beginResetModel, this),
-                                    [this]() {
+                                    [this] {
         finalize();
         notesChanged(QmlProfilerStatisticsModel::s_invalidTypeId); // Reload notes
     }, [this](const QString &message) {
@@ -121,14 +121,10 @@ QStringList QmlProfilerStatisticsModel::details(int typeIndex) const
             data = data.left(maxColumnWidth - 1) + ellipsisChar;
     }
 
-    return QStringList({
-        displayName,
-        data,
-        QString::number(durationPercent(typeIndex), 'f', 2) + QLatin1Char('%')
-    });
+    return {displayName, data, QString::number(durationPercent(typeIndex), 'f', 2) + '%'};
 }
 
-QString QmlProfilerStatisticsModel::summary(const QVector<int> &typeIds) const
+QString QmlProfilerStatisticsModel::summary(const QList<int> &typeIds) const
 {
     const double cutoff = 0.1;
     const double round = 0.05;
@@ -205,14 +201,14 @@ QVariant QmlProfilerStatisticsModel::dataForMainEntry(const QModelIndex &index,
     case TypeIdRole:
         return s_mainEntryTypeId;
     case Qt::ForegroundRole:
-        return Utils::creatorTheme()->color(Utils::Theme::Timeline_TextColor);
+        return Utils::creatorColor(Utils::Theme::Timeline_TextColor);
     case SortRole:
         switch (index.column()) {
         case MainTimeInPercent:
-            return 100;
+            return double(100);
         case MainSelfTimeInPercent:
         case MainSelfTime:
-            return 0;
+            return double(0);
         case MainTotalTime:
         case MainTimePerCall:
         case MainMedianTime:
@@ -283,8 +279,8 @@ QVariant QmlProfilerStatisticsModel::data(const QModelIndex &index, int role) co
         }
     case Qt::ForegroundRole:
         return (stats.recursive > 0 || m_notes.contains(typeIndex))
-                ? Utils::creatorTheme()->color(Utils::Theme::Timeline_HighlightColor)
-                : Utils::creatorTheme()->color(Utils::Theme::Timeline_TextColor);
+                ? Utils::creatorColor(Utils::Theme::Timeline_HighlightColor)
+                : Utils::creatorColor(Utils::Theme::Timeline_TextColor);
     case SortRole:
         switch (index.column()) {
         case MainLocation:
@@ -374,12 +370,12 @@ QVariant QmlProfilerStatisticsModel::headerData(int section, Qt::Orientation ori
 void QmlProfilerStatisticsModel::typeDetailsChanged(int typeIndex)
 {
     const QModelIndex index = createIndex(typeIndex, MainDetails);
-    emit dataChanged(index, index, QVector<int>({SortRole, Qt::DisplayRole}));
+    emit dataChanged(index, index, QList<int>({SortRole, Qt::DisplayRole}));
 }
 
 void QmlProfilerStatisticsModel::notesChanged(int typeIndex)
 {
-    static const QVector<int> noteRoles({Qt::ToolTipRole, Qt::ForegroundRole});
+    static const QList<int> noteRoles({Qt::ToolTipRole, Qt::ForegroundRole});
     const Timeline::TimelineNotesModel *notesModel = m_modelManager->notesModel();
     if (typeIndex == s_invalidTypeId) {
         m_notes.clear();
@@ -510,7 +506,7 @@ void QmlProfilerStatisticsRelativesModel::loadEvent(RangeType type, const QmlEve
         int selfTypeIndex = (m_relation == QmlProfilerStatisticsCallers) ? event.typeIndex() :
                                                                            callerTypeIndex;
 
-        QVector<QmlStatisticsRelativesData> &relatives = m_data[selfTypeIndex];
+        QList<QmlStatisticsRelativesData> &relatives = m_data[selfTypeIndex];
         auto it = std::lower_bound(relatives.begin(), relatives.end(), relativeTypeIndex);
         if (it != relatives.end() && it->typeIndex == relativeTypeIndex) {
             it->calls++;
@@ -551,7 +547,7 @@ QVariant QmlProfilerStatisticsRelativesModel::dataForMainEntry(qint64 totalDurat
     case TypeIdRole:
         return QmlProfilerStatisticsModel::s_mainEntryTypeId;
     case Qt::ForegroundRole:
-        return Utils::creatorTheme()->color(Utils::Theme::Timeline_TextColor);
+        return Utils::creatorColor(Utils::Theme::Timeline_TextColor);
     case SortRole:
         if (column == RelativeTotalTime)
             return totalDuration;
@@ -577,7 +573,7 @@ QVariant QmlProfilerStatisticsRelativesModel::data(const QModelIndex &index, int
     auto main_it = m_data.find(m_relativeTypeIndex);
     QTC_ASSERT(main_it != m_data.end(), return QVariant());
 
-    const QVector<QmlStatisticsRelativesData> &data = main_it.value();
+    const QList<QmlStatisticsRelativesData> &data = main_it.value();
     QTC_ASSERT(row >= 0 && row < data.length(), return QVariant());
 
     const QmlStatisticsRelativesData &stats = data.at(row);
@@ -602,8 +598,8 @@ QVariant QmlProfilerStatisticsRelativesModel::data(const QModelIndex &index, int
         return stats.isRecursive ? Tr::tr("called recursively") : QString();
     case Qt::ForegroundRole:
         return stats.isRecursive
-                ? Utils::creatorTheme()->color(Utils::Theme::Timeline_HighlightColor)
-                : Utils::creatorTheme()->color(Utils::Theme::Timeline_TextColor);
+                ? Utils::creatorColor(Utils::Theme::Timeline_HighlightColor)
+                : Utils::creatorColor(Utils::Theme::Timeline_TextColor);
     case SortRole:
         switch (index.column()) {
         case RelativeLocation:
@@ -682,11 +678,11 @@ void QmlProfilerStatisticsRelativesModel::typeDetailsChanged(int typeId)
     if (main_it == m_data.constEnd())
         return;
 
-    const QVector<QmlStatisticsRelativesData> &rows = main_it.value();
+    const QList<QmlStatisticsRelativesData> &rows = main_it.value();
     for (int row = 0, end = rows.length(); row != end; ++row) {
         if (rows[row].typeIndex == typeId) {
             const QModelIndex index = createIndex(row, RelativeDetails);
-            emit dataChanged(index, index, QVector<int>({SortRole, Qt::DisplayRole}));
+            emit dataChanged(index, index, QList<int>({SortRole, Qt::DisplayRole}));
             return;
         }
     }
