@@ -74,7 +74,7 @@ bool QmlProjectFileGenerator::execute()
 
     QMessageBox::information(Core::ICore::dialogParent(),
                              Tr::tr("Project File Generated"),
-                             Tr::tr("File created:\n\n%1").arg(m_targetFile.toUrlishString()),
+                             Tr::tr("File created:") + "\n\n" + m_targetFile.toUrlishString(),
                              QMessageBox::Ok);
 
     return true;
@@ -203,7 +203,7 @@ const FilePath QmlProjectFileGenerator::findInDirTree(const FilePath &dir, const
     if (!files.isEmpty())
         return dir;
 
-    FilePaths subdirs = dir.dirEntries(DIRS_ONLY);
+    const FilePaths subdirs = dir.dirEntries(DIRS_ONLY);
     for (const FilePath &subdir : subdirs) {
         const FilePath result = findInDirTree(subdir, suffixes, currentSearchDepth);
         if (!result.isEmpty())
