@@ -12,7 +12,6 @@
 
 #include <debugger/debuggerkitaspect.h>
 #include <debugger/debuggerruncontrol.h>
-#include <debugger/debuggertr.h>
 
 #include <projectexplorer/devicesupport/devicekitaspects.h>
 #include <projectexplorer/devicesupport/deviceprocessesdialog.h>
@@ -25,6 +24,8 @@
 #include <projectexplorer/target.h>
 #include <projectexplorer/toolchain.h>
 
+#include <solutions/tasking/barrier.h>
+
 #include <qtsupport/qtkitaspect.h>
 
 #include <utils/fileutils.h>
@@ -41,29 +42,24 @@
 
 using namespace Debugger;
 using namespace ProjectExplorer;
+using namespace Tasking;
 using namespace Utils;
 
 namespace Qnx::Internal {
 
 const char QNX_DEBUG_EXECUTABLE[] = "pdebug";
 
-static QStringList searchPaths(Kit *kit)
+static FilePaths searchPaths(Kit *kit)
 {
     auto qtVersion = dynamic_cast<QnxQtVersion *>(QtSupport::QtKitAspect::qtVersion(kit));
     if (!qtVersion)
         return {};
 
-    const QDir pluginDir(qtVersion->pluginPath().toUrlishString());
-    const QStringList pluginSubDirs = pluginDir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+    FilePaths searchPaths = qtVersion->pluginPath().dirEntries(QDir::Dirs | QDir::NoDotAndDotDot);
 
-    QStringList searchPaths;
-
-    for (const QString &dir : pluginSubDirs)
-        searchPaths << qtVersion->pluginPath().toUrlishString() + '/' + dir;
-
-    searchPaths << qtVersion->libraryPath().toUrlishString();
-    searchPaths << qtVersion->qnxTarget().pathAppended(qtVersion->cpuDir() + "/lib").toUrlishString();
-    searchPaths << qtVersion->qnxTarget().pathAppended(qtVersion->cpuDir() + "/usr/lib").toUrlishString();
+    searchPaths << qtVersion->libraryPath();
+    searchPaths << qtVersion->qnxTarget().pathAppended(qtVersion->cpuDir() + "/lib");
+    searchPaths << qtVersion->qnxTarget().pathAppended(qtVersion->cpuDir() + "/usr/lib");
 
     return searchPaths;
 }
@@ -101,6 +97,19 @@ private:
     PathChooser *m_localExecutable;
 };
 
+static Group attachToProcessRecipe(RunControl *runControl, const DebuggerRunParameters &rp)
+{
+    if (!rp.isCppDebugging())
+        return debuggerRecipe(runControl, rp);
+
+    const auto modifier = [runControl](Process &process) {
+        process.setCommand({QNX_DEBUG_EXECUTABLE, {QString::number(runControl->debugChannel().port())}});
+    };
+    return When (runControl->processTaskWithModifier(modifier), &Process::started) >> Do {
+        debuggerRecipe(runControl, rp)
+    };
+}
+
 void showAttachToProcessDialog()
 {
     auto kitChooser = new KitChooser;
@@ -109,7 +118,7 @@ void showAttachToProcessDialog()
     });
 
     QnxAttachDebugDialog dlg(kitChooser);
-    dlg.addAcceptButton(::Debugger::Tr::tr("&Attach to Process"));
+    dlg.addAcceptButton(msgAttachToProcess());
     dlg.showAllDevices();
     if (dlg.exec() == QDialog::Rejected)
         return;
@@ -142,22 +151,12 @@ void showAttachToProcessDialog()
     rp.setSymbolFile(localExecutable);
 //    setRunControlName(Tr::tr("Remote: \"%1\" - Process %2").arg(remoteChannel).arg(m_process.pid));
     rp.setDisplayName(Tr::tr("Remote QNX process %1").arg(pid));
-    rp.setSolibSearchPath(FileUtils::toFilePathList(searchPaths(kit)));
+    rp.setSolibSearchPath(searchPaths(kit));
     if (auto qtVersion = dynamic_cast<QnxQtVersion *>(QtSupport::QtKitAspect::qtVersion(kit)))
         rp.setSysRoot(qtVersion->qnxTarget());
     rp.setUseContinueInsteadOfRun(true);
 
-    auto debugger = createDebuggerWorker(runControl, rp);
-
-    if (rp.isCppDebugging()) {
-        const auto modifier = [runControl](Process &process) {
-            const int pdebugPort = runControl->debugChannel().port();
-            process.setCommand({QNX_DEBUG_EXECUTABLE, {QString::number(pdebugPort)}});
-        };
-        auto worker = createProcessWorker(runControl, modifier);
-        debugger->addStartDependency(worker);
-    }
-
+    runControl->setRunRecipe(attachToProcessRecipe(runControl, rp));
     runControl->start();
 }
 
@@ -168,9 +167,23 @@ class QnxDebugWorkerFactory final : public RunWorkerFactory
 public:
     QnxDebugWorkerFactory()
     {
-        setProducer([](RunControl *runControl) {
+        setId("QnxDebugWorkerFactory");
+        setRecipeProducer([](RunControl *runControl) {
             runControl->postMessage(Tr::tr("Preparing remote side..."), LogMessageFormat);
 
+            Kit *k = runControl->kit();
+            DebuggerRunParameters rp = DebuggerRunParameters::fromRunControl(runControl);
+            rp.setupPortsGatherer(runControl);
+            rp.setStartMode(AttachToRemoteServer);
+            rp.setCloseMode(KillAtClose);
+            rp.setUseCtrlCStub(true);
+            rp.setSolibSearchPath(searchPaths(k));
+            rp.setSkipDebugServer(true);
+            if (auto qtVersion = dynamic_cast<QnxQtVersion *>(QtSupport::QtKitAspect::qtVersion(k))) {
+                rp.setSysRoot(qtVersion->qnxTarget());
+                rp.modifyDebuggerEnvironment(qtVersion->environment());
+            }
+
             const auto modifier = [runControl](Process &process) {
                 CommandLine cmd = runControl->commandLine();
                 QStringList arguments;
@@ -178,34 +191,20 @@ public:
                     const int pdebugPort = runControl->debugChannel().port();
                     cmd.setExecutable(runControl->device()->filePath(QNX_DEBUG_EXECUTABLE));
                     arguments.append(QString::number(pdebugPort));
-                }
-                if (runControl->usesQmlChannel()) {
+                } else if (runControl->usesQmlChannel()) {
                     arguments.append(qmlDebugTcpArguments(QmlDebuggerServices, runControl->qmlChannel()));
                 }
                 cmd.setArguments(ProcessArgs::joinArgs(arguments));
                 process.setCommand(cmd);
             };
-            auto worker = createProcessWorker(runControl, modifier);
 
-            auto slog2InfoRunner = new RunWorker(runControl, slog2InfoRecipe(runControl));
-            worker->addStartDependency(slog2InfoRunner);
-
-            Kit *k = runControl->kit();
-            DebuggerRunParameters rp = DebuggerRunParameters::fromRunControl(runControl);
-            rp.setupPortsGatherer(runControl);
-            rp.setStartMode(AttachToRemoteServer);
-            rp.setCloseMode(KillAtClose);
-            rp.setUseCtrlCStub(true);
-            rp.setSolibSearchPath(FileUtils::toFilePathList(searchPaths(k)));
-            rp.setSkipDebugServer(true);
-            if (auto qtVersion = dynamic_cast<QnxQtVersion *>(QtSupport::QtKitAspect::qtVersion(k))) {
-                rp.setSysRoot(qtVersion->qnxTarget());
-                rp.modifyDebuggerEnvironment(qtVersion->environment());
-            }
-
-            auto debugger = createDebuggerWorker(runControl, rp);
-            debugger->addStartDependency(worker);
-            return debugger;
+            return Group {
+                parallel,
+                slog2InfoRecipe(runControl),
+                When (runControl->processTaskWithModifier(modifier), &Process::started) >> Do {
+                    debuggerRecipe(runControl, rp)
+                }
+            };
         });
         addSupportedRunMode(ProjectExplorer::Constants::DEBUG_RUN_MODE);
         addSupportedRunConfig(Constants::QNX_RUNCONFIG_ID);
