@@ -79,19 +79,15 @@ Group slog2InfoRecipe(RunControl *runControl)
                                     .arg(process.errorString()), StdErrFormat);
     };
 
-    const auto onCanceled = [storage](DoneWith result) {
-        if (result == DoneWith::Cancel)
-            storage->processRemainingLogData();
-    };
+    const auto onCanceled = [storage] { storage->processRemainingLogData(); };
 
     return Group {
         storage,
-        onGroupSetup([] { emit runStorage()->started(); }),
-        ProcessTask(onTestSetup, onTestDone, CallDoneIf::Error),
-        ProcessTask(onLaunchTimeSetup, onLaunchTimeDone, CallDoneIf::Success),
-        ProcessTask(onLogSetup, onLogError, CallDoneIf::Error),
-        onGroupDone(onCanceled, CallDoneIf::Error)
-    }.withCancel(canceler());
+        ProcessTask(onTestSetup, onTestDone, CallDone::OnError),
+        ProcessTask(onLaunchTimeSetup, onLaunchTimeDone, CallDone::OnSuccess),
+        ProcessTask(onLogSetup, onLogError, CallDone::OnError),
+        onGroupDone(onCanceled, CallDone::OnCancel)
+    }.withCancel(runControl->canceler());
 }
 
 void SlogData::processRemainingLogData()
