@@ -264,19 +264,19 @@ static QList<ExampleItem *> parseTutorials(QXmlStreamReader *reader, const FileP
     return result;
 }
 
-expected_str<ParsedExamples> parseExamples(const FilePath &manifest,
+Result<ParsedExamples> parseExamples(const FilePath &manifest,
                                            const FilePath &examplesInstallPath,
                                            const FilePath &demosInstallPath,
                                            const bool examples)
 {
-    const expected_str<QByteArray> contents = manifest.fileContents();
+    const Result<QByteArray> contents = manifest.fileContents();
     if (!contents)
         return make_unexpected(contents.error());
 
     return parseExamples(*contents, manifest, examplesInstallPath, demosInstallPath, examples);
 }
 
-expected_str<ParsedExamples> parseExamples(const QByteArray &manifestData,
+Result<ParsedExamples> parseExamples(const QByteArray &manifestData,
                                            const Utils::FilePath &manifestPath,
                                            const FilePath &examplesInstallPath,
                                            const FilePath &demosInstallPath,
@@ -373,9 +373,9 @@ QList<std::pair<Core::Section, QList<ExampleItem *>>> getCategories(const QList<
             // order "known" categories as wanted, others come afterwards
             const int defaultIndex = defaultOrder.indexOf(it->first);
             const int priority = defaultIndex >= 0 ? defaultIndex : (index + defaultOrderSize);
-            const std::optional<int> maxRows = restrictRows
-                                                   ? std::make_optional<int>(index == 0 ? 2 : 1)
-                                                   : std::nullopt;
+            const std::optional<int> maxRows = restrictRows ? std::make_optional<int>(
+                                                   defaultIndex == 0 ? 2 : 1)
+                                                            : std::nullopt;
             categories.append({{it->first, priority, maxRows}, it->second});
             ++index;
         }
