@@ -4,6 +4,7 @@
 #include "qtbuildaspects.h"
 
 #include "baseqtversion.h"
+#include "qtkitaspect.h"
 #include "qtsupporttr.h"
 
 #include <projectexplorer/buildconfiguration.h>
@@ -22,25 +23,29 @@ using namespace Utils;
 
 namespace QtSupport {
 
-QmlDebuggingAspect::QmlDebuggingAspect(AspectContainer *container)
-    : TriStateAspect(container)
+QmlDebuggingAspect::QmlDebuggingAspect(BuildConfiguration *buildConfig)
+    : TriStateAspect(buildConfig)
 {
     setSettingsKey("EnableQmlDebugging");
     setDisplayName(Tr::tr("QML debugging and profiling:"));
     setValue(buildPropertiesSettings().qmlDebugging());
 }
 
-void QmlDebuggingAspect::addToLayout(Layouting::LayoutItem &parent)
+void QmlDebuggingAspect::addToLayoutImpl(Layouting::Layout &parent)
 {
-    SelectionAspect::addToLayout(parent);
+    SelectionAspect::addToLayoutImpl(parent);
     const auto warningLabel = createSubWidget<InfoLabel>(QString(), InfoLabel::Warning);
     warningLabel->setElideMode(Qt::ElideNone);
-    parent.addRow({{}, warningLabel});
-    const auto changeHandler = [this, warningLabel] {
+    parent.addRow({Layouting::empty, warningLabel});
+    const auto changeHandler = [this, warningLabel = QPointer<InfoLabel>(warningLabel)] {
+        QTC_ASSERT(warningLabel, return);
         QString warningText;
-        QTC_ASSERT(m_buildConfig, return);
-        Kit *kit = m_buildConfig->kit();
-        const bool supported = kit && QtVersion::isQmlDebuggingSupported(kit, &warningText);
+        BuildConfiguration *buildConfig = qobject_cast<BuildConfiguration *>(container());
+        QTC_ASSERT(buildConfig, return);
+        QTC_ASSERT(buildConfig->target(), return);
+        Kit *kit = buildConfig->kit();
+        QTC_ASSERT(kit, return);
+        const bool supported = QtVersion::isQmlDebuggingSupported(kit, &warningText);
         if (!supported) {
             setValue(TriState::Default);
         } else if (value() == TriState::Enabled) {
@@ -55,48 +60,45 @@ void QmlDebuggingAspect::addToLayout(Layouting::LayoutItem &parent)
         if (warningLabel->parentWidget() || !warningLabelsVisible)
             warningLabel->setVisible(warningLabelsVisible);
     };
-    connect(KitManager::instance(), &KitManager::kitsChanged, warningLabel, changeHandler);
-    connect(this, &QmlDebuggingAspect::changed, warningLabel, changeHandler);
+    connect(KitManager::instance(), &KitManager::kitsChanged, this, changeHandler);
+    connect(this, &QmlDebuggingAspect::changed, this, changeHandler);
     changeHandler();
 }
 
-void QmlDebuggingAspect::setBuildConfiguration(const BuildConfiguration *buildConfig)
-{
-    m_buildConfig = buildConfig;
-}
-
-QtQuickCompilerAspect::QtQuickCompilerAspect(AspectContainer *container)
-    : TriStateAspect(container)
+QtQuickCompilerAspect::QtQuickCompilerAspect(BuildConfiguration *buildConfig)
+    : TriStateAspect(buildConfig)
 {
     setSettingsKey("QtQuickCompiler");
     setDisplayName(Tr::tr("Qt Quick Compiler:"));
     setValue(buildPropertiesSettings().qtQuickCompiler());
 }
 
-void QtQuickCompilerAspect::setBuildConfiguration(const BuildConfiguration *buildConfig)
+void QtQuickCompilerAspect::addToLayoutImpl(Layouting::Layout &parent)
 {
-    m_buildConfig = buildConfig;
-}
-
-void QtQuickCompilerAspect::addToLayout(Layouting::LayoutItem &parent)
-{
-    SelectionAspect::addToLayout(parent);
+    SelectionAspect::addToLayoutImpl(parent);
     const auto warningLabel = createSubWidget<InfoLabel>(QString(), InfoLabel::Warning);
     warningLabel->setElideMode(Qt::ElideNone);
     warningLabel->setVisible(false);
-    parent.addRow({{}, warningLabel});
-    const auto changeHandler = [this, warningLabel] {
+    parent.addRow({Layouting::empty, warningLabel});
+    const auto changeHandler = [this, warningLabel = QPointer<InfoLabel>(warningLabel)] {
+        QTC_ASSERT(warningLabel, return);
         QString warningText;
-        QTC_ASSERT(m_buildConfig, return);
-        Kit *kit = m_buildConfig->kit();
-        const bool supported = kit
-                && QtVersion::isQtQuickCompilerSupported(kit, &warningText);
+        BuildConfiguration *buildConfig = qobject_cast<BuildConfiguration *>(container());
+        QTC_ASSERT(buildConfig, return);
+        QTC_ASSERT(buildConfig->target(), return);
+        Kit *kit = buildConfig->kit();
+        QTC_ASSERT(kit, return);
+        const bool supported = QtVersion::isQtQuickCompilerSupported(kit, &warningText);
         if (!supported)
             setValue(TriState::Default);
         if (value() == TriState::Enabled) {
-            if (auto qmlDebuggingAspect = m_buildConfig->aspect<QmlDebuggingAspect>()) {
-                if (qmlDebuggingAspect->value() == TriState::Enabled)
-                    warningText = Tr::tr("Disables QML debugging. QML profiling will still work.");
+            if (auto qmlDebuggingAspect = buildConfig->aspect<QmlDebuggingAspect>()) {
+                if (qmlDebuggingAspect->value() == TriState::Enabled) {
+                    if (QtVersion *qtVersion = QtKitAspect::qtVersion(kit)) {
+                        if (qtVersion->qtVersion() < QVersionNumber(6, 0, 0))
+                            warningText = Tr::tr("Disables QML debugging. QML profiling will still work.");
+                    }
+                }
             }
         }
         warningLabel->setText(warningText);
@@ -105,10 +107,12 @@ void QtQuickCompilerAspect::addToLayout(Layouting::LayoutItem &parent)
         if (warningLabel->parentWidget())
             warningLabel->setVisible(warningLabelsVisible);
     };
-    connect(KitManager::instance(), &KitManager::kitsChanged, warningLabel, changeHandler);
-    connect(this, &QmlDebuggingAspect::changed, warningLabel, changeHandler);
-    connect(this, &QtQuickCompilerAspect::changed, warningLabel, changeHandler);
-    if (auto qmlDebuggingAspect = m_buildConfig->aspect<QmlDebuggingAspect>())
+    connect(KitManager::instance(), &KitManager::kitsChanged, this, changeHandler);
+    connect(this, &QmlDebuggingAspect::changed, this, changeHandler);
+    connect(this, &QtQuickCompilerAspect::changed, this, changeHandler);
+
+    BuildConfiguration *buildConfig = qobject_cast<BuildConfiguration *>(container());
+    if (auto qmlDebuggingAspect = buildConfig->aspect<QmlDebuggingAspect>())
         connect(qmlDebuggingAspect, &QmlDebuggingAspect::changed,  warningLabel, changeHandler);
     changeHandler();
 }
