@@ -9,9 +9,9 @@
 #include "remotelinux_constants.h"
 #include "remotelinuxtr.h"
 
+#include <projectexplorer/buildconfiguration.h>
 #include <projectexplorer/deployconfiguration.h>
 #include <projectexplorer/project.h>
-#include <projectexplorer/projectexplorerconstants.h>
 #include <projectexplorer/target.h>
 
 using namespace ProjectExplorer;
@@ -28,15 +28,16 @@ public:
         setDefaultDisplayName(Tr::tr("Deploy to Remote Linux Host"));
         setUseDeploymentDataView();
 
-        const auto needsMakeInstall = [](Target *target)
+        const auto needsMakeInstall = [](BuildConfiguration *bc)
         {
-            const Project * const prj = target->project();
+            const Project * const prj = bc->project();
             return prj->deploymentKnowledge() == DeploymentKnowledge::Bad
                    && prj->hasMakeInstallEquivalent();
         };
         setPostRestore([needsMakeInstall](DeployConfiguration *dc, const Utils::Store &map) {
             // 4.9 -> 4.10. See QTCREATORBUG-22689.
-            if (map.value("_checkMakeInstall").toBool() && needsMakeInstall(dc->target())) {
+            if (map.value("_checkMakeInstall").toBool()
+                && needsMakeInstall(dc->buildConfiguration())) {
                 dc->stepList()->insertStep(0, Constants::MakeInstallStepId);
             }
         });
