@@ -47,7 +47,7 @@ private:
 class File : public Node
 {
 public:
-    File(Prefix *prefix, const QString &_name, const QString &_alias = QString());
+    File(Prefix *prefix, const Utils::FilePath &_name, const QString &_alias = QString());
     void checkExistence();
     bool exists();
     void setExists(bool exists);
@@ -56,7 +56,7 @@ public:
     bool operator == (const File &other) const { return name == other.name; }
     bool operator != (const File &other) const { return name != other.name; }
 
-    QString name;
+    Utils::FilePath name;
     QString alias;
     QIcon icon;
 
@@ -119,7 +119,7 @@ public:
 
     int fileCount(int prefix_idx) const;
 
-    QString file(int prefix_idx, int file_idx) const;
+    Utils::FilePath file(int prefix_idx, int file_idx) const;
     QString alias(int prefix_idx, int file_idx) const;
 
     int addFile(int prefix_idx, const QString &file, int file_idx = -1);
@@ -133,17 +133,17 @@ public:
     bool replacePrefixAndLang(int prefix_idx, const QString &prefix, const QString &lang);
     void replaceAlias(int prefix_idx, int file_idx, const QString &alias);
 
-    bool renameFile(const QString &fileName, const QString &newFileName);
+    bool renameFile(const Utils::FilePath &fileName, const Utils::FilePath &newFileName);
 
-    void replaceFile(int pref_idx, int file_idx, const QString &file);
+    void replaceFile(int pref_idx, int file_idx, const Utils::FilePath &file);
     int indexOfPrefix(const QString &prefix, const QString &lang) const;
     int indexOfFile(int pref_idx, const QString &file) const;
 
     bool contains(const QString &prefix, const QString &lang, const QString &file = QString()) const;
     bool contains(int pref_idx, const QString &file) const;
 
-    QString relativePath(const QString &abs_path) const;
-    QString absolutePath(const QString &rel_path) const;
+    QString relativePath(const Utils::FilePath &abs_path) const;
+    Utils::FilePath absolutePath(const QString &rel_path) const;
 
     void orderList();
 
@@ -202,14 +202,15 @@ public:
 
     QString lang(const QModelIndex &index) const;
     QString alias(const QModelIndex &index) const;
-    QString file(const QModelIndex &index) const;
+    Utils::FilePath file(const QModelIndex &index) const;
 
     virtual QModelIndex addNewPrefix();
     virtual QModelIndex addFiles(const QModelIndex &idx, const QStringList &file_list);
     QStringList existingFilesSubtracted(int prefixIndex, const QStringList &fileNames) const;
     void addFiles(int prefixIndex, const QStringList &fileNames, int cursorFile, int &firstFile, int &lastFile);
     void insertPrefix(int prefixIndex, const QString &prefix, const QString &lang);
-    void insertFile(int prefixIndex, int fileIndex, const QString &fileName, const QString &alias);
+    void insertFile(
+        int prefixIndex, int fileIndex, const QString &fileName, const QString &alias);
     virtual void changePrefix(const QModelIndex &idx, const QString &prefix);
     virtual void changeLang(const QModelIndex &idx, const QString &lang);
     virtual void changeAlias(const QModelIndex &idx, const QString &alias);
@@ -217,14 +218,12 @@ public:
     QModelIndex getIndex(const QString &prefix, const QString &lang, const QString &file);
     QModelIndex prefixIndex(const QModelIndex &sel_idx) const;
 
-    QString absolutePath(const QString &path) const
-        { return m_resource_file.absolutePath(path); }
-    QString relativePath(const QString &path) const
+    QString relativePath(const Utils::FilePath &path) const
         { return m_resource_file.relativePath(path); }
 
 private:
     QString lastResourceOpenDirectory() const;
-    bool renameFile(const QString &fileName, const QString &newFileName);
+    bool renameFile(const Utils::FilePath &filePath, const Utils::FilePath &newFileName);
 
 public:
     virtual Utils::Result<> reload();
@@ -241,7 +240,7 @@ public:
 private:
     QMimeData *mimeData (const QModelIndexList & indexes) const override;
 
-    static bool iconFileExtension(const QString &path);
+    static bool hasIconFileExtension(const QString &path);
     static QString resourcePath(const QString &prefix, const QString &file);
 
 signals:
