@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -34,7 +34,7 @@ class ColorToolButton : public QToolButton
     Q_OBJECT
 
 public:
-    ColorToolButton(const QString &key, const QString &iconName, const QString &tooltip, QWidget *parent = nullptr);
+    ColorToolButton(const QString &key, const QIcon &icon, const QString &tooltip, QWidget *parent = nullptr);
     ~ColorToolButton() override;
 
 protected:
