@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "outputtabwidget.h"
 #include "outputpane.h"
@@ -42,11 +42,11 @@ PaneTitleButton::PaneTitleButton(OutputPane *pane, QWidget *parent)
         }
     });
 
-    connect(pane, &OutputPane::titleChanged, this, [=] {
+    connect(pane, &OutputPane::titleChanged, this, [this, pane] {
         setText(pane->title());
     });
 
-    connect(pane, &OutputPane::iconChanged, this, [=] {
+    connect(pane, &OutputPane::iconChanged, this, [this, pane] {
         setIcon(pane->icon());
     });
 }
