@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "idwarningitem.h"
 #include "scxmleditortr.h"
@@ -43,7 +43,7 @@ void IdWarningItem::setId(const QString &text)
 void IdWarningItem::checkDuplicates(const QString &id)
 {
     if (scene()) {
-        QVector<IdWarningItem*> foundItems;
+        QList<IdWarningItem*> foundItems;
 
         QList<QGraphicsItem*> items = scene()->items();
         for (int i = 0; i < items.count(); ++i) {
