@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "scxmldocument.h"
 #include "scxmleditorconstants.h"
@@ -476,14 +476,14 @@ ScxmlTag *ScxmlTag::tagForId(const QString &id) const
     return nullptr;
 }
 
-QVector<ScxmlTag*> ScxmlTag::allChildren() const
+QList<ScxmlTag*> ScxmlTag::allChildren() const
 {
     return m_childTags;
 }
 
-QVector<ScxmlTag*> ScxmlTag::children(const QString &name) const
+QList<ScxmlTag*> ScxmlTag::children(const QString &name) const
 {
-    QVector<ScxmlTag*> children;
+    QList<ScxmlTag*> children;
     for (ScxmlTag *tag : std::as_const(m_childTags)) {
         if (tag->tagName() == name)
             children << tag;
