@@ -1,5 +1,5 @@
 // Copyright (C) 2019 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -7,6 +7,8 @@
 
 #if defined(STUDIOWELCOME_LIBRARY)
 #  define STUDIOWELCOME_EXPORT Q_DECL_EXPORT
+#elif defined(STUDIOWELCOME_STATIC_LIBRARY)
+#  define STUDIOWELCOME_EXPORT
 #else
 #  define STUDIOWELCOME_EXPORT Q_DECL_IMPORT
 #endif
