@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -19,8 +19,7 @@ public:
 
 private:
     QString changeUnderCursor(const QTextCursor &) const override;
-    VcsBase::BaseAnnotationHighlighter *createAnnotationHighlighter(
-            const QSet<QString> &changes) const override;
+    VcsBase::BaseAnnotationHighlighterCreator annotationHighlighterCreator() const override;
     QStringList annotationPreviousVersions(const QString &) const override;
 
     QRegularExpression m_changeNumberPattern;
