@@ -12,12 +12,12 @@
 #include <coreplugin/icontext.h>
 #include <coreplugin/terminal/searchableterminal.h>
 
+#include <solutions/tasking/tasktreerunner.h>
+
 #include <utils/link.h>
 #include <utils/qtcprocess.h>
 #include <utils/terminalhooks.h>
 
-#include <QFutureWatcher>
-
 #include <memory>
 
 namespace Terminal {
@@ -107,10 +107,13 @@ private:
     RegisteredAction m_selectAll;
     RegisteredAction m_moveCursorWordLeft;
     RegisteredAction m_moveCursorWordRight;
+    RegisteredAction m_deleteWordLeft;
+    RegisteredAction m_deleteLineLeft;
+    RegisteredAction m_closeTerminal;
 
     Internal::ShortcutMap m_shortcutMap;
 
-    std::unique_ptr<QFutureWatcher<Utils::expected_str<Utils::FilePath>>> m_findShellWatcher;
+    Tasking::SingleTaskTreeRunner m_taskTreeRunner;
 };
 
 } // namespace Terminal
