@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "genericproposalwidget.h"
 #include "genericproposalmodel.h"
@@ -249,7 +249,6 @@ public:
     QRect m_displayRect;
     bool m_isSynchronized = true;
     bool m_explicitlySelected = false;
-    AssistReason m_reason = IdleEditor;
     AssistKind m_kind = Completion;
     bool m_justInvoked = false;
     QPointer<GenericProposalInfoFrame> m_infoFrame;
@@ -358,9 +357,9 @@ void GenericProposalWidget::setAssistant(CodeAssistant *assistant)
 
 void GenericProposalWidget::setReason(AssistReason reason)
 {
-    d->m_reason = reason;
-    if (d->m_reason == ExplicitlyInvoked)
+    if (reason == ExplicitlyInvoked)
         d->m_justInvoked = true;
+    IAssistProposalWidget::setReason(reason);
 }
 
 void GenericProposalWidget::setKind(AssistKind kind)
@@ -393,31 +392,26 @@ void GenericProposalWidget::setIsSynchronized(bool isSync)
     d->m_isSynchronized = isSync;
 }
 
-bool GenericProposalWidget::supportsModelUpdate(const Utils::Id &proposalId) const
-{
-    return proposalId == Constants::GENERIC_PROPOSAL_ID;
-}
-
-void GenericProposalWidget::updateModel(ProposalModelPtr model)
+void GenericProposalWidget::updateModel(GenericProposalModelPtr model, const QString &prefix)
 {
     QString currentText;
     if (d->m_explicitlySelected)
         currentText = d->m_model->text(d->m_completionListView->currentIndex().row());
-    d->m_model = model.staticCast<GenericProposalModel>();
+    d->m_model = model;
     if (d->m_model->containsDuplicates())
         d->m_model->removeDuplicates();
     d->m_completionListView->setModel(new ModelAdapter(d->m_model, d->m_completionListView));
     connect(d->m_completionListView->selectionModel(), &QItemSelectionModel::currentChanged,
             &d->m_infoTimer, QOverload<>::of(&QTimer::start));
-    int currentRow = -1;
     if (!currentText.isEmpty()) {
-        currentRow = d->m_model->indexOf(
+        const int currentRow = d->m_model->indexOf(
             Utils::equal(&AssistProposalItemInterface::text, currentText));
+        if (currentRow < 0)
+            d->m_explicitlySelected = false;
+        else
+            d->m_completionListView->selectRow(currentRow);
     }
-    if (currentRow >= 0)
-        d->m_completionListView->selectRow(currentRow);
-    else
-        d->m_explicitlySelected = false;
+    updateAndCheck(prefix);
 }
 
 void GenericProposalWidget::showProposal(const QString &prefix)
@@ -431,7 +425,7 @@ void GenericProposalWidget::showProposal(const QString &prefix)
     d->m_completionListView->setFocus();
 }
 
-void GenericProposalWidget::updateProposal(const QString &prefix)
+void GenericProposalWidget::filterProposal(const QString &prefix)
 {
     if (!isVisible())
         return;
@@ -470,7 +464,7 @@ bool GenericProposalWidget::updateAndCheck(const QString &prefix)
         if (!prefix.isEmpty())
             d->m_model->filter(prefix);
     }
-    if (!d->m_model->hasItemsToPropose(prefix, d->m_reason)) {
+    if (!d->m_model->hasItemsToPropose(prefix, reason())) {
         d->m_completionListView->reset();
         abort();
         return false;
@@ -660,7 +654,7 @@ bool GenericProposalWidget::eventFilter(QObject *o, QEvent *e)
             AssistProposalItemInterface *item =
                 d->m_model->proposalItem(d->m_completionListView->currentIndex().row());
             if (item->prematurelyApplies(typedChar)
-                    && (d->m_reason == ExplicitlyInvoked || item->text().endsWith(typedChar))) {
+                    && (reason() == ExplicitlyInvoked || item->text().endsWith(typedChar))) {
                 abort();
                 emit proposalItemActivated(item);
                 return true;
