@@ -1,34 +1,13 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 Dmitry Savchenko
-** Copyright (C) 2016 Vasiliy Sorokin
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 Dmitry Savchenko
+// Copyright (C) 2016 Vasiliy Sorokin
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "todoitemsmodel.h"
+
 #include "constants.h"
+#include "todotr.h"
 
 #include <utils/algorithm.h>
-
 #include <utils/theme/theme.h>
 
 #include <QIcon>
@@ -40,9 +19,7 @@ namespace Internal {
 
 TodoItemsModel::TodoItemsModel(QObject *parent) :
     QAbstractTableModel(parent),
-    m_todoItemsList(0),
-    m_currentSortColumn(Constants::OutputColumnIndex(0)),
-    m_currentSortOrder(Qt::AscendingOrder)
+    m_currentSortColumn(Constants::OutputColumnIndex(0))
 {
 }
 
@@ -80,12 +57,8 @@ QVariant TodoItemsModel::data(const QModelIndex &index, int role) const
 
     TodoItem item = m_todoItemsList->at(index.row());
 
-    if (role == Qt::BackgroundColorRole)
-        return item.color;
-    if (role == Qt::TextColorRole)
-        return creatorTheme()->color(Theme::TodoItemTextColor);
     if (role == Qt::ForegroundRole)
-        return creatorTheme()->color(Theme::TodoItemTextColor);
+        return item.color;
 
     switch (index.column()) {
 
@@ -122,14 +95,11 @@ QVariant TodoItemsModel::headerData(int section, Qt::Orientation orientation, in
 
     switch (section) {
         case Constants::OUTPUT_COLUMN_TEXT:
-            return tr(Constants::OUTPUT_COLUMN_TEXT_TITLE);
-
+            return Tr::tr("Description");
         case Constants::OUTPUT_COLUMN_FILE:
-            return tr(Constants::OUTPUT_COLUMN_FILE_TITLE);
-
+            return Tr::tr("File");
         case Constants::OUTPUT_COLUMN_LINE:
-            return tr(Constants::OUTPUT_COLUMN_LINE_TITLE);
-
+            return Tr::tr("Line");
         default:
             return QVariant();
     }
