@@ -1,5 +1,5 @@
 // Copyright (C) 2022 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -9,7 +9,7 @@ namespace Todo {
 
 struct Tr
 {
-    Q_DECLARE_TR_FUNCTIONS(Todo)
+    Q_DECLARE_TR_FUNCTIONS(QtC::Todo)
 };
 
 } // namespace Todo
