@@ -1,20 +1,17 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "callgrindtextmark.h"
 
-#include "callgrindhelper.h"
-
 #include "callgrind/callgrinddatamodel.h"
 #include "callgrind/callgrindfunction.h"
+#include "callgrindhelper.h"
 #include "valgrindtr.h"
 
 #include <utils/qtcassert.h>
 
-#include <QDebug>
 #include <QLabel>
 #include <QLayout>
-#include <QPainter>
 
 using namespace Utils;
 using namespace Valgrind::Internal;
@@ -23,8 +20,11 @@ using namespace Valgrind::Callgrind;
 namespace Constants { const char CALLGRIND_TEXT_MARK_CATEGORY[] = "Callgrind.Textmark"; }
 
 CallgrindTextMark::CallgrindTextMark(const QPersistentModelIndex &index,
-                                     const FilePath &fileName, int lineNumber)
-    : TextEditor::TextMark(fileName, lineNumber, Constants::CALLGRIND_TEXT_MARK_CATEGORY)
+                                     const FilePath &fileName,
+                                     int lineNumber)
+    : TextEditor::TextMark(fileName,
+                           lineNumber,
+                           {Tr::tr("Callgrind"), Constants::CALLGRIND_TEXT_MARK_CATEGORY})
     , m_modelIndex(index)
 {
     setPriority(TextEditor::TextMark::HighPriority);
