@@ -53,7 +53,8 @@ static void askUserAboutEmSdkSetup()
 {
     const char setupWebAssemblyEmSdk[] = "SetupWebAssemblyEmSdk";
 
-    if (!ICore::infoBar()->canInfoBeAdded(setupWebAssemblyEmSdk)
+    InfoBar *infoBar = ICore::popupInfoBar();
+    if (!infoBar->canInfoBeAdded(setupWebAssemblyEmSdk)
             || !WebAssemblyQtVersion::isQtVersionInstalled()
             || areToolChainsRegistered())
         return;
@@ -62,11 +63,14 @@ static void askUserAboutEmSdkSetup()
                       Tr::tr("Setup Emscripten SDK for WebAssembly? "
                              "To do it later, select Edit > Preferences > Devices > WebAssembly."),
                       InfoBarEntry::GlobalSuppression::Enabled);
-    info.addCustomButton(Tr::tr("Setup Emscripten SDK"), [setupWebAssemblyEmSdk] {
-        ICore::infoBar()->removeInfo(setupWebAssemblyEmSdk);
-        QTimer::singleShot(0, []() { ICore::showOptionsDialog(Constants::SETTINGS_ID); });
-    });
-    ICore::infoBar()->addInfo(info);
+    info.setTitle(Tr::tr("Set up WebAssembly?"));
+    info.setInfoType(InfoLabel::Information);
+    info.addCustomButton(
+        Tr::tr("Setup Emscripten SDK"),
+        [] { QTimer::singleShot(0, []() { ICore::showOptionsDialog(Constants::SETTINGS_ID); }); },
+        {},
+        InfoBarEntry::ButtonAction::Hide);
+    infoBar->addInfo(info);
 }
 
 class WebAssemblyDeviceFactory final : public IDeviceFactory
@@ -88,7 +92,7 @@ void setupWebAssemblyDevice()
     static WebAssemblyDeviceFactory theWebAssemblyDeviceFactory;
 
     QObject::connect(KitManager::instance(), &KitManager::kitsLoaded, [] {
-        DeviceManager::instance()->addDevice(createWebAssemblyDevice());
+        DeviceManager::addDevice(createWebAssemblyDevice());
         askUserAboutEmSdkSetup();
     });
 }
