@@ -1,11 +1,12 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "qmakeparser.h"
 #include "prowriter.h"
 #include "proitems.h"
 
 #include <utils/algorithm.h>
+#include <utils/filepath.h>
 
 #include <QDir>
 #include <QLoggingCategory>
@@ -154,12 +155,12 @@ static const ushort *skipToken(ushort tok, const ushort *&tokPtr, int &lineNo)
     return nullptr;
 }
 
-QString ProWriter::compileScope(const QString &scope)
+QString ProWriter::compileScope(const QString &device, const QString &scope)
 {
     if (scope.isEmpty())
         return QString();
     QMakeParser parser(nullptr, nullptr, nullptr);
-    ProFile *includeFile = parser.parsedProBlock(QStringView(scope), 0, "no-file", 1);
+    ProFile *includeFile = parser.parsedProBlock(device, QStringView(scope), 0, "no-file", 1);
     if (!includeFile)
         return QString();
     const QString result = includeFile->items();
@@ -181,7 +182,7 @@ static bool startsWithTokens(const ushort *that, const ushort *thatEnd, const us
     return true;
 }
 
-bool ProWriter::locateVarValues(const ushort *tokPtr, const ushort *tokPtrEnd,
+bool ProWriter::locateVarValues(const QString &device, const ushort *tokPtr, const ushort *tokPtrEnd,
     const QString &scope, const QString &var, int *scopeStart, int *bestLine)
 {
     const bool inScope = scope.isEmpty();
@@ -190,7 +191,7 @@ bool ProWriter::locateVarValues(const ushort *tokPtr, const ushort *tokPtrEnd,
     const ushort *lastXpr = nullptr;
     bool fresh = true;
 
-    QString compiledScope = compileScope(scope);
+    QString compiledScope = compileScope(device, scope);
     const ushort *cTokPtr = reinterpret_cast<const ushort *>(compiledScope.constData());
 
     while (ushort tok = *tokPtr++) {
@@ -206,7 +207,7 @@ bool ProWriter::locateVarValues(const ushort *tokPtr, const ushort *tokPtrEnd,
                     && startsWithTokens(tokPtr - 1, tokPtrEnd, cTokPtr, cTokPtr + compiledScope.size())
                     && *(tokPtr -1 + compiledScope.size()) == TokBranch) {
                 *scopeStart = lineNo - 1;
-                if (locateVarValues(tokPtr + compiledScope.size() + 2, tokPtrEnd,
+                if (locateVarValues(device, tokPtr + compiledScope.size() + 2, tokPtrEnd,
                                     QString(), var, scopeStart, bestLine))
                     return true;
             }
@@ -298,7 +299,7 @@ void ProWriter::putVarValues(ProFile *profile, QStringList *lines, const QString
         return !ci.indent.isEmpty() ? ci.indent : continuationIndent + indent;
     };
     int scopeStart = -1, lineNo;
-    if (locateVarValues(profile->tokPtr(), profile->tokPtrEnd(), scope, var, &scopeStart, &lineNo)) {
+    if (locateVarValues(profile->device(), profile->tokPtr(), profile->tokPtrEnd(), scope, var, &scopeStart, &lineNo)) {
         if (flags & ReplaceValues) {
             // remove continuation lines with old values
             const ContinuationInfo contInfo = skipContLines(lines, lineNo, false);
@@ -394,13 +395,28 @@ void ProWriter::putVarValues(ProFile *profile, QStringList *lines, const QString
 void ProWriter::addFiles(ProFile *profile, QStringList *lines, const QStringList &values,
                          const QString &var, const QString &continuationIndent)
 {
+    qCDebug(prowriterLog) << Q_FUNC_INFO << values;
+
+    using namespace Utils;
     QStringList valuesToWrite;
     QString prefixPwd;
-    QDir baseDir = QFileInfo(profile->fileName()).absoluteDir();
+    FilePath baseDir = FilePath::fromString(profile->fileName()).parentDir();
+    qCDebug(prowriterLog) << "base dir:" << baseDir;
     if (profile->fileName().endsWith(".pri"))
         prefixPwd = "$$PWD/";
-    for (const QString &v : values)
-        valuesToWrite << (prefixPwd + baseDir.relativeFilePath(v));
+    for (const QString &v : values) {
+        // v may contain a device prefix, that needs to be handled by FilePath.
+        FilePath tmp = FilePath::fromString(v);
+        /* If v does not have a prefix while baseDir does, or if they somehow have
+         * different prefixes we try using prefix of baseDir assuming it is the right one.
+         * Prefixes should be the same for relativePathFromDir to work properly.
+         */
+        if (!tmp.isSameDevice(baseDir))
+            tmp = FilePath::fromParts(baseDir.scheme(), baseDir.host(), tmp.path());
+        const QString relPath = tmp.relativePathFromDir(baseDir);
+        qCDebug(prowriterLog) << "relative path from" << baseDir << "to" << tmp << "is" << relPath;
+        valuesToWrite << (prefixPwd + relPath);
+    }
 
     putVarValues(profile, lines, valuesToWrite, var, AppendValues | MultiLine | AppendOperator,
                  QString(), continuationIndent);
@@ -564,20 +580,22 @@ QList<int> ProWriter::removeVarValues(ProFile *profile, QStringList *lines,
 QStringList ProWriter::removeFiles(
         ProFile *profile,
         QStringList *lines,
-        const QDir &proFileDir,
-        const QStringList &values,
+        const Utils::FilePath &proFileDir,
+        const Utils::FilePaths &values,
         const QStringList &vars,
         VarLocations *removedLocations)
 {
+    using namespace Utils;
     // This is a tad stupid - basically, it can remove only entries which
     // the above code added.
     QStringList valuesToFind;
-    for (const QString &absoluteFilePath : values)
-        valuesToFind << proFileDir.relativeFilePath(absoluteFilePath);
+    for (const FilePath &absoluteFilePath : values) {
+        valuesToFind << absoluteFilePath.relativePathFromDir(proFileDir);
+    }
 
     const QStringList notYetChanged =
             Utils::transform(removeVarValues(profile, lines, valuesToFind, vars, removedLocations),
-                             [values](int i) { return values.at(i); });
+                             [values](int i) { return values.at(i).toFSPathString(); });
 
     if (!profile->fileName().endsWith(".pri"))
         return notYetChanged;
@@ -586,10 +604,12 @@ QStringList ProWriter::removeFiles(
     // maybe those files can be found via $$PWD/relativeToPriFile
 
     valuesToFind.clear();
-    const QDir baseDir = QFileInfo(profile->fileName()).absoluteDir();
+    const FilePath baseDir = FilePath::fromString(profile->fileName()).parentDir();
     const QString prefixPwd = "$$PWD/";
-    for (const QString &absoluteFilePath : notYetChanged)
-        valuesToFind << (prefixPwd + baseDir.relativeFilePath(absoluteFilePath));
+    for (const QString &absoluteFilePath : notYetChanged) {
+        auto tmp = FilePath::fromString(absoluteFilePath);
+        valuesToFind << (prefixPwd + tmp.relativePathFromDir(baseDir));
+    }
 
     const QStringList notChanged =
             Utils::transform(removeVarValues(profile, lines, valuesToFind, vars, removedLocations),
