@@ -39,6 +39,7 @@
 
 #include "session.h"
 
+#include "lspserver.h"
 #include "sessionpacket.h"
 #include "sessionpacketreader.h"
 
@@ -57,6 +58,7 @@
 #include <tools/qbsassert.h>
 #include <tools/settings.h>
 #include <tools/setupprojectparameters.h>
+#include <tools/stlutils.h>
 #include <tools/stringconstants.h>
 
 #include <QtCore/qcoreapplication.h>
@@ -66,10 +68,10 @@
 #include <QtCore/qobject.h>
 #include <QtCore/qprocess.h>
 
-#include <algorithm>
 #include <cstdlib>
 #include <iostream>
 #include <memory>
+#include <utility>
 
 #ifdef Q_OS_WIN32
 #include <cerrno>
@@ -82,6 +84,8 @@
 namespace qbs {
 namespace Internal {
 
+using FilePair = std::pair<QString, QString>;
+
 class SessionLogSink : public QObject, public ILogSink
 {
     Q_OBJECT
@@ -89,6 +93,12 @@ signals:
     void newMessage(const QJsonObject &msg);
 
 private:
+    static const QString &warningString()
+    {
+        static const QString warning(QLatin1String("warning"));
+        return warning;
+    }
+
     void doPrintMessage(LoggerLevel, const QString &message, const QString &) override
     {
         QJsonObject msg;
@@ -100,9 +110,18 @@ private:
     void doPrintWarning(const ErrorInfo &warning) override
     {
         QJsonObject msg;
-        static const QString warningString(QLatin1String("warning"));
-        msg.insert(StringConstants::type(), warningString);
-        msg.insert(warningString, warning.toJson());
+        msg.insert(StringConstants::type(), warningString());
+        msg.insert(warningString(), warning.toJson());
+        emit newMessage(msg);
+    }
+
+    void doPrintError(const ErrorInfo &error) override
+    {
+        QJsonObject msg;
+        msg.insert(StringConstants::type(), warningString());
+        static const QString errorString(QLatin1String("error"));
+        msg.insert(errorString, error.toJson());
+        msg.insert(warningString(), error.toJson()); // Backward compatibility
         emit newMessage(msg);
     }
 };
@@ -133,6 +152,8 @@ private:
     void installProject(const QJsonObject &request);
     void addFiles(const QJsonObject &request);
     void removeFiles(const QJsonObject &request);
+    void renameFiles(const QJsonObject &request);
+    void addDependencies(const QJsonObject &request);
     void getRunEnvironment(const QJsonObject &request);
     void getGeneratedFilesForSources(const QJsonObject &request);
     void releaseProject();
@@ -155,20 +176,25 @@ private:
     };
     ProductSelection getProductSelection(const QJsonObject &request);
 
-    struct FileUpdateData {
-        QJsonObject createErrorReply(const char *type, const QString &mainMessage) const;
+    template<typename ArgType>
+    struct FileUpdateData
+    {
+        QJsonObject createErrorReply(
+            const char *type, const QString &mainMessage, bool addFailedFiles) const;
 
         ProductData product;
         GroupData group;
-        QStringList filePaths;
+        QList<ArgType> arguments;
         ErrorInfo error;
     };
-    FileUpdateData prepareFileUpdate(const QJsonObject &request);
+    template<typename ArgType>
+    FileUpdateData<ArgType> prepareFileUpdate(const QJsonObject &request, const QString &paramKey);
 
     SessionPacketReader m_packetReader;
+    LspServer m_lspServer;
+    SessionLogSink m_logSink;
     Project m_project;
     ProjectData m_projectData;
-    SessionLogSink m_logSink;
     std::unique_ptr<Settings> m_settings;
     QJsonObject m_resolveRequest;
     QStringList m_moduleProperties;
@@ -193,7 +219,7 @@ Session::Session()
         qApp->exit(EXIT_FAILURE);
     }
 #endif
-    sendPacket(SessionPacket::helloMessage());
+    sendPacket(SessionPacket::helloMessage(m_lspServer.socketPath()));
     connect(&m_logSink, &SessionLogSink::newMessage, this, &Session::sendPacket);
     connect(&m_packetReader, &SessionPacketReader::errorOccurred,
             this, [](const QString &msg) {
@@ -215,6 +241,10 @@ Session::Session()
             addFiles(packet);
         else if (type == QLatin1String("remove-files"))
             removeFiles(packet);
+        else if (type == QLatin1String("rename-files"))
+            renameFiles(packet);
+        else if (type == QLatin1String("add-dependencies"))
+            addDependencies(packet);
         else if (type == QLatin1String("get-run-environment"))
             getRunEnvironment(packet);
         else if (type == QLatin1String("get-generated-files-for-sources"))
@@ -287,6 +317,7 @@ void Session::setupProject(const QJsonObject &request)
         const ProjectData oldProjectData = m_projectData;
         m_project = setupJob->project();
         m_projectData = m_project.projectData();
+        m_lspServer.updateProjectData(m_projectData, m_project.codeLinks());
         QJsonObject reply;
         reply.insert(StringConstants::type(), QLatin1String("project-resolved"));
         if (success)
@@ -391,16 +422,17 @@ void Session::installProject(const QJsonObject &request)
 
 void Session::addFiles(const QJsonObject &request)
 {
-    const FileUpdateData data = prepareFileUpdate(request);
+    const FileUpdateData data = prepareFileUpdate<QString>(request, QLatin1String("files"));
     if (data.error.hasError()) {
-        sendPacket(data.createErrorReply("files-added", tr("Failed to add files to project: %1")
-                                         .arg(data.error.toString())));
+        sendPacket(data.createErrorReply(
+            "files-added",
+            tr("Failed to add files to project: %1").arg(data.error.toString()),
+            true));
         return;
     }
     ErrorInfo error;
     QStringList failedFiles;
-#ifdef QBS_ENABLE_PROJECT_FILE_UPDATES
-    for (const QString &filePath : data.filePaths) {
+    for (const QString &filePath : data.arguments) {
         const ErrorInfo e = m_project.addFiles(data.product, data.group, {filePath});
         if (e.hasError()) {
             for (const ErrorItem &ei : e.items())
@@ -408,12 +440,11 @@ void Session::addFiles(const QJsonObject &request)
             failedFiles.push_back(filePath);
         }
     }
-#endif
     QJsonObject reply;
     reply.insert(StringConstants::type(), QLatin1String("files-added"));
     insertErrorInfoIfNecessary(reply, error);
 
-    if (failedFiles.size() != data.filePaths.size()) {
+    if (failedFiles.size() != data.arguments.size()) {
         // Note that Project::addFiles() directly changes the existing project data object, so
         // there's no need to retrieve it from m_project.
         insertProjectDataIfNecessary(reply, ProjectDataMode::Always, {}, false);
@@ -426,17 +457,17 @@ void Session::addFiles(const QJsonObject &request)
 
 void Session::removeFiles(const QJsonObject &request)
 {
-    const FileUpdateData data = prepareFileUpdate(request);
+    const FileUpdateData data = prepareFileUpdate<QString>(request, QLatin1String("files"));
     if (data.error.hasError()) {
-        sendPacket(data.createErrorReply("files-removed",
-                                         tr("Failed to remove files from project: %1")
-                                         .arg(data.error.toString())));
+        sendPacket(data.createErrorReply(
+            "files-removed",
+            tr("Failed to remove files from project: %1").arg(data.error.toString()),
+            true));
         return;
     }
     ErrorInfo error;
     QStringList failedFiles;
-#ifdef QBS_ENABLE_PROJECT_FILE_UPDATES
-    for (const QString &filePath : data.filePaths) {
+    for (const QString &filePath : data.arguments) {
         const ErrorInfo e = m_project.removeFiles(data.product, data.group, {filePath});
         if (e.hasError()) {
             for (const ErrorItem &ei : e.items())
@@ -444,17 +475,74 @@ void Session::removeFiles(const QJsonObject &request)
             failedFiles.push_back(filePath);
         }
     }
-#endif
     QJsonObject reply;
     reply.insert(StringConstants::type(), QLatin1String("files-removed"));
     insertErrorInfoIfNecessary(reply, error);
-    if (failedFiles.size() != data.filePaths.size())
+    if (failedFiles.size() != data.arguments.size())
         insertProjectDataIfNecessary(reply, ProjectDataMode::Always, {}, false);
     if (!failedFiles.isEmpty())
         reply.insert(QLatin1String("failed-files"), QJsonArray::fromStringList(failedFiles));
     sendPacket(reply);
 }
 
+void Session::renameFiles(const QJsonObject &request)
+{
+    const FileUpdateData data = prepareFileUpdate<FilePair>(request, QLatin1String("files"));
+    if (data.error.hasError()) {
+        sendPacket(data.createErrorReply(
+            "files-renamed",
+            tr("Failed to rename files in project: %1").arg(data.error.toString()),
+            true));
+        return;
+    }
+    ErrorInfo error;
+    QStringList failedFiles;
+    for (const FilePair &sourceAndTarget : data.arguments) {
+        const ErrorInfo removeError = m_project.removeFiles(
+            data.product, data.group, {sourceAndTarget.first});
+        if (removeError.hasError()) {
+            for (const ErrorItem &ei : removeError.items())
+                error.append(ei);
+            failedFiles.push_back(sourceAndTarget.first);
+        } else {
+            const ErrorInfo addError = m_project.addFiles(
+                data.product, data.group, {sourceAndTarget.second});
+            if (addError.hasError()) {
+                for (const ErrorItem &ei : addError.items())
+                    error.append(ei);
+                failedFiles.push_back(sourceAndTarget.first);
+            }
+        }
+    }
+    QJsonObject reply;
+    reply.insert(StringConstants::type(), QLatin1String("files-renamed"));
+    insertErrorInfoIfNecessary(reply, error);
+    if (failedFiles.size() != data.arguments.size())
+        insertProjectDataIfNecessary(reply, ProjectDataMode::Always, {}, false);
+    if (!failedFiles.isEmpty())
+        reply.insert(QLatin1String("failed-files"), QJsonArray::fromStringList(failedFiles));
+    sendPacket(reply);
+}
+
+void Session::addDependencies(const QJsonObject &request)
+{
+    const FileUpdateData data = prepareFileUpdate<QString>(request, QLatin1String("dependencies"));
+    if (data.error.hasError()) {
+        sendPacket(data.createErrorReply(
+            "dependencies-added",
+            tr("Failed to add dependencies to project: %1").arg(data.error.toString()),
+            false));
+        return;
+    }
+    ErrorInfo error;
+    const ErrorInfo e = m_project.addDependencies(data.product, data.group, data.arguments);
+    QJsonObject reply;
+    reply.insert(StringConstants::type(), QLatin1String("dependencies-added"));
+    insertErrorInfoIfNecessary(reply, error);
+    insertProjectDataIfNecessary(reply, ProjectDataMode::Always, {}, false);
+    sendPacket(reply);
+}
+
 void Session::connectProgressSignals(AbstractJob *job)
 {
     static QString maxProgressString(QLatin1String("max-progress"));
@@ -558,7 +646,7 @@ void Session::getGeneratedFilesForSources(const QJsonObject &request)
     reply.insert(StringConstants::type(), QLatin1String(replyType));
     const QJsonArray specs = request.value(StringConstants::productsKey()).toArray();
     QJsonArray resultProducts;
-    for (const QJsonValue &p : specs) {
+    for (const auto &p : specs) {
         const QJsonObject productObject = p.toObject();
         const ProductData product = getProductByName(
                     productObject.value(StringConstants::fullDisplayNameKey()).toString());
@@ -568,7 +656,7 @@ void Session::getGeneratedFilesForSources(const QJsonObject &request)
         resultProduct.insert(StringConstants::fullDisplayNameKey(), product.fullDisplayName());
         QJsonArray results;
         const QJsonArray requests = productObject.value(QLatin1String("requests")).toArray();
-        for (const QJsonValue &r : requests) {
+        for (const auto &r : requests) {
             const QJsonObject request = r.toObject();
             const QString filePath = request.value(QLatin1String("source-file")).toString();
             const QStringList tags = fromJson<QStringList>(request.value(QLatin1String("tags")));
@@ -625,15 +713,18 @@ Session::ProductSelection Session::getProductSelection(const QJsonObject &reques
 {
     const QJsonValue productSelection = request.value(StringConstants::productsKey());
     if (productSelection.isArray())
-        return ProductSelection(getProductsByName(fromJson<QStringList>(productSelection)));
-    return ProductSelection(productSelection.toString() == QLatin1String("all")
-                            ? Project::ProductSelectionWithNonDefault
-                            : Project::ProductSelectionDefaultOnly);
+        return {getProductsByName(fromJson<QStringList>(productSelection))};
+    return {
+        productSelection.toString() == QLatin1String("all")
+            ? Project::ProductSelectionWithNonDefault
+            : Project::ProductSelectionDefaultOnly};
 }
 
-Session::FileUpdateData Session::prepareFileUpdate(const QJsonObject &request)
+template<typename ArgType>
+Session::FileUpdateData<ArgType> Session::prepareFileUpdate(
+    const QJsonObject &request, const QString &paramKey)
 {
-    FileUpdateData data;
+    FileUpdateData<ArgType> data;
     const QString productName = request.value(QLatin1String("product")).toString();
     data.product = getProductByName(productName);
     if (data.product.isValid()) {
@@ -649,16 +740,20 @@ Session::FileUpdateData Session::prepareFileUpdate(const QJsonObject &request)
     } else {
         data.error = tr("Product '%1' not found in project.").arg(productName);
     }
-    const QJsonArray filesArray = request.value(QLatin1String("files")).toArray();
-    for (const QJsonValue &v : filesArray)
-        data.filePaths << v.toString();
+    const QJsonArray argsArray = request.value(paramKey).toArray();
+    for (const auto &v : argsArray)
+        if constexpr (std::is_same_v<ArgType, QString>) {
+            data.arguments << v.toString();
+        } else if constexpr (std::is_same_v<ArgType, FilePair>) {
+            const QJsonObject file = v.toObject();
+            data.arguments << std::make_pair(
+                file.value(QLatin1String("source-path")).toString(),
+                file.value(QLatin1String("target-path")).toString());
+        }
     if (m_currentJob)
-        data.error = tr("Cannot update the list of source files while a job is running.");
+        data.error = tr("Cannot update the project while a job is running.");
     if (!m_project.isValid())
         data.error = tr("No valid project. You need to resolve first.");
-#ifndef QBS_ENABLE_PROJECT_FILE_UPDATES
-    data.error = ErrorInfo(tr("Project file updates are not enabled in this build of qbs."));
-#endif
     return data;
 }
 
@@ -749,8 +844,9 @@ void Session::quitSession()
     }
 }
 
-QJsonObject Session::FileUpdateData::createErrorReply(const char *type,
-                                                      const QString &mainMessage) const
+template<typename ArgType>
+QJsonObject Session::FileUpdateData<ArgType>::createErrorReply(
+    const char *type, const QString &mainMessage, bool addFailedFiles) const
 {
     QBS_ASSERT(error.hasError(), return QJsonObject());
     ErrorInfo error(mainMessage);
@@ -759,7 +855,17 @@ QJsonObject Session::FileUpdateData::createErrorReply(const char *type,
     QJsonObject reply;
     reply.insert(StringConstants::type(), QLatin1String(type));
     reply.insert(QLatin1String("error"), error.toJson());
-    reply.insert(QLatin1String("failed-files"), QJsonArray::fromStringList(filePaths));
+    if (addFailedFiles) {
+        QStringList failedFiles;
+        if constexpr (std::is_same_v<ArgType, QString>) {
+            failedFiles = arguments;
+        } else if constexpr (std::is_same_v<ArgType, FilePair>) {
+            failedFiles = transformed<QStringList>(arguments, [](const FilePair &fp) {
+                return fp.first;
+            });
+        }
+        reply.insert(QLatin1String("failed-files"), QJsonArray::fromStringList(failedFiles));
+    }
     return reply;
 }
 
