@@ -385,6 +385,8 @@ public:
     static ResolvedModulePtr create() { return ResolvedModulePtr(new ResolvedModule); }
 
     QString name;
+    CodeLocation location;
+    QList<std::pair<QString, CodeLocation>> properties;
     QStringList moduleDependencies; // TODO: Still needed?
     PrivateScriptFunction setupBuildEnvironmentScript;
     PrivateScriptFunction setupRunEnvironmentScript;
@@ -396,8 +398,14 @@ public:
 
     template<PersistentPool::OpType opType> void completeSerializationOp(PersistentPool &pool)
     {
-        pool.serializationOp<opType>(name, moduleDependencies, setupBuildEnvironmentScript,
-                                     setupRunEnvironmentScript, isProduct);
+        pool.serializationOp<opType>(
+            name,
+            location,
+            properties,
+            moduleDependencies,
+            setupBuildEnvironmentScript,
+            setupRunEnvironmentScript,
+            isProduct);
     }
 
 private:
