@@ -229,9 +229,16 @@ void Logger::printWarning(const ErrorInfo &warning)
     logSink()->printWarning(warning);
 }
 
+void Logger::printError(const ErrorInfo &error)
+{
+    if (m_storeWarnings)
+        m_errors.push_back(error);
+    logSink()->printError(error);
+}
+
 LogWriter Logger::qbsLog(LoggerLevel level, bool force) const
 {
-    return LogWriter(m_logSink, level, force);
+    return {m_logSink, level, force};
 }
 
 } // namespace Internal
