@@ -286,14 +286,14 @@ void qbs::MakefileGenerator::generate()
                 }
                 if (!processCommandEncountered && builtByDefault) {
                     const auto outputs = transformerData.outputs();
-                    for (const ArtifactData &output : outputs)
-                        filesCreatedByJsCommands.push_back(output.filePath());
+                    transform(outputs, filesCreatedByJsCommands, [](const auto &output) {
+                        return output.filePath(); });
                 }
             }
             stream << "install-" << productTarget << ": " << productTarget << '\n';
             Set<QString> createdDirs;
             const auto installableArtifacts = productData.installableArtifacts();
-            for (const ArtifactData &artifact : productData.installableArtifacts()) {
+            for (const ArtifactData &artifact : installableArtifacts) {
                 const QString &outputDir = artifact.installData().localInstallDir();
                 if (outputDir.contains(QLatin1Char(' '))) {
                     logger().qbsWarning() << Tr::tr("Skipping installation of '%1', because "
@@ -332,15 +332,15 @@ void qbs::MakefileGenerator::generate()
         }
 
         stream << "all:";
-        for (const QString &target : qAsConst(allDefaultTargets))
+        for (const QString &target : std::as_const(allDefaultTargets))
             stream << ' ' << target;
         stream << '\n';
         stream << "install:";
-        for (const QString &target : qAsConst(allDefaultTargets))
+        for (const QString &target : std::as_const(allDefaultTargets))
             stream << ' ' << "install-" << target;
         stream << '\n';
         stream << "clean:";
-        for (const QString &target : qAsConst(allTargets))
+        for (const QString &target : std::as_const(allTargets))
             stream << ' ' << "clean-" << target;
         stream << '\n';
         if (!filesCreatedByJsCommands.empty()) {
