@@ -26,21 +26,14 @@
 **
 ****************************************************************************/
 
-#include <stdio.h>
+#include "../dllexport.h"
 
-#if defined(_WIN32) || defined(WIN32)
-#   define EXPORT __declspec(dllexport)
-#   define IMPORT __declspec(dllimport)
-#else
-#   define EXPORT
-#   define IMPORT
-#endif
+#include <cstdio>
 
-IMPORT int mylib_hello();
+DLL_IMPORT int mylib_hello();
 
 int main()
 {
-    puts("application says hello!");
+    std::puts("application says hello!");
     return mylib_hello();
 }
-
