@@ -131,9 +131,9 @@ void TestBlackboxAndroid::android()
         buildParams.buildDirectory = buildSubDir;
         buildParams.profile = p.name();
         QCOMPARE(runQbs(buildParams), 0);
-        for (const QString &productName : qAsConst(productNames)) {
+        for (const QString &productName : std::as_const(productNames)) {
             const QByteArray tag(QTest::currentDataTag());
-            QCOMPARE(m_qbsStdout.count("Generating BuildConfig.java"),
+            QCOMPARE(m_qbsStdout.count("generating BuildConfig.java"),
                      isIncrementalBuild ? 0 : productNames.size());
             const QString packageName = productName + (generateAab ? ".aab" : ".apk");
             QVERIFY(m_qbsStdout.contains(packageName.toLocal8Bit()));
@@ -174,8 +174,8 @@ void TestBlackboxAndroid::android()
                     return f.contains("qmltooling");
                 };
                 if (none_of(actualFiles, isFileSharedObject)
-                        || std::all_of(actualFiles.cbegin(), actualFiles.cend(), isQmlToolingLib)) {
-                    QWARN(msg);
+                        || qbs::Internal::all_of(actualFiles, isQmlToolingLib)) {
+                    qWarning() << msg;
                 } else {
                     QFAIL(msg);
                 }
@@ -221,7 +221,7 @@ void TestBlackboxAndroid::android_data()
         const bool usesClang = (forQt ? pQt : p).value(QStringLiteral("qbs.toolchainType"))
                 .toString() == "clang";
         const QByteArray path = "lib/${ARCH}/";
-        return path + (usesClang ? "libc++_shared.so" : oldcxxLib);
+        return path + (usesClang ? QByteArrayLiteral("libc++_shared.so") : oldcxxLib);
     };
     qbs::Version version(5, 13);
     QStringList qmakeFilePaths = pQt.value(QStringLiteral("moduleProviders.Qt.qmakeFilePaths")).
@@ -259,10 +259,10 @@ void TestBlackboxAndroid::android_data()
     auto expandArchs = [] (const QByteArrayList &archs, const QByteArrayList &lst, bool aabPackage) {
         const QByteArray &archPlaceHolder = "${ARCH}";
         QByteArrayList result;
-        QByteArray base( aabPackage ? "base/" : QByteArray());
+        QByteArray base( aabPackage ? "base/" : "");
         for (const QByteArray &entry : lst) {
             if (entry.contains(archPlaceHolder)) {
-                for (const QByteArray &arch : qAsConst(archs))
+                for (const QByteArray &arch : std::as_const(archs))
                     result << (base + QByteArray(entry).replace(archPlaceHolder, arch));
             } else {
                 result << (base + entry);
@@ -309,7 +309,6 @@ void TestBlackboxAndroid::android_data()
         return QString("modules.Android.sdk.dexCompilerName:") + (enableD8 ? "d8" : "dx");
     };
     bool enableD8 = true;
-
     auto qtAppExpectedFiles = [&](bool generateAab, bool enableAapt2, bool codeSign = true,
             QString keyAlias="androiddebugkey") {
         QByteArrayList expectedFile;
@@ -357,6 +356,11 @@ void TestBlackboxAndroid::android_data()
                        "lib/${ARCH}/libplugins_imageformats_qtiff_${ARCH}.so",
                        "lib/${ARCH}/libplugins_imageformats_qwbmp_${ARCH}.so",
                        "lib/${ARCH}/libplugins_imageformats_qwebp_${ARCH}.so"}, generateAab);
+        if (version >= qbs::Version(6, 5))
+            expectedFile << expandArchs(ndkArchsForQt, {
+                       "lib/${ARCH}/libQt6Svg_${ARCH}.so",
+                       "lib/${ARCH}/libplugins_iconengines_qsvgicon_${ARCH}.so",
+                       "lib/${ARCH}/libplugins_imageformats_qsvg_${ARCH}.so"}, generateAab);
         if (!enableAapt2 && version < qbs::Version(6, 0))
             expectedFile << "res/layout/splash.xml";
         return expectedFile;
@@ -613,9 +617,35 @@ void TestBlackboxAndroid::android_data()
                            "lib/${ARCH}/libplugins_imageformats_qtiff_${ARCH}.so",
                            "lib/${ARCH}/libplugins_imageformats_qwbmp_${ARCH}.so",
                            "lib/${ARCH}/libplugins_imageformats_qwebp_${ARCH}.so"}, generateAab);
+            if (version >= qbs::Version(6, 5))
+                expectedFile << expandArchs(ndkArchsForQt, {
+                           "lib/${ARCH}/libQt6Svg_${ARCH}.so",
+                           "lib/${ARCH}/libplugins_iconengines_qsvgicon_${ARCH}.so",
+                           "lib/${ARCH}/libplugins_imageformats_qsvg_${ARCH}.so"}, generateAab);
             if (version >= qbs::Version(6, 0)) {
                 expectedFile << expandArchs(ndkArchsForQt, {
                            "lib/${ARCH}/libQt6OpenGL_${ARCH}.so",
+                           "lib/${ARCH}/libqml_QtQml_Models_modelsplugin_${ARCH}.so",
+                           "lib/${ARCH}/libqml_QtQml_WorkerScript_workerscriptplugin_${ARCH}.so",
+                           "lib/${ARCH}/libqml_QtQuick_qtquick2plugin_${ARCH}.so"}, generateAab);
+                if (version >= qbs::Version(6, 5))
+                    expectedFile << expandArchs(ndkArchsForQt, {
+                                "lib/${ARCH}/libqml_QtQml_Base_qmlplugin_${ARCH}.so",
+                                "lib/${ARCH}/libqml_QtQml_qmlmetaplugin_${ARCH}.so"}, generateAab);
+                else
+                    expectedFile << expandArchs(ndkArchsForQt, {
+                                "lib/${ARCH}/libqml_QtQml_qmlplugin_${ARCH}.so"}, generateAab);
+            }
+            if (version >= qbs::Version(6, 2))
+                expectedFile << expandArchs(ndkArchsForQt, {
+                           "lib/${ARCH}/libplugins_networkinformation_qandroidnetworkinformation_${ARCH}.so",
+                           "lib/${ARCH}/libplugins_tls_qcertonlybackend_${ARCH}.so",
+                           "lib/${ARCH}/libplugins_tls_qopensslbackend_${ARCH}.so",
+                           "lib/${ARCH}/libqml_QtQuick_Window_quickwindowplugin_${ARCH}.so",
+                                            }, generateAab);
+
+            if (version >= qbs::Version(6, 0) && version < qbs::Version(6, 3)) {
+                expectedFile << expandArchs(ndkArchsForQt, {
                            "lib/${ARCH}/libQt6QuickControls2Impl_${ARCH}.so",
                            "lib/${ARCH}/libQt6QuickControls2_${ARCH}.so",
                            "lib/${ARCH}/libQt6QuickParticles_${ARCH}.so",
@@ -623,9 +653,6 @@ void TestBlackboxAndroid::android_data()
                            "lib/${ARCH}/libQt6QuickTemplates2_${ARCH}.so",
                            "lib/${ARCH}/libQt6Sql_${ARCH}.so",
                            "lib/${ARCH}/libplugins_sqldrivers_qsqlite_${ARCH}.so",
-                           "lib/${ARCH}/libqml_QtQml_Models_modelsplugin_${ARCH}.so",
-                           "lib/${ARCH}/libqml_QtQml_WorkerScript_workerscriptplugin_${ARCH}.so",
-                           "lib/${ARCH}/libqml_QtQml_qmlplugin_${ARCH}.so",
                            "lib/${ARCH}/libqml_QtQuick_Controls_Basic_impl_qtquickcontrols2basicstyleimplplugin_${ARCH}.so",
                            "lib/${ARCH}/libqml_QtQuick_Controls_Basic_qtquickcontrols2basicstyleplugin_${ARCH}.so",
                            "lib/${ARCH}/libqml_QtQuick_Controls_Fusion_impl_qtquickcontrols2fusionstyleimplplugin_${ARCH}.so",
@@ -644,11 +671,9 @@ void TestBlackboxAndroid::android_data()
                            "lib/${ARCH}/libqml_QtQuick_Shapes_qmlshapesplugin_${ARCH}.so",
                            "lib/${ARCH}/libqml_QtQuick_Templates_qtquicktemplates2plugin_${ARCH}.so",
                            "lib/${ARCH}/libqml_QtQuick_Timeline_qtquicktimelineplugin_${ARCH}.so",
-                           "lib/${ARCH}/libqml_QtQuick_Layouts_qquicklayoutsplugin_${ARCH}.so",
-                           "lib/${ARCH}/libqml_QtQuick_qtquick2plugin_${ARCH}.so"}, generateAab);
+                           "lib/${ARCH}/libqml_QtQuick_Layouts_qquicklayoutsplugin_${ARCH}.so"}, generateAab);
                 if (version >= qbs::Version(6, 2))
                     expectedFile << expandArchs(ndkArchsForQt, {
-                                "lib/${ARCH}/libqml_QtQuick_Window_quickwindowplugin_${ARCH}.so",
                                 "lib/${ARCH}/libqml_QtQuick_tooling_quicktoolingplugin_${ARCH}.so",
                                 "lib/${ARCH}/libQt6QmlLocalStorage_${ARCH}.so",
                                 "lib/${ARCH}/libQt6QmlXmlListModel_${ARCH}.so",
@@ -657,15 +682,12 @@ void TestBlackboxAndroid::android_data()
                                 "lib/${ARCH}/libQt6QuickDialogs2_${ARCH}.so",
                                 "lib/${ARCH}/libQt6QuickLayouts_${ARCH}.so",
                                 "lib/${ARCH}/libQt6QuickTimeline_${ARCH}.so",
-                                "lib/${ARCH}/libplugins_networkinformation_qandroidnetworkinformation_${ARCH}.so",
-                                "lib/${ARCH}/libplugins_tls_qcertonlybackend_${ARCH}.so",
-                                "lib/${ARCH}/libplugins_tls_qopensslbackend_${ARCH}.so",
                                 "lib/${ARCH}/libqml_QtQml_XmlListModel_qmlxmllistmodelplugin_${ARCH}.so",
                                 "lib/${ARCH}/libqml_QtQuick_Dialogs_qtquickdialogsplugin_${ARCH}.so",
                                 "lib/${ARCH}/libqml_QtQuick_Dialogs_quickimpl_qtquickdialogs2quickimplplugin_${ARCH}.so"},
                                             generateAab);
-                    else
-                        expectedFile << expandArchs(ndkArchsForQt, {
+                else
+                    expectedFile << expandArchs(ndkArchsForQt, {
                                 "lib/${ARCH}/libqml_QtQuick_Window_quickwindow_${ARCH}.so",
                                 "lib/${ARCH}/libqml_QtQuick_tooling_quicktooling_${ARCH}.so"}, generateAab);
             }
@@ -769,9 +791,34 @@ void TestBlackboxAndroid::android_data()
                            "lib/${ARCH}/libplugins_imageformats_qtiff_${ARCH}.so",
                            "lib/${ARCH}/libplugins_imageformats_qwbmp_${ARCH}.so",
                            "lib/${ARCH}/libplugins_imageformats_qwebp_${ARCH}.so"}, generateAab);
+            if (version >= qbs::Version(6, 5))
+                expectedFile << expandArchs(ndkArchsForQt, {
+                           "lib/${ARCH}/libQt6Svg_${ARCH}.so",
+                           "lib/${ARCH}/libplugins_iconengines_qsvgicon_${ARCH}.so",
+                           "lib/${ARCH}/libplugins_imageformats_qsvg_${ARCH}.so"}, generateAab);
             if (version >= qbs::Version(6, 0)) {
                 expectedFile << expandArchs(ndkArchsForQt, {
                            "lib/${ARCH}/libQt6OpenGL_${ARCH}.so",
+                           "lib/${ARCH}/libqml_QtQml_Models_modelsplugin_${ARCH}.so",
+                           "lib/${ARCH}/libqml_QtQml_WorkerScript_workerscriptplugin_${ARCH}.so",
+                           "lib/${ARCH}/libqml_QtQuick_qtquick2plugin_${ARCH}.so"}, generateAab);
+                if (version >= qbs::Version(6, 5))
+                    expectedFile << expandArchs(ndkArchsForQt, {
+                                "lib/${ARCH}/libqml_QtQml_Base_qmlplugin_${ARCH}.so",
+                                "lib/${ARCH}/libqml_QtQml_qmlmetaplugin_${ARCH}.so"}, generateAab);
+                else
+                    expectedFile << expandArchs(ndkArchsForQt, {
+                                "lib/${ARCH}/libqml_QtQml_qmlplugin_${ARCH}.so"}, generateAab);
+            }
+            if (version >= qbs::Version(6, 2))
+                expectedFile << expandArchs(ndkArchsForQt, {
+                           "lib/${ARCH}/libplugins_networkinformation_qandroidnetworkinformation_${ARCH}.so",
+                           "lib/${ARCH}/libplugins_tls_qcertonlybackend_${ARCH}.so",
+                           "lib/${ARCH}/libplugins_tls_qopensslbackend_${ARCH}.so",
+                           "lib/${ARCH}/libqml_QtQuick_Window_quickwindowplugin_${ARCH}.so",
+                                            }, generateAab);
+            if (version >= qbs::Version(6, 0) && version < qbs::Version(6, 3)) {
+                expectedFile << expandArchs(ndkArchsForQt, {
                            "lib/${ARCH}/libQt6QuickControls2Impl_${ARCH}.so",
                            "lib/${ARCH}/libQt6QuickControls2_${ARCH}.so",
                            "lib/${ARCH}/libQt6QuickParticles_${ARCH}.so",
@@ -779,9 +826,6 @@ void TestBlackboxAndroid::android_data()
                            "lib/${ARCH}/libQt6QuickTemplates2_${ARCH}.so",
                            "lib/${ARCH}/libQt6Sql_${ARCH}.so",
                            "lib/${ARCH}/libplugins_sqldrivers_qsqlite_${ARCH}.so",
-                           "lib/${ARCH}/libqml_QtQml_Models_modelsplugin_${ARCH}.so",
-                           "lib/${ARCH}/libqml_QtQml_WorkerScript_workerscriptplugin_${ARCH}.so",
-                           "lib/${ARCH}/libqml_QtQml_qmlplugin_${ARCH}.so",
                            "lib/${ARCH}/libqml_QtQuick_Controls_Basic_impl_qtquickcontrols2basicstyleimplplugin_${ARCH}.so",
                            "lib/${ARCH}/libqml_QtQuick_Controls_Basic_qtquickcontrols2basicstyleplugin_${ARCH}.so",
                            "lib/${ARCH}/libqml_QtQuick_Controls_Fusion_impl_qtquickcontrols2fusionstyleimplplugin_${ARCH}.so",
@@ -800,11 +844,9 @@ void TestBlackboxAndroid::android_data()
                            "lib/${ARCH}/libqml_QtQuick_Shapes_qmlshapesplugin_${ARCH}.so",
                            "lib/${ARCH}/libqml_QtQuick_Templates_qtquicktemplates2plugin_${ARCH}.so",
                            "lib/${ARCH}/libqml_QtQuick_Timeline_qtquicktimelineplugin_${ARCH}.so",
-                           "lib/${ARCH}/libqml_QtQuick_Layouts_qquicklayoutsplugin_${ARCH}.so",
-                           "lib/${ARCH}/libqml_QtQuick_qtquick2plugin_${ARCH}.so"}, generateAab);
+                           "lib/${ARCH}/libqml_QtQuick_Layouts_qquicklayoutsplugin_${ARCH}.so"}, generateAab);
                 if (version >= qbs::Version(6, 2))
                     expectedFile << expandArchs(ndkArchsForQt, {
-                                "lib/${ARCH}/libqml_QtQuick_Window_quickwindowplugin_${ARCH}.so",
                                 "lib/${ARCH}/libqml_QtQuick_tooling_quicktoolingplugin_${ARCH}.so",
                                 "lib/${ARCH}/libQt6QmlLocalStorage_${ARCH}.so",
                                 "lib/${ARCH}/libQt6QmlXmlListModel_${ARCH}.so",
@@ -813,9 +855,6 @@ void TestBlackboxAndroid::android_data()
                                 "lib/${ARCH}/libQt6QuickDialogs2_${ARCH}.so",
                                 "lib/${ARCH}/libQt6QuickLayouts_${ARCH}.so",
                                 "lib/${ARCH}/libQt6QuickTimeline_${ARCH}.so",
-                                "lib/${ARCH}/libplugins_networkinformation_qandroidnetworkinformation_${ARCH}.so",
-                                "lib/${ARCH}/libplugins_tls_qcertonlybackend_${ARCH}.so",
-                                "lib/${ARCH}/libplugins_tls_qopensslbackend_${ARCH}.so",
                                 "lib/${ARCH}/libqml_QtQml_XmlListModel_qmlxmllistmodelplugin_${ARCH}.so",
                                 "lib/${ARCH}/libqml_QtQuick_Dialogs_qtquickdialogsplugin_${ARCH}.so",
                                 "lib/${ARCH}/libqml_QtQuick_Dialogs_quickimpl_qtquickdialogs2quickimplplugin_${ARCH}.so"},
@@ -957,14 +996,14 @@ void TestBlackboxAndroid::android_data()
                                << QStringList{aaptVersion(enableAapt2), packageType(generateAab)}
                                << enableAapt2 << generateAab << isIncrementalBuild << enableD8;
     enableAapt2 = true;
-    QTest::newRow("aidl") << "aidl" << QStringList("io.qbs.aidltest")
+    QTest::newRow("aidl aapt2") << "aidl" << QStringList("io.qbs.aidltest")
                                << (QList<QByteArrayList>() << (QByteArrayList()
                                                                << commonFiles(generateAab)
                                                                << "resources.arsc"))
                                << QStringList{aaptVersion(enableAapt2), packageType(generateAab)}
                                << enableAapt2 << generateAab << isIncrementalBuild << enableD8;
     generateAab = true;
-    QTest::newRow("aidl") << "aidl" << QStringList("io.qbs.aidltest")
+    QTest::newRow("aidl aab") << "aidl" << QStringList("io.qbs.aidltest")
                                << (QList<QByteArrayList>() << (QByteArrayList()
                                                                << commonFiles(generateAab)
                                                                << "base/resources.pb"))
@@ -1021,6 +1060,7 @@ void TestBlackboxAndroid::android_data()
             << QStringList{aaptVersion(enableAapt2), packageType(generateAab),
                dexCompilerVersion(enableD8)}
             << enableAapt2 << generateAab << isIncrementalBuild << enableD8;
+
     enableAapt2 = false;
     generateAab = false;
     auto expectedFiles1 = [&](bool generateAab) {
@@ -1044,7 +1084,6 @@ void TestBlackboxAndroid::android_data()
                                          cxxLibPath("libstlport_shared.so", false)}, generateAab);
         return expectedFile;
     };
-
     QTest::newRow("multiple apks")
             << "multiple-apks-per-project"
             << (QStringList() << "twolibs1" << "twolibs2")
