@@ -99,7 +99,7 @@ void TestBlackboxQt::autoQrc()
 {
     QDir::setCurrent(testDataDir + "/auto-qrc");
     QCOMPARE(runQbs(QbsRunParameters("resolve")), 0);
-    if (m_qbsStdout.contains("targetPlatform differs from hostPlatform"))
+    if (m_qbsStdout.contains("target platform/arch differ from host platform/arch"))
         QSKIP("Cannot run binaries in cross-compiled build");
     QCOMPARE(runQbs(QbsRunParameters("run", QStringList{"-p", "app"})), 0);
     QVERIFY2(m_qbsStdout.simplified().contains("resource data: resource1 resource2"),
@@ -198,7 +198,7 @@ void TestBlackboxQt::forcedMoc()
     QCOMPARE(runQbs(QbsRunParameters("resolve")), 0);
     if (m_qbsStdout.contains("using qt4"))
         QSKIP("Qt version too old");
-    if (m_qbsStdout.contains("targetPlatform differs from hostPlatform"))
+    if (m_qbsStdout.contains("target platform/arch differ from host platform/arch"))
         QSKIP("Cannot run binaries in cross-compiled build");
     QCOMPARE(runQbs(QbsRunParameters("run")), 0);
     QVERIFY2(m_qbsStderr.contains("Hello from slot"), m_qbsStderr.constData());
@@ -249,7 +249,7 @@ void TestBlackboxQt::lrelease()
 {
     QDir::setCurrent(testDataDir + QLatin1String("/lrelease"));
     QCOMPARE(runQbs(), 0);
-    if (m_qbsStdout.contains("targetPlatform differs from hostPlatform"))
+    if (m_qbsStdout.contains("target platform/arch differ from host platform/arch"))
         QSKIP("Cannot run binaries in cross-compiled build");
 
     QVERIFY(regularFileExists(relativeProductBuildDir("lrelease-test") + "/de.qm"));
@@ -457,6 +457,25 @@ void TestBlackboxQt::mocAndCppCombining()
     QCOMPARE(runQbs(), 0);
 }
 
+void TestBlackboxQt::mocChangeTracking()
+{
+    QDir::setCurrent(testDataDir + "/moc-change-tracking");
+    QCOMPARE(runQbs(), 0);
+    QVERIFY2(m_qbsStdout.contains("compiling moc_class.cpp"), m_qbsStdout.constData());
+
+    WAIT_FOR_NEW_TIMESTAMP();
+    REPLACE_IN_FILE("moc-change-tracking.qbs", "// ", "");
+    QCOMPARE(runQbs(), 0);
+    QVERIFY2(
+        m_qbsStdout.contains("compiling amalgamated_moc-change-tracking.cpp"),
+        m_qbsStdout.constData());
+
+    WAIT_FOR_NEW_TIMESTAMP();
+    touch("moc-change-tracking.qbs");
+    QCOMPARE(runQbs(), 0);
+    QVERIFY2(!m_qbsStdout.contains("linking"), m_qbsStdout.constData());
+}
+
 void TestBlackboxQt::mocFlags()
 {
     QDir::setCurrent(testDataDir + "/moc-flags");
@@ -563,7 +582,7 @@ void TestBlackboxQt::pkgconfig()
 {
     QDir::setCurrent(testDataDir + "/pkgconfig");
     QCOMPARE(runQbs(QbsRunParameters("resolve")), 0);
-    if (m_qbsStdout.contains("targetPlatform differs from hostPlatform"))
+    if (m_qbsStdout.contains("target platform/arch differ from host platform/arch"))
         QSKIP("Cannot run binaries in cross-compiled build");
     QbsRunParameters params;
     params.command = "run";
@@ -638,7 +657,7 @@ void TestBlackboxQt::pluginMetaData()
     QCOMPARE(runQbs(QbsRunParameters("resolve")), 0);
     if (m_qbsStdout.contains("using qt4"))
         QSKIP("Qt version too old");
-    if (m_qbsStdout.contains("targetPlatform differs from hostPlatform"))
+    if (m_qbsStdout.contains("target platform/arch differ from host platform/arch"))
         QSKIP("Cannot run binaries in cross-compiled build");
 
     QVERIFY2(runQbs(QbsRunParameters("run", QStringList{"-p", "app"})) == 0,
@@ -709,7 +728,7 @@ void TestBlackboxQt::qdoc()
 {
     QDir::setCurrent(testDataDir + "/qdoc");
     QCOMPARE(runQbs(QbsRunParameters("resolve")), 0);
-    if (m_qbsStdout.contains("targetPlatform differs from hostPlatform"))
+    if (m_qbsStdout.contains("target platform/arch differ from host platform/arch"))
         QSKIP("Cannot run binaries in cross-compiled build");
     if (m_qbsStdout.contains("Qt is too old"))
         QSKIP("Skip test since qdoc3 does not work properly");
@@ -721,7 +740,7 @@ void TestBlackboxQt::qmlDebugging()
 {
     QDir::setCurrent(testDataDir + "/qml-debugging");
     QCOMPARE(runQbs(), 0);
-    if (m_qbsStdout.contains("targetPlatform differs from hostPlatform"))
+    if (m_qbsStdout.contains("target platform/arch differ from host platform/arch"))
         QSKIP("Cannot run binaries in cross-compiled build");
 
     const bool isGcc = m_qbsStdout.contains("is gcc: true");
@@ -835,7 +854,7 @@ void TestBlackboxQt::qtScxml()
 {
     QDir::setCurrent(testDataDir + "/qtscxml");
     QCOMPARE(runQbs(QbsRunParameters("resolve")), 0);
-    if (m_qbsStdout.contains("targetPlatform differs from hostPlatform"))
+    if (m_qbsStdout.contains("target platform/arch differ from host platform/arch"))
         QSKIP("Cannot run binaries in cross-compiled build");
     QCOMPARE(runQbs(), 0);
     if (m_qbsStdout.contains("QtScxml not present"))
@@ -849,6 +868,14 @@ void TestBlackboxQt::qtScxml()
     QVERIFY2(runQbs(params) != 0, m_qbsStdout.constData());
 }
 
+// see, https://bugreports.qt.io/projects/QBS/issues/QBS-1839
+// checks Qt.xml framework is linked correctly
+void TestBlackboxQt::qtXml()
+{
+    QDir::setCurrent(testDataDir + "/qt-xml");
+    QCOMPARE(runQbs(), 0);
+}
+
 void TestBlackboxQt::removeMocHeaderFromFileList()
 {
     QDir::setCurrent(testDataDir + "/remove-moc-header-from-file-list");
@@ -1008,7 +1035,7 @@ void TestBlackboxQt::track_qrc()
     QCOMPARE(runQbs(QbsRunParameters("resolve")), 0);
     if (m_qbsStdout.contains("using qt4"))
         QSKIP("Qt version too old");
-    if (m_qbsStdout.contains("targetPlatform differs from hostPlatform"))
+    if (m_qbsStdout.contains("target platform/arch differ from host platform/arch"))
         QSKIP("Cannot run binaries in cross-compiled build");
     const QString fileName = relativeExecutableFilePath("i", m_qbsStdout);
     QCOMPARE(runQbs(QbsRunParameters("run")), 0);
