@@ -33,12 +33,12 @@
 #include <QDebug>
 #include <QDir>
 #include <QFile>
-#include <QScopedPointer>
 #include <QTcpSocket>
 #include <QTimer>
 #include <QtEndian>
 
 #include <cstring>
+#include <memory>
 
 #ifdef Q_OS_LINUX
 #include <signal.h>
@@ -79,8 +79,8 @@ private:
 int main(int argc, char *argv[])
 {
     QCoreApplication app(argc, argv);
-    app.setApplicationName(QLatin1String("perfparser"));
-    app.setApplicationVersion(QLatin1String("7.0"));
+    app.setApplicationName(QStringLiteral("perfparser"));
+    app.setApplicationVersion(QStringLiteral("10.0"));
 
     if (qEnvironmentVariableIsSet("PERFPARSER_DEBUG_WAIT")) {
 #ifdef Q_OS_LINUX
@@ -93,130 +93,128 @@ int main(int argc, char *argv[])
     }
 
     QCommandLineParser parser;
-    parser.setApplicationDescription(QLatin1String("Perf data parser and unwinder."));
+    parser.setApplicationDescription(QStringLiteral("Perf data parser and unwinder."));
     parser.addHelpOption();
     parser.addVersionOption();
 
-    QCommandLineOption input(QLatin1String("input"),
-                             QCoreApplication::translate(
-                                 "main", "Read perf data from <file> instead of stdin."),
-                             QLatin1String("file"));
+    QCommandLineOption input(QStringLiteral("input"),
+                             QCoreApplication::translate("main", "Read perf data from <file> instead of stdin."),
+                             QStringLiteral("file"));
     parser.addOption(input);
 
-    QCommandLineOption host(QLatin1String("host"),
-                            QCoreApplication::translate(
-                                "main", "Read perf data from remote <host> instead of stdin."),
-                            QLatin1String("host"));
+    QCommandLineOption host(QStringLiteral("host"),
+                            QCoreApplication::translate("main", "Read perf data from remote <host> instead of stdin."),
+                            QStringLiteral("host"));
     parser.addOption(host);
 
-    QCommandLineOption port(QLatin1String("port"),
-                            QCoreApplication::translate(
-                              "main", "When reading from remote host, connect to <port> (default: "
-                                      "9327)."),
-                            QLatin1String("port"),
-                            QLatin1String("9327"));
+    QCommandLineOption port(QStringLiteral("port"),
+                            QCoreApplication::translate("main",
+                                                        "When reading from remote host, connect to <port> (default: "
+                                                        "9327)."),
+                            QStringLiteral("port"), QStringLiteral("9327"));
     parser.addOption(port);
 
-    QCommandLineOption output(QLatin1String("output"),
-                              QCoreApplication::translate(
-                                  "main", "Write b2qt data to <file> instead of stdout."),
-                              QLatin1String("file"));
+    QCommandLineOption output(QStringLiteral("output"),
+                              QCoreApplication::translate("main", "Write b2qt data to <file> instead of stdout."),
+                              QStringLiteral("file"));
     parser.addOption(output);
 
-    QCommandLineOption sysroot(QLatin1String("sysroot"),
-                               QCoreApplication::translate(
-                                   "main", "Look for system libraries in <path> (default: %1).")
-                               .arg(QDir::rootPath()),
-                               QLatin1String("path"),
-                               QDir::rootPath());
+    QCommandLineOption sysroot(
+        QStringLiteral("sysroot"),
+        QCoreApplication::translate("main", "Look for system libraries in <path> (default: %1).").arg(QDir::rootPath()),
+        QStringLiteral("path"), QDir::rootPath());
     parser.addOption(sysroot);
 
     const auto defaultDebug = PerfUnwind::defaultDebugInfoPath();
-    QCommandLineOption debug(QLatin1String("debug"),
-                             QCoreApplication::translate(
-                                 "main",
-                                 "Look for debug information in <path>. "
-                                 "You can specify multiple paths separated by ':'. "
-                                 "Relative paths are relative to the original file's path. "
-                                 "The default is: <sysroot>%1 .").arg(defaultDebug),
-                             QLatin1String("path"), defaultDebug);
+    QCommandLineOption debug(QStringLiteral("debug"),
+                             QCoreApplication::translate("main",
+                                                         "Look for debug information in <path>. "
+                                                         "You can specify multiple paths separated by ':'. "
+                                                         "Relative paths are relative to the original file's path. "
+                                                         "The default is: <sysroot>%1 .")
+                                 .arg(defaultDebug),
+                             QStringLiteral("path"), defaultDebug);
     parser.addOption(debug);
 
-    QCommandLineOption extra(QLatin1String("extra"),
-                             QCoreApplication::translate(
-                                 "main", "Look for additional libraries in <path> (default: .)."),
-                             QLatin1String("path"));
+    QCommandLineOption extra(
+        QStringLiteral("extra"),
+        QCoreApplication::translate("main", "Look for additional libraries in <path> (default: .)."),
+        QStringLiteral("path"));
     parser.addOption(extra);
 
-    QCommandLineOption appPath(QLatin1String("app"),
-                               QCoreApplication::translate(
-                                   "main", "Look for application binary in <path> (default: .)."),
-                               QLatin1String("path"));
+    QCommandLineOption appPath(
+        QStringLiteral("app"),
+        QCoreApplication::translate("main", "Look for application binary in <path> (default: .)."),
+        QStringLiteral("path"));
     parser.addOption(appPath);
 
-    const auto defaultArch = QLatin1String(PerfRegisterInfo::defaultArchitecture());
-    QCommandLineOption arch(QLatin1String("arch"),
-                            QCoreApplication::translate(
-                                "main",
-                                "Set the fallback architecture, in case the architecture is not "
-                                "given in the data itself, to <arch>. "
-                                "The default is: %1").arg(defaultArch),
-                            QLatin1String("arch"),
-                            defaultArch);
+    const auto defaultArch = PerfRegisterInfo::defaultArchitecture();
+    QCommandLineOption arch(
+        QStringLiteral("arch"),
+        QCoreApplication::translate("main",
+                                    "Set the fallback architecture, in case the architecture is not "
+                                    "given in the data itself, to <arch>. "
+                                    "The default is: %1")
+            .arg(defaultArch),
+        QStringLiteral("arch"), defaultArch);
     parser.addOption(arch);
 
     const auto defaultKallsyms = PerfUnwind::defaultKallsymsPath();
-    QCommandLineOption kallsymsPath(QLatin1String("kallsyms"),
-                                    QCoreApplication::translate(
-                                        "main", "Path to kallsyms mapping to resolve kernel "
-                                        "symbols. The default is: <sysroot>%1 .")
-                                    .arg(defaultKallsyms), QLatin1String("path"), defaultKallsyms);
+    QCommandLineOption kallsymsPath(QStringLiteral("kallsyms"),
+                                    QCoreApplication::translate("main",
+                                                                "Path to kallsyms mapping to resolve kernel "
+                                                                "symbols. The default is: <sysroot>%1 .")
+                                        .arg(defaultKallsyms),
+                                    QStringLiteral("path"), defaultKallsyms);
     parser.addOption(kallsymsPath);
 
-    QCommandLineOption printStats(QLatin1String("print-stats"),
-                               QCoreApplication::translate(
-                                   "main", "Print statistics instead of converting the data."));
+    QCommandLineOption printStats(
+        QStringLiteral("print-stats"),
+        QCoreApplication::translate("main", "Print statistics instead of converting the data."));
     parser.addOption(printStats);
 
-    QCommandLineOption bufferSize(QLatin1String("buffer-size"),
-                                  QCoreApplication::translate(
-                                   "main", "Initial size of event buffer in kilobytes. This"
-                                   " influences how many events get buffered before they get"
-                                   " sorted by time and then analyzed. Increase this value when"
-                                   " your perf.data file was recorded with a large buffer value"
-                                   " (perf record -m). Pass 0 to buffer events until a"
-                                   " FINISHED_ROUND event is encountered. perfparser will switch to"
-                                   " automatic buffering by FINISHED_ROUND events if either the"
-                                   " data indicates that the tace was recorded with a version of"
-                                   " perf >= 3.17, or a FINISHED_ROUND event is encountered and no"
-                                   " time order violations have occurred before. When encountering"
-                                   " a time order violation, perfparser will switch back to dynamic"
-                                   " buffering using buffer-size and max-buffer-size."
-                                   " The default value is 32MB."),
-                                   QLatin1String("buffer-size"), QString::number(1 << 15));
+    QCommandLineOption bufferSize(
+        QStringLiteral("buffer-size"),
+        QCoreApplication::translate("main",
+                                    "Initial size of event buffer in kilobytes. This"
+                                    " influences how many events get buffered before they get"
+                                    " sorted by time and then analyzed. Increase this value when"
+                                    " your perf.data file was recorded with a large buffer value"
+                                    " (perf record -m). Pass 0 to buffer events until a"
+                                    " FINISHED_ROUND event is encountered. perfparser will switch to"
+                                    " automatic buffering by FINISHED_ROUND events if either the"
+                                    " data indicates that the tace was recorded with a version of"
+                                    " perf >= 3.17, or a FINISHED_ROUND event is encountered and no"
+                                    " time order violations have occurred before. When encountering"
+                                    " a time order violation, perfparser will switch back to dynamic"
+                                    " buffering using buffer-size and max-buffer-size."
+                                    " The default value is 32MB."),
+        QStringLiteral("buffer-size"), QString::number(1 << 15));
     parser.addOption(bufferSize);
 
-    QCommandLineOption maxBufferSize(QLatin1String("max-buffer-size"),
-                                  QCoreApplication::translate(
-                                   "main", "Maximum size of event buffer in kilobytes. perfparser"
-                                   " increases the size of the event buffer when time order"
-                                   " violations are detected. It will never increase it beyond this"
-                                   " value, though. The default value is 1GB"),
-                                   QLatin1String("max-buffer-size"), QString::number(1 << 20));
+    QCommandLineOption maxBufferSize(
+        QStringLiteral("max-buffer-size"),
+        QCoreApplication::translate("main",
+                                    "Maximum size of event buffer in kilobytes. perfparser"
+                                    " increases the size of the event buffer when time order"
+                                    " violations are detected. It will never increase it beyond this"
+                                    " value, though. The default value is 1GB"),
+        QStringLiteral("max-buffer-size"), QString::number(1 << 20));
     parser.addOption(maxBufferSize);
 
-    QCommandLineOption maxFrames(QLatin1String("max-frames"),
-                                  QCoreApplication::translate(
-                                   "main", "Maximum number of frames that will be unwound."
-                                   " Set the value to -1 to unwind as many frames as possible."
-                                   " Beware that this can then potentially lead to infinite loops "
-                                   " when the stack got corrupted. Default value is 64."),
-                                   QLatin1String("max-frames"), QLatin1String("64"));
+    QCommandLineOption maxFrames(
+        QStringLiteral("max-frames"),
+        QCoreApplication::translate("main",
+                                    "Maximum number of frames that will be unwound."
+                                    " Set the value to -1 to unwind as many frames as possible."
+                                    " Beware that this can then potentially lead to infinite loops "
+                                    " when the stack got corrupted. Default value is 64."),
+        QStringLiteral("max-frames"), QStringLiteral("64"));
     parser.addOption(maxFrames);
 
     parser.process(app);
 
-    QScopedPointer<QFile> outfile;
+    std::unique_ptr<QFile> outfile;
     if (parser.isSet(output)) {
         outfile.reset(new QFile(parser.value(output)));
         if (!outfile->open(QIODevice::WriteOnly))
@@ -230,7 +228,7 @@ int main(int argc, char *argv[])
             return CannotOpen;
     }
 
-    QScopedPointer<QIODevice> infile;
+    std::unique_ptr<QIODevice> infile;
     if (parser.isSet(host)) {
         PerfTcpSocket *socket = new PerfTcpSocket(&app, parser.value(host),
                                                   parser.value(port).toUShort());
@@ -268,7 +266,7 @@ int main(int argc, char *argv[])
         return InvalidOption;
     }
 
-    PerfUnwind unwind(outfile.data(), parser.value(sysroot), parser.isSet(debug) ?
+    PerfUnwind unwind(outfile.get(), parser.value(sysroot), parser.isSet(debug) ?
                           parser.value(debug) : parser.value(sysroot) + parser.value(debug),
                       parser.value(extra), parser.value(appPath), parser.isSet(printStats));
 
@@ -282,7 +280,7 @@ int main(int argc, char *argv[])
     unwind.setMaxEventBufferSize(maxEventBufferSize);
     unwind.setMaxUnwindFrames(maxFramesValue);
 
-    PerfHeader header(infile.data());
+    PerfHeader header(infile.get());
     PerfAttributes attributes;
     PerfFeatures features;
     PerfData data(&unwind, &header, &attributes);
@@ -291,12 +289,12 @@ int main(int argc, char *argv[])
 
     auto readFileHeader = [&]() {
         const qint64 filePos = infile->pos();
-        if (!attributes.read(infile.data(), &header)) {
+        if (!attributes.read(infile.get(), &header)) {
             qWarning() << "Failed to read attributes";
             qApp->exit(DataError);
             return;
         }
-        if (!features.read(infile.data(), &header)) {
+        if (!features.read(infile.get(), &header)) {
             qWarning() << "Failed to read features";
             qApp->exit(DataError);
             return;
@@ -326,10 +324,10 @@ int main(int argc, char *argv[])
             return;
         }
 
-        data.setSource(infile.data());
-        QObject::connect(infile.data(), &QIODevice::aboutToClose, &data, &PerfData::finishReading);
-        QObject::connect(&data, &PerfData::finished, infile.data(), [&](){ infile->disconnect(); });
-        QObject::connect(infile.data(), &QIODevice::readyRead, &data, &PerfData::read);
+        data.setSource(infile.get());
+        QObject::connect(infile.get(), &QIODevice::aboutToClose, &data, &PerfData::finishReading);
+        QObject::connect(&data, &PerfData::finished, infile.get(), [&](){ infile->disconnect(); });
+        QObject::connect(infile.get(), &QIODevice::readyRead, &data, &PerfData::read);
         if (infile->bytesAvailable() > 0)
             data.read();
     };
@@ -345,7 +343,7 @@ int main(int argc, char *argv[])
         return true;
     };
 
-    QScopedPointer<QIODevice> tempfile;
+    std::unique_ptr<QIODevice> tempfile;
     auto bufferSequentialData = [&](){
         QByteArray buffer(1 << 25, Qt::Uninitialized);
         const qint64 read = infile->read(buffer.data(), buffer.length());
@@ -355,14 +353,14 @@ int main(int argc, char *argv[])
             return;
         }
 
-        if (!writeBytes(tempfile.data(), buffer.data(), read)) {
+        if (!writeBytes(tempfile.get(), buffer.data(), read)) {
             qWarning() << "Failed to write buffer file.";
             qApp->exit(BufferingError);
             return;
         }
     };
 
-    QObject::connect(&header, &PerfHeader::finished, [&]() {
+    QObject::connect(&header, &PerfHeader::finished, &app, [&]() {
         unwind.setByteOrder(static_cast<QSysInfo::Endian>(header.byteOrder()));
         if (!header.isPipe()) {
             if (infile->isSequential()) {
@@ -377,14 +375,14 @@ int main(int argc, char *argv[])
                 // We've checked this when parsing the header.
                 Q_ASSERT(header.size() <= std::numeric_limits<int>::max());
                 const QByteArray fakeHeader(static_cast<int>(header.size()), 0);
-                if (!writeBytes(tempfile.data(), fakeHeader.data(), fakeHeader.length())) {
+                if (!writeBytes(tempfile.get(), fakeHeader.data(), fakeHeader.length())) {
                     qWarning() << "Failed to write fake header to buffer file.";
                     qApp->exit(BufferingError);
                     return;
                 }
 
-                QObject::connect(infile.data(), &QIODevice::readyRead, bufferSequentialData);
-                QObject::connect(infile.data(), &QIODevice::aboutToClose, [&]() {
+                QObject::connect(infile.get(), &QIODevice::readyRead, bufferSequentialData);
+                QObject::connect(infile.get(), &QIODevice::aboutToClose, [&]() {
                     infile->disconnect();
                     infile.swap(tempfile);
                     if (!infile->reset()) {
@@ -420,12 +418,12 @@ int main(int argc, char *argv[])
     });
 
     if (parser.isSet(host)) {
-        PerfTcpSocket *socket = static_cast<PerfTcpSocket *>(infile.data());
+        PerfTcpSocket *socket = static_cast<PerfTcpSocket *>(infile.get());
         socket->tryConnect();
     } else {
         if (!infile->open(QIODevice::ReadOnly))
             return CannotOpen;
-        if (qobject_cast<QFile *>(infile.data())) // We don't get readyRead then ...
+        if (qobject_cast<QFile *>(infile.get())) // We don't get readyRead then ...
             QTimer::singleShot(0, &header, &PerfHeader::read);
     }
 
