@@ -1,8 +1,8 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
-#include <QtTest>
 #include <QDebug>
+#include <QTest>
 
 #include <cplusplus/ASTVisitor.h>
 #include <cplusplus/Control.h>
@@ -2082,7 +2082,7 @@ void tst_AST::placementNewWithEmptyConstructorArgs()
 
 void tst_AST::initTestCase()
 {
-    control.setDiagnosticClient(&diag);
+    control.setDiagnosticClient(&diag, true);
 }
 
 void tst_AST::cleanup()
