@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "../cplusplus_global.h"
 
@@ -31,8 +9,10 @@
 #include <cplusplus/TranslationUnit.h>
 #include <cplusplus/pp-engine.h>
 
-#include <QtTest>
+#include <utils/filepath.h>
+
 #include <QDebug>
+#include <QTest>
 
 #ifdef Q_OS_WIN
     #include <cctype>  // std:isspace
@@ -93,7 +73,7 @@ private:
         Document()
             : m_translationUnit(&m_control, m_control.stringLiteral("testFile"))
         {
-            m_control.setDiagnosticClient(&m_diagnosticClient);
+            m_control.setDiagnosticClient(&m_diagnosticClient, true);
         }
 
         TranslationUnit *translationUnit()
@@ -129,7 +109,7 @@ private:
             Diagnostic() : errorCount(0) {}
 
             void report(int /*level*/, const StringLiteral *fileName, int line,
-                        int column, const char *format, va_list ap)
+                        int column, const char *format, va_list ap) override
             {
                 ++errorCount;
                 qDebug() << fileName->chars() << ':' << line << ':' << column
