@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -24,7 +24,7 @@ public:
     MyPlugin3() = default;
     ~MyPlugin3() final;
 
-    bool initialize(const QStringList &arguments, QString *errorString) final;
+    Utils::Result<> initialize(const QStringList &arguments) final;
     void extensionsInitialized() final;
 
 private:
