@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include <tracing/flamegraph.h>
 #include <tracing/flamegraphattached.h>
@@ -7,8 +7,7 @@
 #include <QStandardItemModel>
 #include <QQmlComponent>
 #include <QQuickItem>
-#include <QtTest>
-#include <QQuickItem>
+#include <QTest>
 
 class DelegateObject : public QQuickItem
 {
@@ -84,7 +83,8 @@ void tst_FlameGraph::testRebuild()
     QCOMPARE(flameGraph.depth(), 3);
     qreal i = 0;
     qreal position = 0;
-    foreach (QQuickItem *child, flameGraph.childItems()) {
+    const QList<QQuickItem *> children = flameGraph.childItems();
+    for (QQuickItem *child : children) {
         FlameGraph::FlameGraphAttached *attached =
                 FlameGraph::FlameGraph::qmlAttachedProperties(child);
         QVERIFY(attached);
@@ -94,7 +94,8 @@ void tst_FlameGraph::testRebuild()
         QVERIFY(attached->isDataValid());
 
         qreal j = 0;
-        foreach (QQuickItem *grandchild, child->childItems()) {
+        const QList<QQuickItem *> grandchildren = child->childItems();
+        for (QQuickItem *grandchild : grandchildren) {
             FlameGraph::FlameGraphAttached *attached2 =
                     FlameGraph::FlameGraph::qmlAttachedProperties(grandchild);
             QVERIFY(attached2);
