@@ -4,7 +4,7 @@
 #include <utils/algorithm.h>
 #include <utils/async.h>
 
-#include <QtTest>
+#include <QTest>
 
 using namespace Utils;
 
@@ -206,38 +206,38 @@ void tst_Async::runAsync()
     const QString cs = QLatin1String("c string");
 
     QCOMPARE(createAsyncTask(reportString1, s)->results(),
-             QList<QString>({s}));
+             QStringList({s}));
     QCOMPARE(Utils::asyncRun(reportString1, s).results(),
-             QList<QString>({s}));
+             QStringList({s}));
     QCOMPARE(createAsyncTask(reportString1, crs)->results(),
-             QList<QString>({crs}));
+             QStringList({crs}));
     QCOMPARE(Utils::asyncRun(reportString1, crs).results(),
-             QList<QString>({crs}));
+             QStringList({crs}));
     QCOMPARE(createAsyncTask(reportString1, cs)->results(),
-             QList<QString>({cs}));
+             QStringList({cs}));
     QCOMPARE(Utils::asyncRun(reportString1, cs).results(),
-             QList<QString>({cs}));
+             QStringList({cs}));
     QCOMPARE(createAsyncTask(reportString1, QString(QLatin1String("rvalue")))->results(),
-             QList<QString>({QString(QLatin1String("rvalue"))}));
+             QStringList({QString(QLatin1String("rvalue"))}));
     QCOMPARE(Utils::asyncRun(reportString1, QString(QLatin1String("rvalue"))).results(),
-             QList<QString>({QString(QLatin1String("rvalue"))}));
+             QStringList({QString(QLatin1String("rvalue"))}));
 
     QCOMPARE(createAsyncTask(reportString2, s)->results(),
-             QList<QString>({s}));
+             QStringList({s}));
     QCOMPARE(Utils::asyncRun(reportString2, s).results(),
-             QList<QString>({s}));
+             QStringList({s}));
     QCOMPARE(createAsyncTask(reportString2, crs)->results(),
-             QList<QString>({crs}));
+             QStringList({crs}));
     QCOMPARE(Utils::asyncRun(reportString2, crs).results(),
-             QList<QString>({crs}));
+             QStringList({crs}));
     QCOMPARE(createAsyncTask(reportString2, cs)->results(),
-             QList<QString>({cs}));
+             QStringList({cs}));
     QCOMPARE(Utils::asyncRun(reportString2, cs).results(),
-             QList<QString>({cs}));
+             QStringList({cs}));
     QCOMPARE(createAsyncTask(reportString2, QString(QLatin1String("rvalue")))->results(),
-             QList<QString>({QString(QLatin1String("rvalue"))}));
+             QStringList({QString(QLatin1String("rvalue"))}));
     QCOMPARE(Utils::asyncRun(reportString2, QString(QLatin1String("rvalue"))).results(),
-             QList<QString>({QString(QLatin1String("rvalue"))}));
+             QStringList({QString(QLatin1String("rvalue"))}));
 
     // lambda
     QCOMPARE(createAsyncTask([](QPromise<double> &promise, int n) {
@@ -293,37 +293,37 @@ void tst_Async::runAsync()
     QCOMPARE(Utils::asyncRun(&MyObject::member1, &obj, 4).results(),
              QList<double>({0, 0, 0, 0}));
     QCOMPARE(createAsyncTask(&MyObject::memberString1, &obj, s)->results(),
-             QList<QString>({s}));
+             QStringList({s}));
     QCOMPARE(Utils::asyncRun(&MyObject::memberString1, &obj, s).results(),
-             QList<QString>({s}));
+             QStringList({s}));
     QCOMPARE(createAsyncTask(&MyObject::memberString1, &obj, crs)->results(),
-             QList<QString>({crs}));
+             QStringList({crs}));
     QCOMPARE(Utils::asyncRun(&MyObject::memberString1, &obj, crs).results(),
-             QList<QString>({crs}));
+             QStringList({crs}));
     QCOMPARE(createAsyncTask(&MyObject::memberString1, &obj, cs)->results(),
-             QList<QString>({cs}));
+             QStringList({cs}));
     QCOMPARE(Utils::asyncRun(&MyObject::memberString1, &obj, cs).results(),
-             QList<QString>({cs}));
+             QStringList({cs}));
     QCOMPARE(createAsyncTask(&MyObject::memberString1, &obj, QString(QLatin1String("rvalue")))->results(),
-             QList<QString>({QString(QLatin1String("rvalue"))}));
+             QStringList({QString(QLatin1String("rvalue"))}));
     QCOMPARE(Utils::asyncRun(&MyObject::memberString1, &obj, QString(QLatin1String("rvalue"))).results(),
-             QList<QString>({QString(QLatin1String("rvalue"))}));
+             QStringList({QString(QLatin1String("rvalue"))}));
     QCOMPARE(createAsyncTask(&MyObject::memberString2, &obj, s)->results(),
-             QList<QString>({s}));
+             QStringList({s}));
     QCOMPARE(Utils::asyncRun(&MyObject::memberString2, &obj, s).results(),
-             QList<QString>({s}));
+             QStringList({s}));
     QCOMPARE(createAsyncTask(&MyObject::memberString2, &obj, crs)->results(),
-             QList<QString>({crs}));
+             QStringList({crs}));
     QCOMPARE(Utils::asyncRun(&MyObject::memberString2, &obj, crs).results(),
-             QList<QString>({crs}));
+             QStringList({crs}));
     QCOMPARE(createAsyncTask(&MyObject::memberString2, &obj, cs)->results(),
-             QList<QString>({cs}));
+             QStringList({cs}));
     QCOMPARE(Utils::asyncRun(&MyObject::memberString2, &obj, cs).results(),
-             QList<QString>({cs}));
+             QStringList({cs}));
     QCOMPARE(createAsyncTask(&MyObject::memberString2, &obj, QString(QLatin1String("rvalue")))->results(),
-             QList<QString>({QString(QLatin1String("rvalue"))}));
+             QStringList({QString(QLatin1String("rvalue"))}));
     QCOMPARE(Utils::asyncRun(&MyObject::memberString2, &obj, QString(QLatin1String("rvalue"))).results(),
-             QList<QString>({QString(QLatin1String("rvalue"))}));
+             QStringList({QString(QLatin1String("rvalue"))}));
     MyObject nonConstObj{};
     QCOMPARE(createAsyncTask(&MyObject::nonConstMember, &nonConstObj)->results(),
              QList<double>({0, 2, 1}));
@@ -482,15 +482,14 @@ void tst_Async::taskTree()
         value = task.result();
     };
 
-    const Group root {
-        AsyncTask<int>(setupIntAsync, handleIntAsync, CallDoneIf::Success),
-        AsyncTask<int>(setupIntAsync, handleIntAsync, CallDoneIf::Success),
-        AsyncTask<int>(setupIntAsync, handleIntAsync, CallDoneIf::Success),
-        AsyncTask<int>(setupIntAsync, handleIntAsync, CallDoneIf::Success),
+    const Group recipe {
+        AsyncTask<int>(setupIntAsync, handleIntAsync, CallDone::OnSuccess),
+        AsyncTask<int>(setupIntAsync, handleIntAsync, CallDone::OnSuccess),
+        AsyncTask<int>(setupIntAsync, handleIntAsync, CallDone::OnSuccess),
+        AsyncTask<int>(setupIntAsync, handleIntAsync, CallDone::OnSuccess),
     };
 
-
-    QCOMPARE(TaskTree::runBlocking(root, 1000ms), DoneWith::Success);
+    QCOMPARE(TaskTree::runBlocking(recipe.withTimeout(1000ms)), DoneWith::Success);
     QCOMPARE(value, 16);
 }
 
@@ -511,7 +510,7 @@ void tst_Async::mapReduce_data()
 {
     using namespace Tasking;
 
-    QTest::addColumn<Group>("root");
+    QTest::addColumn<Group>("recipe");
     QTest::addColumn<double>("sum");
     QTest::addColumn<QList<double>>("results");
 
@@ -555,12 +554,12 @@ void tst_Async::mapReduce_data()
         return Group {
             executeMode,
             onGroupSetup(initTree),
-            AsyncTask<int>(std::bind(setupHandler, _1, 1), handleAsync, CallDoneIf::Success),
-            AsyncTask<int>(std::bind(setupHandler, _1, 2), handleAsync, CallDoneIf::Success),
-            AsyncTask<int>(std::bind(setupHandler, _1, 3), handleAsync, CallDoneIf::Success),
-            AsyncTask<int>(std::bind(setupHandler, _1, 4), handleAsync, CallDoneIf::Success),
-            AsyncTask<int>(std::bind(setupHandler, _1, 5), handleAsync, CallDoneIf::Success),
-            onGroupDone(doneHandler, CallDoneIf::Success)
+            AsyncTask<int>(std::bind(setupHandler, _1, 1), handleAsync, CallDone::OnSuccess),
+            AsyncTask<int>(std::bind(setupHandler, _1, 2), handleAsync, CallDone::OnSuccess),
+            AsyncTask<int>(std::bind(setupHandler, _1, 3), handleAsync, CallDone::OnSuccess),
+            AsyncTask<int>(std::bind(setupHandler, _1, 4), handleAsync, CallDone::OnSuccess),
+            AsyncTask<int>(std::bind(setupHandler, _1, 5), handleAsync, CallDone::OnSuccess),
+            onGroupDone(doneHandler, CallDone::OnSuccess)
         };
     };
 
@@ -591,9 +590,9 @@ void tst_Async::mapReduce_data()
     const Group simpleRoot = {
         sequential,
         onGroupSetup([] { s_sum = 0; }),
-        AsyncTask<int>(std::bind(setupSimpleAsync, _1, 1), handleSimpleAsync, CallDoneIf::Success),
-        AsyncTask<int>(std::bind(setupSimpleAsync, _1, 2), handleSimpleAsync, CallDoneIf::Success),
-        AsyncTask<int>(std::bind(setupSimpleAsync, _1, 3), handleSimpleAsync, CallDoneIf::Success)
+        AsyncTask<int>(std::bind(setupSimpleAsync, _1, 1), handleSimpleAsync, CallDone::OnSuccess),
+        AsyncTask<int>(std::bind(setupSimpleAsync, _1, 2), handleSimpleAsync, CallDone::OnSuccess),
+        AsyncTask<int>(std::bind(setupSimpleAsync, _1, 3), handleSimpleAsync, CallDone::OnSuccess)
     };
     QTest::newRow("Simple") << simpleRoot << 3.0 << QList<double>({.5, 1.5, 3.});
 
@@ -606,9 +605,9 @@ void tst_Async::mapReduce_data()
     const Group stringRoot = {
         parallel,
         onGroupSetup([] { s_sum = 90.0; }),
-        AsyncTask<int>(std::bind(setupStringAsync, _1, "blubb"), handleStringAsync, CallDoneIf::Success),
-        AsyncTask<int>(std::bind(setupStringAsync, _1, "foo"), handleStringAsync, CallDoneIf::Success),
-        AsyncTask<int>(std::bind(setupStringAsync, _1, "blah"), handleStringAsync, CallDoneIf::Success)
+        AsyncTask<int>(std::bind(setupStringAsync, _1, "blubb"), handleStringAsync, CallDone::OnSuccess),
+        AsyncTask<int>(std::bind(setupStringAsync, _1, "foo"), handleStringAsync, CallDone::OnSuccess),
+        AsyncTask<int>(std::bind(setupStringAsync, _1, "blah"), handleStringAsync, CallDone::OnSuccess)
     };
     QTest::newRow("String") << stringRoot << 1.5 << QList<double>({});
 }
@@ -622,11 +621,11 @@ void tst_Async::mapReduce()
 
     using namespace Tasking;
 
-    QFETCH(Group, root);
+    QFETCH(Group, recipe);
     QFETCH(double, sum);
     QFETCH(QList<double>, results);
 
-    QCOMPARE(TaskTree::runBlocking(root, 1000ms), DoneWith::Success);
+    QCOMPARE(TaskTree::runBlocking(recipe.withTimeout(1000ms)), DoneWith::Success);
     QCOMPARE(s_results, results);
     QCOMPARE(s_sum, sum);
 }
