@@ -4,7 +4,9 @@
 #include <utils/filepath.h>
 #include <utils/stringutils.h>
 
-#include <QtTest>
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QTest>
 
 //TESTED_COMPONENT=src/libs/utils
 
@@ -30,8 +32,214 @@ private slots:
     void testSplitAtFirst();
     void testAsciify_data();
     void testAsciify();
+    void testNormalizeNewlinesInString();
+    void testNormalizeNewlinesInByteArray();
+    void testRemoveCommentsFromJson();
+    void testRemoveCommentsFromJson_data();
+    void testRemoveExtraCommasFromJson();
+    void testRemoveExtraCommasFromJson_data();
+    void testCleanJson();
+    void testCleanJson_data();
+    void testApplyJsonPatch();
 };
 
+void tst_StringUtils::testCleanJson_data()
+{
+    QTest::addColumn<QByteArray>("input");
+    QTest::addColumn<QByteArray>("expected");
+
+    QTest::newRow("simple object with trailing comma")
+        << QByteArray(R"({"key1": "value1", "key2": "value2",})")
+        << QByteArray(R"({"key1": "value1", "key2": "value2"})");
+
+    QTest::newRow("simple with comment")
+        << QByteArray(R"({"key1": "value1", "key2": "value2"} // comment)")
+        << QByteArray(R"({"key1": "value1", "key2": "value2"} )");
+
+    QTest::newRow("comma in comment")
+        << QByteArray(R"({"key1": "value1", "key2": "value2"} // comment,)")
+        << QByteArray(R"({"key1": "value1", "key2": "value2"} )");
+
+    QTest::newRow("comma after comment")
+        << QByteArray(R"({"key1": "value1", "key2": "value2" /* comment*/,})")
+        << QByteArray(R"({"key1": "value1", "key2": "value2" })");
+
+    QTest::newRow("comma before comment")
+        << QByteArray(R"({"key1": "value1", "key2": "value2", /* comment*/})")
+        << QByteArray(R"({"key1": "value1", "key2": "value2" })");
+
+    QTest::newRow("escaped comma in string")
+        << QByteArray(R"({"key1": "value1", "key2": "value2\,"})")
+        << QByteArray(R"({"key1": "value1", "key2": "value2\,"})");
+    QTest::newRow("escaped quote in string")
+        << QByteArray(R"({"key1": "val\"ue1", "key2": "\,value2\"",})")
+        << QByteArray(R"({"key1": "val\"ue1", "key2": "\,value2\""})");
+}
+
+void tst_StringUtils::testCleanJson()
+{
+    QFETCH(QByteArray, input);
+    QFETCH(QByteArray, expected);
+
+    QByteArray result = cleanJson(input);
+    QCOMPARE(result, expected);
+}
+
+void tst_StringUtils::testApplyJsonPatch()
+{
+    QString targetJson = R"json({"v1":1,"v2":{"v21":1,"v22":2},"v3":{},"v4":[1,2],"v5":{}})json";
+    QString patchJson
+        = R"json({"v1":2,"v2":{"v21":2},"v4":[1,2,3],"v5":{},"v6":{"v61":[1,2],"v62":"1"}})json";
+    QString expectedJson
+        = R"json({"v1":2,"v2":{"v21":2,"v22":2},"v3":{},"v4":[1,2,1,2,3],"v5":{},"v6":{"v61":[1,2],"v62":"1"}})json";
+
+    QJsonDocument targetDoc = QJsonDocument::fromJson(targetJson.toUtf8());
+    QJsonDocument patchDoc = QJsonDocument::fromJson(patchJson.toUtf8());
+    QJsonValue target = targetDoc.object();
+    QJsonValue patch = patchDoc.object();
+
+    applyJsonPatch(target, patch);
+
+    QJsonDocument resultDoc = QJsonDocument(target.toObject());
+    QCOMPARE(resultDoc.toJson(QJsonDocument::Compact), expectedJson.toUtf8());
+
+    // Empty value should not change target ...
+    target = targetDoc.object();
+    applyJsonPatch(target, QJsonValue());
+    resultDoc = QJsonDocument(target.toObject());
+    QCOMPARE(resultDoc.toJson(QJsonDocument::Compact), targetJson.toUtf8());
+}
+
+void tst_StringUtils::testRemoveExtraCommasFromJson_data()
+{
+    QTest::addColumn<QByteArray>("input");
+    QTest::addColumn<QByteArray>("expected");
+
+    QTest::newRow("object with trailing comma")
+        << QByteArray(R"({"a": 1, "b": 2,})") << QByteArray(R"({"a": 1, "b": 2})");
+
+    QTest::newRow("array with trailing comma")
+        << QByteArray(R"([1, 2, 3,])") << QByteArray(R"([1, 2, 3])");
+
+    QTest::newRow("array with many trailing comma")
+        << QByteArray(R"([1, 2, 3,,,,])") << QByteArray(R"([1, 2, 3,,,])");
+
+    QTest::newRow("nested structures") << QByteArray(R"({"a": [1,2,3,], "b": {"x": 5,},})")
+                                       << QByteArray(R"({"a": [1,2,3], "b": {"x": 5}})");
+
+    QTest::newRow("empty array and object")
+        << QByteArray(R"({"emptyArray": [], "emptyObject": {},})")
+        << QByteArray(R"({"emptyArray": [], "emptyObject": {}})");
+
+    QTest::newRow("already valid JSON") << QByteArray(R"({"valid": [1,2], "obj": {"a": 1}})")
+                                        << QByteArray(R"({"valid": [1,2], "obj": {"a": 1}})");
+
+    QTest::newRow("commas in strings")
+        << QByteArray(R"({"text": "hello, world,", "another": "brace } test",})")
+        << QByteArray(R"({"text": "hello, world,", "another": "brace } test"})");
+
+    QTest::newRow("whitespace before closing") << QByteArray("{\n  \"a\": 1, \n  \"b\": 2,\n}")
+                                               << QByteArray("{\n  \"a\": 1, \n  \"b\": 2\n}");
+
+    QTest::newRow("whitespace before comma")
+        << QByteArray(R"({"a": 1, "b": 2   ,  })") << QByteArray(R"({"a": 1, "b": 2     })");
+}
+
+void tst_StringUtils::testRemoveExtraCommasFromJson()
+{
+    QFETCH(QByteArray, input);
+    QFETCH(QByteArray, expected);
+
+    QByteArray result = removeExtraCommasFromJson(input);
+    QCOMPARE(result, expected);
+}
+
+void tst_StringUtils::testRemoveCommentsFromJson_data()
+{
+    QTest::addColumn<QByteArray>("json");
+    QTest::addColumn<QByteArray>("expected");
+
+    QTest::newRow("single-line comments") << QByteArray(R"(
+        {
+            "key1": "value1", // comment
+            "key2": "value2",
+            "key3": "value3" // another comment
+        }
+    )") << QByteArray(R"(
+        {
+            "key1": "value1", 
+            "key2": "value2",
+            "key3": "value3" 
+        }
+    )");
+
+    QTest::newRow("multi-line comments") << QByteArray(R"(
+        {
+            "key1": "value1", /* comment */
+            "key2": "value2",
+            "key3": "value3" /* another comment */
+        }
+    )") << QByteArray(R"(
+        {
+            "key1": "value1", 
+            "key2": "value2",
+            "key3": "value3" 
+        }
+    )");
+
+    QTest::newRow("comment in string value") << QByteArray(R"(
+        {
+            "key1": "value1", // comment
+            "key2": "value2",
+            "key3": "value3 // another comment"
+        }
+    )") << QByteArray(R"(
+        {
+            "key1": "value1", 
+            "key2": "value2",
+            "key3": "value3 // another comment"
+        }
+    )");
+
+    QTest::newRow("comment after string value") << QByteArray(R"(
+        {
+            "key1": "value1", // comment
+            "key2": "value2",
+            "key3": "value3 // another comment" /* comment */
+        }
+    )") << QByteArray(R"(
+        {
+            "key1": "value1", 
+            "key2": "value2",
+            "key3": "value3 // another comment" 
+        }
+    )");
+
+    QTest::newRow("multi-line block comment") << QByteArray(R"(
+        {
+            "key1": "value1", /* comment
+            */
+            "key2": "value2",
+            "key3": "value3" /* another comment
+            and another line */
+        }
+    )") << QByteArray(R"(
+        {
+            "key1": "value1", 
+            "key2": "value2",
+            "key3": "value3" 
+        }
+    )");
+}
+
+void tst_StringUtils::testRemoveCommentsFromJson()
+{
+    QFETCH(QByteArray, json);
+    QFETCH(QByteArray, expected);
+
+    QCOMPARE(Utils::removeCommentsFromJson(json), expected);
+}
+
 void tst_StringUtils::testWithTildeHomePath()
 {
     const QString home = QDir::homePath();
@@ -355,6 +563,27 @@ void tst_StringUtils::testAsciify()
     QCOMPARE(asciified, expected);
 }
 
+void tst_StringUtils::testNormalizeNewlinesInString()
+{
+    const QString input = "asd\r\r\nfoo\r\nbar\nfoo\r";
+    const QString expected = "asd\nfoo\nbar\nfoo\r";
+
+    const QString normalized = Utils::normalizeNewlines(input);
+
+    QCOMPARE(normalized, expected);
+}
+
+void tst_StringUtils::testNormalizeNewlinesInByteArray()
+{
+    const QByteArray input = "asd\r\r\nfoo\r\nbar\nfoo\r";
+    const QByteArray expected = "asd\nfoo\nbar\nfoo\r";
+
+    const QByteArray normalized = Utils::normalizeNewlines(input);
+
+    QCOMPARE(normalized, expected);
+}
+
+
 QTEST_GUILESS_MAIN(tst_StringUtils)
 
 #include "tst_stringutils.moc"
