@@ -1,5 +1,5 @@
 // Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "plugin2.h"
 
@@ -13,15 +13,12 @@ MyPlugin2::~MyPlugin2()
     ExtensionSystem::PluginManager::removeObject(object2);
 }
 
-bool MyPlugin2::initialize(const QStringList & /*arguments*/, QString *errorString)
+void MyPlugin2::initialize()
 {
-    Q_UNUSED(errorString)
     initializeCalled = true;
     object1 = new QObject(this);
     object1->setObjectName("MyPlugin2");
     ExtensionSystem::PluginManager::addObject(object1);
-
-    return true;
 }
 
 void MyPlugin2::extensionsInitialized()
