@@ -37,7 +37,7 @@ public:
     AssetDownloaderPrivate(AssetDownloader *q) : m_q(q) {}
 
     AssetDownloader *m_q = nullptr;
-    TaskTreeRunner m_taskTreeRunner;
+    SingleTaskTreeRunner m_taskTreeRunner;
     QString m_lastProgressText;
 
     QNetworkAccessManager *m_manager = nullptr;
@@ -497,11 +497,11 @@ void AssetDownloader::start()
         d->updateProgress(storageData.doneCount, storageData.assets.allAssets.size());
     };
 
-    const Group root {
+    const Group recipe {
         storage,
         onGroupSetup(onSetup),
         NetworkQueryTask(onJsonDownloadSetup, onJsonDownloadDone),
-        ConcurrentCallTask<DownloadableAssets>(onReadAssetsFileSetup, onReadAssetsFileDone, CallDoneIf::Success),
+        ConcurrentCallTask<DownloadableAssets>(onReadAssetsFileSetup, onReadAssetsFileDone, CallDone::OnSuccess),
         Group {
             onGroupSetup(onSkipIfAllAssetsPresent),
             NetworkQueryTask(onZipDownloadSetup, onZipDownloadDone),
@@ -522,6 +522,6 @@ void AssetDownloader::start()
             }
         }
     };
-    d->m_taskTreeRunner.start(root,[this](TaskTree *) { emit started(); },
+    d->m_taskTreeRunner.start(recipe, [this] { emit started(); },
             [this](DoneWith result) { emit finished(result == DoneWith::Success); });
 }
